/**
 * @license
 * Copyright 2019 The Emscripten Authors
 * SPDX-License-Identifier: MIT
 */

// wasm2js.js - enough of a polyfill for the WebAssembly object so that we can load
// wasm2js code that way.

// Emit "var WebAssembly" if definitely using wasm2js. Otherwise, in MAYBE_WASM2JS
// mode, we can't use a "var" since it would prevent normal wasm from working.
/** @suppress{duplicate, const} */
var
WebAssembly = {
  // Note that we do not use closure quoting (this['buffer'], etc.) on these
  // functions, as they are just meant for internal use. In other words, this is
  // not a fully general polyfill.
  /** @constructor */
  Memory: function(opts) {
    this.buffer = new ArrayBuffer(opts['initial'] * 65536);
  },

  Module: function(binary) {
    // TODO: use the binary and info somehow - right now the wasm2js output is embedded in
    // the main JS
  },

  /** @constructor */
  Instance: function(module, info) {
    // TODO: use the module somehow - right now the wasm2js output is embedded in
    // the main JS
    // This will be replaced by the actual wasm2js code.
    this.exports = (
// EMSCRIPTEN_START_ASM
function instantiate(vb){function c(d){d.set=function(a,b){this[a]=b};d.get=function(a){return this[a]};return d}var e;var f=new ArrayBuffer(16);var g=new Int32Array(f);var h=new Float32Array(f);var i=new Float64Array(f);function j(k){return g[k]}function l(k,m){g[k]=m}function n(){return i[0]}function o(m){i[0]=m}function p(){throw new Error("abort")}function q(m){h[2]=m}function r(){return h[2]}function tb(ub){var s=ub.a;var t=s.a;var u=t.buffer;t.grow=rb;var v=new Int8Array(u);var w=new Int16Array(u);var x=new Int32Array(u);var y=new Uint8Array(u);var z=new Uint16Array(u);var A=new Uint32Array(u);var B=new Float32Array(u);var C=new Float64Array(u);var D=Math.imul;var E=Math.fround;var F=Math.abs;var G=Math.clz32;var H=Math.min;var I=Math.max;var J=Math.floor;var K=Math.ceil;var L=Math.trunc;var M=Math.sqrt;var N=NaN;var O=Infinity;var P=s.b;var Q=s.c;var R=s.d;var S=s.e;var T=s.f;var U=s.g;var V=s.h;var W=s.i;var X=s.j;var Y=s.k;var Z=s.l;var _=s.m;var $=s.n;var aa=s.o;var ba=s.p;var ca=s.q;var da=s.r;var ea=s.s;var fa=s.t;var ga=s.u;var ha=s.v;var ia=s.w;var ja=s.x;var ka=s.y;var la=s.z;var ma=s.A;var na=s.B;var oa=s.C;var pa=s.D;var qa=s.E;var ra=s.F;var sa=s.G;var ta=s.H;var ua=s.I;var va=s.J;var wa=s.K;var xa=s.L;var ya=s.M;var za=s.N;var Aa=s.O;var Ba=s.P;var Ca=s.Q;var Da=s.R;var Ea=s.S;var Fa=s.T;var Ga=s.U;var Ha=s.V;var Ia=s.W;var Ja=s.X;var Ka=s.Y;var La=s.Z;var Ma=s._;var Na=s.$;var Oa=s.aa;var Pa=s.ba;var Qa=s.ca;var Ra=s.da;var Sa=s.ea;var Ta=s.fa;var Ua=s.ga;var Va=s.ha;var Wa=s.ia;var Xa=s.ja;var Ya=s.ka;var Za=s.la;var _a=s.ma;var $a=s.na;var ab=s.oa;var bb=s.pa;var cb=s.qa;var db=s.ra;var eb=s.sa;var fb=s.ta;var gb=s.ua;var hb=s.va;var ib=5728256;var jb=0;var kb=0;
// EMSCRIPTEN_START_FUNCS
function HJ(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,C=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,Q=0,R=0,T=0,V=0,W=E(0),X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=E(0),Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=E(0),_a=0;ca=ib-32|0;ib=ca;fa=ca+24|0;x[fa>>2]=50468;x[fa>>2]=50368;e=GJ(ca+16|0);h=GJ(ca+8|0);ga=b;ma=c;na=x[e>>2];Ea=y[e+4|0];oa=x[h>>2];Fa=y[h+4|0];c=0;M=ib-112|0;ib=M;d=a;pa=a+24604|0;a=pa;a:{if(!x[a+16>>2]){break a}b=x[a+20>>2];if(b>>>0>4|!(1<<b&22)){break a}a=x[a+28>>2];if(a>>>0>4){break a}c=23>>>a&1}if(!c){a=M+96|0;VO(a,9081,12966,220,45);b=ib-48|0;ib=b;c=xc(b+16|0,17730);x[27524]=0;U(5,b|0,1,17393);e=x[27524];x[27524]=0;b:{c:{d:{e:{if((e|0)!=1){x[27524]=0;U(2,b+32|0,c|0,b|0);e=x[27524];x[27524]=0;if((e|0)==1){break e}x[27524]=0;ea(849,b|0,a|0,1,b|0,b+32|0);a=x[27524];x[27524]=0;if((a|0)!=1){break b}a=P()|0;xb(b+32|0);break d}a=P()|0;break c}a=P()|0}xb(b)}xb(c);S(a|0);p()}xb(b+32|0);xb(b);xb(c);ib=b+48|0}qa=d+8204|0;ra=d+397452|0;sa=d+397448|0;$=d+393352|0;I=d+397456|0;Z=d+12|0;Ga=d+1074376|0;Ha=d+1298424|0;Ia=d+1074365|0;while(1){f:{g:{a=x[d+480208>>2];if(!(!ga|a&512)){h:{if(x[d+1074380>>2]){break h}b=a|512;i:{if(a&256){break i}s=0;i=ib-48|0;ib=i;u=ib-32|0;ib=u;o=d+1074312|0;e=d+1074992|0;k=d+1298264|0;n=d+1074424|0;t=d+484360|0;l=d+1074448|0;r=d+1074376|0;b=x[d+1074392>>2];C=d+480188|0;J=d+480180|0;j=d+484376|0;m=d+484348|0;H=d+480210|0;G=d+484364|0;j:{k:{l:while(1){m:{a=b+1|0;x[d+1074392>>2]=a;if(nl(r)>>>0>a>>>0){break m}rQ(u+24|0,x[J>>2],z[C>>1],r,(x[d+480208>>2]&524288)>>>19|0);n:{o:{p:{q:{r:{if(y[d+480208|0]&32){f=x[m>>2];q=x[d+484344>>2];b=z[d+1074446>>1];break r}b=65535;c=x[d+484360>>2];h=y[j|0];a=Tb(c,h);f=x[a>>2];g=Oc(f,x[a+4>>2]);a=z[d+1074448>>1];if(g>>>0>a>>>0){b=z[bc(f,a)>>1]}w[d+1074446>>1]=b;s:{t:{q=x[d+484344>>2];f=x[m>>2];g=b&65535;if(Jf(q,f)>>>0<=g>>>0){break t}g=Xb(q,g);if(Mb(x[g>>2],x[g+4>>2])){break t}g=0;break s}g=1}while(1){u:{v:{w:{if(!g){b=65534;w[d+1074446>>1]=65534;break w}g=b&65535;if(Jf(q,f)>>>0>g>>>0){break v}x:{y:{z:{if((g|0)==65535){f=Tb(c,h);break z}f=Tb(c,h);if(Oc(x[f>>2],x[f+4>>2])>>>0>(a&65535)>>>0){break y}}b=z[f+28>>1];A:{if(b){g=x[f>>2];q=Oc(g,x[f+4>>2]);break A}b=0;g=x[f>>2];q=Oc(g,x[f+4>>2]);c=a&65535;if(q>>>0<c>>>0|!c){break A}while(1){c=a;a=a-1|0;h=a&65535;if(!h){break A}if(z[bc(g,h)>>1]!=65535){continue}break}b=c}w[d+1074448>>1]=b;x[d+480208>>2]=x[d+480208>>2]&-524289;while(1){a=b&65535;if(a>>>0>=q>>>0){break q}if(z[bc(g,a)>>1]==65534){b=b+1|0;w[l>>1]=b;continue}break}if(!Sq(f,a)){break q}a=z[d+1074448>>1];c=x[d+484360>>2];h=y[j|0];f=Tb(c,h);break x}a=a+1|0;w[l>>1]=a}b=65535;g=Oc(x[f>>2],x[f+4>>2]);f=a&65535;if(g>>>0>f>>>0){b=z[bc(x[Tb(c,h)>>2],f)>>1]}w[d+1074446>>1]=b;q=x[d+484344>>2];f=x[m>>2];g=b&65535;if(Jf(q,f)>>>0<=g>>>0){break w}g=Xb(q,g);if(!Mb(x[g>>2],x[g+4>>2])){break u}}g=1;continue}w[d+1074450>>1]=a;break r}g=0;continue}}a=b&65535;if(!Ce(q,f,a)){break k}b=x[n>>2];if(b>>>0>=A[Xb(q,a)+12>>2]){x[n>>2]=0;b=0}if(x[d+480208>>2]&32?x[d+480272>>2]!=-1:0){break n}if(!Lt(k,z[l>>1],b,eq(u+16|0,e),y[u+24|0])){break n}a=x[d+480272>>2];if(a){if((a|0)>0){x[d+480272>>2]=a-1}eo(k,1);Lt(k,z[l>>1],x[n>>2],eq(u+16|0,e),y[u+24|0]);break n}if(!(y[H|0]&64)){break q}b=0;if(GQ(k,l,n)){break o}x[d+1074424>>2]=0;x[d+1074428>>2]=0;x[d+1074448>>2]=0;c=wj(x[d+484360>>2],x[G>>2])-1|0;a=y[j|0];if((c|0)>(a|0)){break p}Lj(t,0)}eo(k,1);break k}Lj(t,a+1&255);eo(k,1)}while(1){if((b|0)==256){MO(d);x[d+1074416>>2]=x[d+480196>>2];x[d+1074420>>2]=x[d+480204>>2];x[d+1074456>>2]=x[d+480200>>2];a=z[d+1074448>>1];w[d+1074450>>1]=a;b=x[d+1074424>>2];x[d+1074428>>2]=b;c=Tb(x[d+484360>>2],y[j|0]);h=x[c>>2];if(Oc(h,x[c+4>>2])>>>0>a>>>0){Xa=d,Ya=z[bc(h,a)>>1],w[Xa+1074446>>1]=Ya}Lt(k,a,b,eq(u+16|0,e),y[u+24|0]);if(!Ce(x[d+484344>>2],x[m>>2],z[d+1074446>>1])){break k}}else{io((D(b,872)+d|0)+1074992|0,d,b&65535,134217728);b=b+1|0;continue}break}}qQ(d,r,(x[d+480208>>2]&32)>>>5|0);a=Xb(x[d+484344>>2],z[d+1074446>>1]);a=hd(x[a>>2],x[x[a+48>>2]+12>>2],x[d+1074424>>2],0);h=e+D(z[C>>1],872)|0;b=e;while(1){if((b|0)==(h|0)){B:{C:{a=x[d+484344>>2];b=z[d+1074446>>1];if(Sm(a,x[d+484348>>2],b)){a=Xb(a,b);b=x[a+16>>2];c=x[a+20>>2];if(nQ(b,c)){break C}}x[d+1074408>>2]=x[d+480216>>2];c=x[d+480220>>2];break B}x[d+1074408>>2]=b}x[d+1074412>>2]=c;if(!y[u+24|0]){break m}b=x[d+1074416>>2];x[d+1074392>>2]=b;continue l}Ab(u+16|0,o,82);D:{if(!zb(x[x[u+16>>2]>>2],x[u+20>>2])|y[b+805|0]!=1){break D}c=y[a+3|0];if((c|0)!=2&(c|0)!=3){break D}Xa=b,Ya=nh(d,y[b+800|0],w[b+772>>1],x[b+704>>2]),x[Xa+700>>2]=Ya}Ab(u+16|0,o,91);E:{if(!zb(x[x[u+16>>2]>>2],x[u+20>>2])){break E}if(Wc(y[a|0])){break E}c=y[b+788|0];if(!Wc(c)|y[b+791|0]!=19){break E}f=y[b+793|0];if((f&240)!=208|A[d+1074416>>2]>(f&15)>>>0){break E}Xa=b,Ya=nh(d,c,w[b+772>>1],0),x[Xa+700>>2]=Ya}Ab(u+16|0,o,118);F:{if(!zb(x[x[u+16>>2]>>2],x[u+20>>2])){break F}if(Wc(y[a|0])|!(y[b+89|0]&2)){break F}c=x[b+708>>2];if(!c){break F}if(!Wc(y[b+788|0])){break F}if(!ok(y[b+790|0],y[b+791|0])){break F}x[b+700>>2]=c}Ab(u+16|0,o,92);G:{if(!zb(x[x[u+16>>2]>>2],x[u+20>>2])){break G}Ab(u+8|0,o,5);if(zb(x[x[u+8>>2]>>2],x[u+12>>2])|x[d+1074416>>2]!=1|y[b+791|0]!=17){break G}v[u+16|0]=1;Xa=d,Ya=D(y[mf(u+16|0,b+793|0)|0],1e4),x[Xa+1074420>>2]=Ya}c=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);v[b+788|0]=c;v[b+789|0]=c>>>8;v[b+790|0]=c>>>16;v[b+791|0]=c>>>24;c=y[a+4|0]|y[a+5|0]<<8;v[b+792|0]=c;v[b+793|0]=c>>>8;c=x[b+676>>2];x[b+20>>2]=x[b+672>>2];x[b+24>>2]=c;x[b+88>>2]=x[b+88>>2]&-393217;Ab(u+16|0,o,21);if(!zb(x[x[u+16>>2]>>2],x[u+20>>2])){v[b+831|0]=0}x[b+860>>2]=0;v[b+805|0]=0;a=a+6|0;b=b+872|0;continue}}break}c=x[d+1074416>>2];if(!c){x[d+1074416>>2]=1;c=1}b=x[d+480208>>2];e=x[d+1074392>>2];H:{I:{if(e){a=b&-4097;x[d+480208>>2]=a;h=x[d+480180>>2];if(h&1048580|!(b&2097152)&(h|0)==1){break H}if(nl(r)>>>0<=e>>>0){break H}if(!((e>>>0)%(x[d+1074400>>2]+c>>>0)|0)){break I}break H}a=b&-528385}x[d+480208>>2]=a|4096}j=ib-16|0;ib=j;w[d+1074444>>1]=65535;a=d+1074436|0;x[a>>2]=-1;x[a+4>>2]=-1;C=d+480180|0;_=d+1075809|0;t=d+1074312|0;N=d+906300|0;J=d+480208|0;L=d+1074376|0;Y=d+480188|0;aa=d+480210|0;V=d+480190|0;O=d+480192|0;while(1){if(z[Y>>1]<=s>>>0){J:{if(!(y[J+1|0]&16)){break J}if(!gQ(d,L,Tb(x[d+484360>>2],y[d+484376|0]),1)){break J}x[J>>2]=x[J>>2]|524288}ib=j+16|0}else{m=D(s,872)+d|0;k=m+1075785|0;e=y[k|0];o=m+1075784|0;q=y[o|0];R=m+1075781|0;f=y[R|0];a=x[d+1074392>>2];b=x[d+1074400>>2];h=x[d+1074416>>2];X=m+1075782|0;g=y[X|0];l=m+1075783|0;H=y[l|0];c=ok(g,H);n=m+1075843|0;v[n|0]=x[J>>2]>>>12&1|y[n|0]&254;h=(a>>>0)%(b+h>>>0)|0;K=m+1075780|0;b=y[K|0];K:{L:{M:{if((b|0)==252){r=nk(g,q);G=nk(H,e);b=252;a=f-1|0;if((a&255)>>>0>249){break M}a=x[Nd(N,a)>>2];if(!a){break M}lb[x[x[a>>2]+44>>2]](a,r,E(E(G>>>0)/E(999)));b=y[K|0]}if((b&255)==251){break L}}if(B[m+1075852>>2]==E(0)|H){break K}}r=x[J>>2]&4096;N:{if(!r){a=y[m+1075862|0];break N}a=y[R|0];v[m+1075862|0]=a}if((a-1&255)>>>0>249){break K}G=Nd(N,(a&255)-1|0);a=x[G>>2];if(!a){break K}O:{if(!r){b=z[m+1075860>>1];break O}b=Bz(y[X|0],y[o|0]);w[m+1075860>>1]=b;W=E(E(Bz(y[l|0],y[k|0])>>>0)/E(999));B[m+1075856>>2]=W;Xa=m+1075852|0,Za=E(E(W-E(lb[x[x[a>>2]+48>>2]](a,b)))/E(nl(L)>>>0)),B[Xa>>2]=Za;a=x[G>>2]}l=b;b=(x[d+1074392>>2]+1|0)==(nl(L)|0);lb[x[x[a>>2]+(b?44:108)>>2]](a,l,B[(b?m+1075856|0:m+1075852|0)>>2]);b=y[K|0]}k=m+1074992|0;if(YP(b&255)){b=ib-16|0;ib=b;w[b+12>>1]=0;x[b+8>>2]=0;a=Bg(b+8|0);c=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);v[k+788|0]=c;v[k+789|0]=c>>>8;v[k+790|0]=c>>>16;v[k+791|0]=c>>>24;a=y[a+4|0]|y[a+5|0]<<8;v[k+792|0]=a;v[k+793|0]=a>>>8;ib=b+16|0;H=0;q=0;g=0;f=0;e=0;c=0}P:{if(!(y[J+1|0]&16)){AP(d,k);break P}if(!f){break P}x[m+1075752>>2]=0}Q:{R:{if((H|0)==33){Ab(j+8|0,t,30);b=e>>>4|0;nz(d,s&65535,b+(e&15)|0,zb(x[x[j+8>>2]>>2],x[j+12>>2]));break R}b=0;if((H-19&255)>>>0>1){break R}S:{if(!(!(x[C>>2]&16777250)|e)){e=y[m+1075825|0];break S}v[m+1075825|0]=e}a=e&240;if((a|0)==208){a=e&15;if(!a){a=x[C>>2];if(a&16777248){b=1;break R}if((a|0)!=2){break R}break Q}if(a>>>0>=x[d+1074400>>2]+x[d+1074416>>2]>>>0){Ab(j+8|0,t,14);b=a;if(!zb(x[x[j+8>>2]>>2],x[j+12>>2])){break R}if(!f){break Q}v[m+1075795|0]=f;break Q}b=a;break R}if(!(y[J+1|0]&16)|(a|0)!=224){break R}a=x[C>>2];if(x[d+1074396>>2]?a&16777250:0){break R}l=a&2;a=e&15;if(a?0:l){break R}x[d+1074396>>2]=a+1}a=b;b=x[C>>2]==16&(H|0)==19&(e&240)==208;G=b?0:a;T:{if(!G|y[K|0]!=255|y[X|0]!=2){break T}Ab(j+8|0,t,74);if(!zb(x[x[j+8>>2]>>2],x[j+12>>2])){break T}v[X|0]=0}Q=e&15;a=x[d+1074392>>2];Ab(j+8|0,t,72);U:{if(zb(x[x[j+8>>2]>>2],x[j+12>>2])){r=0;if(G>>>0>=A[d+1074416>>2]){break U}}Ab(j+8|0,t,88);r=(h|0)==(G|0)|(a|0)==(G|0);if(!(!zb(x[x[j+8>>2]>>2],x[j+12>>2])|!G)){break U}r=(a|0)==(G|0)}Ab(j+8|0,t,44);e=b?Q|144:e;V:{if(!zb(x[x[j+8>>2]>>2],x[j+12>>2])){a=y[n|0];break V}a=y[n|0]&-2|(h|0)==(G|0)}v[n|0]=a&253|(r?2:0);Ab(j+8|0,t,66);h=(!G|zb(x[x[j+8>>2]>>2],x[j+12>>2])^1)&c;W:{X:{Y:{if(!(x[d+1074392>>2]|(!(y[aa|0]&32)|!f))){x[m+1075652>>2]=0;if(r){c=y[K|0];break Y}if(!Gi(x[k+8>>2],x[k+12>>2])){break W}v[m+1075795|0]=f;if(z[V>>1]<f>>>0){break W}a=D(f,104)+d|0;x[m+1075680>>2]=z[a+484410>>1];w[m+1075764>>1]=v[a+484417|0];break W}if(!r){break W}c=y[K|0];if(!f){break X}}v[m+1075795|0]=f}Z:{_:{a=c&255;if(!Wc(a)){break _}Ab(j+8|0,t,67);if(!zb(x[x[j+8>>2]>>2],x[j+12>>2])){break _}b=w[m+1075762>>1];$:{if(!f|h){break $}o=Gq(d,a,f);if(!o){break $}b=v[Oi(d,o)+36|0]}c=(a+b|0)-132>>>0>=4294967176?c:0;break Z}if(!(x[C>>2]&25165856)){break Z}b=z[O>>1];if(!b){break Z}if(a){a=Wc(a)}else{a=1}if(!a){break Z}a=f;aa:{if(!a){a=y[m+1075796|0];if(!a){break aa}}if(x[((a<<2)+d|0)+900380>>2]?a>>>0<=b>>>0:0){break Z}c=0}f=0}if(!((H|0)!=25|e)){Ab(j+8|0,t,55);a=zb(x[x[j+8>>2]>>2],x[j+12>>2]);f=a?0:f;c=a?0:c}Ab(j+8|0,t,65);b=(f|0)!=0;a=c&255;l=!a;ba=zb(x[x[j+8>>2]>>2],x[j+12>>2]);T=1;ba:{if(x[C>>2]&16777248){break ba}Ab(j+8|0,t,107);if(zb(x[x[j+8>>2]>>2],x[j+12>>2])){break ba}Ab(j,t,85);T=0;if(!zb(x[x[j>>2]>>2],x[j+4>>2])){break ba}if(Gi(x[k+8>>2],x[k+12>>2])){break ba}T=1;o=x[m+1075096>>2];if(!o){break ba}T=_d(x[o>>2],x[o+20>>2])^1}l=b&l;o=b&ba;ca:{da:{ea:{fa:{ga:{ha:{if(!(x[C>>2]&1048580)){break ha}ia:{if((a|0)!=255){break ia}if(!(!((g|0)==1|f)&(H|0)!=13)){Ab(j+8|0,t,55);if(zb(x[x[j+8>>2]>>2],x[j+12>>2])){break ia}}b=x[m+1075648>>2];if(v[b+60|0]&1?b:0){break ia}x[m+1075680>>2]=0;a=m+1075080|0;x[a>>2]=x[a>>2]|2097152;ja:{if(!(x[J>>2]&4096)){break ja}Ab(j+8|0,t,86);if(!zb(x[x[j+8>>2]>>2],x[j+12>>2])){break ja}x[a>>2]=x[a>>2]|4096}f=0;c=0;a=0;b=0;l=1;if(o){break da}break ca}Ab(j+8|0,t,59);if(!zb(x[x[j+8>>2]>>2],x[j+12>>2])|x[J>>2]&4096){break ha}ka:{if(!a){c=y[m+1075789|0]-y[m+1075762|0]|0;break ka}if(a>>>0>250){T=0;o=1;c=0;break ka}la:{if(f){break la}Ab(j+8|0,t,98);if(!zb(x[x[j+8>>2]>>2],x[j+12>>2])){break la}f=0;break ka}T=1;o=1}b=c;h=0;break ga}b=0;if(!l){break fa}}Ab(j+8|0,t,65);if(!zb(x[x[j+8>>2]>>2],x[j+12>>2])){break ea}c=b;b=1}a=c;l=1;if(o){break da}break ca}c=b;b=1;l=o}ma:{na:{if(!z[O>>1]){if(z[V>>1]<f>>>0){break ma}a=(D(f,104)+d|0)+484380|0;break na}a=x[m+1075096>>2];if(!a){break ma}}oa:{if(w[a+34>>1]<0){break oa}if(x[C>>2]==2){if(!_d(x[a>>2],x[a+20>>2])){break oa}}x[m+1075680>>2]=z[a+30>>1]}if(!l){break ma}lq(k,z[a+28>>1],d)}a=c}Ab(j+8|0,t,71);if(!(!zb(x[x[j+8>>2]>>2],x[j+12>>2])|!f)){v[m+1075831|0]=32}pa:{if(!z[O>>1]){break pa}Ab(j+8|0,t,100);if(!zb(x[x[j+8>>2]>>2],x[j+12>>2])|!f){break pa}if(Wc(a&255)){break pa}c=x[J>>2];qa:{if(h){if(c&8){break qa}break pa}if(!(c&4)){break pa}}ym(k);x[m+1075688>>2]=65536;c=m+1075080|0;x[c>>2]=x[c>>2]|2097152}if(b){Ab(j+8|0,t,11);ra:{sa:{ta:{if(!(zb(x[x[j+8>>2]>>2],x[j+12>>2])|x[C>>2]==268435456)){c=z[O>>1];break ta}Ab(j+8|0,t,87);b=0;if(zb(x[x[j+8>>2]>>2],x[j+12>>2])){b=Gi(x[k+8>>2],x[k+12>>2])^1}c=z[O>>1];ua:{if(c){if(c>>>0<f>>>0){break sa}if(x[m+1075648>>2]!=x[((f<<2)+d|0)+900380>>2]|b){break ua}break sa}if((b^-1)&x[m+1075096>>2]==((D(f,104)+d|0)+484380|0)){break ra}}a=y[m+1075789|0]}if(!(c&65535)){break ra}}if(!(x[C>>2]&1048588)){break ra}ym(k);v[m+1075810|0]=0;x[m+1075748>>2]=0;x[m+1075688>>2]=65536;b=m+1075080|0;x[b>>2]=x[b>>2]&-2101249|2097152;Ab(j+8|0,t,86);if(!zb(x[x[j+8>>2]>>2],x[j+12>>2])){break ra}x[b>>2]=x[b>>2]&-2049}f=T?f:0}c=a&255;va:{if(c>>>0<251){break va}Ab(j+8|0,t,50);wa:{if(!zb(x[x[j+8>>2]>>2],x[j+12>>2])|!f){break wa}b=Gq(d,y[m+1075791|0],f);if(!b){break wa}b=D(b,104)+d|0;if(w[b+484414>>1]<0){break wa}x[m+1075680>>2]=z[b+484410>>1]}Ab(j+8|0,t,100);if(Xa=zb(x[x[j+8>>2]>>2],x[j+12>>2]),Ya=0,_a=x[J>>2]&4,_a?Xa:Ya){break va}f=0}o=Wc(c);if(o){v[m+1075794|0]=a;v[m+1075791|0]=a;if(!h){BP(d,s&65535,f,c,0)}XR(k)}xa:{ya:{za:{Aa:{Ba:{if(f){b=m+1075096|0;l=x[b>>2];cq(d,k,f,h,1,1);a=x[b>>2];Ca:{if(!a|!(y[a+35|0]&2)){break Ca}T=x[d+1298300>>2];if(!Ed(T)){break Ca}Zz(T,s&65535,a+68|0)}Da:{Ea:{if(x[C>>2]==1){if(!h){break Ea}Ab(j+8|0,t,85);if(!zb(x[x[j+8>>2]>>2],x[j+12>>2])){break Ea}break Da}Ab(j+8|0,t,50);if((o|zb(x[x[j+8>>2]>>2],x[j+12>>2])^1)!=1){break Da}}v[m+1075795|0]=0}Ab(j+8|0,t,42);if(zb(x[x[j+8>>2]>>2],x[j+12>>2])){if(!o|(l|0)==x[b>>2]){break Aa}break Ba}if(x[C>>2]&16777248){a=0;if(o&(l|0)!=x[b>>2]){break za}}Ab(j+8|0,t,107);Fa:{if(!zb(x[x[j+8>>2]>>2],x[j+12>>2])|(!(o^1|h)|(l|0)==x[b>>2])){break Fa}a=m+1075068|0;if(A[a>>2]>=A[k+4>>2]){break Fa}x[a>>2]=0;break Aa}Ab(j+8|0,t,85);if(!zb(x[x[j+8>>2]>>2],x[j+12>>2])){break Aa}if(!Gi(x[k+8>>2],x[k+12>>2])){break Ba}break Aa}if(!c){a=h;break xa}b=0;l=m+1075795|0;a=y[l|0];if(!(!a|o^1)){cq(d,k,a,h,!(x[m+1075096>>2]?1:x[m+1075648>>2]),!(x[C>>2]&1048580));v[l|0]=0;b=1}a=h;break ya}x[k>>2]=0;x[k+4>>2]=0}a=h}b=0;if(!c){break xa}}h=x[m+1075096>>2];Ga:{if(!h|!(y[h+35|0]&2)){break Ga}o=x[d+1298300>>2];if(!Ed(o)){break Ga}if(!b){if(CP(o,s&65535)){break Ga}}Zz(o,s&65535,h+68|0)}b=s&65535;Gt(d,k,c,a,!(x[C>>2]&1048580),0,b);lQ(x[C>>2],z[Y>>1],L,b);if(!(!a|(!(x[C>>2]&1048580)|!f))){h=m+1075080|0;x[h>>2]=x[h>>2]|2097152;ym(k);v[m+1075810|0]=0;x[m+1075748>>2]=0}if(!(x[m+1075080>>2]&512)){break xa}if(!Ed(x[d+1298300>>2])){break xa}if(c>>>0<=253){if((c|0)!=253){break xa}Ab(j+8|0,t,99);if(zb(x[x[j+8>>2]>>2],x[j+12>>2])){break xa}}Ab(j+8|0,t,110);if(zb(x[x[j+8>>2]>>2],x[j+12>>2])){_z(x[d+1298300>>2],b,0,1,0)}pk(x[d+1298300>>2],b)}Ha:{Ia:{switch(g-1|0){case 0:q=q>>>0>=64?64:q;x[m+1075680>>2]=q<<2;b=m+1075080|0;x[b>>2]=x[b>>2]|2097152;break Ha;case 1:break Ia;default:break Ha}}zm(d,k,q,6)}if(z[O>>1]){zP(d,s&65535)}h=a}Ab(j+8|0,t,77);if(Xa=zb(x[x[j+8>>2]>>2],x[j+12>>2]),Ya=0,_a=x[((s<<5)+d|0)+480280>>2]&1024,_a?Xa:Ya){break Q}a=x[d+1074392>>2];Ab(j+8|0,t,75);c=a>>>0>=G>>>0;Ja:{Ka:{La:{Ma:{if(!zb(x[x[j+8>>2]>>2],x[j+12>>2])|!G){break Ma}b=x[d+1074392>>2];if(!b){break La}c=1;if((b|0)!=(G|0)){break Ma}c=!y[R|0]&(g|0)!=11}a=g;if(!c|a>>>0<3){break La}if((a|0)==11){a=j+8|0;Fz(a,d,y[K+3|0],y[K+4|0],G);a=y[Ze(a)|0];mz(d,s&65535,z[j+8>>1]);if(a){break Ka}g=11;break La}Ab(j+8|0,t,62);Na:{Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{if(!(!zb(x[x[j+8>>2]>>2],x[j+12>>2])|q)){q=0;g=0;Ua:{switch(a-8|0){case 0:break Ta;case 1:break Ua;default:break La}}if(y[J+1|0]&16){break La}x[m+1075684>>2]=0;break La}Ab(j+8|0,t,41);Va:{if(zb(x[x[j+8>>2]>>2],x[j+12>>2])){break Va}if(q){v[m+1075826|0]=q;break Va}q=y[m+1075826|0]}Wa:{switch(a-3|0){case 0:case 1:Xa:{Ya:{if(q){break Ya}Ab(j+8|0,t,41);if(!zb(x[x[j+8>>2]>>2],x[j+12>>2])){break Ya}q=y[m+1075826|0];if(q){break Xa}q=0;break La}v[m+1075826|0]=q}ao(d,k,((a|0)==3?q<<4:q)&255);break La;case 2:if((G|0)!=x[d+1074392>>2]){Ab(j+8|0,t,41);g=5;if(zb(x[x[j+8>>2]>>2],x[j+12>>2])){break La}}Ab(j+8|0,t,41);$n(d,k,q,zb(x[x[j+8>>2]>>2],x[j+12>>2]));g=5;break La;case 3:if((G|0)!=x[d+1074392>>2]){Ab(j+8|0,t,41);g=6;if(zb(x[x[j+8>>2]>>2],x[j+12>>2])){break La}}Ab(j+8|0,t,41);_n(d,k,q,zb(x[x[j+8>>2]>>2],x[j+12>>2]));g=6;break La;case 11:break Na;case 12:break Oa;case 10:break Pa;case 9:break Qa;case 7:break Ra;case 6:break Sa;case 5:break Ta;case 4:break Wa;default:break La}}Ab(j+8|0,t,53);if(zb(x[x[j+8>>2]>>2],x[j+12>>2])){v[m+1075815|0]=q&15;g=7;break La}ml(k,q<<4);g=7;break La}ml(k,q);g=8;break La}Ab(j+8|0,t,62);lz(d,k,q,zb(x[x[j+8>>2]>>2],x[j+12>>2])^1);g=9;break La}Ab(j+8|0,t,62);lz(d,k,q<<4&240,zb(x[x[j+8>>2]>>2],x[j+12>>2])^1);g=10;break La}g=12;Ab(j+8|0,t,12);yP(d,s&65535,q<<2&252,zb(x[x[j+8>>2]>>2],x[j+12>>2]));break La}Ab(j+8|0,t,12);xP(d,s&65535,q<<2&252,zb(x[x[j+8>>2]>>2],x[j+12>>2]));g=13;break La}g=15;if(!r){break La}a=x[m+1075096>>2];if(!a|q>>>0>9){break La}Za:{if(!q){f=x[m+1075656>>2];break Za}f=x[Bb(a+68|0,q-1|0)>>2];x[m+1075656>>2]=f}bo(d,k,f);break La}g=14;if(q>>>0>1){break La}v[n|0]=y[n|0]&247|!q<<3}f=e;_a:{$a:{ab:{switch(H-1|0){case 12:if(!(y[J+1|0]&16)){break Ka}a=D(s,872)+d|0;x[a+1075680>>2]=e>>>0>=64?256:e<<2;a=a+1075080|0;x[a>>2]=x[a>>2]|2097152;break Ka;case 1:if(!e){f=0;if(v[C|0]&1){break Ja}}yP(d,s&65535,e,0);break Ka;case 2:if(!e){f=0;if(v[C|0]&1){break Ja}}xP(d,s&65535,e,0);break Ka;case 10:if(!e){f=0;if(x[C>>2]==1){break Ja}}ao(d,k,e);break Ka;case 3:mz(d,s&65535,e);break Ka;case 5:if(!(!e&x[C>>2]==1)){ao(d,k,e)}mz(d,s&65535,0);break Ka;case 4:ml(k,e);break Ka;case 6:if(!(!e&x[C>>2]==1)){ao(d,k,e)}ml(k,0);break Ka;case 15:if(!(y[J+1|0]&16)){break Ka}break _a;case 16:Ab(j+8|0,t,5);if(zb(x[x[j+8>>2]>>2],x[j+12>>2])){if(!(y[J+1|0]&16)){break Ka}if(e){break _a}break Ka}f=Zn(d,z[d+1074446>>1],x[d+1074424>>2],s&65535,0);bb:{if(!(x[d+480180>>2]&16777250)){break bb}if(f){v[(D(s,872)+d|0)+1075827|0]=f;break bb}f=y[(D(s,872)+d|0)+1075827|0]}x[j+8>>2]=D(f,1e4);wc(j+8|0,D(x[x[d+8>>2]+24>>2],1e4));a=ib-16|0;ib=a;c=x[j+8>>2];x[a+8>>2]=c;b=x[d+8>>2];cb:{if(c>>>0>=(x[d+480180>>2]&16393?1e4:32e4)>>>0){c=x[d+480208>>2];Ab(a,d+1074312|0,92);if((zb(x[x[a>>2]>>2],x[a+4>>2])|0)==((c&4096)>>>12|0)){break cb}x[a>>2]=D(x[b+24>>2],1e4);Xa=d+1074420|0,Ya=x[Hb(a+8|0,a)>>2],x[Xa>>2]=Ya;break cb}if(y[d+480209|0]&16){break cb}e=d+1074420|0;c=(c>>>0)/1e4|0;h=D(c&15,1e4);x[e>>2]=x[e>>2]+((c&240)==16?h:0-h|0);c=x[b+20>>2];b=x[b+24>>2];Ab(a,d+1074312|0,8);Xo(e,D(c,1e4),zb(x[x[a>>2]>>2],x[a+4>>2])?255e4:D(b,1e4))}ib=a+16|0;break Ja;case 9:if(!r|x[C>>2]==4&h){break Ka}kQ(d,k,s&65535,x[d+1074424>>2],z[d+1074446>>1]);break Ka;case 43:if(!r){break Ka}b=qoa(x[(D(s,872)+d|0)+1075068>>2],0,e,0);a=kb;f=a>>>8|0;bo(d,k,Ec((a&255)<<24|b>>>8,f));break Ka;case 0:if(x[d+1074392>>2]){break Ka}a=D(s,872)+d|0;db:{if(y[a+1075789|0]?x[a+1075692>>2]:0){break db}a=x[a+1075648>>2];if(a){if(zj(y[a+31|0])){break db}}Ab(j+8|0,t,13);if(zb(x[x[j+8>>2]>>2],x[j+12>>2])){break db}if(x[C>>2]&16777248){break Ka}}if(!e){f=0;if(y[C|0]&5){break Ja}v[(D(s,872)+d|0)+1075797|0]=1;break Ja}a=D(s,872)+d|0;v[a+1075798|0]=e;v[a+1075797|0]=1;break Ka;case 14:if(x[C>>2]&1048580){e=e&240?e:y[(D(s,872)+d|0)+1075799|0]&240|e;if(!(e&15)){e=y[(D(s,872)+d|0)+1075799|0]&15|e}e=e|256}f=e;Ab(j+8|0,t,23);if(zb(x[x[j+8>>2]>>2],x[j+12>>2])){b=d;c=s&65535;if(f){v[(D(s,872)+d|0)+1075799|0]=f;a=f}else{a=y[(D(s,872)+d|0)+1075799|0]}kz(b,c,a&255,(g|0)==15?q+1|0:0);break Ja}eb:{if(f){v[(D(s,872)+d|0)+1075799|0]=f;break eb}f=y[(D(s,872)+d|0)+1075799|0]}kz(d,s&65535,f,(g|0)==15?q+1|0:0);break Ja;case 17:if(!(y[J+1|0]&16)){break Ka}Ab(j+8|0,t,22);fb:{gb:{if(zb(x[x[j+8>>2]>>2],x[j+12>>2])){if(!e){e=0;break gb}if(y[J|0]&4){break gb}a=e&240?e-16|0:e;e=a-((a&15)!=0)|0;v[(D(s,872)+d|0)+1075832|0]=e;break gb}Ab(j+8|0,t,71);if(!zb(x[x[j+8>>2]>>2],x[j+12>>2])){break fb}}a=(D(s,872)+d|0)+1075831|0;v[a|0]=y[a|0]|128}a=D(s,872)+d|0;v[a+1075797|0]=18;if(!e){f=0;break Ja}v[a+1075832|0]=e;break Ka;case 22:if(!(y[J+1|0]&16)){break Ka}a=x[C>>2];f=e<<!(a&59593760);if(f>>>0<=128){x[d+1074456>>2]=f<<1;break Ja}if(a&16777250){break Ja}x[d+1074456>>2]=256;break Ja;case 23:Ab(j+8|0,t,9);if(zb(x[x[j+8>>2]>>2],x[j+12>>2])){wP(d,e,(D(s,872)+d|0)+1075809|0);break Ka}wP(d,e,_);break Ka;case 8:if(!(y[J+1|0]&16)){break Ka}zm(d,k,e,8);break Ka;case 28:lz(d,k,e,1);break Ka;case 7:cQ(k,e);break Ka;case 25:dQ(d,k,e);break Ka;case 18:h=ib-16|0;ib=h;g=d+1074376|0;b=s&65535;f=D(b,872);c=(g+f|0)+616|0;a=e&15;hb:{ib:{switch(e>>>4|0){case 0:b=(e&1)<<14;c=z[d+480188>>1];a=0;while(1){if((a|0)==(c|0)){break hb}f=(D(a,872)+d|0)+1075080|0;x[f>>2]=(b|x[f>>2]&-16385)^16384;a=a+1|0;continue};case 1:if(!a){a=0;if(!(x[d+480180>>2]&1048580)){break hb}}xz(d,c,a);Ab(h+8|0,d+1074312|0,117);if(zb(x[x[h+8>>2]>>2],x[h+12>>2])){break hb}Tn(d,b,e|240,1);break hb;case 2:if(!a){a=0;if(!(x[d+480180>>2]&1048580)){break hb}}wz(d,c,a);Ab(h+8|0,d+1074312|0,117);if(zb(x[x[h+8>>2]>>2],x[h+12>>2])){break hb}Tn(d,b,0-(e|240)|0,1);break hb;case 3:b=(d+f|0)+1075080|0;x[b>>2]=x[b>>2]&-1048577|((a|0)!=0)<<20;break hb;case 4:v[(d+f|0)+1075814|0]=e&7;break hb;case 5:if(!(y[d+480209|0]&16)){break hb}f=x[d+480180>>2];if(f&69206025){c=D(b,872)+d|0;w[c+1075764>>1]=a<<28>>24;f=c+1075692|0;if(!x[f>>2]){break hb}if(!Wc(y[c+1075780|0])){break hb}b=D(b,872)+d|0;Xa=f,Ya=nh(d,y[b+1075789|0],a<<28>>24,x[b+1075696>>2]),x[Xa>>2]=Ya;break hb}c=Wc(y[(D(b,872)+d|0)+1075780|0]);if((f|0)==16){if(!c){break hb}c=D(b,872)+d|0;f=x[c+1075096>>2];if(!f){break hb}v[f+37|0]=a;w[c+1075764>>1]=a;c=c+1075692|0;if(!x[c>>2]){break hb}b=D(b,872)+d|0;Xa=c,Ya=nh(d,y[b+1075789|0],a,x[b+1075696>>2]),x[Xa>>2]=Ya;break hb}if(!c){break hb}a=D(b,872)+d|0;b=(e<<4^-128)<<24>>24;w[a+1075764>>1]=b;c=a+1075692|0;if(!x[c>>2]){break hb}Xa=c,Ya=nh(d,y[a+1075789|0],b,x[a+1075696>>2]),x[Xa>>2]=Ya;break hb;case 6:if(!(y[d+480209|0]&16)){break hb}Ez(d,g,c,a);break hb;case 7:v[(d+f|0)+1075817|0]=e&7;break hb;case 8:if(!(y[d+480209|0]&16)){break hb}zm(d,c,a,4);break hb;case 9:kz(d,b,a,0);break hb;case 10:if(a){$n(d,c,a,0);break hb}if(!(x[d+480180>>2]&1048580)){break hb}$n(d,c,0,0);break hb;case 11:if(a){_n(d,c,a,0);break hb}if(!(x[d+480180>>2]&1048580)){break hb}_n(d,c,0,0);break hb;case 12:nz(d,b,a,0);break hb;case 15:break ib;default:break hb}}if(x[d+480180>>2]==1){v[(D(b,872)+d|0)+1075838|0]=a;if(!(y[d+480209|0]&16)){break hb}AP(d,c);break hb}v[(D(b,872)+d|0)+1075836|0]=a}ib=h+16|0;break Ka;case 19:vP(d,s&65535,e);break Ka;case 24:Ab(j+8|0,t,55);if(zb(x[x[j+8>>2]>>2],x[j+12>>2])){if(x[d+1074392>>2]!=(e|0)){break Ka}a=x[(D(s,872)+d|0)+1075648>>2];if(v[a+60|0]&1?a:0){break $a}if(!(!(y[R|0]|y[X|0])|e)){a=(D(s,872)+d|0)+1075080|0;x[a>>2]=x[a>>2]|4096;break $a}a=D(s,872)+d|0;x[a+1075680>>2]=0;a=a+1075080|0;x[a>>2]=x[a>>2]|2097152;break $a}if(y[J+1|0]&16){break $a}break Ka;case 27:a=(e&240)-16>>>4|0;if(a>>>0>9){break Ka}if(!(1<<a&880)){if(a){if((a|0)!=1){break Ka}vz(d,k,Q);Ab(j+8|0,t,117);if(zb(x[x[j+8>>2]>>2],x[j+12>>2])){break Ka}Tn(d,s&65535,-224-Q|0,1);break Ka}yz(d,k,Q);Ab(j+8|0,t,117);if(zb(x[x[j+8>>2]>>2],x[j+12>>2])){break Ka}Tn(d,s&65535,Q|224,1);break Ka}Ab(j+8|0,t,58);if(zb(x[x[j+8>>2]>>2],x[j+12>>2])){break Ka}vP(d,s&65535,e);break Ka;case 34:case 35:if(!(y[J+1|0]&16)&(H|0)!=36){break Ka}b=s&65535;hQ(d,b,L,(H|0)==36);a=_p(d,x[k+88>>2],x[k+656>>2]);if(!a){break Ka}lb[x[x[a>>2]+80>>2]](a,w[k+774>>1]+32768>>>2|0,b);break Ka;case 20:if(!(y[J+1|0]&16)|e>>>0>64){break Ka}a=D(s,872)+d|0;x[a+1075740>>2]=e;a=a+1075080|0;x[a>>2]=x[a>>2]|2097152;break Ka;case 21:f=x[C>>2];h=x[J>>2];a=e;jb:{if(a){v[k+816|0]=a;break jb}a=y[k+816|0]}b=a&15;c=a&255;kb:{lb:{if(!((b|0)!=15|c>>>0<16)){if(!(h&4096)){break kb}a=c>>>4|0;break lb}h=h&4096;g=c&240;if(!(!b|(g|0)!=240)){if(!h){break kb}a=0-b|0;break lb}if(h){break kb}if(b){a=0-b|0;if(!(f&25690144)|!g){break lb}break kb}if((a&255)>>>0<16){break kb}a=c>>>4|0}Xa=k,Ya=Vb(a+x[k+748>>2]|0,0,64),x[Xa+748>>2]=Ya}break Ka;case 26:bQ(k,e);break Ka;case 29:if(!(y[J+1|0]&16)){break Ka}a=D(s,872)+d|0;x[a+1075716>>2]=e;Ab(j+8|0,t,60);if(Xa=0,Ya=zb(x[x[j+8>>2]>>2],x[j+12>>2]),_a=y[a+1075722|0]&4,_a?Xa:Ya){break Ka}a=D(s,872)+d|0;x[a+1075732>>2]=e;x[a+1075724>>2]=e;break Ka;case 11:fQ(d,L,s&65535);break Ka;case 13:a=eQ(d,L,s&65535,e);if((a|0)==-1){break Ka}x[d+1074436>>2]=a;if(!(y[d+480208|0]&32)){break Ka}w[d+1074444>>1]=z[d+1074448>>1];break Ka;case 37:case 38:case 39:case 40:VP(d,k,e,(H|0)==38|(H|0)==40,(H&254)==40);break Ka;case 41:jQ(k,e);break Ka;case 42:if(x[d+1074392>>2]|Q>>>0>1|e>>>0>47){break Ka}a=(e&240)==16;c=a?z[d+480188>>1]-1|0:s;f=a?0:s;a=((Q|0)==1)<<26;while(1){b=f&65535;if(b>>>0>(c&65535)>>>0){break Ka}h=((b<<5)+d|0)+480280|0;x[h>>2]=a|x[h>>2]&-67108865;b=(D(b,872)+d|0)+1075080|0;x[b>>2]=a|x[b>>2]&-67108865;f=f+1|0;continue};case 44:break ab;default:break Ja}}iQ(k,e);break Ka}Yn(d,k);break Ka}oQ(d,L,e)}f=e}Ab(j+8|0,t,78);if(!(!zb(x[x[j+8>>2]>>2],x[j+12>>2])|!f)){_P(k,f&255)}a=y[R|0];if(!a){break Q}v[m+1075796|0]=a}s=s+1|0;continue}break}a=1;break j}a=0}ib=u+32|0;Q=!x[d+1074420>>2]|a^1;mb:{if(Q){break mb}a=mQ(d,d+1074376|0);x[d+1074380>>2]=a;x[d+1074404>>2]=a;b=Bd(z[d+480188>>1],1,31);nb:{if(Qd(y[d+1074366|0])){a=x[d+24628>>2];if((a|0)>=129){a=((D(a-128|0,b+4|0)|0)/16|0)+128|0}o=((D(x[d+480228>>2],a)<<1&-128)>>>0)/y[(b>>>1|0)+32176|0]|0;break nb}o=x[d+480228>>2]}w[d+480212>>1]=0;j=d+1074312|0;O=d+1074365|0;t=d+480180|0;G=d+480210|0;L=d+480209|0;T=d+1074366|0;R=d+1074364|0;X=d+1074360|0;H=0;while(1){if((H|0)==256){b=x[d+24608>>2];h=z[d+480212>>1];if(b>>>0>h>>>0){break mb}e=ib-16|0;ib=e;x[e+8>>2]=d;a=d+1074478|0;c=a;h=a+(h<<1)|0;ob:{b=a+(b<<1)|0;if((a|0)==(b|0)){break ob}pb:{a=b-c|0;if((a|0)<3){break pb}f=a>>1;a=f-2>>>1|0;while(1){if((a|0)<0){break pb}Qy(c,x[e+8>>2],f,c+(a<<1)|0);a=a-1|0;continue}}f=b-c>>1;a=b;while(1){if((a|0)==(h|0)){a=b-c>>1;while(1){if((a|0)>1){b=b-2|0;Ry(c,b);a=a-1|0;Qy(c,x[e+8>>2],a,c);continue}break}break ob}if(Vp(x[e+8>>2],z[a>>1],z[c>>1])){Ry(a,c);Qy(c,x[e+8>>2],f,c)}a=a+2|0;continue}}ib=e+16|0}else{n=D(H,872)+d|0;r=n+1075080|0;qb:{if(!(x[r>>2]&4096)|(x[n+1075016>>2]|(x[n+1075012>>2]|x[n+1075688>>2]))){break qb}Ab(i+16|0,j,64);if(zb(x[x[i+16>>2]>>2],x[i+20>>2])){break qb}x[n+1075068>>2]=0;a=n+1075084|0;x[a>>2]=0;x[a+4>>2]=0}b=z[d+480188>>1];a=x[r>>2];rb:{if(x[n+1075068>>2]|b>>>0>H>>>0?a&1024:1){if(b>>>0>H>>>0){CO(d,H&65535)}w[n+1075834>>1]=0;break rb}g=0;K=n+1075712|0;x[K>>2]=0;u=n+1075672|0;x[u>>2]=0;s=n+1075e3|0;c=s;x[c>>2]=0;x[c+4>>2]=0;x[n+1075092>>2]=0;x[i+44>>2]=1065353216;w[i+42>>1]=0;J=n+1075648|0;C=x[J>>2];x[i+36>>2]=0;q=0;m=n+1075692|0;q=x[m>>2]?x[n+1075068>>2]!=0:q;k=n+1074992|0;sb:{tb:{ub:{if(b>>>0<=H>>>0){break ub}if(y[((H<<5)+d|0)+480288|0]){break tb}if(!C){break ub}g=y[C+34|0]!=0}if((g|q)!=1){break sb}}x[i+8>>2]=x[n+1075680>>2];x[i+32>>2]=x[n+1075744>>2];Ab(i+16|0,j,28);a=i+8|0;b=zb(x[x[i+16>>2]>>2],x[i+20>>2])?i+32|0:a;c=ib-16|0;ib=c;e=d+1074312|0;Ab(c+8|0,e,28);vb:{if(zb(x[x[c+8>>2]>>2],x[c+12>>2])){x[b>>2]=x[b>>2]+w[k+776>>1];re(b,0,64);break vb}Ab(c+8|0,e,1);e=w[k+776>>1];if(zb(x[x[c+8>>2]>>2],x[c+12>>2])){x[b>>2]=e+x[b>>2];re(b,0,256);break vb}x[k+688>>2]=e+x[k+688>>2];re(k+688|0,0,256);x[b>>2]=x[k+688>>2];w[k+776>>1]=0}ib=c+16|0;b=ib-16|0;ib=b;c=d+1074312|0;Ab(b+8|0,c,28);wb:{xb:{if(!zb(x[x[b+8>>2]>>2],x[b+12>>2])){Ab(b,c,1);if(!zb(x[x[b>>2]>>2],x[b+4>>2])){break xb}}x[k+684>>2]=x[k+692>>2]+w[k+778>>1];re(k+684|0,0,256);break wb}x[k+692>>2]=x[k+692>>2]+w[k+778>>1];re(k+692|0,0,256);w[k+778>>1]=0;x[k+684>>2]=x[k+692>>2]}ib=b+16|0;b=ib-16|0;ib=b;yb:{if(!(y[k+90|0]&4)|(x[d+480208>>2]&2101248)==2101248){break yb}zb:{if(x[a>>2]<=0){Ab(b+8|0,d+1074312|0,21);if(!zb(x[x[b+8>>2]>>2],x[b+12>>2])){break zb}}e=5;if(!(x[d+480180>>2]&5)){Ab(b+8|0,d+1074312|0,21);e=zb(x[x[b+8>>2]>>2],x[b+12>>2])?5:6}c=Uy(d,y[k+825|0],y[k+820|0]);Ab:{if((y[k+825|0]&3)!=1){break Ab}Ab(b+8|0,d+1074312|0,89);if(!zb(x[x[b+8>>2]>>2],x[b+12>>2])){break Ab}c=y[k+819|0];f=y[k+820|0];h=f<<2&124;c=(!(y[k+90|0]&2)|y[d+480209|0]&16?c:y[k+823|0]+c|0)&32?h^127:h;c=f&32?0-c|0:c}if(x[d+480180>>2]!=131072){c=x[a>>2]+((D(y[k+827|0],c)|0)/(1<<e)|0)|0}else{e=64-c|0;c=x[a>>2];c=((D(y[k+827|0],D(e,c))|0)/-8192|0)+c|0}x[a>>2]=c}c=x[d+480208>>2];if(!(x[d+480180>>2]&16777248)|c&4?c&4096:0){break yb}Ab(b+8|0,d+1074312|0,21);c=y[k+826|0];e=y[k+820|0];h=zb(x[x[b+8>>2]>>2],x[b+12>>2]);v[k+820|0]=(h?c<<2:e)+(h?e:c)}ib=b+16|0;h=H&65535;c=h;l=ib-16|0;ib=l;b=d+1074312|0;Ab(l+8|0,b,71);Bb:{if(zb(x[x[l+8>>2]>>2],x[l+12>>2])){b=(D(c,872)+d|0)+1075831|0;e=v[b|0];if((e|0)>=0){break Bb}if(!(y[d+480209|0]&16|y[(D(c,872)+d|0)+1075797|0]!=18)){Cb:{Db:{if((e&-33)!=-64){e=e&223;if((e|0)!=128){break Db}e=y[(D(c,872)+d|0)+1075832|0]>>>4|-64;break Cb}e=y[(D(c,872)+d|0)+1075832|0]&15|-128;break Cb}e=e-1|0}v[b|0]=e;b=(D(c,872)+d|0)+1075080|0;x[b>>2]=x[b>>2]|2097152}if((e&224)!=128){break Bb}x[a>>2]=0;break Bb}if(y[(D(c,872)+d|0)+1075797|0]!=18){break Bb}Ab(l+8|0,b,22);Eb:{if(zb(x[x[l+8>>2]>>2],x[l+12>>2])){g=D(c,872)+d|0;b=g+1075831|0;f=y[b|0];e=f<<24>>24;if(!((e|0)>=0|!x[g+1075068>>2])){Fb:{Gb:{if((f|0)!=192){if((f|0)!=128){break Gb}e=y[(D(c,872)+d|0)+1075832|0]>>>4|-64;break Fb}e=y[(D(c,872)+d|0)+1075832|0]&15|-128;break Fb}e=e-1|0}v[b|0]=e}if((e&192)!=128){break Eb}x[a>>2]=0;break Eb}b=y[(D(c,872)+d|0)+1075832|0];g=b>>>4|0;f=g+(b&15)|0;N=x[d+480180>>2];if(!(y[d+480208|0]&4?0:N&16777248)){g=g+1|0;f=f+2|0}b=(D(c,872)+d|0)+1075831|0;e=y[b|0];if(!(N&4)){e=(e&255)>>>0<f>>>0?e:0;if((e&255)>>>0>=g>>>0){x[a>>2]=0}v[b|0]=e+1;break Eb}Hb:{if(y[d+480209|0]&16){e=e&255?e-1|0:0;break Hb}v[b|0]=e+1}if(((e&255)>>>0)%(f>>>0)>>>0<g>>>0){break Eb}x[a>>2]=0}b=(D(c,872)+d|0)+1075080|0;x[b>>2]=x[b>>2]|2097152}b=D(c,872)+d|0;Ib:{if(y[b+1075797|0]!=18){break Ib}e=x[b+1075648>>2];if(!e){break Ib}b=y[e+34|0];if(!b|y[e+15|0]&2){break Ib}f=D(c,872)+d|0;if(x[f+1075080>>2]&134218752){break Ib}f=f+1075791|0;g=y[f|0];if(!Wc(g)){break Ib}b=x[Nd(d+906300|0,b-1|0)>>2];if(!b){break Ib}g=lb[x[x[b>>2]+104>>2]](b,g,c)|0;N=x[a>>2];if(!(!g|N)){lb[x[x[b>>2]+96>>2]](b,e,y[f|0]|256,0,c);break Ib}if(g|!N){break Ib}lb[x[x[b>>2]+96>>2]](b,e,y[f|0],z[(D(c,872)+d|0)+1075680>>1],c)}ib=l+16|0;re(a,0,256);x[i+8>>2]=x[i+8>>2]<<6;Jb:{if(C){Ab(i+16|0,j,31);if(zb(x[x[i+16>>2]>>2],x[i+20>>2])){Ct(d,k)}c=i+8|0;b=ib-16|0;ib=b;Kb:{if(!Sy(d,k,0)){break Kb}e=x[k+656>>2];f=d+1074312|0;Ab(b+8|0,f,31);Lb:{if(zb(x[x[b+8>>2]>>2],x[b+12>>2])){a=x[k+724>>2];if(a){break Lb}break Kb}a=x[k+724>>2]}Ab(b+8|0,f,31);l=a-zb(x[x[b+8>>2]>>2],x[b+12>>2])|0;a=kq(e+48|0,l,256,64);N=y[e+65|0];Mb:{if((N|0)==255){break Mb}g=w[k+728>>1];if((g|0)==-1){break Mb}N=Bb(x[e+48>>2],N);e=y[N+2|0];N=z[N>>1];Ab(b+8|0,f,94);f=e<<2;a=(l|0)==(N|0)?f:a;if(zb(x[x[b+8>>2]>>2],x[b+12>>2])){a=g+(a-f<<1)|0;break Mb}if(!e){a=0;break Mb}a=(D(a,g)|0)/(f|0)|0}Xa=c,Ya=(D(Vb(a,0,512),x[c>>2])|0)/256|0,x[Xa>>2]=Ya}ib=b+16|0;TP(k,c);b=ib-16|0;ib=b;Nb:{if(!Sy(d,k,1)){break Nb}c=x[k+656>>2];e=d+1074312|0;Ab(b+8|0,e,31);Ob:{if(zb(x[x[b+8>>2]>>2],x[b+12>>2])){a=x[k+732>>2];if(a){break Ob}break Nb}a=x[k+732>>2]}Ab(b+8|0,e,31);c=kq(c+68|0,a-zb(x[x[b+8>>2]>>2],x[b+12>>2])|0,64,64)-32|0;a=x[k+684>>2];Xa=k,Ya=Vb(((D(c,(a|0)>127?256-a|0:a)|0)/32|0)+a|0,0,256),x[Xa+684>>2]=Ya}ib=b+16|0;Ab(i+16|0,j,115);if(zb(x[x[i+16>>2]>>2],x[i+20>>2])){break Jb}b=y[n+1075789|0];if(!b){break Jb}a=x[J>>2];if(!a|!y[a+26|0]){break Jb}WP(n+1075676|0,b,y[a+26|0],y[a+27|0]);break Jb}if(!(y[r+1|0]&16)){break Jb}x[n+1075688>>2]=0;x[i+8>>2]=0}Pb:{if(y[n+1075843|0]&8){e=0;x[i+8>>2]=0;break Pb}e=x[i+8>>2];if(!e){e=0;break Pb}if(y[r+3|0]&8){x[u>>2]=0;break Pb}if(Qd(y[O|0])){a=D(x[i+32>>2],x[n+1075740>>2]);b=a;c=a>>31;a=e<<8;Xa=u,Ya=Dc(roa(qoa(b,c,a,a>>31),kb,1048576,0),kb),x[Xa>>2]=Ya;break Pb}a=D(x[i+32>>2],x[n+1075740>>2]);b=a;c=a>>31;a=D(x[d+1074456>>2],e);Xa=u,Ya=Dc(roa(qoa(b,c,a,a>>31),kb,1048576,0),kb),x[Xa>>2]=Ya}x[K>>2]=e;Qb:{Rb:{e=x[m>>2];if(!(x[t>>2]==2|(e|0)>=x[d+480260>>2])){if(!sj(d)){break Rb}e=x[m>>2]}if((e|0)<x[d+480264>>2]){break Qb}Ab(i+16|0,j,113);if(!zb(x[x[i+16>>2]>>2],x[i+20>>2])){break Qb}if(sj(d)){break Qb}x[m>>2]=x[d+480264>>2];break Qb}x[m>>2]=x[d+480260>>2]}Ab(i+16|0,j,73);a=x[m>>2];x[i+36>>2]=a;Sb:{if((x[r>>2]&1572864)!=1572864){break Sb}b=x[d+480208>>2];if(b&2097152){if(!ok(y[n+1075782|0],y[n+1075783|0])|b&4096){break Sb}}b=n+1075704|0;Tb:{if((a|0)==x[b>>2]){e=x[n+1075708>>2];break Tb}x[b>>2]=a;c=a;a=n+1075764|0;b=n+1075696|0;e=nh(d,xt(d,c,w[a>>1],x[b>>2]),w[a>>1],x[b>>2]);x[n+1075708>>2]=e}x[i+36>>2]=e}f=ib-16|0;ib=f;l=D(h,872)+d|0;N=l+1075648|0;a=x[N>>2];Ub:{if(!a){break Ub}b=y[a+34|0];if(x[(D(h,872)+d|0)+1075080>>2]&134218752|(!b|y[a+15|0]&2)){break Ub}if(!x[Nd(d+906300|0,b-1|0)>>2]){break Ub}a=D(h,872)+d|0;c=a+1075780|0;b=y[a+1075793|0];Y=a+1075783|0;g=y[Y|0];Vb:{Wb:{if((g|0)==1){a=b;Xb:{Yb:{switch(((A[d+1074392>>2]%(x[d+1074400>>2]+x[d+1074416>>2]>>>0)>>>0)%3|0)-1|0){case 0:a=b+(y[(D(h,872)+d|0)+1075798|0]>>>4|0)|0;break Xb;case 1:break Yb;default:break Xb}}a=b+(y[(D(h,872)+d|0)+1075798|0]&15)|0}e=D(h,872)+d|0;if(y[e+1075792|0]==(a&255)){break Vb}if(!(v[e+1075843|0]&1)){break Wb}if(!Wc(y[c|0])){break Wb}if(ok(y[c+2|0],1)){break Wb}break Vb}if(y[c|0]){a=b;if(!ok(y[c+2|0],g)){break Vb}}a=b;if(!y[(D(h,872)+d|0)+1075792|0]){break Vb}}wm(d,h,a&255|512,z[(D(h,872)+d|0)+1075680>>1])}V=(D(h,872)+d|0)+1075792|0;e=y[V|0];Zb:{_b:{if(e){if((g|0)!=1|(a&255)!=(e|0)){break _b}break Zb}if(!(v[(D(h,872)+d|0)+1075843|0]&1)|(g|0)!=1){break Zb}if(Wc(y[c|0])){break Zb}e=b;if(!Wc(b)){break Zb}}wm(d,h,e&255|256,0)}v[V|0]=y[Y|0]==1?a:0}$b:{if(y[l+1075797|0]!=1){break $b}if(Aj(x[N>>2])){a=0;ac:{bc:{cc:{switch(A[d+1074392>>2]%3|0){case 1:a=y[(D(h,872)+d|0)+1075798|0]>>>4|0;break bc;case 0:break bc;case 2:break cc;default:break ac}}a=y[(D(h,872)+d|0)+1075798|0]&15}w[i+42>>1]=a}a=(D(h,872)+d|0)+1075843|0;v[a|0]=y[a|0]|96;break $b}if(!(!(y[d+480209|0]&16)|x[d+480180>>2]!=1048576)){a=D(h,872)+d|0;b=nh(d,y[a+1075789|0],w[a+1075764>>1],x[a+1075696>>2]);x[i+36>>2]=b;x[a+1075692>>2]=b}b=d+1074312|0;Ab(f+8|0,b,13);if(zb(x[x[f+8>>2]>>2],x[f+12>>2])){a=y[(D(h,872)+d|0)+1075798|0];if(!a){break $b}c=65536;dc:{switch(((A[d+1074392>>2]%(x[d+1074400>>2]+x[d+1074416>>2]>>>0)>>>0)%3|0)-1|0){case 1:a=a<<4;case 0:c=x[((a&240)<<2)+37152>>2];break;default:break dc}}e=sj(d);a=x[i+36>>2];b=a;a=a>>31;if(e){a=qoa(b,a,c,c>>31)+32768|0;h=kb;a=roa(a,a>>>0<32768?h+1|0:h,65536,0)}else{e=(c|0)/2|0;h=e>>31;l=a<<16|b>>>16;b=b<<16;a=b+e|0;l=h+l|0;a=roa(a,a>>>0<b>>>0?l+1|0:l,c,c>>31)}b=kb;Xa=i,Ya=Dc(a,b),x[Xa+36>>2]=Ya;break $b}Ab(f+8|0,b,51);if(zb(x[x[f+8>>2]>>2],x[f+12>>2])){if(y[d+480209|0]&16){break $b}ec:{fc:{a=x[d+1074416>>2];a=a-(A[d+1074392>>2]%(a>>>0)|0)|0;if((a|0)>16){break fc}if((a|0)==16){break $b}c=0;gc:{switch((a|0)%3|0){case 0:break $b;case 2:break fc;case 1:break gc;default:break ec}}c=y[(D(h,872)+d|0)+1075798|0]>>>4|0;break ec}c=y[(D(h,872)+d|0)+1075798|0]&15}a=D(h,872)+d|0;b=a+1075764|0;a=a+1075696|0;c=xt(d,x[i+36>>2],w[b>>1],x[a>>2])+c|0;b=nh(d,c,w[b>>1],x[a>>2]);x[i+36>>2]=b;if(c>>>0<109){break $b}x[f+8>>2]=b;Xa=f,Ya=nh(d,109,0,x[a>>2]),x[Xa+4>>2]=Ya;Xa=i,Ya=x[Yc(f+8|0,f+4|0)>>2],x[Xa+36>>2]=Ya;break $b}e=x[d+1074392>>2];g=d+480180|0;a=x[g>>2];hc:{if((a|0)!=1){c=y[(D(h,872)+d|0)+1075789|0];break hc}a=D(h,872)+d|0;c=xt(d,x[i+36>>2],w[a+1075764>>1],x[a+1075696>>2]);a=x[g>>2]}ic:{jc:{switch((((a&67633152?e+2|0:e)>>>0)%3|0)-1|0){case 0:c=(y[(D(h,872)+d|0)+1075798|0]>>>4|0)+c|0;break ic;case 1:break jc;default:break ic}}c=(y[(D(h,872)+d|0)+1075798|0]&15)+c|0}if(!(a&67633408|y[(D(h,872)+d|0)+1075789|0]!=(c&255))){Ab(f+8|0,b,82);if(!zb(x[x[f+8>>2]>>2],x[f+12>>2])){break $b}}if(y[d+480210|0]&32){a=c&255;if((a|0)==85){x[i+36>>2]=2147483647;break $b}c=a>>>0>85?c-37|0:c}a=D(h,872)+d|0;e=nh(d,c&255,w[a+1075764>>1],x[a+1075696>>2]);x[i+36>>2]=e;if(x[d+480180>>2]&71860480){x[a+1075692>>2]=e;break $b}Ab(f+8|0,b,82);if(!zb(x[x[f+8>>2]>>2],x[f+12>>2])){break $b}v[(D(h,872)+d|0)+1075792|0]=c}ib=f+16|0;if(!(!(y[G|0]&33)|x[i+36>>2]==2147483647)){kc:{if(x[t>>2]==2){e=452;a=3424;break kc}a=D(z[n+1075764>>1]>>>4&15,24);b=z[a+32886>>1]>>>1|0;e=b>>>0<=452?452:b;a=z[a+32864>>1]<<1}re(i+36|0,e,a);re(m,e,a)}$P(d,k);a=x[r>>2]}lc:{if(!(a&256)|y[L|0]&64){break lc}Ab(i+16|0,j,37);if(!zb(x[x[i+16>>2]>>2],x[i+20>>2])){break lc}x[n+1075676>>2]=128}m=H&65535;CO(d,m);mc:{if(!q){break mc}a=UP(d,k,i+36|0);if((a|0)<0|!(y[r+1|0]&2)){break mc}b=x[d+1298300>>2];if(!Ed(b)){break mc}jq(b,m,a>>>2&255,1)}nc:{if(y[n+1075782|0]!=8){break nc}oc:{pc:{a=y[n+1075783|0];switch(a-5|0){case 1:break nc;case 0:case 2:break oc;default:break pc}}if((a|0)!=26){break nc}}a=x[t>>2];if((a|0)==4){if(y[L|0]&16){break nc}a=n+1075811|0;v[a|0]=y[a|0]+y[n+1075815|0];break nc}if(!(a&16777248)){break nc}ml(k,y[n+1075784|0]);BO(d,m,i+36|0,i+44|0)}BO(d,m,i+36|0,i+44|0);qc:{if(!q){break qc}x[i+32>>2]=0;b=i+36|0;l=ib-16|0;ib=l;h=x[k+104>>2];rc:{if(!h|!y[h+40|0]){break rc}q=Aj(x[k+656>>2]);f=sj(d);Ab(l+8|0,d+1074312|0,21);c=f?38176:37152;e=f?37152:38176;if(!(q|!zb(x[x[l+8>>2]>>2],x[l+12>>2])|x[d+480180>>2]==1048576)){q=y[h+41|0];if(!q){break rc}a=y[k+818|0];x[l+4>>2]=x[k+756>>2]+y[h+39|0];gi(l+4|0,y[h+40|0]<<8);g=x[l+4>>2];v[k+818|0]=a+q;x[k+756>>2]=g;g=(g|0)/256|0;sc:{tc:{switch(y[h+38|0]-1|0){case 3:h=zO(Xn(d))+-64|0;break sc;case 2:h=64-(a+1>>>1|0)|0;break sc;case 1:h=(a+1>>>1|0)+-64|0;break sc;case 0:h=(a^-1)>>>1&64;break sc;default:break tc}}h=v[a+33456|0]}gi(b,8388607);a=x[b>>2]<<8;x[b>>2]=a;N=D(g,h);g=(N|0)/64|0;h=g>>31;g=(g^h)-h|0;h=g&3;g=g>>>2|0;q=a>>31;uc:{vc:{if((N|0)<=-64){c=x[(g<<2)+c>>2];c=Dc(roa(qoa(c,c>>31,a,q),kb,65536,0),kb)-a|0;if(!h){break uc}e=f?37088:37024;break vc}c=x[e+(g<<2)>>2];c=Dc(roa(qoa(c,c>>31,a,q),kb,65536,0),kb)-a|0;if(!h){break uc}e=f?37024:37088}f=c;c=x[(h<<2)+e>>2];c=(f+Dc(roa(qoa(a,q,c,c>>31),kb,65536,0),kb)|0)-a|0}x[b>>2]=(c+a|0)/256;x[i+32>>2]=c&255;break rc}f=x[d+480180>>2]&16777248;a=y[h+39|0];wc:{if(!(f|a)){x[k+756>>2]=y[h+40|0]<<8;break wc}xc:{yc:{if(f){f=a<<1;g=x[k+756>>2];a=k+756|0;break yc}if(y[k+89|0]&8){break xc}g=((y[h+40|0]<<8&65280)>>>0)/(a>>>0)|0;f=x[k+756>>2];a=k+756|0}x[a>>2]=f+g}gi(k+756|0,y[h+40|0]<<8)}a=y[k+818|0]+y[h+41|0]|0;v[k+818|0]=a;a=a<<24>>24;zc:{Ac:{switch(y[h+38|0]-1|0){case 3:v[k+818|0]=a+1;f=v[(a&63)+33392|0];break zc;case 2:f=(64-(a>>>1|0)&127)+-64|0;break zc;case 1:f=((a>>>1|0)- -64&127)+-64|0;break zc;case 0:f=(a|0)>=0?-64:64;break zc;default:break Ac}}f=0-v[(a&255)+33456|0]|0;if(x[d+480180>>2]!=1048576){break zc}f=(64-v[(a+-64&255)+33456|0]|0)/2<<16>>16}a=f;g=D(a,x[k+756>>2]);f=(g|0)/256|0;if(q){B[i+44>>2]=B[i+44>>2]+E(E(E(E(y[h+40|0])*E(.05000000074505806))*E(a|0))*E(.000244140625));v[k+851|0]=y[k+851|0]|64;break rc}if(x[d+480180>>2]!=4){Bc:{if((g|0)<=-256){f=0-f|0;g=f>>>8|0;a=(g<<2)+c|0;break Bc}c=e;g=f>>>8|0;a=e+(g<<2)|0}e=x[b>>2];a=x[a>>2];a=((D(x[((g<<2)+c|0)+4>>2]-a|0,f>>>2&63)|0)/64|0)+a|0;a=Dc(roa(qoa(e,e>>31,a,a>>31),kb,256,0),kb);x[b>>2]=a;x[i+32>>2]=a&255;x[b>>2]=x[b>>2]/256;break rc}x[b>>2]=x[b>>2]+((g|0)/16384|0)}ib=l+16|0;q=x[i+36>>2];if((q|0)<=x[d+480260>>2]){Ab(i+16|0,j,81);if(zb(x[x[i+16>>2]>>2],x[i+20>>2])){x[n+1075068>>2]=0}q=x[d+480260>>2];x[i+36>>2]=q}Cc:{if(!Aj(x[k+656>>2])){break Cc}a=n+1075843|0;b=y[a|0];if(!(x[d+1074392>>2]|!(b&32)?b&64:1)){break Cc}WR(k,B[i+44>>2],w[i+42>>1],d);b=a;a=y[a|0];v[b|0]=(a&64?-65:-33)&a}a=i+16|0;Hz(a,d,k,q,x[i+32>>2]);a=Db(a);b=qoa(x[i+16>>2],x[i+20>>2],x[d+480240>>2],0);f=kb;c=roa(b,f,65536,0);e=kb;b=b+65535|0;f=b>>>0<65535?f+1|0:f;b=!f&b>>>0<131071;c=b?1:c;x[i+16>>2]=c;b=b?0:e;x[i+20>>2]=b;x[s>>2]=c;x[s+4>>2]=b;if((x[r>>2]&134219264)!=512){break qc}if(!Ed(x[d+1298300>>2])){break qc}Ab(i+8|0,j,99);Dc:{Ec:{if(Xa=zb(x[x[i+8>>2]>>2],x[i+12>>2]),Ya=1,_a=y[r+1|0]&16,_a?Xa:Ya){c=x[t>>2];break Ec}c=x[t>>2];if((c|0)!=2){break Dc}}e=(c|0)==2;b=x[r>>2];c=b&2048;Fc:{if(c?e:0){break Fc}a=qoa(x[a>>2],0,261625,0)+66904|0;e=kb;e=Ec(soa(a,a>>>0<66904?e+1|0:e,133808,0),kb);a=1;Gc:{if(c){break Gc}a=0;if(!(b&4096)){break Gc}a=!x[n+1075688>>2]}Ab(i+8|0,j,110);if(Xa=zb(x[x[i+8>>2]>>2],x[i+12>>2]),Ya=0,_a=a,_a?Xa:Ya){break Fc}b=x[d+1298300>>2];Ab(i+8|0,j,95);_z(b,m,e,a,zb(x[x[i+8>>2]>>2],x[i+12>>2]))}b=x[d+1298300>>2];a=qoa(D(x[n+1075744>>2],D(x[n+1075740>>2],x[K>>2])),0,63,0)+33554432|0;f=kb;f=a>>>0<33554432?f+1|0:f;jq(b,m,Ec((f&67108863)<<6|a>>>26,f>>>26|0)&255,0);a=n+1075676|0;h=a;b=x[a>>2];e=0;a=x[d+1298300>>2];c=sl(a,m);Hc:{if((c|0)==255){break Hc}f=x[a>>2];if(qk(f)){break Hc}e=Jb(Cd(a+318|0,c),10);g=x[a+4>>2];c=Qt(c)|192;a=y[e|0]&-49;a=(b|0)<171?a|16:a;a=(b|0)>84?a|32:a;ph(f,g,m,c,a&255);e=(a>>>5&1)+(a<<27>>31)|0}x[h>>2]=(e<<7)+128}Ic:{a=x[J>>2];if(!a|(y[a+60|0]&7)!=1){break Ic}b=x[a+48>>2];a=x[a+52>>2];if(pc(b,a)){break Ic}b=x[AO(k,0)>>2];a=Fj(a);if(b>>>0<z[a>>1]|y[a+2|0]){break Ic}vj(x[d+1298300>>2],m,1);Ab(i+8|0,j,109);a=x[r>>2];Xa=r,Ya=(zb(x[x[i+8>>2]>>2],x[i+12>>2])?a:a&-4609)|4096,x[Xa>>2]=Ya;x[n+1075688>>2]=0;break qc}Ab(i+8|0,j,99);if(!zb(x[x[i+8>>2]>>2],x[i+12>>2])|!(y[r+1|0]&16)|x[n+1075688>>2]){break qc}vj(x[d+1298300>>2],m,1);x[r>>2]=x[r>>2]&-513}Jc:{if(!C){break Jc}Ab(i+16|0,j,31);if(zb(x[x[i+16>>2]>>2],x[i+20>>2])){break Jc}Ct(d,k)}b=x[r>>2];a=b&-65537;f=x[u>>2];l=n+1075016|0;m=n+1075012|0;e=f|(x[l>>2]|x[m>>2])?(a|b<<7&65536)^65536:a;x[r>>2]=e;u=n+1075664|0;a=u;x[a>>2]=0;x[a+4>>2]=0;h=n+1075834|0;a=y[h|0];b=a-4|0;a=a>>>0>=b>>>0?b:0;v[h|0]=a;g=n+1075835|0;b=y[g|0];c=b-4|0;c=b>>>0>=c>>>0?c:0;v[g|0]=c;Kc:{Lc:{Mc:{Nc:{Oc:{Pc:{Qc:{Rc:{Sc:{b=x[n+1075096>>2];Tc:{if(!b){break Tc}q=x[b+20>>2];if(!_d(x[b>>2],q)|!x[n+1075068>>2]){break Tc}if(Gi(x[k+8>>2],x[k+12>>2])){break Sc}}x[n+1075008>>2]=0;break Rc}x[n+1075008>>2]=q;if(q){break Qc}}if(!uj(x[k+656>>2])){break Pc}q=0;if(e&6144){break Pc}}C=x[n+1075676>>2];b=(D(f,256-C|0)|0)/16384|0;b=b>>>0>=127?127:b;if(a<<24>>24<0){v[h|0]=b;V=b}else{V=a}a=b>>>1|0;if((V&255)>>>0<a>>>0){v[h|0]=a}a=(D(f,C)|0)/16384|0;a=a>>>0>=127?127:a;if(c<<24>>24<0){v[g|0]=a;c=a}a=a>>>1|0;if(a>>>0>(c&255)>>>0){break Oc}break Nc}if((a&255)>>>0>=129){v[h|0]=0}q=0;a=0;if((c&255)>>>0<129){break Mc}}v[g|0]=a}if(!q){break Mc}q=128;h=x[d+24624>>2];if(h>>>0>=2){q=Vb(x[n+1075676>>2],0,256)}x[i+16>>2]=q;a=D(f,o)>>>(Qd(y[T|0])?7:8)|0;Uc:{Vc:{Wc:{switch(y[R|0]){case 0:if(!(y[d+24616|0]&16)){break Vc}case 1:if((q|0)<=127){c=a>>>1|0;a=(D(a,q)|0)/256|0;break Uc}c=(D(a,256-q|0)|0)/256|0;a=a>>>1|0;break Uc;case 3:break Wc;default:break Vc}}gi(i+16|0,255);b=x[i+16>>2];if((b|0)<=0){c=65536}else{c=z[(0-b<<1)+39712>>1]}c=D(c,a)>>>16|0;a=D(a,z[(b<<1)+39200>>1])>>>16|0;break Uc}c=(D(a,256-q|0)|0)/256|0;a=(D(a,q)|0)/256|0}b=x[J>>2];Xc:{if(b){q=y[b+14|0];if(Oo(q)){break Xc}}q=y[d+480268|0];if(Oo(q)){break Xc}b=y[d+24648|0];q=y[G|0]&128?x[d+24668>>2]?-1:b:b}f=n+1075668|0;g=n+1075786|0;v[g|0]=q;b=x[s>>2];l=x[s+4>>2];if(!(e&131072|((b|0)!=0|(l|0)!=1)|(x[n+1075748>>2]|(q&255)==255))){v[g|0]=0}g=c;c=1<<x[X>>2];x[u>>2]=(g|0)/(c|0);a=(a|0)/(c|0)|0;x[f>>2]=(e&256)>>>8|0?(h|0)==2?0-a|0:a:a;if(e&128){x[s>>2]=0-b;x[s+4>>2]=0-(((b|0)!=0)+l|0)}f=0;l=ib-16|0;ib=l;x[k+28>>2]=0;x[k+32>>2]=0;gi(k+672|0,524287);gi(k+676|0,524287);Yc:{Zc:{a=x[k+88>>2];if(!(a&65536)){b=x[k+676>>2];c=x[k+672>>2];break Zc}c=x[k+20>>2];e=x[k+672>>2];_c:{if((c|0)!=(e|0)){b=x[k+24>>2];g=x[k+676>>2];break _c}b=x[k+24>>2];g=x[k+676>>2];if((b|0)==(g|0)){break Zc}}a=x[d+24620>>2];e=(b|0)<(g|0)|(c|0)<(e|0);$c:{if(e){c=St(a,x[d+24636>>2]);break $c}c=St(a,x[d+24640>>2])}Ab(l,d+1074312|0,4);if(!(!zb(x[x[l>>2]>>2],x[l+4>>2])|!(x[d+480180>>2]&4))){a=x[d+24620>>2];a=qoa(a,a>>31,5,0)+500|0;h=kb;c=Dc(roa(a,a>>>0<500?h+1|0:h,1e3,0),kb)}a=x[k+656>>2];ad:{if(!a){b=c;break ad}b=c;if(!e){break ad}a=z[a+12>>1];if(a){b=(D(a,x[d+24620>>2])>>>0)/1e5|0}f=(a|0)!=0}g=b?b:1;e=x[k+672>>2];q=x[k+20>>2];m=e-q<<12;s=k;a=x[k+676>>2];b=x[k+24>>2];h=a-b<<12;if(!(y[k+90|0]&32|(!(a|e)|(!(b|q)|f)))){x[l+12>>2]=x[d+1074380>>2];re(l+12|0,c,2048);g=x[l+12>>2]}h=(h|0)/(g|0)|0;x[s+32>>2]=h;f=(m|0)/(g|0)|0;x[k+28>>2]=f;b=a+((D(g,h)|0)/-4096|0)|0;x[k+24>>2]=b;c=e+((D(f,g)|0)/-4096|0)|0;x[k+20>>2]=c;if(f|h){x[k+100>>2]=g;a=x[k+88>>2];break Yc}x[k+24>>2]=a;x[k+20>>2]=e;b=a;c=e;a=x[k+88>>2]&-65537;break Yc}x[k+24>>2]=b;x[k+20>>2]=c;a=a&-65537}x[k+88>>2]=a&-2097153;x[k+40>>2]=b<<12;x[k+36>>2]=c<<12;ib=l+16|0;e=x[r>>2];if(!(e&512)){break Lc}break Kc}x[m>>2]=0;x[l>>2]=0;x[n+1075068>>2]=0;if(x[n+1075088>>2]){break Lc}if(!x[n+1075084>>2]){break Kc}}a=z[d+480212>>1];w[d+480212>>1]=a+1;w[((a<<1)+d|0)+1074478>>1]=H}x[n+1075660>>2]=e}H=H+1|0;continue}break}}ib=i+48|0;if(Q^1){a=x[d+480208>>2];break h}if(Qd(y[Ha|0])){b=x[d+480208>>2]|512;break i}o=0;bd:{a=x[d+24620>>2]/10|0;c=Dc(a,a>>31);if(!c){break bd}b=c>>>0>=1048576?1048576:c;x[d+1074380>>2]=b;h=z[d+480212>>1];e=d+1074376|0;while(1){if((h|0)==(o|0)){break bd}a=e+D(z[(e+(o<<1)|0)+102>>1],872)|0;f=a+1288|0;x[f>>2]=0;x[f+4>>2]=0;x[a+716>>2]=b;f=x[a+640>>2]<<12;x[a+656>>2]=f;g=x[a+636>>2]<<12;x[a+652>>2]=g;x[a+704>>2]=x[a+704>>2]|65536;x[a+644>>2]=(0-g|0)/(b|0);x[a+648>>2]=(0-f|0)/(b|0);o=o+1|0;continue}}a=x[d+480208>>2];b=a|256;if(c){break i}b=a|512}a=b;x[d+480208>>2]=a}if(!(a&512)){break g}Xa=d+1074392|0,Ya=nl(Ga),x[Xa>>2]=Ya}ib=M+112|0;break f}x[M+96>>2]=512;a=x[d+1074380>>2];x[M+104>>2]=ga;x[M+100>>2]=a;k=pC(M+96|0);if(x[d+24632>>2]){a=0;b=ib-48|0;ib=b;c=k<<2;while(1){if((a|0)==4){cd:{a=0;while(1){if((a|0)==4){break cd}x[(b+32|0)+(a<<2)>>2]=((a<<11)+d|0)+16396;a=a+1|0;continue}}}else{x[b+32>>2]=0;e=((a<<11)+d|0)+16396|0;AA(e,c+e|0,b+32|0);a=a+1|0;continue}break}a=x[d+24632>>2];x[b+24>>2]=k;x[b+20>>2]=a;x[b+16>>2]=b+32;a=x[x[fa>>2]+8>>2];x[b+8>>2]=k;c=x[b+20>>2];x[b>>2]=x[b+16>>2];x[b+4>>2]=c;lb[a|0](fa,b);ib=b+48|0}if(Qd(Fa)){a=0;while(1){if((a|0)==4){a=x[d+24632>>2];x[M+88>>2]=k;x[M+84>>2]=a;x[M+80>>2]=M+96;a=x[x[oa>>2]+8>>2];x[M+40>>2]=k;b=x[M+84>>2];x[M+32>>2]=x[M+80>>2];x[M+36>>2]=b;lb[a|0](oa,M+32|0)}else{x[(M+96|0)+(a<<2)>>2]=((a<<11)+d|0)+16396;a=a+1|0;continue}break}}_=0;ha=0;G=ib-48|0;ib=G;if(k){s=d+12|0;t=d+24592|0;u=d+24588|0;bn(s,k,t,u);if(A[d+24624>>2]>=3){bn(d+8204|0,k,d+24600|0,d+24596|0)}w[G+42>>1]=0;ta=d+1074312|0;Ja=d+24648|0;ua=d+906300|0;Ka=d+24596|0;La=d+24600|0;Ma=d+8204|0;C=d+397452|0;J=d+397448|0;m=d+393352|0;va=d+397456|0;ja=d+1074376|0;Na=d+480190|0;while(1){if(z[d+480212>>1]<=_>>>0){Xa=d,Ya=z[pe(d+480214|0,G+42|0)>>1],w[Xa+480214>>1]=Ya}else{h=(_<<1)+ja|0;l=z[h+102>>1];a=D(l,872);Q=a+ja|0;dd:{ed:{if(x[Q+632>>2]){break ed}b=a+d|0;if(x[b+1075088>>2]){break ed}if(!x[b+1075084>>2]){break dd}}i=a+d|0;a=y[i+1075786|0]+1&255;if(a>>>0<=5){g=x[(a<<2)+27792>>2]}else{g=0}L=i+1075080|0;f=x[L>>2];fd:{if(!(!(f&16777216)&y[d+24612|0]>>>5)){a=t;b=u;c=f;e=s;if(!(c&8388608)){break fd}}a=J;b=C;if(!y[va+12|0]){bn(m,k,a,b)}v[va+12|0]=1;l=z[h+102>>1];c=x[L>>2];e=m}h=b;b=c>>>8&A[d+24624>>2]>2;H=b?Ka:h;T=b?La:a;c=b?Ma:e;ka=Ql(d,ja,l,2,1)-1|0;wa=(ka&255)>>>0>249;gd:{if(wa){break gd}b=x[Nd(ua,ka)>>2];if(!b){break gd}a=x[b+24>>2];if(!a){break gd}H=b+36|0;T=b+40|0;if(!(v[b+28|0]&1)){bn(a,k,T,H);x[b+28>>2]=x[b+28>>2]|1}c=a}o=Q+616|0;if(y[i+1075843|0]&8){OD(o,c,k);a=i+1075084|0;x[T>>2]=x[T>>2]+x[a>>2];x[H>>2]=x[H>>2]+x[i+1075088>>2];x[a>>2]=0;x[a+4>>2]=0;break dd}aa=0;e=ib-16|0;ib=e;a=G+16|0;x[a>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;b=e+8|0;h=d+1074312|0;Ab(b,h,33);Xa=a,Ya=zb(x[x[e+8>>2]>>2],x[e+12>>2]),v[Xa+16|0]=Ya;Ab(b,h,116);Xa=a,Ya=zb(x[x[e+8>>2]>>2],x[e+12>>2])^1,v[Xa+17|0]=Ya;if(x[o+16>>2]){MD(a,o);n=x[o+8>>2];l=x[o+12>>2];b=l>>31;l=(b^l)-((b>>>0>(b^n)>>>0)+b|0)|0;b=l;x[a+12>>2]=b>>>0>8191?2:16384/(b+1>>>0)|0}Oa=f>>>12&8|(f>>>5&2|(g|f&1));Pa=ha&65535;Qa=i+1075795|0;Ra=i+1075778|0;Sa=i+1075688|0;Ta=i+1075024|0;Ua=i+1075020|0;Va=i+1075668|0;Wa=i+1075664|0;R=i+1075088|0;X=i+1075084|0;xa=i+1075016|0;ya=i+1075012|0;ba=i+1075096|0;N=i+1075076|0;O=i+1075068|0;K=i+1075e3|0;ia=i+1075072|0;Y=i+1075092|0;ib=e+16|0;q=a;a=k;while(1){hd:{b=x[Y>>2];da=b?a>>>0>b>>>0?b:a:a;x[G+8>>2]=da;id:{jd:{if(!da){break jd}g=x[K>>2];e=x[K+4>>2];if(!(g|e)){break jd}f=x[O>>2];if(!f){break jd}h=x[q>>2];if(!h){break jd}b=x[L>>2];l=x[ia>>2];x[Q+632>>2]=h;i=x[o>>2];kd:{ld:{n=l&b<<30>>31;h=x[o+4>>2];r=h;if((n|0)>(h|0)){if((e|0)<0){i=$g(0,n<<1,i,h);x[o>>2]=i;h=kb;x[o+4>>2]=h;if(!((h|0)>=(n|0)&h>>>0<f+n>>>1>>>0)){i=0;x[o>>2]=i;h=n;x[o+4>>2]=h}md:{if(b&4){b=b&-129;x[L>>2]=b;e=0-(((g|0)!=0)+e|0)|0;g=0-g|0;x[K>>2]=g;x[K+4>>2]=e;break md}x[o>>2]=i;h=f-1|0;x[o+4>>2]=h}if(!(b&2)){break jd}if(f>>>0>h>>>0){break kd}break jd}if((h|0)>0|(h|0)>=0){break kd}h=0;break ld}if(f>>>0>r>>>0){break kd}if(!(b&2)){break jd}if(b&4){if(!!g&(e|0)>=0|(e|0)>0){e=0-(((g|0)!=0)+e|0)|0;g=0-g|0;x[K>>2]=g;x[K+4>>2]=e}b=b|128;x[L>>2]=b;if(y[G+33|0]){r=y[G+32|0];j=x[N>>2]-(r+l|0)|0;h=$g(i,h,0,f);i=kb;if(i>>>0<j>>>0){i=$g(0,f-r|0,h,i);h=kb;break ld}h=l;i=0;break ld}h=1-((i|0)!=0)|0;i=0-i|0;j=(f<<1)-(h+r|0)|0;r=i;x[o>>2]=i;V=0;h=V|j;x[o+4>>2]=h;if(f>>>0>j>>>0&j>>>0>l>>>0){break kd}x[G+44>>2]=y[G+32|0]+1;i=r;h=V|f-x[Hb(O,G+44|0)>>2];break ld}if((e|0)<0){e=0-(((g|0)!=0)+e|0)|0;g=0-g|0;x[K>>2]=g;x[K+4>>2]=e}Pb(o,0,n-f|0);b=x[L>>2]|8192;x[L>>2]=b;i=x[o>>2];h=x[o+4>>2];break kd}x[o>>2]=i;x[o+4>>2]=h}V=h;nd:{if((h|0)<(n|0)){if((e|h)<0){break jd}x[G+44>>2]=da;f=g;l=e;break nd}f=x[O>>2];if(f>>>0<V>>>0|(!!g&(e|0)>=0|(e|0)>0)&(f|0)==(V|0)){break jd}x[G+44>>2]=da;f=e>>31;l=f;j=f^g;f=j-f|0;l=(e^l)-((j>>>0<l>>>0)+l|0)|0}r=f;j=l;wc(G+8|0,x[G+28>>2]);f=x[ia>>2];za=f+16|0;Aa=x[G+8>>2];Zf(i,h,rf(g,e,Aa-1|0),kb);l=kb;Ba=f>>>0>V>>>0;if(!(!Ba&V>>>0<za>>>0)){b=b&-8193;x[L>>2]=b}od:{pd:{la=x[G+20>>2];qd:{if(la){f=x[G+24>>2];if(f>>>0<=V>>>0){rd:{if((e|0)<0){g=0;e=f;break rd}g=i;e=h;i=0;h=x[N>>2]}Xa=G,Ya=Yo($g($g(i,h,g,e),kb,1,0),kb,r,j)+1|0,x[Xa+44>>2]=Ya;x[Q+632>>2]=la;break od}if(!(Ba|!(b&8192)|V>>>0>=za>>>0)){Xa=G,Ya=Yo($g($g(0,n+16|0,i,h),kb,1,0),kb,r,j)+1|0,x[Xa+44>>2]=Ya;Xa=Q,Ya=la+D(x[N>>2]-n|0,Mk(z[x[ba>>2]+34>>1]))|0,x[Xa+632>>2]=Ya;break od}if(!g&(e|0)<=0|(e|0)<0){break qd}if(da>>>0<2|f>>>0>l>>>0){break pd}Xa=G,Ya=Yo($g($g(0,f,i,h),kb,1,0),kb,r,j)+1|0,x[Xa+44>>2]=Ya;break od}if((e|0)>0|(e|0)>=0){break pd}}if((l|0)>=(n|0)){break od}Xa=G,Ya=Yo($g($g(i,h,0,n),kb,1,0),kb,r,j)+1|0,x[Xa+44>>2]=Ya;break od}b=x[O>>2];if((b|0)>(l|0)){break od}Xa=G,Ya=Yo($g($g(0,b,i,h),kb,1,0),kb,r,j)+1|0,x[Xa+44>>2]=Ya}Xo(G+44|0,1,Aa);h=x[G+44>>2];if((h|0)>0){break id}}x[Q+632>>2]=0;x[O>>2]=0;x[o>>2]=0;x[o+4>>2]=0;x[Y>>2]=0;OD(o,c,a);x[T>>2]=x[T>>2]+x[X>>2];x[H>>2]=x[H>>2]+x[R>>2];x[R>>2]=0;x[X>>2]=0;x[L>>2]=x[L>>2]&-129;break hd}sd:{td:{if(Pa>>>0<A[d+24608>>2]){b=4;if(x[Y>>2]){break td}b=0;if(x[xa>>2]|x[ya>>2]){break td}}Pb(o,rf(x[K>>2],x[K+4>>2],h),kb);aa=0;x[R>>2]=0;x[X>>2]=0;c=(h<<3)+c|0;break sd}e=(h<<3)+c|0;f=e-8|0;x[X>>2]=0-x[f>>2];g=e-4|0;x[R>>2]=0-x[g>>2];lb[x[((b|Oa)<<2)+27408>>2]](o,Ja,c,h);x[X>>2]=x[X>>2]+x[f>>2];x[R>>2]=x[R>>2]+x[g>>2];aa=1;c=e}b=x[Y>>2];ud:{if(!b){break ud}if(b>>>0<=h>>>0){x[Y>>2]=0;x[ya>>2]=x[Wa>>2];x[xa>>2]=x[Va>>2];x[Ua>>2]=0;x[Ta>>2]=0;if(x[Sa>>2]|!(y[L+1|0]&16)){break ud}x[O>>2]=0;x[Q+632>>2]=0;break ud}x[Y>>2]=b-h}f=0;l=0;b=x[o+4>>2];l=b>>>0>=A[N>>2]?(y[L|0]&2)>>>1|0:l;e=b;b=x[O>>2];f=e>>>0<b>>>0|(!b|y[L|0]&2)?f:!z[Ra>>1];a=a-h|0;Ab(G+8|0,ta,85);vd:{wd:{xd:{if(!zb(x[x[G+8>>2]>>2],x[G+12>>2])){break xd}b=y[Qa|0];if(!b){break xd}if(b>>>0<=z[Na>>1]){break wd}}b=0;break vd}g=x[ba>>2];e=D(b,104)+d|0;h=e+484380|0;b=(g|0)!=(h|0);if((g|0)==(h|0)|(f|l)!=1){break vd}x[ba>>2]=h;x[Q+632>>2]=x[e+484400>>2];b=z[e+484414>>1];x[L>>2]=b|x[L>>2]&-768;h=b<<30>>31;b=x[e+484388>>2];x[O>>2]=h&b;e=x[e+484384>>2];x[ia>>2]=e;x[N>>2]=b;x[o+4>>2]=e;MD(q,o);if(!x[Q+632>>2]){break hd}if((a|0)>0){continue}break hd}yd:{if(!l|b){break yd}Ab(G+8|0,ta,83);if(!zb(x[x[G+8>>2]>>2],x[G+12>>2])|x[ia>>2]){break yd}x[o>>2]=x[o>>2];x[o+4>>2]=0;b=x[x[ba>>2]+8>>2];x[O>>2]=b;x[N>>2]=b}if((a|0)>0){continue}}break}x[Q+632>>2]=x[q>>2];ha=aa+ha|0;w[G+42>>1]=ha;if(wa|!aa){break dd}a=x[Nd(ua,ka)>>2];if(!a){break dd}lb[x[x[a>>2]+152>>2]](a)}_=_+1|0;continue}break}}ib=G+48|0;j=x[d+1298300>>2];if(Ed(j)){a=Z;b=k;c=(D(x[d+480232>>2],x[d+480236>>2])>>>0)/48|0;o=ib-16|0;ib=o;zd:{if(!y[j+534|0]){break zd}h=qoa(c,0,6169,0);c=kb;e=c>>>16|0;m=Ec((c&65535)<<16|h>>>16,e);while(1){if(!b){break zd}g=x[j>>2];h=x[g>>2];c=x[g+4>>2];while(1){if((c|0)>=(h|0)){x[g+8>>2]=x[g+12>>2];h=0;i=0;q=0;c=ib-16|0;ib=c;while(1){if((q|0)==18){e=(h|0)>=32767?32767:h;w[g+12>>1]=(e|0)<=-32768?-32768:e;e=(i|0)>=32767?32767:i;w[g+14>>1]=(e|0)<=-32768?-32768:e;w[g+3832>>1]=z[g+3832>>1]+1;e=(z[g+3834>>1]+1>>>0)%13440|0;w[g+3834>>1]=e;e=e>>>0<6720?e:13440-e|0;w[g+3836>>1]=e>>>8;if(!y[g+3843|0]){w[g+3836>>1]=e>>>10}e=z[g+3838>>1]+1|0;w[g+3838>>1]=e;if((e&65535)>>>0>=1024){w[g+3838>>1]=0;w[g+3840>>1]=z[g+3840>>1]+1&7}ib=c+16|0}else{f=g+D(q,44)|0;Ad:{if(!y[f+56|0]){w[c+12>>1]=0;w[c+14>>1]=0;break Ad}l=x[f+32>>2];e=z[l+3840>>1];if(e&3){l=(z[f+36>>1]>>>7&7)>>>(y[l+3844|0]^1)>>>(e&1)<<z[f+38>>1];e=e&4?0-l|0:l}else{e=0}l=x[f+52>>2];Bd:{if(l){t=z[l+32>>1];s=z[f+48>>1];l=og(x[f+16>>2],x[f+40>>2],e<<16>>16,0,w[f+46>>1]);n=x[f+40>>2];r=x[f+20>>2];if(!t){if(!s){e=e<<16>>16;l=og(r,n,e,l,0);l=og(x[f+24>>2],x[f+40>>2],e,l,0);e=og(x[f+28>>2],x[f+40>>2],e,l,0);break Bd}e=e<<16>>16;n=og(r,n,e,0,0);n=og(x[f+24>>2],x[f+40>>2],e,n,0);e=og(x[f+28>>2],x[f+40>>2],e,n,0)+l|0;break Bd}if(!s){e=e<<16>>16;l=og(r,n,e,l,0);n=og(x[f+24>>2],x[f+40>>2],e,0,0);e=og(x[f+28>>2],x[f+40>>2],e,n,0)+l|0;break Bd}e=e<<16>>16;n=og(r,n,e,0,0);e=(og(x[f+24>>2],x[f+40>>2],e,n,0)+l|0)+og(x[f+28>>2],x[f+40>>2],e,0,0)|0;break Bd}s=z[f+48>>1];e=e<<16>>16;l=og(x[f+16>>2],x[f+40>>2],e,0,w[f+46>>1]);n=x[f+40>>2];r=x[f+20>>2];if(!s){e=og(r,n,e,l,0);break Bd}e=og(r,n,e,0,0)+l|0}w[c+14>>1]=y[f+57|0]?e:0;w[c+12>>1]=y[f+58|0]?e:0}q=q+1|0;i=w[c+12>>1]+i|0;h=w[c+14>>1]+h|0;continue}break}h=x[g>>2];c=x[g+4>>2]-h|0;x[g+4>>2]=c;continue}break}e=h-c|0;w[o+14>>1]=(D(w[g+12>>1],c)+D(e,w[g+8>>1])|0)/(h|0);w[o+12>>1]=(D(w[g+14>>1],c)+D(e,w[g+10>>1])|0)/(h|0);x[g+4>>2]=c+49716;x[a>>2]=x[a>>2]+D(m,w[o+14>>1]);x[a+4>>2]=x[a+4>>2]+D(m,w[o+12>>1]);a=a+8|0;b=b-1|0;continue}}ib=o+16|0}a=y[I+12|0];if(a|x[I+16>>2]){if(!a){bn($,k,sa,ra)}a=x[I>>2];b=x[I+80>>2];c=D(a,b)>>>4|0;c=c>>>0>=32767?32767:c;w[I+98>>1]=c;w[I+96>>1]=c;c=x[I+49948>>2];e=D(c,a)>>>4|0;e=e>>>0>=65536?65536:e;h=e+127>>>3|0;w[I+49946>>1]=h;e=e+255>>>4|0;w[I+49944>>1]=e;w[I+49942>>1]=e;w[I+49940>>1]=h;b=(b|0)>(c|0)?b:c;a=36-a>>>1|0;a=16-(a>>>0<=8?8:a)|0;a=16-(D((b|0)>=32768?32768:b,a>>>0<=16?a:0)>>15)|0;q=0;while(1){if((k|0)!=(q|0)){b=q<<3;c=b+Z|0;x[c>>2]=x[c>>2]+D(a,x[b+$>>2]>>4);b=b|4;c=b+Z|0;x[c>>2]=x[c>>2]+D(a,x[b+$>>2]>>4);q=q+1|0;continue}break}l=I+68|0;o=0;b=w[I+84>>1];c=x[I+40>>2];h=x[I+36>>2];while(1){if((k|0)==(o|0)){x[I+40>>2]=c;x[I+36>>2]=h;f=k}else{a=(o<<3)+$|0;e=x[a>>2]>>12;h=(D(b,e-h|0)>>15)+e|0;x[a>>2]=h;e=a;a=x[a+4>>2]>>12;c=(D(b,a-c|0)>>15)+a|0;x[e+4>>2]=c;o=o+1|0;continue}break}if(f){b=$;a=f;n=x[l>>2]-1|0;s=z[l+22>>1];c=z[l+20>>1];e=w[l+26>>1];h=w[l+24>>1];r=w[l+18>>1];j=w[l+16>>1];q=x[l+4>>2];g=l+32928|0;while(1){if(a){i=id(x[b>>2]);o=id(x[b+4>>2]);c=id((c<<16>>16)-i|0);m=id((s<<16>>16)-o|0);c=dd(id((D(c,j)|0)/65536<<1)+i|0);s=dd(id((D(m,r)|0)/65536<<1)+o|0);o=g+(q<<2)|0;m=w[o>>1];i=dd(((D(m,h)|0)/-65536|0)+c|0);q=q+1&127;t=g+(q<<2)|0;o=w[o+2>>1];u=dd(((D(o,e)|0)/-65536|0)+s|0);w[t+2>>1]=u;w[t>>1]=i;n=n+1&8191;t=l+(n<<2)|0;Xa=t,Ya=dd(m+((D(h,i)|0)/65536|0)|0),w[Xa+160>>1]=Ya;Xa=t,Ya=dd(o+((D(e,u)|0)/65536|0)|0),w[Xa+162>>1]=Ya;b=b+8|0;a=a-1|0;continue}break}w[l+22>>1]=s;w[l+20>>1]=c;x[l+4>>2]=q}i=I+49892|0;J=I+33508|0;b=f;a=$;while(1){if(b){e=x[I+76>>2];h=e&4095;s=J+(h<<2)|0;c=a;h=4096-h|0;t=e-x[I+49892>>2]&4095;e=4096-t|0;e=e>>>0>h>>>0?h:e;e=b>>>0<e>>>0?b:e;h=e>>>0>=64?64:e;q=h;e=0;r=ib-32|0;ib=r;g=x[l>>2];while(1){if((e|0)==7){Cd:{j=w[l+28>>1]/8<<16>>16;Dd:while(1){if(!q){break Cd}q=q-1|0;e=0;o=0;g=0;while(1)if((e|0)==4){e=4;n=0;u=dd((g|0)/32768|0);C=dd((o|0)/32768|0);o=0;while(1)if((e|0)==7){e=dd(u+((o|0)/32768|0)|0);w[s>>1]=e;x[c>>2]=D(e,j);e=dd(C+((n|0)/32768|0)|0);w[s+2>>1]=e;x[c+4>>2]=D(e,j);c=c+8|0;s=s+4|0;continue Dd}else{g=r+(e<<2)|0;m=x[g>>2]+1&8191;x[g>>2]=m;V=n;n=l+(m<<2)|0;m=w[n+160>>1];g=l+(e<<4)|0;H=w[n+162>>1];n=(V+D(m,w[g+44>>1])|0)+D(H,w[g+46>>1])|0;o=(D(m,w[g+40>>1])+o|0)+D(H,w[g+42>>1])|0;e=e+1|0;continue}}else{n=r+(e<<2)|0;m=x[n>>2]+1&8191;x[n>>2]=m;V=o;o=l+(m<<2)|0;m=w[o+160>>1];n=l+(e<<4)|0;u=w[o+162>>1];o=(V+D(m,w[n+44>>1])|0)+D(u,w[n+46>>1])|0;g=(D(m,w[n+40>>1])+g|0)+D(u,w[n+42>>1])|0;e=e+1|0;continue}}}}else{x[r+(e<<2)>>2]=g+(x[(l+(e<<4)|0)+32>>2]^-1);e=e+1|0;continue}break}ib=r+32|0;q=J+(t<<2)|0;e=a;c=h;g=x[i+4>>2];o=i+8256|0;n=i- -64|0;r=i+24640|0;j=i+16448|0;while(1){m=g&2047;if(c){H=w[o+((g+1206&2047)<<2)>>1];G=w[(o+((g+754&2047)<<2)|0)+2>>1];C=w[(n+((g+1602&2047)<<2)|0)+2>>1];L=w[n+((g+1750&2047)<<2)>>1];s=w[q>>1];t=w[q+2>>1];u=r+((g+502&2047)<<2)|0;K=w[u>>1];Q=id(w[i+32>>1]-K|0);u=w[u+2>>1];O=id(w[i+34>>1]-u|0);T=w[i+26>>1];R=r+((g+22&2047)<<2)|0;X=w[R>>1];N=id(w[i+36>>1]-X|0);Y=w[i+28>>1];R=w[R+2>>1];V=id(w[i+38>>1]-R|0);_=w[i+30>>1];K=dd(id((D(Q,w[i+24>>1])|0)/65536<<1)+K|0);w[i+32>>1]=K;Xa=i,Ya=dd(id((D(O,T)|0)/65536<<1)+u|0),w[Xa+34>>1]=Ya;Xa=i,Ya=dd(id((D(N,Y)|0)/65536<<1)+X|0),w[Xa+36>>1]=Ya;u=dd(id((D(V,_)|0)/65536<<1)+R|0);w[i+38>>1]=u;K=id((D(K,w[i+16>>1])|0)/32768|0);u=id((D(u,w[i+22>>1])|0)/32768|0);K=id(K+((s|0)/4<<16>>16)|0);Q=id(u+((t|0)/4<<16>>16)|0);s=w[i+8>>1];O=id(K+((D(s,L)|0)/-65536|0)|0);t=m<<2;T=t+n|0;u=w[i+10>>1];R=id(Q+((D(u,C)|0)/-65536|0)|0);w[T+2>>1]=R;w[T>>1]=O;L=id(L+((D(s,O)|0)/65536|0)|0);O=j+t|0;C=id(C+((D(u,R)|0)/65536|0)|0);w[O+2>>1]=C;w[O>>1]=L;L=id(L+K|0);K=id(C+Q|0);C=j+((g+682&2047)<<2)|0;Q=w[C+2>>1];O=w[C>>1];C=id((D(Q,w[i+42>>1])+D(O,w[i+40>>1])|0)/32768|0);g=j+((g+426&2047)<<2)|0;T=w[g+2>>1];R=w[g>>1];g=id((D(T,w[i+46>>1])+D(R,w[i+44>>1])|0)/32768|0);O=id(id(L+O|0)-C|0);Q=id(id(K+Q|0)-g|0);L=id(id(L+R|0)-C|0);K=id(id(K+T|0)-g|0);C=id(C+((D(s,H)|0)/-65536|0)|0);T=o+t|0;R=id(g+((D(u,G)|0)/-65536|0)|0);w[T+2>>1]=R;w[T>>1]=C;s=(D(s,C)|0)/65536|0;g=id(s+H|0);t=t+r|0;u=(D(u,R)|0)/65536|0;C=id(u+G|0);w[t+2>>1]=C;w[t>>1]=g;Xa=e,Ya=(x[e>>2]+D(id(g+O|0),w[i+48>>1])|0)+D(id(C+Q|0),w[i+50>>1])|0,x[Xa>>2]=Ya;Xa=e,Ya=(x[e+4>>2]+D(id(id(s)+L|0),w[i+52>>1])|0)+D(id(id(u)+K|0),w[i+54>>1])|0,x[Xa+4>>2]=Ya;e=e+8|0;g=m+1|0;q=q+4|0;c=c-1|0;continue}break}x[i+4>>2]=m;x[I+76>>2]=h+x[I+76>>2]&4095;x[I+68>>2]=h+x[I+68>>2]&8191;b=b-h|0;a=(h<<3)+a|0;continue}break}x[I+68>>2]=x[I+68>>2]&8191;o=$;e=Z;c=f;h=0;g=0;i=x[I+56>>2];b=x[I- -64>>2];q=x[I+52>>2];a=x[I+60>>2];while(1){if(c){h=x[o>>2];g=x[o+4>>2];b=b-g|0;b=(((b|0)/1024|0)-b|0)+i|0;x[e+4>>2]=b+x[e+4>>2];a=a-h|0;a=(((a|0)/1024|0)-a|0)+q|0;x[e>>2]=a+x[e>>2];i=b+((b|0)/-512|0)|0;q=a+((a|0)/-512|0)|0;e=e+8|0;o=o+8|0;c=c-1|0;a=h;b=g;continue}break}x[I+64>>2]=g;x[I+60>>2]=h;x[I+56>>2]=i;x[I+52>>2]=q;a=x[I+20>>2];Ed:{if(y[I+12|0]){break Ed}a=x[I+16>>2];if(a>>>0>f>>>0){a=a-f|0;break Ed}IM(I,sa,ra);a=0}v[I+12|0]=0;x[I+16>>2]=a}if(x[d+946300>>2]){Fd:{g=0;e=0;h=k<<2;j=d+906300|0;s=z[d+480214>>1]!=0;Ca=B[d+1074336>>2];W=B[d+1074332>>2];while(1)if((g|0)==250){h=d+12|0;l=d+12300|0;n=d+14348|0;Ov(h,l,n,k,W);a=d+1074476|0;u=y[a|0];v[a|0]=0;a=n;c=l;while(1){Gd:{Hd:{Id:{if((e|0)!=250){r=Nd(j,e);o=x[r>>2];if(!o|!x[o+24>>2]){break Gd}if(!fi(o+44|0)){break Gd}i=o;Jd:{if(Wo(y[r+24|0])){break Jd}b=lb[x[x[o>>2]+148>>2]](o)|0;i=x[r>>2];if(b){break Jd}g=0;if(y[i+28|0]&2){break Jd}while(1){if((e|0)==(g|0)){break Gd}b=Nd(j,g);g=g+1|0;if(($m(x[b+28>>2])|0)!=(e|0)){continue}break}}b=x[o+44>>2];q=Hc(b,0);t=Hc(b,1);m=(c|0)==(q|0);c=m?l:c;b=c;a=m?n:a;g=x[r+28>>2];f=a;Kd:{if(!g){break Kd}b=c;g=$m(g);f=a;if(g>>>0<=e>>>0){break Kd}f=a;if(g>>>0>249){break Kd}g=x[Nd(j,g)>>2];f=a;if(!g){break Kd}if(!(y[i+28|0]&4)){lb[x[x[g>>2]+152>>2]](g)}f=a;if(!fi(g+44|0)){break Kd}f=x[g+44>>2];b=Hc(f,0);f=Hc(f,1)}if(!Wo(y[r+24|0])){break Hd}g=0;Ld:{if(m){break Ld}while(1){if((g|0)==(k|0)){break Ld}m=g<<2;C=m+q|0;J=c+m|0;B[C>>2]=B[J>>2]+B[C>>2];C=m+t|0;m=a+m|0;B[C>>2]=B[m>>2]+B[C>>2];x[J>>2]=0;x[m>>2]=0;g=g+1|0;continue}}a=f;c=b;if(!(s&1)){break Hd}a=x[r>>2];if(a){lb[x[x[a>>2]+152>>2]](a)}g=$m(x[r+28>>2]);a=e;while(1){c=g;g=c&255;if(g>>>0>249|g>>>0<=(a&255)>>>0){break Id}m=Nd(j,g);g=$m(x[m+28>>2]);a=c;c=x[m>>2];if(!c){continue}lb[x[x[c>>2]+152>>2]](c);continue}}b=0;while(1){if((b|0)!=(k|0)){W=E(B[c>>2]*Ca);Md:{if(E(F(W))<E(2147483648)){e=~~W;break Md}e=-2147483648}x[h>>2]=e;W=E(B[a>>2]*Ca);Nd:{if(E(F(W))<E(2147483648)){e=~~W;break Nd}e=-2147483648}x[h+4>>2]=e;b=b+1|0;h=h+8|0;a=a+4|0;c=c+4|0;continue}break}break Fd}a=f;c=b}g=0;Od:{Pd:{m=y[r+24|0];if(!KD(m)){if(!JD(m)|!(y[i+28|0]&4)){break Pd}}while(1){if((g|0)==(k|0)){break Od}o=g<<2;r=o+b|0;B[r>>2]=B[o+q>>2]+B[r>>2];r=f+o|0;B[r>>2]=B[o+t>>2]+B[r>>2];g=g+1|0;continue}}if(u){lb[x[x[o>>2]+132>>2]](o)}lb[x[x[o>>2]+60>>2]](o,b,f,k);x[i+32>>2]=k+x[i+32>>2];if(!JD(y[r+24|0])){break Od}if((lb[x[x[o>>2]+160>>2]](o)|0)<=0|A[i+32>>2]<x[d+24620>>2]<<2>>>0){break Od}Qd:{while(1){if((g|0)==(k|0)){break Qd}o=g<<2;W=B[o+b>>2];Rd:{if(W>=E(1.1920928955078125e-7)|W<=E(-1.1920928955078125e-7)){break Rd}W=B[f+o>>2];if(W>=E(1.1920928955078125e-7)){break Rd}g=g+1|0;if(!(W<=E(-1.1920928955078125e-7))){continue}}break}x[i+32>>2]=0;break Od}x[i+28>>2]=x[i+28>>2]|4}x[i+28>>2]=x[i+28>>2]&-3}e=e+1|0;continue}}else{f=Nd(j,g);a=x[f>>2];Sd:{if(!a|!x[a+24>>2]){break Sd}if(!fi(a+44|0)){break Sd}if(!(lb[x[x[a>>2]+116>>2]](a)|0)){lb[x[x[a>>2]+112>>2]](a,1);lb[x[x[a>>2]+124>>2]](a)}c=x[a+44>>2];b=Hc(c,0);c=Hc(c,1);Td:{if(v[a+28|0]&1){Ov(x[a+24>>2],b,c,k,W);break Td}i=a+40|0;if(x[i>>2]|x[a+36>>2]){bn(x[a+24>>2],k,i,a+36|0);Ov(x[a+24>>2],b,c,k,W);break Td}Rb(b,0,h);Rb(c,0,h)}b=a;a=x[a+28>>2];x[b+28>>2]=a&-2;if(Wo(y[f+24|0])){break Sd}s=!(a&4)|s}g=g+1|0;continue}}}if(x[d+24624>>2]==1){b=0;while(1){if((b|0)!=(k|0)){a=(b<<3)+Z|0;x[(b<<2)+Z>>2]=(x[a+4>>2]+x[a>>2]|0)/2;b=b+1|0;continue}break}}if(Qd(y[Ia|0])){c=0;h=ib-16|0;ib=h;Ud:{if(!x[d+1074376>>2]){o=d+1074460|0;a=o;x[a>>2]=0;x[a+4>>2]=0;a=x[d+1074456>>2];x[d+1074468>>2]=a;break Ud}a=x[d+1074456>>2];b=x[d+1074468>>2];Vd:{if((a|0)==(b|0)){e=x[d+1074460>>2];break Vd}x[d+1074468>>2]=a;e=x[d+24620>>2];f=d+1074460|0;Wd:{if((a|0)>(b|0)){e=St(e,x[d+24636>>2]);break Wd}e=St(e,x[d+24640>>2])}x[f>>2]=e;x[d+1074464>>2]=e;b=a}o=d+1074460|0;if((e|0)<=0){break Ud}b=(b<<12)-x[d+1074472>>2]|0;c=(b|0)/(e|0)|0;if(y[d+1074368|0]!=2){break Ud}x[h+12>>2]=50;f=x[d+1074464>>2];x[h+8>>2]=1e4/(f+1|0);g=x[Ve(h+12|0,h+8|0)>>2];while(1){i=c>>31;if((g|0)>=((i^c)-i|0)){break Ud}e=e+f|0;x[o>>2]=e;c=(b|0)/(e|0)|0;continue}}Xd:{Yd:{switch(x[d+24624>>2]-1|0){case 0:b=0;g=(k|0)>0?k:0;i=a<<12;e=d+12|0;l=a>>31;while(1){if((b|0)==(g|0)){break Xd}Zd:{if(x[o>>2]>0){f=x[d+1074472>>2]+c|0;x[d+1074472>>2]=f;n=x[e>>2];Xa=e,Ya=Dc(roa(qoa(n,n>>31,f,f>>31),kb,1048576,0),kb),x[Xa>>2]=Ya;x[d+1074460>>2]=x[d+1074460>>2]-1;break Zd}f=x[e>>2];Xa=e,Ya=Dc(roa(qoa(f,f>>31,a,l),kb,256,0),kb),x[Xa>>2]=Ya;x[d+1074472>>2]=i}b=b+1|0;e=e+4|0;continue};case 1:b=0;i=(k|0)>0?k:0;l=a<<12;e=d+12|0;f=a>>31;while(1){if((b|0)==(i|0)){break Xd}_d:{if(x[o>>2]>0){g=x[d+1074472>>2]+c|0;x[d+1074472>>2]=g;n=x[e>>2];Xa=e,Ya=Dc(roa(qoa(n,n>>31,g,g>>31),kb,1048576,0),kb),x[Xa>>2]=Ya;g=x[d+1074472>>2];r=g;n=g>>31;g=x[e+4>>2];Xa=e,Ya=Dc(roa(qoa(r,n,g,g>>31),kb,1048576,0),kb),x[Xa+4>>2]=Ya;x[d+1074460>>2]=x[d+1074460>>2]-1;break _d}g=x[e>>2];Xa=e,Ya=Dc(roa(qoa(g,g>>31,a,f),kb,256,0),kb),x[Xa>>2]=Ya;g=x[e+4>>2];Xa=e,Ya=Dc(roa(qoa(g,g>>31,a,f),kb,256,0),kb),x[Xa+4>>2]=Ya;x[d+1074472>>2]=l}b=b+1|0;e=e+8|0;continue};case 3:break Yd;default:break Xd}}g=0;l=(k|0)>0?k:0;n=a<<12;e=d+8204|0;b=d+12|0;f=a>>31;while(1){if((g|0)==(l|0)){break Xd}$d:{if(x[o>>2]>0){i=x[d+1074472>>2]+c|0;x[d+1074472>>2]=i;r=x[b>>2];Xa=b,Ya=Dc(roa(qoa(r,r>>31,i,i>>31),kb,1048576,0),kb),x[Xa>>2]=Ya;i=x[d+1074472>>2];r=i;j=i>>31;i=x[b+4>>2];Xa=b,Ya=Dc(roa(qoa(r,j,i,i>>31),kb,1048576,0),kb),x[Xa+4>>2]=Ya;i=x[d+1074472>>2];r=i;j=i>>31;i=x[e>>2];Xa=e,Ya=Dc(roa(qoa(r,j,i,i>>31),kb,1048576,0),kb),x[Xa>>2]=Ya;i=x[d+1074472>>2];r=i;j=i>>31;i=x[e+4>>2];Xa=e,Ya=Dc(roa(qoa(r,j,i,i>>31),kb,1048576,0),kb),x[Xa+4>>2]=Ya;x[d+1074460>>2]=x[d+1074460>>2]-1;break $d}i=x[b>>2];Xa=b,Ya=Dc(roa(qoa(i,i>>31,a,f),kb,256,0),kb),x[Xa>>2]=Ya;i=x[b+4>>2];Xa=b,Ya=Dc(roa(qoa(i,i>>31,a,f),kb,256,0),kb),x[Xa+4>>2]=Ya;i=x[e>>2];Xa=e,Ya=Dc(roa(qoa(i,i>>31,a,f),kb,256,0),kb),x[Xa>>2]=Ya;i=x[e+4>>2];Xa=e,Ya=Dc(roa(qoa(i,i>>31,a,f),kb,256,0),kb),x[Xa+4>>2]=Ya;x[d+1074472>>2]=n}g=g+1|0;e=e+8|0;b=b+8|0;continue}}ib=h+16|0}if(x[pa>>2]!=128){b=d+12|0;c=d+8204|0;a=x[d+24604>>2];e=x[d+24624>>2];ae:{if((a|0)==128|e>>>0<2){break ae}xO(b,k,a);if(e>>>0<4){break ae}xO(c,k,a)}}if(x[d+24624>>2]==4){a=k;while(1){a=a-1|0;if((a|0)>=0){b=(a<<4)+Z|0;c=a<<3;e=c|4;x[b+12>>2]=x[e+qa>>2];x[b+8>>2]=x[c+qa>>2];x[b+4>>2]=x[e+Z>>2];x[b>>2]=x[c+Z>>2];continue}break}}if(Qd(Ea)){a=x[d+24624>>2];x[M+72>>2]=k;x[M+68>>2]=a;x[M+64>>2]=Z;a=x[x[na>>2]+8>>2];x[M+24>>2]=k;b=x[M+68>>2];x[M+16>>2]=x[M+64>>2];x[M+20>>2]=b;lb[a|0](na,M+16|0)}a=x[d+24624>>2];x[M+56>>2]=k;x[M+52>>2]=a;x[M+48>>2]=Z;a=x[x[ma>>2]+8>>2];x[M+8>>2]=k;b=x[M+52>>2];x[M>>2]=x[M+48>>2];x[M+4>>2]=b;lb[a|0](ma,M);x[d+1074380>>2]=x[d+1074380>>2]-k;x[d+1074376>>2]=k+x[d+1074376>>2];ga=ga-k|0;Da=k+Da|0;continue}break}ib=ca+32|0;return Da}function Eg(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=E(0),k=0,m=0,o=0,q=0,s=0,t=0,u=E(0),G=0,H=0,I=E(0),J=0,K=0,L=0,M=0,N=0;k=ib-2288|0;ib=k;a:{b:{c:{d:{e:{f:{if(Qv(x[c>>2])){wc(b,268435456);K=x[c+8>>2];H=k+2264|0;e=H;x[e>>2]=0;x[e+4>>2]=0;Nb(e+8|0);x[k+2260>>2]=0;g:{h:{i:{j:{k:{l:{e=y[a+3|0];m:{n:{if((e-4&255)>>>0<=4){x[27524]=0;d=T(206,c|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break l}x[k+2260>>2]=d;break n}if(e>>>0>17){break m}o:{g=1<<e;if(!(g&63503)){if(!(g&198144)){break m}break o}if(y[a|0]){break o}break n}e=0;f=yB(a,x[b>>2]);x[27524]=0;U(207,k+96|0,c|0,f|0);f=x[27524];x[27524]=0;if((f|0)==1){break k}d=k+96|0;f=x[d+4>>2];x[H>>2]=x[d>>2];x[H+4>>2]=f;Om(H+8|0,d+8|0);Rc(d);f=Le(H);d=x[H>>2];x[k+2260>>2]=d;if(!f){break g}}e=y[a+3|0]}h=1;p:{q:{switch(e&255){case 0:case 1:case 2:case 3:case 11:case 12:case 13:case 14:case 15:h=!y[a|0];break p;case 9:case 10:case 16:case 17:break q;default:break p}}h=0}g=x[b>>2];if(!(g>>>0<262145|h)){e=e&255;x[k+96>>2]=((e|0)==10)<<4;h=d-x[Hb(k+96|0,k+2260|0)>>2]|0;if(e>>>0>15){break j}r:{if(!(1<<e&63503)){if((e|0)==10){break r}break j}if(!(y[a|0]&7)){break j}}e=(h|0)<0?-1:h<<1;break i}e=e&255;if(e>>>0>8){break h}if(!(1<<e&432)){if((e|0)!=6){break h}e=0;if(d>>>0<10){break g}x[27524]=0;Q(192,c|0,4)|0;d=x[27524];x[27524]=0;if((d|0)==1){break l}x[27524]=0;e=T(161,c|0)|0;d=x[27524];x[27524]=0;if((d|0)!=1){x[k+96>>2]=e;x[k+72>>2]=x[k+2260>>2];d=x[Hb(k+96|0,k+72|0)>>2];Gg(c,8);e=((d>>>0>50529027?-1:D(d,85))>>>0)/(y[a|0]>>>3>>>0)|0;break i}a=P()|0;break a}e=8/(Bq(y[a+1|0])>>>0)|0;qoa(e,0,d,0);e=kb?-1:D(e,d);break i}a=P()|0;break a}a=P()|0;break a}g=0;d=Bq(y[a+1|0]);s:{t:{switch(e|0){case 0:case 1:case 2:case 3:case 11:case 12:case 13:case 14:case 15:g=y[a|0];break s;case 9:g=16;break s;case 10:g=4;break s;case 16:case 17:break t;default:break s}}g=8}e=D(d,g&255)>>>3|0;d=(e+h|0)-1|0;e=((d>>>0<h>>>0?-1:d)>>>0)/(e>>>0)|0}wc(b,e);g=x[b>>2]}if(!g){e=0;break g}w[b+34>>1]=z[b+34>>1]&65470|y[a|0]>15|(y[a+1|0]!=1)<<6;if(!Xg(b)){e=0;x[b>>2]=0;break g}u:{if(qe(a,Zc(k+96|0,8,1,0,10))){x[27524]=0;d=Q(208,c|0,k+96|0)|0;a=x[27524];x[27524]=0;if((a|0)!=1){e=0;if(!d){break u}a=x[b>>2];d=0;x[27524]=0;x[k+72>>2]=a+1>>>1;e=T(206,c|0)|0;a=x[27524];x[27524]=0;if((a|0)==1){break b}wc(k+72|0,e);a=f+16|0;b=x[b+20>>2];h=x[k+72>>2];e=h;while(1)if(e){g=k+96|0;f=d+y[g|y[a|0]&15]|0;v[b|0]=f;d=y[g|y[a|0]>>>4]+(f&255)|0;v[b+1|0]=d;e=e-1|0;a=a+1|0;b=b+2|0;continue}else{e=h+16|0;break u}}a=P()|0;break a}v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{g=y[a+3|0];switch(g-4|0){case 3:break D;case 4:break E;case 5:break F;case 2:break G;case 0:case 1:break H;default:break B}}x[27524]=0;b=fa(209,k+1168|0,c|0,b|0,(g|0)==5|0)|0;a=x[27524];x[27524]=0;if((a|0)==1){break f}yb(b);e=x[c+8>>2]-K|0;break u}if(y[a+1|0]!=1){break C}x[27524]=0;Q(192,c|0,4)|0;a=x[27524];x[27524]=0;if((a|0)==1){break f}x[27524]=0;f=T(161,c|0)|0;a=x[27524];x[27524]=0;I:{J:{K:{if((a|0)!=1){x[27524]=0;x[k+72>>2]=f;h=T(210,c|0)|0;a=x[27524];x[27524]=0;if((a|0)==1){break K}x[27524]=0;U(211,k+96|0,c|0,f|0);a=x[27524];x[27524]=0;if((a|0)==1){break J}wc(k+72|0,x[k+96>>2]);g=x[k+72>>2];e=Le(k+96|0);d=z[b+34>>1];f=x[b+20>>2];b=x[b>>2];a=x[k+96>>2];x[27524]=0;ea(212,e|0,a|0,f|0,Nj(b,d)|0,h<<24>>24);a=x[27524];x[27524]=0;if((a|0)==1){break I}e=g+9|0;Rc(k+96|0);break u}a=P()|0;break a}a=P()|0;break a}a=P()|0;break a}a=P()|0;Rc(k+96|0);break a}if(y[a+1|0]!=1|y[a|0]!=16){break C}e=x[k+2260>>2];d=Kk(k+1160|0);a=x[b>>2];b=x[b+20>>2];g=z[d>>1];h=ib-16|0;ib=h;x[h+12>>2]=e>>>1;x[h+8>>2]=a;d=x[Hb(h+12|0,h+8|0)>>2];e=d;while(1){if(e){a=y[f|0]+g|0;g=a+y[f+1|0]|0;w[b>>1]=g<<8|a&255;b=b+2|0;f=f+2|0;e=e-1|0;continue}break}ib=h+16|0;e=d<<1;break u}if(y[a+1|0]!=1|y[a|0]>16){break C}d=x[c+8>>2];f=x[c>>2];e=0;x[27524]=0;d=W(160,f|0,d|0,8)|0;f=x[27524];x[27524]=0;if((f|0)==1){break f}if(!d){break u}x[27524]=0;d=T(161,c|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break f}x[k+2260>>2]=d;if(d>>>0<4){break u}x[27524]=0;U(194,k+72|0,c|0,d|0);f=x[27524];x[27524]=0;if((f|0)==1){break c}f=k+72|0;t=zr(k+96|0,f);yb(f);f=x[t>>2];x[27524]=0;d=T(213,f|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break e}e=d+4|0;q=y[a|0];m=(q|0)!=16;g=0;h=0;while(1){if(A[b>>2]<=h>>>0){break w}L:{if(m){break L}x[27524]=0;s=Q(168,t|0,8)|0;a=x[27524];x[27524]=0;if((a|0)!=1){break L}a=V(30496)|0;break x}x[27524]=0;i=Q(168,t|0,1)|0;a=x[27524];x[27524]=0;if((a|0)==1){break y}x[27524]=0;f=Q(168,t|0,1)|0;a=x[27524];x[27524]=0;if((a|0)==1){break y}M:{N:{O:{if(!f){f=8;while(1){x[27524]=0;d=Q(168,t|0,1)|0;a=x[27524];x[27524]=0;if((a|0)==1){break M}if(d){break O}f=f+16|0;continue}}x[27524]=0;a=Q(168,t|0,3)|0;f=x[27524];x[27524]=0;if((f|0)!=1){break N}break y}x[27524]=0;d=Q(168,t|0,4)|0;a=x[27524];x[27524]=0;if((a|0)==1){break y}a=f+d|0}g=(g&255)+(((i?-1:0)^a)&255)|0;P:{if((q|0)!=16){v[x[b+20>>2]+h|0]=g;break P}w[x[b+20>>2]+(h<<1)>>1]=s&255|g<<8}h=h+1|0;continue}break}a=V(30496)|0;break x}if(y[a+1|0]!=1){break B}break A}if((g|0)!=7){break B}if(y[a+1|0]==1){break A}}e=y[a|0];break z}e=y[a|0];if(e>>>0>16){break z}e=0;if(A[k+2260>>2]<5){break u}d=z[b+34>>1];f=x[b+20>>2];a=x[b>>2];x[27524]=0;e=W(214,c|0,f|0,Nj(a,d)|0)|0;a=x[27524];x[27524]=0;if((a|0)!=1){break u}break f}Q:{if((g&254)!=16|(e&255)!=16){break Q}d=y[a+1|0];if((d-1&255)>>>0>1){break Q}L=k,M=D(x[b>>2],Bq(d)),x[L+96>>2]=M;wc(k+96|0,x[k+2260>>2]);a=x[b+20>>2];e=x[k+96>>2];if((g|0)==16){b=e;while(1){if(!b){break u}L=a,M=z[bc(30528,y[f|0])>>1],w[L>>1]=M;a=a+2|0;f=f+1|0;b=b-1|0;continue}}b=e;while(1){if(!b){break u}L=a,M=z[bc(31040,y[f|0])>>1],w[L>>1]=M;a=a+2|0;f=f+1|0;b=b-1|0;continue}}d=(e&255)!=8;if(!(d|y[a+1|0]!=1)){R:{switch(g|0){case 0:a=x[b>>2];b=x[b+20>>2];d=ib-16|0;ib=d;x[d+12>>2]=x[k+2260>>2];x[d+8>>2]=a;a=x[Hb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){v[b|0]=y[f|0];b=b+1|0;f=f+1|0;e=e-1|0;continue}break};ib=d+16|0;e=a;break u;case 1:a=x[b>>2];b=x[b+20>>2];d=ib-16|0;ib=d;x[d+12>>2]=x[k+2260>>2];x[d+8>>2]=a;a=x[Hb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){v[b|0]=y[f|0]^128;b=b+1|0;f=f+1|0;e=e-1|0;continue}break};ib=d+16|0;e=a;break u;default:e=0;if((g|0)!=11){break u}break;case 2:break R}}e=x[k+2260>>2];d=Kr(k- -64|0);a=x[b>>2];b=x[b+20>>2];g=y[d|0];d=ib-16|0;ib=d;x[d+12>>2]=e;x[d+8>>2]=a;a=x[Hb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){g=y[f|0]+g|0;v[b|0]=g;b=b+1|0;f=f+1|0;e=e-1|0;continue}break}ib=d+16|0;e=a;break u}if(!(y[a+1|0]!=3|d)){S:{switch(g|0){case 0:i=ib-16|0;ib=i;e=x[k+2260>>2];x[i+12>>2]=e;d=x[b>>2];x[i+8>>2]=d;a=i+8|0;g=x[Hb(a,i+12|0)>>2];x[i+8>>2]=d;x[i+4>>2]=e-g;e=x[Hb(a,i+4|0)>>2];h=x[b+20>>2];a=g;d=f;while(1){if(a){v[h|0]=y[d|0];h=h+2|0;d=d+1|0;a=a-1|0;continue}break};h=x[b+20>>2]+1|0;d=x[b>>2]+f|0;a=e;while(1){if(a){v[h|0]=y[d|0];h=h+2|0;d=d+1|0;a=a-1|0;continue}break};ib=i+16|0;e=e+g|0;break u;case 1:i=ib-16|0;ib=i;e=x[k+2260>>2];x[i+12>>2]=e;d=x[b>>2];x[i+8>>2]=d;a=i+8|0;g=x[Hb(a,i+12|0)>>2];x[i+8>>2]=d;x[i+4>>2]=e-g;e=x[Hb(a,i+4|0)>>2];h=x[b+20>>2];a=g;d=f;while(1){if(a){v[h|0]=y[d|0]^128;h=h+2|0;d=d+1|0;a=a-1|0;continue}break};h=x[b+20>>2]+1|0;d=x[b>>2]+f|0;a=e;while(1){if(a){v[h|0]=y[d|0]^128;h=h+2|0;d=d+1|0;a=a-1|0;continue}break};ib=i+16|0;e=e+g|0;break u;default:e=0;if((g|0)!=11){break u}break;case 2:break S}}h=x[k+2260>>2];e=y[Kr(k+56|0)|0];q=ib-16|0;ib=q;x[q+12>>2]=h;g=x[b>>2];x[q+8>>2]=g;d=q+8|0;i=x[Hb(d,q+12|0)>>2];x[q+8>>2]=g;x[q+4>>2]=h-i;h=x[Hb(d,q+4|0)>>2];m=b;s=x[b+20>>2];d=e;b=i;g=f;while(1){if(b){d=y[g|0]+d|0;v[s|0]=d;s=s+2|0;g=g+1|0;b=b-1|0;continue}break}s=x[m+20>>2]+1|0;g=x[m>>2]+f|0;b=h;while(1){if(b){e=y[g|0]+e|0;v[s|0]=e;s=s+2|0;g=g+1|0;b=b-1|0;continue}break}ib=q+16|0;e=h+i|0;if(y[a+3|0]!=11){break u}a=x[m+20>>2];b=a+(x[m>>2]<<1)|0;while(1){if(a>>>0>=b>>>0){break u}v[a+1|0]=y[a+1|0]+y[a|0];a=a+2|0;continue}}d=e&255;if(!((d|0)!=8|y[a+1|0]!=2)){e=0;T:{switch(g|0){case 0:a=x[b>>2];b=x[b+20>>2];d=ib-16|0;ib=d;x[d+12>>2]=x[k+2260>>2]>>>1;x[d+8>>2]=a;a=x[Hb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){v[b|0]=y[f|0];v[b+1|0]=y[f+1|0];b=b+2|0;f=f+2|0;e=e-1|0;continue}break};ib=d+16|0;e=a<<1;break u;case 1:a=x[b>>2];b=x[b+20>>2];d=ib-16|0;ib=d;x[d+12>>2]=x[k+2260>>2]>>>1;x[d+8>>2]=a;a=x[Hb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){v[b|0]=y[f|0]^128;v[b+1|0]=y[f+1|0]^128;b=b+2|0;f=f+2|0;e=e-1|0;continue}break};ib=d+16|0;e=a<<1;break u;case 2:break T;default:break u}}e=x[k+2260>>2];a=Kr(k+48|0);d=x[b>>2];g=x[b+20>>2];a=y[a|0];h=ib-16|0;ib=h;x[h+12>>2]=e>>>1;x[h+8>>2]=d;b=a;e=x[Hb(h+12|0,h+8|0)>>2];d=e;while(1){if(d){a=y[f|0]+a|0;v[g|0]=a;b=y[f+1|0]+b|0;v[g+1|0]=b;g=g+2|0;f=f+2|0;d=d-1|0;continue}break}ib=h+16|0;e=e<<1;break u}if(!(y[a+2|0]|((d|0)!=16|y[a+1|0]!=1))){U:{switch(g|0){case 0:a=x[b>>2];b=x[b+20>>2];d=ib-16|0;ib=d;x[d+12>>2]=x[k+2260>>2]>>>1;x[d+8>>2]=a;a=x[Hb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){w[b>>1]=y[f|0]|y[f+1|0]<<8;b=b+2|0;f=f+2|0;e=e-1|0;continue}break};ib=d+16|0;e=a<<1;break u;case 1:a=x[b>>2];b=x[b+20>>2];d=ib-16|0;ib=d;x[d+12>>2]=x[k+2260>>2]>>>1;x[d+8>>2]=a;a=x[Hb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){w[b>>1]=(y[f|0]|y[f+1|0]<<8)^32768;b=b+2|0;f=f+2|0;e=e-1|0;continue}break};ib=d+16|0;e=a<<1;break u;default:e=0;if((g|0)!=11){break u}break;case 2:break U}}e=x[k+2260>>2];d=Kk(k+40|0);a=x[b>>2];b=x[b+20>>2];g=z[d>>1];d=ib-16|0;ib=d;x[d+12>>2]=e>>>1;x[d+8>>2]=a;a=x[Hb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){g=(y[f|0]+g|0)+(y[f+1|0]<<8)|0;w[b>>1]=g;b=b+2|0;f=f+2|0;e=e-1|0;continue}break}ib=d+16|0;e=a<<1;break u}d=e&255;if(!((d|0)!=16|y[a+1|0]!=1|y[a+2|0]!=1)){e=0;V:{switch(g|0){case 0:a=x[b>>2];b=x[b+20>>2];g=ib-16|0;ib=g;x[g+12>>2]=x[k+2260>>2]>>>1;x[g+8>>2]=a;d=x[Hb(g+12|0,g+8|0)>>2];e=d;while(1){if(e){a=y[f|0]|y[f+1|0]<<8;w[b>>1]=a<<8|a>>>8;b=b+2|0;f=f+2|0;e=e-1|0;continue}break};ib=g+16|0;e=d<<1;break u;case 1:a=x[b>>2];b=x[b+20>>2];g=ib-16|0;ib=g;x[g+12>>2]=x[k+2260>>2]>>>1;x[g+8>>2]=a;d=x[Hb(g+12|0,g+8|0)>>2];e=d;while(1){if(e){a=y[f|0]|y[f+1|0]<<8;w[b>>1]=(a<<8|a>>>8)^32768;b=b+2|0;f=f+2|0;e=e-1|0;continue}break};ib=g+16|0;e=d<<1;break u;case 2:break V;default:break u}}e=x[k+2260>>2];d=Kk(k+32|0);a=x[b>>2];b=x[b+20>>2];g=z[d>>1];d=ib-16|0;ib=d;x[d+12>>2]=e>>>1;x[d+8>>2]=a;a=x[Hb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){g=(y[f+1|0]+g|0)+(y[f|0]<<8)|0;w[b>>1]=g;b=b+2|0;f=f+2|0;e=e-1|0;continue}break}ib=d+16|0;e=a<<1;break u}h=a;if(!(y[a+2|0]|((d|0)!=16|y[a+1|0]!=3))){W:{switch(g|0){case 0:m=ib-16|0;ib=m;d=x[k+2260>>2];x[m+12>>2]=d;i=x[b>>2]<<1;x[m+8>>2]=i;a=m+8|0;g=x[Hb(a,m+12|0)>>2];x[m+8>>2]=i;x[m+4>>2]=d-g;a=x[Hb(a,m+4|0)>>2];e=x[b+20>>2];h=g>>>1|0;g=h;d=f;while(1){if(g){w[e>>1]=y[d|0]|y[d+1|0]<<8;e=e+4|0;d=d+2|0;g=g-1|0;continue}break};e=f+i|0;d=x[b+20>>2]+2|0;a=a>>>1|0;g=a;while(1){if(g){w[d>>1]=y[e|0]|y[e+1|0]<<8;d=d+4|0;e=e+2|0;g=g-1|0;continue}break};ib=m+16|0;e=a+h<<1;break u;case 1:m=ib-16|0;ib=m;d=x[k+2260>>2];x[m+12>>2]=d;i=x[b>>2]<<1;x[m+8>>2]=i;a=m+8|0;g=x[Hb(a,m+12|0)>>2];x[m+8>>2]=i;x[m+4>>2]=d-g;a=x[Hb(a,m+4|0)>>2];e=x[b+20>>2];h=g>>>1|0;g=h;d=f;while(1){if(g){w[e>>1]=(y[d|0]|y[d+1|0]<<8)^32768;e=e+4|0;d=d+2|0;g=g-1|0;continue}break};e=f+i|0;d=x[b+20>>2]+2|0;a=a>>>1|0;g=a;while(1){if(g){w[d>>1]=(y[e|0]|y[e+1|0]<<8)^32768;d=d+4|0;e=e+2|0;g=g-1|0;continue}break};ib=m+16|0;e=a+h<<1;break u;default:e=0;if((g|0)!=11){break u}break;case 2:break W}}g=x[k+2260>>2];a=z[Kk(k+24|0)>>1];t=ib-16|0;ib=t;x[t+12>>2]=g;q=x[b>>2]<<1;x[t+8>>2]=q;d=t+8|0;e=x[Hb(d,t+12|0)>>2];x[t+8>>2]=q;x[t+4>>2]=g-e;m=x[Hb(d,t+4|0)>>2];g=b;d=x[g+20>>2];b=a;i=e>>>1|0;s=i;e=f;while(1){if(s){b=(y[e|0]+b|0)+(y[e+1|0]<<8)|0;w[d>>1]=b;d=d+4|0;e=e+2|0;s=s-1|0;continue}break}e=f+q|0;d=x[g+20>>2]+2|0;b=m>>>1|0;s=b;while(1){if(s){a=(y[e|0]+a|0)+(y[e+1|0]<<8)|0;w[d>>1]=a;d=d+4|0;e=e+2|0;s=s-1|0;continue}break}ib=t+16|0;e=b+i<<1;if(y[h+3|0]!=11){break u}a=x[g+20>>2];b=a+(x[g>>2]<<2)|0;while(1){if(a>>>0>=b>>>0){break u}w[a+2>>1]=z[a+2>>1]+z[a>>1];a=a+4|0;continue}}a=e&255;if(!((a|0)!=16|y[h+1|0]!=3|y[h+2|0]!=1)){e=0;X:{switch(g|0){case 0:q=ib-16|0;ib=q;d=x[k+2260>>2];x[q+12>>2]=d;m=x[b>>2]<<1;x[q+8>>2]=m;a=q+8|0;g=x[Hb(a,q+12|0)>>2];x[q+8>>2]=m;x[q+4>>2]=d-g;i=x[Hb(a,q+4|0)>>2];e=x[b+20>>2];h=g>>>1|0;g=h;d=f;while(1){if(g){a=y[d|0]|y[d+1|0]<<8;w[e>>1]=a<<8|a>>>8;e=e+4|0;d=d+2|0;g=g-1|0;continue}break};e=f+m|0;d=x[b+20>>2]+2|0;b=i>>>1|0;g=b;while(1){if(g){a=y[e|0]|y[e+1|0]<<8;w[d>>1]=a<<8|a>>>8;d=d+4|0;e=e+2|0;g=g-1|0;continue}break};ib=q+16|0;e=b+h<<1;break u;case 1:q=ib-16|0;ib=q;d=x[k+2260>>2];x[q+12>>2]=d;m=x[b>>2]<<1;x[q+8>>2]=m;a=q+8|0;g=x[Hb(a,q+12|0)>>2];x[q+8>>2]=m;x[q+4>>2]=d-g;i=x[Hb(a,q+4|0)>>2];e=x[b+20>>2];h=g>>>1|0;g=h;d=f;while(1){if(g){a=y[d|0]|y[d+1|0]<<8;w[e>>1]=(a<<8|a>>>8)^32768;e=e+4|0;d=d+2|0;g=g-1|0;continue}break};e=f+m|0;d=x[b+20>>2]+2|0;b=i>>>1|0;g=b;while(1){if(g){a=y[e|0]|y[e+1|0]<<8;w[d>>1]=(a<<8|a>>>8)^32768;d=d+4|0;e=e+2|0;g=g-1|0;continue}break};ib=q+16|0;e=b+h<<1;break u;case 2:break X;default:break u}}e=x[k+2260>>2];a=z[Kk(k+16|0)>>1];s=ib-16|0;ib=s;x[s+12>>2]=e;q=x[b>>2]<<1;x[s+8>>2]=q;d=s+8|0;g=x[Hb(d,s+12|0)>>2];x[s+8>>2]=q;x[s+4>>2]=e-g;m=x[Hb(d,s+4|0)>>2];e=b;h=x[b+20>>2];b=a;i=g>>>1|0;d=i;g=f;while(1){if(d){b=(y[g+1|0]+b|0)+(y[g|0]<<8)|0;w[h>>1]=b;h=h+4|0;g=g+2|0;d=d-1|0;continue}break}g=f+q|0;h=x[e+20>>2]+2|0;b=m>>>1|0;d=b;while(1){if(d){a=(y[g+1|0]+a|0)+(y[g|0]<<8)|0;w[h>>1]=a;h=h+4|0;g=g+2|0;d=d-1|0;continue}break}ib=s+16|0;e=b+i<<1;break u}if(!(y[h+2|0]|((a|0)!=16|y[h+1|0]!=2))){e=0;Y:{switch(g|0){case 0:a=x[b>>2];b=x[b+20>>2];d=ib-16|0;ib=d;x[d+12>>2]=x[k+2260>>2]>>>2;x[d+8>>2]=a;a=x[Hb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){w[b>>1]=y[f|0]|y[f+1|0]<<8;w[b+2>>1]=y[f+2|0]|y[f+3|0]<<8;b=b+4|0;f=f+4|0;e=e-1|0;continue}break};ib=d+16|0;e=a<<2;break u;case 1:a=x[b>>2];b=x[b+20>>2];d=ib-16|0;ib=d;x[d+12>>2]=x[k+2260>>2]>>>2;x[d+8>>2]=a;a=x[Hb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){w[b>>1]=(y[f|0]|y[f+1|0]<<8)^32768;w[b+2>>1]=(y[f+2|0]|y[f+3|0]<<8)^32768;b=b+4|0;f=f+4|0;e=e-1|0;continue}break};ib=d+16|0;e=a<<2;break u;case 2:break Y;default:break u}}e=x[k+2260>>2];a=Kk(k+8|0);d=x[b>>2];g=x[b+20>>2];a=z[a>>1];h=ib-16|0;ib=h;x[h+12>>2]=e>>>2;x[h+8>>2]=d;b=a;e=x[Hb(h+12|0,h+8|0)>>2];d=e;while(1){if(d){a=(y[f|0]+a|0)+(y[f+1|0]<<8)|0;w[g>>1]=a;b=(y[f+2|0]+b|0)+(y[f+3|0]<<8)|0;w[g+2>>1]=b;g=g+4|0;f=f+4|0;d=d-1|0;continue}break}ib=h+16|0;e=e<<2;break u}a=e&255;if(!((a|0)!=16|y[h+1|0]!=2|y[h+2|0]!=1)){e=0;Z:{switch(g|0){case 0:a=x[b>>2];b=x[b+20>>2];g=ib-16|0;ib=g;x[g+12>>2]=x[k+2260>>2]>>>2;x[g+8>>2]=a;d=x[Hb(g+12|0,g+8|0)>>2];e=d;while(1){if(e){a=y[f|0]|y[f+1|0]<<8;w[b>>1]=a<<8|a>>>8;a=y[f+2|0]|y[f+3|0]<<8;w[b+2>>1]=a<<8|a>>>8;b=b+4|0;f=f+4|0;e=e-1|0;continue}break};ib=g+16|0;e=d<<2;break u;case 1:a=x[b>>2];b=x[b+20>>2];g=ib-16|0;ib=g;x[g+12>>2]=x[k+2260>>2]>>>2;x[g+8>>2]=a;d=x[Hb(g+12|0,g+8|0)>>2];e=d;while(1){if(e){a=y[f|0]|y[f+1|0]<<8;w[b>>1]=(a<<8|a>>>8)^32768;a=y[f+2|0]|y[f+3|0]<<8;w[b+2>>1]=(a<<8|a>>>8)^32768;b=b+4|0;f=f+4|0;e=e-1|0;continue}break};ib=g+16|0;e=d<<2;break u;case 2:break Z;default:break u}}e=x[k+2260>>2];a=Kk(k);d=x[b>>2];g=x[b+20>>2];a=z[a>>1];h=ib-16|0;ib=h;x[h+12>>2]=e>>>2;x[h+8>>2]=d;b=a;e=x[Hb(h+12|0,h+8|0)>>2];d=e;while(1){if(d){a=(y[f+1|0]+a|0)+(y[f|0]<<8)|0;w[g>>1]=a;b=(y[f+3|0]+b|0)+(y[f+2|0]<<8)|0;w[g+2>>1]=b;g=g+4|0;f=f+4|0;d=d-1|0;continue}break}ib=h+16|0;e=e<<2;break u}if(!(g|y[h+1|0]!=1|(a|0)!=24)){a=x[b+20>>2];d=x[b>>2];b=x[k+2260>>2];if(!y[h+2|0]){g=ib-16|0;ib=g;x[g+12>>2]=(b>>>0)/3;x[g+8>>2]=d;b=x[Hb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){L=a,M=kd(y[f+1|0]<<16|y[f|0]<<8|y[f+2|0]<<24,16),w[L>>1]=M;a=a+2|0;f=f+3|0;e=e-1|0;continue}break}ib=g+16|0;e=D(b,3);break u}g=ib-16|0;ib=g;x[g+12>>2]=(b>>>0)/3;x[g+8>>2]=d;b=x[Hb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){L=a,M=kd(y[f+1|0]<<16|y[f+2|0]<<8|y[f|0]<<24,16),w[L>>1]=M;a=a+2|0;f=f+3|0;e=e-1|0;continue}break}ib=g+16|0;e=D(b,3);break u}a=e&255;if(!(g|y[h+1|0]!=2|(a|0)!=24)){a=x[b+20>>2];d=x[b>>2];b=x[k+2260>>2];if(!y[h+2|0]){g=ib-16|0;ib=g;x[g+12>>2]=(b>>>0)/6;x[g+8>>2]=d;b=x[Hb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){L=a,M=kd(y[f+1|0]<<16|y[f|0]<<8|y[f+2|0]<<24,16),w[L>>1]=M;L=a,M=kd(y[f+4|0]<<16|y[f+3|0]<<8|y[f+5|0]<<24,16),w[L+2>>1]=M;a=a+4|0;f=f+6|0;e=e-1|0;continue}break}ib=g+16|0;e=D(b,6);break u}g=ib-16|0;ib=g;x[g+12>>2]=(b>>>0)/6;x[g+8>>2]=d;b=x[Hb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){L=a,M=kd(y[f+1|0]<<16|y[f+2|0]<<8|y[f|0]<<24,16),w[L>>1]=M;L=a,M=kd(y[f+4|0]<<16|y[f+5|0]<<8|y[f+3|0]<<24,16),w[L+2>>1]=M;a=a+4|0;f=f+6|0;e=e-1|0;continue}break}ib=g+16|0;e=D(b,6);break u}if(!(g|y[h+1|0]!=1|(a|0)!=32)){a=x[b+20>>2];d=x[b>>2];b=x[k+2260>>2];if(!y[h+2|0]){g=ib-16|0;ib=g;x[g+12>>2]=b>>>2;x[g+8>>2]=d;b=x[Hb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){L=a,M=kd(y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24),16),w[L>>1]=M;a=a+2|0;f=f+4|0;e=e-1|0;continue}break}ib=g+16|0;e=b<<2;break u}g=ib-16|0;ib=g;x[g+12>>2]=b>>>2;x[g+8>>2]=d;b=x[Hb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){d=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);L=a,M=kd(d<<24|d<<8&16711680|(d>>>8&65280|d>>>24),16),w[L>>1]=M;a=a+2|0;f=f+4|0;e=e-1|0;continue}break}ib=g+16|0;e=b<<2;break u}a=e&255;if(!(g|y[h+1|0]!=2|(a|0)!=32)){a=x[b+20>>2];d=x[b>>2];b=x[k+2260>>2];if(!y[h+2|0]){g=ib-16|0;ib=g;x[g+12>>2]=b>>>3;x[g+8>>2]=d;b=x[Hb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){L=a,M=kd(y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24),16),w[L>>1]=M;L=a,M=kd(y[f+4|0]|y[f+5|0]<<8|(y[f+6|0]<<16|y[f+7|0]<<24),16),w[L+2>>1]=M;a=a+4|0;f=f+8|0;e=e-1|0;continue}break}ib=g+16|0;e=b<<3;break u}g=ib-16|0;ib=g;x[g+12>>2]=b>>>3;x[g+8>>2]=d;b=x[Hb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){d=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);L=a,M=kd(d<<24|d<<8&16711680|(d>>>8&65280|d>>>24),16),w[L>>1]=M;d=y[f+4|0]|y[f+5|0]<<8|(y[f+6|0]<<16|y[f+7|0]<<24);L=a,M=kd(d<<24|d<<8&16711680|(d>>>8&65280|d>>>24),16),w[L+2>>1]=M;a=a+4|0;f=f+8|0;e=e-1|0;continue}break}ib=g+16|0;e=b<<3;break u}if(!(g|y[h+1|0]!=1|(a|0)!=64)){a=x[b+20>>2];d=x[b>>2];b=x[k+2260>>2];if(!y[h+2|0]){g=ib-16|0;ib=g;x[g+12>>2]=b>>>3;x[g+8>>2]=d;b=x[Hb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){L=a,M=Vc(y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24),y[f+4|0]|y[f+5|0]<<8|(y[f+6|0]<<16|y[f+7|0]<<24),48),w[L>>1]=M;a=a+2|0;f=f+8|0;e=e-1|0;continue}break}ib=g+16|0;e=b<<3;break u}i=ib-16|0;ib=i;x[i+12>>2]=b>>>3;x[i+8>>2]=d;d=x[Hb(i+12|0,i+8|0)>>2];e=d;while(1){if(e){h=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);b=h<<24|h<<8&16711680;m=h>>>8|0;g=y[f+4|0]|y[f+5|0]<<8|(y[f+6|0]<<16|y[f+7|0]<<24);h=h>>>24|0;b=b|((m|g<<24)&65280|(h|g<<8)&255);L=a,M=Vc((m|(g&255)<<24)&-16777216|(h|(g&16777215)<<8)&16711680|(g>>>8&65280|g>>>24),b,48),w[L>>1]=M;a=a+2|0;f=f+8|0;e=e-1|0;continue}break}ib=i+16|0;e=d<<3;break u}a=e&255;if(!(g|y[h+1|0]!=2|(a|0)!=64)){a=x[b+20>>2];d=x[b>>2];b=x[k+2260>>2];if(!y[h+2|0]){g=ib-16|0;ib=g;x[g+12>>2]=b>>>4;x[g+8>>2]=d;b=x[Hb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){L=a,M=Vc(y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24),y[f+4|0]|y[f+5|0]<<8|(y[f+6|0]<<16|y[f+7|0]<<24),48),w[L>>1]=M;L=a,M=Vc(y[f+8|0]|y[f+9|0]<<8|(y[f+10|0]<<16|y[f+11|0]<<24),y[f+12|0]|y[f+13|0]<<8|(y[f+14|0]<<16|y[f+15|0]<<24),48),w[L+2>>1]=M;a=a+4|0;f=f+16|0;e=e-1|0;continue}break}ib=g+16|0;e=b<<4;break u}i=ib-16|0;ib=i;x[i+12>>2]=b>>>4;x[i+8>>2]=d;d=x[Hb(i+12|0,i+8|0)>>2];e=d;while(1){if(e){h=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);b=h<<24|h<<8&16711680;m=h>>>8|0;g=y[f+4|0]|y[f+5|0]<<8|(y[f+6|0]<<16|y[f+7|0]<<24);h=h>>>24|0;b=b|((m|g<<24)&65280|(h|g<<8)&255);L=a,M=Vc((m|(g&255)<<24)&-16777216|(h|(g&16777215)<<8)&16711680|(g>>>8&65280|g>>>24),b,48),w[L>>1]=M;h=y[f+8|0]|y[f+9|0]<<8|(y[f+10|0]<<16|y[f+11|0]<<24);g=y[f+12|0]|y[f+13|0]<<8|(y[f+14|0]<<16|y[f+15|0]<<24);b=h<<24|h<<8&16711680|((g<<24|h>>>8)&65280|(g<<8|h>>>24)&255);L=a,M=Vc(((g&255)<<24|h>>>8)&-16777216|((g&16777215)<<8|h>>>24)&16711680|(g>>>8&65280|g>>>24),b,48),w[L+2>>1]=M;a=a+4|0;f=f+16|0;e=e-1|0;continue}break}ib=i+16|0;e=d<<4;break u}if(!(y[h+1|0]!=1|(g|0)!=3|(a|0)!=32)){a=x[b+20>>2];d=x[b>>2];b=x[k+2260>>2];if(!y[h+2|0]){g=ib-16|0;ib=g;x[g+12>>2]=b>>>2;x[g+8>>2]=d;b=x[Hb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){j=Tf((l(2,y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24)),r()));j=$h(E(Ld(vg(j)?j>=E(0)?E(1):E(-1):j,E(-1))*E(32768)));_:{if(E(F(j))<E(2147483648)){d=~~j;break _}d=-2147483648}L=a,M=dd(d),w[L>>1]=M;a=a+2|0;f=f+4|0;e=e-1|0;continue}break}ib=g+16|0;e=b<<2;break u}g=ib-16|0;ib=g;x[g+12>>2]=b>>>2;x[g+8>>2]=d;b=x[Hb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){d=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);j=Tf((l(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),r()));j=$h(E(Ld(vg(j)?j>=E(0)?E(1):E(-1):j,E(-1))*E(32768)));$:{if(E(F(j))<E(2147483648)){d=~~j;break $}d=-2147483648}L=a,M=dd(d),w[L>>1]=M;a=a+2|0;f=f+4|0;e=e-1|0;continue}break}ib=g+16|0;e=b<<2;break u}a=e&255;if(!(y[h+1|0]!=2|(g|0)!=3|(a|0)!=32)){a=x[b+20>>2];d=x[b>>2];b=x[k+2260>>2];if(!y[h+2|0]){g=ib-16|0;ib=g;x[g+12>>2]=b>>>3;x[g+8>>2]=d;b=x[Hb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){j=Tf((l(2,y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24)),r()));j=$h(E(Ld(vg(j)?j>=E(0)?E(1):E(-1):j,E(-1))*E(32768)));aa:{if(E(F(j))<E(2147483648)){d=~~j;break aa}d=-2147483648}L=a,M=dd(d),w[L>>1]=M;j=Tf((l(2,y[f+4|0]|y[f+5|0]<<8|(y[f+6|0]<<16|y[f+7|0]<<24)),r()));j=$h(E(Ld(vg(j)?j>=E(0)?E(1):E(-1):j,E(-1))*E(32768)));ba:{if(E(F(j))<E(2147483648)){d=~~j;break ba}d=-2147483648}L=a,M=dd(d),w[L+2>>1]=M;a=a+4|0;f=f+8|0;e=e-1|0;continue}break}ib=g+16|0;e=b<<3;break u}g=ib-16|0;ib=g;x[g+12>>2]=b>>>3;x[g+8>>2]=d;b=x[Hb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){d=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);j=Tf((l(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),r()));j=$h(E(Ld(vg(j)?j>=E(0)?E(1):E(-1):j,E(-1))*E(32768)));ca:{if(E(F(j))<E(2147483648)){d=~~j;break ca}d=-2147483648}L=a,M=dd(d),w[L>>1]=M;d=y[f+4|0]|y[f+5|0]<<8|(y[f+6|0]<<16|y[f+7|0]<<24);j=Tf((l(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),r()));j=$h(E(Ld(vg(j)?j>=E(0)?E(1):E(-1):j,E(-1))*E(32768)));da:{if(E(F(j))<E(2147483648)){d=~~j;break da}d=-2147483648}L=a,M=dd(d),w[L+2>>1]=M;a=a+4|0;f=f+8|0;e=e-1|0;continue}break}ib=g+16|0;e=b<<3;break u}if(!(y[h+1|0]!=1|(g|0)!=3|(a|0)!=64)){a=x[b+20>>2];d=x[b>>2];b=x[k+2260>>2];if(!y[h+2|0]){g=ib-32|0;ib=g;x[g+24>>2]=b>>>3;x[g+16>>2]=d;d=x[Hb(g+24|0,g+16|0)>>2];e=d;while(1){if(e){b=y[f+4|0]|y[f+5|0]<<8|(y[f+6|0]<<16|y[f+7|0]<<24);l(0,y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24));l(1,b|0);o=ug(+n());L=g,N=tf(o)?o>=0?1:-1:o,C[L+24>>3]=N;x[g+16>>2]=0;x[g+20>>2]=-1074790400;x[g+8>>2]=0;x[g+12>>2]=1072693248;o=Be(C[Qg(g+24|0,g+16|0,g+8|0)>>3]*32768);ea:{if(F(o)<2147483648){b=~~o;break ea}b=-2147483648}L=a,M=dd(b),w[L>>1]=M;a=a+2|0;f=f+8|0;e=e-1|0;continue}break}ib=g+32|0;e=d<<3;break u}m=ib-32|0;ib=m;x[m+24>>2]=b>>>3;x[m+16>>2]=d;h=x[Hb(m+24|0,m+16|0)>>2];e=h;while(1){if(e){b=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);g=b<<24|b<<8&16711680;s=b>>>8|0;i=y[f+4|0]|y[f+5|0]<<8|(y[f+6|0]<<16|y[f+7|0]<<24);d=s|i<<24;b=b>>>24|0;l(0,(s|(i&255)<<24)&-16777216|(b|(i&16777215)<<8)&16711680|(i>>>8&65280|i>>>24));l(1,g|(d&65280|(b|i<<8)&255));o=ug(+n());L=m,N=tf(o)?o>=0?1:-1:o,C[L+24>>3]=N;x[m+16>>2]=0;x[m+20>>2]=-1074790400;x[m+8>>2]=0;x[m+12>>2]=1072693248;o=Be(C[Qg(m+24|0,m+16|0,m+8|0)>>3]*32768);fa:{if(F(o)<2147483648){b=~~o;break fa}b=-2147483648}L=a,M=dd(b),w[L>>1]=M;a=a+2|0;f=f+8|0;e=e-1|0;continue}break}ib=m+32|0;e=h<<3;break u}a=e&255;if(!(y[h+1|0]!=2|(g|0)!=3|(a|0)!=64)){a=x[b+20>>2];d=x[b>>2];b=x[k+2260>>2];if(!y[h+2|0]){g=ib-32|0;ib=g;x[g+24>>2]=b>>>4;x[g+16>>2]=d;d=x[Hb(g+24|0,g+16|0)>>2];e=d;while(1){if(e){b=y[f+4|0]|y[f+5|0]<<8|(y[f+6|0]<<16|y[f+7|0]<<24);l(0,y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24));l(1,b|0);o=ug(+n());L=g,N=tf(o)?o>=0?1:-1:o,C[L+24>>3]=N;x[g+16>>2]=0;x[g+20>>2]=-1074790400;x[g+8>>2]=0;x[g+12>>2]=1072693248;o=Be(C[Qg(g+24|0,g+16|0,g+8|0)>>3]*32768);ga:{if(F(o)<2147483648){b=~~o;break ga}b=-2147483648}L=a,M=dd(b),w[L>>1]=M;b=y[f+12|0]|y[f+13|0]<<8|(y[f+14|0]<<16|y[f+15|0]<<24);l(0,y[f+8|0]|y[f+9|0]<<8|(y[f+10|0]<<16|y[f+11|0]<<24));l(1,b|0);o=ug(+n());L=g,N=tf(o)?o>=0?1:-1:o,C[L+24>>3]=N;x[g+16>>2]=0;x[g+20>>2]=-1074790400;x[g+8>>2]=0;x[g+12>>2]=1072693248;o=Be(C[Qg(g+24|0,g+16|0,g+8|0)>>3]*32768);ha:{if(F(o)<2147483648){b=~~o;break ha}b=-2147483648}L=a,M=dd(b),w[L+2>>1]=M;a=a+4|0;f=f+16|0;e=e-1|0;continue}break}ib=g+32|0;e=d<<4;break u}m=ib-32|0;ib=m;x[m+24>>2]=b>>>4;x[m+16>>2]=d;h=x[Hb(m+24|0,m+16|0)>>2];e=h;while(1){if(e){b=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);d=b<<24|b<<8&16711680;i=b>>>8|0;g=y[f+4|0]|y[f+5|0]<<8|(y[f+6|0]<<16|y[f+7|0]<<24);b=b>>>24|0;d=d|((i|g<<24)&65280|(b|g<<8)&255);l(0,(i|(g&255)<<24)&-16777216|(b|(g&16777215)<<8)&16711680|(g>>>8&65280|g>>>24));l(1,d|0);o=ug(+n());L=m,N=tf(o)?o>=0?1:-1:o,C[L+24>>3]=N;x[m+16>>2]=0;x[m+20>>2]=-1074790400;x[m+8>>2]=0;x[m+12>>2]=1072693248;o=Be(C[Qg(m+24|0,m+16|0,m+8|0)>>3]*32768);ia:{if(F(o)<2147483648){b=~~o;break ia}b=-2147483648}L=a,M=dd(b),w[L>>1]=M;b=y[f+8|0]|y[f+9|0]<<8|(y[f+10|0]<<16|y[f+11|0]<<24);g=b<<24|b<<8&16711680;s=b>>>8|0;i=y[f+12|0]|y[f+13|0]<<8|(y[f+14|0]<<16|y[f+15|0]<<24);d=s|i<<24;b=b>>>24|0;l(0,(s|(i&255)<<24)&-16777216|(b|(i&16777215)<<8)&16711680|(i>>>8&65280|i>>>24));l(1,g|(d&65280|(b|i<<8)&255));o=ug(+n());L=m,N=tf(o)?o>=0?1:-1:o,C[L+24>>3]=N;x[m+16>>2]=0;x[m+20>>2]=-1074790400;x[m+8>>2]=0;x[m+12>>2]=1072693248;o=Be(C[Qg(m+24|0,m+16|0,m+8|0)>>3]*32768);ja:{if(F(o)<2147483648){b=~~o;break ja}b=-2147483648}L=a,M=dd(b),w[L+2>>1]=M;a=a+4|0;f=f+16|0;e=e-1|0;continue}break}ib=m+32|0;e=h<<4;break u}ka:{if((a|0)==24){if((g|0)!=15|(y[h+1|0]-1&255)>>>0>1){break ka}x[k+96>>2]=-2147483648;a=x[k+2260>>2];la:{if(!y[h+2|0]){s=k+96|0;e=0;t=ib-16|0;ib=t;L=t,M=D(x[b>>2],Md(z[b+34>>1])),x[L+12>>2]=M;wc(t+12|0,(a>>>0)/3|0);a=f;g=x[t+12>>2];h=g;while(1){if(h){i=y[a+1|0]<<16|y[a|0]<<8|y[a+2|0]<<24;ma:{na:{oa:{if((i|0)>=0){d=i;break oa}d=-2147483648;if((i|0)==-2147483648){break na}d=0-i|0}if(d>>>0<=e>>>0){break ma}}e=d}h=h-1|0;a=a+3|0;continue}else{pa:{if(!e){break pa}q=e-1|0;m=e>>>1|0;h=x[b+20>>2];a=g;while(1){if(!a){break pa}d=y[f+1|0]<<16|y[f|0]<<8|y[f+2|0]<<24;i=d&-2147483648|d>>>1;d=m|d<<31;qa:{if((i|0)>0|(i|0)>=0){d=soa(d,i,e,0);i=kb;break qa}i=soa(q-d|0,0-((d>>>0>q>>>0)+i|0)|0,e,0);d=0-i|0;i=0-(kb+((i|0)!=0)|0)|0}L=h,M=kd(Dc(d,i),16),w[L>>1]=M;a=a-1|0;f=f+3|0;h=h+2|0;continue}}}break}if(s){x[s>>2]=e}ib=t+16|0;e=D(g,3);break la}s=k+96|0;e=0;t=ib-16|0;ib=t;L=t,M=D(x[b>>2],Md(z[b+34>>1])),x[L+12>>2]=M;wc(t+12|0,(a>>>0)/3|0);a=f;g=x[t+12>>2];h=g;while(1){if(h){i=y[a+1|0]<<16|y[a+2|0]<<8|y[a|0]<<24;ra:{sa:{ta:{if((i|0)>=0){d=i;break ta}d=-2147483648;if((i|0)==-2147483648){break sa}d=0-i|0}if(d>>>0<=e>>>0){break ra}}e=d}h=h-1|0;a=a+3|0;continue}else{ua:{if(!e){break ua}q=e-1|0;m=e>>>1|0;h=x[b+20>>2];a=g;while(1){if(!a){break ua}d=y[f+1|0]<<16|y[f+2|0]<<8|y[f|0]<<24;i=d&-2147483648|d>>>1;d=m|d<<31;va:{if((i|0)>0|(i|0)>=0){d=soa(d,i,e,0);i=kb;break va}i=soa(q-d|0,0-((d>>>0>q>>>0)+i|0)|0,e,0);d=0-i|0;i=0-(kb+((i|0)!=0)|0)|0}L=h,M=kd(Dc(d,i),16),w[L>>1]=M;a=a-1|0;f=f+3|0;h=h+2|0;continue}}}break}if(s){x[s>>2]=e}ib=t+16|0;e=D(g,3)}if(!e){break u}a=x[k+96>>2];if((a|0)==-2147483648){break u}f=qoa(z[b+32>>1],0,a,0)+1073741824|0;a=kb;a=f>>>0<1073741824?a+1|0:a;L=b,M=Bd(Ec((a&2147483647)<<1|f>>>31,a>>>31|0),1,64),w[L+32>>1]=M;w[b+34>>1]=z[b+34>>1]|8192;break u}a=e&255;if((a|0)==32){if(!((g|0)!=15|(y[h+1|0]-1&255)>>>0>1)){x[k+96>>2]=-2147483648;d=x[k+2260>>2];wa:{if(!y[h+2|0]){s=k+96|0;a=0;t=ib-16|0;ib=t;L=t,M=D(x[b>>2],Md(z[b+34>>1])),x[L+12>>2]=M;wc(t+12|0,d>>>2|0);e=f;h=f;g=x[t+12>>2];f=g;while(1){if(f){i=y[h|0]|y[h+1|0]<<8|(y[h+2|0]<<16|y[h+3|0]<<24);xa:{ya:{za:{if((i|0)>=0){d=i;break za}d=-2147483648;if((i|0)==-2147483648){break ya}d=0-i|0}if(d>>>0<=a>>>0){break xa}}a=d}f=f-1|0;h=h+4|0;continue}else{Aa:{if(!a){break Aa}q=a-1|0;m=a>>>1|0;h=x[b+20>>2];f=g;while(1){if(!f){break Aa}d=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);i=d&-2147483648|d>>>1;d=m|d<<31;Ba:{if((i|0)>0|(i|0)>=0){d=soa(d,i,a,0);i=kb;break Ba}i=soa(q-d|0,0-((d>>>0>q>>>0)+i|0)|0,a,0);d=0-i|0;i=0-(kb+((i|0)!=0)|0)|0}L=h,M=kd(Dc(d,i),16),w[L>>1]=M;f=f-1|0;e=e+4|0;h=h+2|0;continue}}}break}if(s){x[s>>2]=a}ib=t+16|0;e=g<<2;break wa}s=k+96|0;a=0;t=ib-16|0;ib=t;L=t,M=D(x[b>>2],Md(z[b+34>>1])),x[L+12>>2]=M;wc(t+12|0,d>>>2|0);e=f;h=f;g=x[t+12>>2];f=g;while(1){if(f){d=y[h|0]|y[h+1|0]<<8|(y[h+2|0]<<16|y[h+3|0]<<24);i=d<<24|d<<8&16711680|(d>>>8&65280|d>>>24);Ca:{Da:{Ea:{if((i|0)>=0){d=i;break Ea}d=-2147483648;if((i|0)==-2147483648){break Da}d=0-i|0}if(a>>>0>=d>>>0){break Ca}}a=d}f=f-1|0;h=h+4|0;continue}else{Fa:{if(!a){break Fa}q=a-1|0;m=a>>>1|0;h=x[b+20>>2];f=g;while(1){if(!f){break Fa}d=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);d=d<<24|d<<8&16711680|(d>>>8&65280|d>>>24);i=d&-2147483648|d>>>1;d=m|d<<31;Ga:{if((i|0)>0|(i|0)>=0){d=soa(d,i,a,0);i=kb;break Ga}i=soa(q-d|0,0-((d>>>0>q>>>0)+i|0)|0,a,0);d=0-i|0;i=0-(kb+((i|0)!=0)|0)|0}L=h,M=kd(Dc(d,i),16),w[L>>1]=M;f=f-1|0;e=e+4|0;h=h+2|0;continue}}}break}if(s){x[s>>2]=a}ib=t+16|0;e=g<<2}if(!e){break u}a=x[k+96>>2];if((a|0)==-2147483648){break u}f=qoa(z[b+32>>1],0,a,0)+1073741824|0;a=kb;a=f>>>0<1073741824?a+1|0:a;L=b,M=Bd(Ec((a&2147483647)<<1|f>>>31,a>>>31|0),1,64),w[L+32>>1]=M;w[b+34>>1]=z[b+34>>1]|8192;break u}if((g|0)!=14|(y[h+1|0]-1&255)>>>0>1){break ka}x[k+96>>2]=1065353216;a=x[k+2260>>2];Ha:{if(!y[h+2|0]){e=k+96|0;h=ib-16|0;ib=h;L=h,M=D(x[b>>2],Md(z[b+34>>1])),x[L+12>>2]=M;wc(h+12|0,a>>>2|0);g=f;d=x[h+12>>2];a=d;while(1){if(a){j=Tf((l(2,y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24)),r()));j=E(F(vg(j)?j>=E(0)?E(1):E(-1):j));u=j>u?j:u;a=a-1|0;g=g+4|0;continue}else{Ia:{a=u==E(0);if(a){break Ia}I=a?E(1):E(E(1)/u);g=x[b+20>>2];a=d;while(1){if(!a){break Ia}j=Tf((l(2,y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24)),r()));j=$h(E(Ld(E(I*(vg(j)?j>=E(0)?E(1):E(-1):j)),E(-1))*E(32768)));Ja:{if(E(F(j))<E(2147483648)){i=~~j;break Ja}i=-2147483648}L=g,M=dd(i),w[L>>1]=M;a=a-1|0;f=f+4|0;g=g+2|0;continue}}if(e){B[e>>2]=u}ib=h+16|0;e=d<<2}break}break Ha}e=k+96|0;i=ib-16|0;ib=i;L=i,M=D(x[b>>2],Md(z[b+34>>1])),x[L+12>>2]=M;wc(i+12|0,a>>>2|0);g=f;d=x[i+12>>2];a=d;while(1){if(a){h=y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24);j=Tf((l(2,h<<24|h<<8&16711680|(h>>>8&65280|h>>>24)),r()));j=E(F(vg(j)?j>=E(0)?E(1):E(-1):j));u=j>u?j:u;a=a-1|0;g=g+4|0;continue}else{Ka:{a=u==E(0);if(a){break Ka}I=a?E(1):E(E(1)/u);g=x[b+20>>2];a=d;while(1){if(!a){break Ka}h=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);j=Tf((l(2,h<<24|h<<8&16711680|(h>>>8&65280|h>>>24)),r()));j=$h(E(Ld(E(I*(vg(j)?j>=E(0)?E(1):E(-1):j)),E(-1))*E(32768)));La:{if(E(F(j))<E(2147483648)){h=~~j;break La}h=-2147483648}L=g,M=dd(h),w[L>>1]=M;a=a-1|0;f=f+4|0;g=g+2|0;continue}}if(e){B[e>>2]=u}ib=i+16|0;e=d<<2}break}}if(!e){break u}j=B[k+96>>2];if(j==E(1)){break u}j=$h(Jz(E(j*E(z[b+32>>1])),E(1),E(64)));a=65535;Ma:{if(j>=E(65535)){break Ma}a=0;if(j<=E(0)){break Ma}a=~~j>>>0;if(j<E(4294967296)&j>=E(0)){break Ma}a=0}w[b+32>>1]=a;w[b+34>>1]=z[b+34>>1]|8192;break u}if((g|0)!=14|(y[h+1|0]-1&255)>>>0>1|(a|0)!=64){break ka}x[k+96>>2]=0;x[k+100>>2]=1072693248;a=x[k+2260>>2];Na:{if(!y[h+2|0]){h=k+96|0;i=ib-32|0;ib=i;L=i,M=D(x[b>>2],Md(z[b+34>>1])),x[L+4>>2]=M;wc(i+4|0,a>>>3|0);d=f;e=x[i+4>>2];a=e;while(1){if(a){g=y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24);l(0,y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24));l(1,g|0);o=ug(+n());o=F(tf(o)?o>=0?1:-1:o);G=o>G?o:G;a=a-1|0;d=d+8|0;continue}else{Oa:{a=G==0;if(a){break Oa}J=a?1:1/G;d=x[b+20>>2];a=e;while(1){if(!a){break Oa}g=y[f+4|0]|y[f+5|0]<<8|(y[f+6|0]<<16|y[f+7|0]<<24);l(0,y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24));l(1,g|0);o=ug(+n());L=i,N=J*(tf(o)?o>=0?1:-1:o),C[L+24>>3]=N;x[i+16>>2]=0;x[i+20>>2]=-1074790400;x[i+8>>2]=0;x[i+12>>2]=1072693248;o=Be(C[Qg(i+24|0,i+16|0,i+8|0)>>3]*32768);Pa:{if(F(o)<2147483648){g=~~o;break Pa}g=-2147483648}L=d,M=dd(g),w[L>>1]=M;a=a-1|0;f=f+8|0;d=d+2|0;continue}}if(h){C[h>>3]=G}ib=i+32|0;e=e<<3}break}break Na}i=k+96|0;q=ib-32|0;ib=q;L=q,M=D(x[b>>2],Md(z[b+34>>1])),x[L+4>>2]=M;wc(q+4|0,a>>>3|0);d=f;g=x[q+4>>2];a=g;while(1){if(a){e=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);h=e<<24|e<<8&16711680;s=e>>>8|0;m=y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24);e=e>>>24|0;h=h|((s|m<<24)&65280|(e|m<<8)&255);l(0,(s|(m&255)<<24)&-16777216|(e|(m&16777215)<<8)&16711680|(m>>>8&65280|m>>>24));l(1,h|0);o=ug(+n());o=F(tf(o)?o>=0?1:-1:o);G=o>G?o:G;a=a-1|0;d=d+8|0;continue}else{Qa:{a=G==0;if(a){break Qa}J=a?1:1/G;d=x[b+20>>2];a=g;while(1){if(!a){break Qa}m=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);e=m<<24|m<<8&16711680;s=m>>>8|0;h=y[f+4|0]|y[f+5|0]<<8|(y[f+6|0]<<16|y[f+7|0]<<24);m=m>>>24|0;e=e|((s|h<<24)&65280|(m|h<<8)&255);l(0,(s|(h&255)<<24)&-16777216|(m|(h&16777215)<<8)&16711680|(h>>>8&65280|h>>>24));l(1,e|0);o=ug(+n());L=q,N=J*(tf(o)?o>=0?1:-1:o),C[L+24>>3]=N;x[q+16>>2]=0;x[q+20>>2]=-1074790400;x[q+8>>2]=0;x[q+12>>2]=1072693248;o=Be(C[Qg(q+24|0,q+16|0,q+8|0)>>3]*32768);Ra:{if(F(o)<2147483648){e=~~o;break Ra}e=-2147483648}L=d,M=dd(e),w[L>>1]=M;a=a-1|0;f=f+8|0;d=d+2|0;continue}}if(i){C[i>>3]=G}ib=q+32|0;e=g<<3}break}}if(!e){break u}o=C[k+96>>3];if(o==1){break u}L=b,M=uW(Pu(o*+z[b+32>>1],1,64)),w[L+32>>1]=M;w[b+34>>1]=z[b+34>>1]|8192;break u}Sa:{Ta:{Ua:{Va:{a=(e&255)!=32;Wa:{if(!(a|(y[h+1|0]!=1|(g|0)!=12))){u=E(30517578125e-15);e=x[k+2260>>2];if(!y[h+2|0]){break Wa}break Sa}if(!(y[h+1|0]!=2|(g|0)!=12|a)){u=E(30517578125e-15);e=x[k+2260>>2];if(!y[h+2|0]){break Ua}break Ta}a=(e&255)!=32;if(a|(y[h+1|0]!=1|(g|0)!=13)){break Va}u=E(1.1920928955078125e-7);e=x[k+2260>>2];if(y[h+2|0]){break Sa}}a=x[b>>2];b=x[b+20>>2];d=ib-16|0;ib=d;x[d+12>>2]=e>>>2;x[d+8>>2]=a;a=x[Hb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){j=Tf((l(2,y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24)),r()));j=$h(E(Ld(E((vg(j)?j>=E(0)?E(1):E(-1):j)*u),E(-1))*E(32768)));Xa:{if(E(F(j))<E(2147483648)){g=~~j;break Xa}g=-2147483648}L=b,M=dd(g),w[L>>1]=M;b=b+2|0;f=f+4|0;e=e-1|0;continue}break}ib=d+16|0;e=a<<2;break u}e=0;if(y[h+1|0]!=2|(g|0)!=13|a){break u}u=E(1.1920928955078125e-7);e=x[k+2260>>2];if(y[h+2|0]){break Ta}}a=x[b>>2];b=x[b+20>>2];d=ib-16|0;ib=d;x[d+12>>2]=e>>>3;x[d+8>>2]=a;a=x[Hb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){j=Tf((l(2,y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24)),r()));j=$h(E(Ld(E((vg(j)?j>=E(0)?E(1):E(-1):j)*u),E(-1))*E(32768)));Ya:{if(E(F(j))<E(2147483648)){g=~~j;break Ya}g=-2147483648}L=b,M=dd(g),w[L>>1]=M;j=Tf((l(2,y[f+4|0]|y[f+5|0]<<8|(y[f+6|0]<<16|y[f+7|0]<<24)),r()));j=$h(E(Ld(E((vg(j)?j>=E(0)?E(1):E(-1):j)*u),E(-1))*E(32768)));Za:{if(E(F(j))<E(2147483648)){g=~~j;break Za}g=-2147483648}L=b,M=dd(g),w[L+2>>1]=M;b=b+4|0;f=f+8|0;e=e-1|0;continue}break}ib=d+16|0;e=a<<3;break u}a=x[b>>2];b=x[b+20>>2];g=ib-16|0;ib=g;x[g+12>>2]=e>>>3;x[g+8>>2]=a;a=x[Hb(g+12|0,g+8|0)>>2];e=a;while(1){if(e){d=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);j=Tf((l(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),r()));j=$h(E(Ld(E((vg(j)?j>=E(0)?E(1):E(-1):j)*u),E(-1))*E(32768)));_a:{if(E(F(j))<E(2147483648)){d=~~j;break _a}d=-2147483648}L=b,M=dd(d),w[L>>1]=M;d=y[f+4|0]|y[f+5|0]<<8|(y[f+6|0]<<16|y[f+7|0]<<24);j=Tf((l(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),r()));j=$h(E(Ld(E((vg(j)?j>=E(0)?E(1):E(-1):j)*u),E(-1))*E(32768)));$a:{if(E(F(j))<E(2147483648)){d=~~j;break $a}d=-2147483648}L=b,M=dd(d),w[L+2>>1]=M;b=b+4|0;f=f+8|0;e=e-1|0;continue}break}ib=g+16|0;e=a<<3;break u}a=x[b>>2];b=x[b+20>>2];g=ib-16|0;ib=g;x[g+12>>2]=e>>>2;x[g+8>>2]=a;a=x[Hb(g+12|0,g+8|0)>>2];e=a;while(1){if(e){d=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);j=Tf((l(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),r()));j=$h(E(Ld(E((vg(j)?j>=E(0)?E(1):E(-1):j)*u),E(-1))*E(32768)));ab:{if(E(F(j))<E(2147483648)){d=~~j;break ab}d=-2147483648}L=b,M=dd(d),w[L>>1]=M;b=b+2|0;f=f+4|0;e=e-1|0;continue}break}ib=g+16|0;e=a<<2;break u}a=V(30496)|0}if((jb|0)!=(da(30496)|0)){break d}_(a|0)|0;x[27524]=0;Z(18);a=x[27524];x[27524]=0;if((a|0)==1){break v}}yb(t);break u}a=P()|0;break d}x[27524]=0;Q(159,c|0,e+K|0)|0;a=x[27524];x[27524]=0;if((a|0)==1){break f}}Rc(H)}ib=k+2288|0;return e|0}a=P()|0;break a}a=P()|0}yb(t);break a}a=P()|0;break a}a=P()|0}Rc(H);S(a|0);p()}function hma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;d=ib-640|0;ib=d;yc(b);f=ib-16|0;ib=f;g=d+448|0;ev(f+8|0,g);j=x[f+12>>2];h=b;kc(f,x[b>>2],x[b+8>>2],x[f+8>>2],x[f+12>>2]);b=x[f+4>>2];if((b|0)==(j|0)){Yb(h,x[f+12>>2])}ib=f+16|0;b=(b|0)==(j|0);if(!b){RV(g)}a:{b:{c:{if(!b){break c}if(!TV(d+448|0)){break c}if(!Ob(x[h>>2],x[h+8>>2],Ec(SV(d+448|0),kb))){break c}if(!c){e=1;break c}zd(a,32);v[d+447|0]=0;j=Kb(d+432|0);d:{e:{f:{g:{h:{i:{j:{k:{if(!Qb(d+448|0,16257,4)){x[27524]=0;R(410,a|0,16777216);b=x[27524];x[27524]=0;if((b|0)==1){break b}b=x[h>>2];x[27524]=0;b=T(164,b|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break b}x[27524]=0;Q(159,h|0,b-4|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break b}x[27524]=0;B=T(161,h|0)|0;b=x[27524];x[27524]=0;if((b|0)!=1){break k}break b}l:{m:{n:{o:{p:{q:{if((z[d+488>>1]-2185&65535)>>>0>1910){break q}b=x[h>>2];x[27524]=0;b=T(164,b|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break b}x[27524]=0;Q(159,h|0,b-4|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break b}x[27524]=0;B=T(161,h|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break b}if(B>>>0<256){break q}b=x[h>>2];x[27524]=0;b=T(164,b|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break b}if(b>>>0<=B>>>0){break q}x[27524]=0;b=Q(159,h|0,B|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break b}if(!b){break q}x[27524]=0;b=T(411,h|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break b}if(!b){break q}x[27524]=0;R(410,a|0,16777216);b=x[27524];x[27524]=0;if((b|0)==1){break b}b=z[d+488>>1];if(b>>>0>=4096){x[27524]=0;c=Q(1,d+168|0,16472)|0;b=x[27524];x[27524]=0;if((b|0)==1){break j}a=x[a+1298472>>2];x[27524]=0;U(380,a|0,1,c|0);a=x[27524];x[27524]=0;if((a|0)!=1){xb(c);e=0;break d}b=P()|0;xb(c);break a}if(b>>>0<2194){break q}x[27524]=0;e=Q(1,d+416|0,15996)|0;b=x[27524];x[27524]=0;if((b|0)==1){break p}b=x[a+1298472>>2];x[27524]=0;U(380,b|0,4,e|0);b=x[27524];x[27524]=0;if((b|0)==1){break o}xb(e)}if(x[a+480180>>2]!=32){break k}b=z[d+488>>1];if((b&61440)!=20480){break l}b=b&4095;e=b<<16;if(Qb(d+508|0,13612,4)){break n}v[d+447|0]=1;break m}b=P()|0;break a}b=P()|0;xb(e);break a}if(b>>>0<297){break m}e=z[d+508>>1]|e}x[a+1074308>>2]=e;break k}e=z[d+490>>1];if(!((e|0)!=2184&(b|0)!=2184)){v[d+447|0]=1;x[a+1074308>>2]=18284544;break k}r:{switch(b-532|0){default:if(x[d+508>>2]|((b|0)!=768|(e|0)!=768)|(z[d+480>>1]!=256|y[d+500|0]!=128)){break k}if(y[d+501|0]){break k}x[a+1074308>>2]=18285088;v[d+447|0]=1;break k;case 3:if(x[d+508>>2]|(e|0)!=512){break k}s:{if(CB(d+512|0,255,64)){x[a+1074308>>2]=18219008;x[27524]=0;b=Q(1,d+400|0,14823)|0;e=x[27524];x[27524]=0;if((e|0)!=1){break s}b=P()|0;break a}x[a+1074308>>2]=18284544;x[27524]=0;b=Q(1,d+400|0,16846)|0;e=x[27524];x[27524]=0;if((e|0)==1){break i}}Gb(j,b);xb(b);v[d+447|0]=1;break k;case 1:case 2:break k;case 0:break r}}if(x[d+508>>2]|(e|0)!=514){break k}x[a+1074308>>2]=17367040;x[27524]=0;b=Q(1,d+400|0,14715)|0;e=x[27524];x[27524]=0;if((e|0)==1){break f}Gb(j,b);xb(b);v[d+447|0]=1}b=z[d+492>>1];e=b>>>2|0;x[a+480208>>2]=b<<3&32768|(e&8|(e&4|(x[a+480208>>2]&-32797|b<<1&16)));b=d+280|0;lr(b,d+448|4);x[27524]=0;R(226,d+168|0,b|0);b=x[27524];x[27524]=0;if((b|0)==1){break h}b=d+168|0;Ac(a+1298308|0,b);wb(b);if(!(!(y[d+494|0]&4)|x[a+1074308>>2]-18285314>>>0>4276681982)){x[a+480216>>2]=y[d+478|0];x[a+480220>>2]=y[d+479|0]}b=y[d+496|0];x[a+480200>>2]=b>>>0>128?256:b<<1;b=y[d+498|0];if(b){x[a+480196>>2]=b}v[d+168|0]=31;v[d+280|0]=y[d+499|0];b=d+168|0;e=d+280|0;J=a,K=D(y[mf(b,e)|0],1e4),x[J+480204>>2]=K;v[d+168|0]=y[d+497|0];v[d+280|0]=128;J=a,K=y[Ub(b,e)|0],x[J+480228>>2]=K;e=0;while(1){if((e|0)==64){t:{x[27524]=0;Q(159,h|0,192)|0;b=x[27524];x[27524]=0;if((b|0)==1){break b}if(x[a+480180>>2]==16777216&(z[d+488>>1]-2187&65535)>>>0<=2){break t}b=y[a+484376|0];e=x[a+484360>>2];x[27524]=0;ea(344,Tb(e,b)|0,h|0,z[d+480>>1],255,254);b=x[27524];x[27524]=0;if((b|0)==1){break b}break e}}else{g=(d+448|0)+e|0;i=g- -64|0;u:{if(y[i|0]==255){break u}f=(e<<5)+a|0;b=f+480280|0;lf(b);J=f+480286|0,K=Bd(y[g+128|0],0,64),w[J>>1]=K;g=v[i|0];if((g|0)<0){x[b>>2]=x[b>>2]|1024}g=g&127;if(g>>>0<=64){w[f+480284>>1]=g<<2;break u}if((g|0)!=100){break u}x[b>>2]=x[b>>2]|256}e=e+1|0;continue}break}e=0;x[27524]=0;b=T(198,h|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break g}if(b){break d}x[27524]=0;b=T(161,h|0)|0;f=x[27524];x[27524]=0;v:{if((f|0)==1){break v}if(b>>>0>4e3){break d}f=y[a+484376|0];g=x[a+484360>>2];x[27524]=0;b=W(412,Tb(g,f)|0,h|0,b|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break v}if(!b){break d}break e}b=P()|0;break a}b=P()|0;break a}b=P()|0;break a}b=P()|0;break a}b=P()|0;break a}b=P()|0;break a}t=Nb(d+384|0);q=Nb(d+368|0);e=0;n=Nb(d+352|0);x[27524]=0;b=W(413,h|0,t|0,z[d+482>>1])|0;f=x[27524];x[27524]=0;w:{x:{y:{if((f|0)==1){break y}if(!b){break w}x[27524]=0;b=W(413,h|0,q|0,z[d+484>>1])|0;f=x[27524];x[27524]=0;if((f|0)==1){break y}if(!b){break w}x[27524]=0;b=W(413,h|0,n|0,z[d+486>>1])|0;f=x[27524];x[27524]=0;if((f|0)==1){break y}if(!b){break w}x[d+348>>2]=-1;J=d,K=Cb(x[t>>2]),x[J+168>>2]=K;e=Cb(x[t+4>>2]);while(1){b=x[d+168>>2];if(Mb(b,e)){b=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);if(!(!b|b>>>0>=A[d+348>>2])){x[d+348>>2]=b}Pe(d+168|0);continue}else{J=d,K=Cb(x[q>>2]),x[J+168>>2]=K;e=Cb(x[q+4>>2]);while(1){b=x[d+168>>2];if(Mb(b,e)){b=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);if(!(!b|b>>>0>=A[d+348>>2])){x[d+348>>2]=b}Pe(d+168|0);continue}else{J=d,K=Cb(x[n>>2]),x[J+168>>2]=K;e=Cb(x[n+4>>2]);z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{while(1){b=x[d+168>>2];if(Mb(b,e)){b=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);if(!(!b|b>>>0>=A[d+348>>2])){x[d+348>>2]=b}Pe(d+168|0);continue}else{if(v[d+494|0]&1){x[d+168>>2]=x[d+504>>2];J=d,K=x[Hb(d+348|0,d+168|0)>>2],x[J+348>>2]=K}e=0;if(z[d+490>>1]!=532){break H}b=z[d+488>>1];if(y[d+479|0]|(b?(b|0)!=532:0)|(y[d+478|0]|y[d+501|0])){break H}if(x[d+508>>2]|y[d+492|0]&192){break H}if(z[d+482>>1]){break I}f=z[d+484>>1];if(!f){break I}if((x[h+8>>2]+(tc(x[q>>2],x[q+4>>2])<<2)|0)+2>>>0>A[d+348>>2]){break I}}break}while(1){if((e&65535)>>>0<(f&65535)>>>0){x[27524]=0;b=T(161,h|0)|0;f=x[27524];x[27524]=0;J:{if((f|0)!=1){if(!b){break J}Gg(h,((e&65535)<<2)+4|0);break I}b=P()|0;break x}e=e+1|0;f=z[d+484>>1];continue}break}x[27524]=0;b=Q(1,d+336|0,14967)|0;e=x[27524];x[27524]=0;if((e|0)==1){break G}Gb(j,b);xb(b)}e=1;if(z[d+488>>1]){break H}x[27524]=0;b=Q(1,d+320|0,15412)|0;f=x[27524];x[27524]=0;if((f|0)==1){break F}Gb(j,b);xb(b)}b=z[d+494>>1];K:{if(b&2){x[27524]=0;f=T(198,h|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break A}b=x[h+8>>2];g=x[h>>2];x[27524]=0;i=b;b=f<<3;g=W(160,g|0,i|0,b|0)|0;i=x[27524];x[27524]=0;if((i|0)==1){break A}if(!(!g|A[d+348>>2]<b+x[h+8>>2]>>>0)){x[27524]=0;b=a+1298412|0;R(414,b|0,f|0);g=x[27524];x[27524]=0;if((g|0)==1){break A}J=d,K=Cb(x[b>>2]),x[J+280>>2]=K;g=Cb(x[a+1298416>>2]);L:{M:{while(1){b=x[d+280>>2];if(!Mb(b,g)){if(!(!f&e)){break K}if(!(y[d+494|0]&4)){break L}x[27524]=0;b=Q(1,d+304|0,15445)|0;e=x[27524];x[27524]=0;if((e|0)==1){break M}Gb(j,b);xb(b);break K}x[27524]=0;R(415,h|0,d+168|0);i=x[27524];x[27524]=0;if((i|0)!=1){x[b>>2]=0;x[b+4>>2]=0;x[b+24>>2]=0;x[b+28>>2]=0;x[b+8>>2]=0;x[b+12>>2]=0;x[b+16>>2]=0;i=y[d+168|0]|y[d+169|0]<<8;if(i|(y[d+170|0]|y[d+171|0]<<8)){x[b>>2]=((i&65024)>>>9|0)+1980;J=b,K=Vb((y[d+168|0]|y[d+169|0]<<8)>>>5&15,1,12),x[J+4>>2]=K;J=b,K=Vb((y[d+168|0]|y[d+169|0]<<8)&31,1,31),x[J+8>>2]=K;J=b,K=Vb((y[d+170|0]|y[d+171|0]<<8)>>>11|0,0,23),x[J+12>>2]=K;J=b,K=Vb((y[d+170|0]|y[d+171|0]<<8)>>>5&63,0,59),x[J+16>>2]=K;i=Vb((y[d+170|0]|y[d+171|0]<<8)<<1&62,0,59);x[b+24>>2]=i;x[b+28>>2]=i>>31}x[b+32>>2]=y[d+172|0]|y[d+173|0]<<8|(y[d+174|0]<<16|y[d+175|0]<<24);x[d+280>>2]=x[d+280>>2]+40;continue}break}b=P()|0;break x}b=P()|0;break x}x[27524]=0;b=Q(1,d+304|0,14994)|0;e=x[27524];x[27524]=0;if((e|0)!=1){Gb(j,b);xb(b);break K}b=P()|0;break x}Gg(h,2);break K}if(!(b>>>0<2&e)){break K}x[27524]=0;b=T(198,h|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break z}if(!b){x[27524]=0;b=Q(1,d+304|0,14967)|0;e=x[27524];x[27524]=0;if((e|0)!=1){Gb(j,b);xb(b);break K}b=P()|0;break x}Gg(h,2)}N:{if(!(y[d+492|0]&128|y[d+494|0]&8)){break N}x[27524]=0;b=a+901404|0;e=Q(416,h|0,b|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break E}if(!e){break N}BB(b)}if(z[d+488>>1]<=531){Dq(a+901404|0)}x[27524]=0;C=T(178,d+280|0)|0;b=x[27524];x[27524]=0;O:{P:{Q:{if((b|0)!=1){x[27524]=0;b=Q(406,h|0,13849)|0;e=x[27524];x[27524]=0;if((e|0)==1){break Q}if(b){x[27524]=0;b=T(161,h|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break P}x[27524]=0;U(194,d+256|0,h|0,b|0);b=x[27524];x[27524]=0;if((b|0)==1){break P}b=d+256|0;e=hc(d+168|0,b);fd(C,e);yb(e);yb(b)}w[a+480188>>1]=1;x[27524]=0;b=Q(406,h|0,13854)|0;e=x[27524];x[27524]=0;if((e|0)==1){break Q}if(!b){break C}x[27524]=0;b=T(161,h|0)|0;e=x[27524];x[27524]=0;if((e|0)!=1){x[27524]=0;U(194,d+256|0,h|0,b|0);b=x[27524];x[27524]=0;if((b|0)!=1){break O}}b=P()|0;break B}b=P()|0;break x}b=P()|0;break B}b=P()|0;break B}b=d+256|0;f=hc(d+168|0,b);yb(b);b=x[f>>2];x[27524]=0;b=T(164,b|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break D}w[d+256>>1]=(b>>>0)/20;b=z[Tc(26660,d+256|0)>>1];w[a+480188>>1]=b;e=0;while(1){if((b|0)==(e|0)){yb(f);break C}x[27524]=0;U(417,f|0,((e<<5)+a|0)+480289|0,20);g=x[27524];x[27524]=0;if((g|0)!=1){e=e+1|0;continue}break}break D}b=P()|0;break x}b=P()|0;break x}b=P()|0;break x}b=P()|0;yb(f);break B}R:{b=x[d+348>>2];e=x[h+8>>2];S:{if(b>>>0>=e>>>0){e=b-e|0;break S}x[27524]=0;e=T(206,h|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break R}}x[27524]=0;U(194,d+168|0,h|0,e|0);b=x[27524];x[27524]=0;if((b|0)==1){break R}b=d+168|0;E=hc(d+256|0,b);yb(b);x[27524]=0;F=Q(418,a|0,E|0)|0;b=x[27524];x[27524]=0;T:{U:{V:{if((b|0)==1){break V}if(!(v[d+494|0]&1)|!z[d+502>>1]){break U}x[27524]=0;b=Q(159,h|0,x[d+504>>2])|0;e=x[27524];x[27524]=0;if((e|0)==1){break V}if(!b){break U}x[27524]=0;X(335,a+1298332|0,h|0,z[d+502>>1],4);b=x[27524];x[27524]=0;if((b|0)!=1){break U}}b=P()|0;break T}g=a+480192|0;w[g>>1]=0;f=0;if(y[d+492|0]&4){w[d+168>>1]=z[d+482>>1];w[d+96>>1]=255;f=z[Tc(d+168|0,d+96|0)>>1];w[g>>1]=f}e=0;W:{while(1){if((f&65535)>>>0<=e>>>0){x[d+252>>2]=0;e=z[d+484>>1];if(e){b=Bb(x[q>>2],e-1|0);x[d+252>>2]=(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))+80}w[d+168>>1]=e;w[d+96>>1]=3999;r=a+480190|0;f=z[Tc(d+168|0,d+96|0)>>1];w[r>>1]=f;m=c&2;o=d+188|0;u=a+1298472|0;e=0;b=0;while(1){X:{Y:{Z:{_:{$:{aa:{ba:{ca:{if((f&65535)>>>0>e>>>0){f=Bb(x[q>>2],e);f=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);if(!f){break Y}x[27524]=0;f=Q(159,h|0,f|0)|0;g=x[27524];x[27524]=0;da:{ea:{fa:{ga:{ha:{if((g|0)==1){break ha}if(!f){break Y}x[27524]=0;f=Q(419,h|0,d+168|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break ha}if(!f){break Y}x[27524]=0;i=e+1|0;f=D(i,104)+a|0;g=f+484380|0;k=Q(420,d+168|0,g|0)|0;l=x[27524];x[27524]=0;if((l|0)==1){break ga}l=d+152|0;lr(l,o);x[27524]=0;R(226,d+96|0,l|0);l=x[27524];x[27524]=0;if((l|0)==1){break fa}l=d+96|0;Cc(((i<<5)+a|0)+946304|0,l);wb(l);x[27524]=0;k=Q(159,h|0,k|0)|0;l=x[27524];x[27524]=0;if((l|0)==1){break ga}if(!k){break Y}f=z[f+484414>>1];if(!(f&512)){break ea}x[27524]=0;f=Q(421,h|0,d+96|0)|0;i=x[27524];x[27524]=0;if((i|0)==1){break ca}if(!f){break da}x[d+8>>2]=x[d+104>>2];f=x[d+100>>2];x[d>>2]=x[d+96>>2];x[d+4>>2]=f;Rm(g,1,d);break da}b=P()|0;break T}b=P()|0;break T}b=P()|0;break T}if(!(f&16384)){s=z[d+488>>1];k=y[d+186|0];l=k&2;f=y[d+214|0];i=Zc(d+96|0,l?16:8,1,0,(f^-1)&1);if(!(!(k&4)|s>>>0<532)){Qo(i,3)}ia:{ja:{if(k&8){k=f&4?5:4;break ja}if(!l){k=10;if((f|0)==255){break ja}}if(f&2){v[i+2|0]=1}if(f&4){jg(i,2)}if(!(f&8)){break ia}k=9;if(!l){break ia}}jg(i,k)}if(m){f=0;x[27524]=0;W(223,d+96|0,g|0,h|0)|0;i=x[27524];x[27524]=0;if((i|0)!=1){break _}break X}f=1;i=y[d+99|0];if(i>>>0>17){break Z}i=1<<i;if(!(i&63503)){if(!(i&198144)){break Z}break $}if(y[d+96|0]){break $}break _}x[27524]=0;R(422,h|0,d+80|0);f=x[27524];x[27524]=0;if((f|0)==1){break aa}g=x[d+80>>2];if(!(!m|!g)){f=Kb(d+96|0);x[27524]=0;U(272,h|0,f|0,g|0);g=x[27524];x[27524]=0;ka:{la:{ma:{na:{oa:{pa:{qa:{if((g|0)!=1){x[27524]=0;R(378,d+136|0,16394);g=x[27524];x[27524]=0;if((g|0)==1){break qa}x[d+64>>2]=i;x[27524]=0;U(11,d+120|0,0,f|0);g=x[27524];x[27524]=0;if((g|0)==1){break pa}x[27524]=0;X(423,d+152|0,d+136|0,d- -64|0,d+120|0);g=x[27524];x[27524]=0;if((g|0)==1){break oa}g=x[u>>2];x[27524]=0;U(380,g|0,2,d+152|0);g=x[27524];x[27524]=0;if((g|0)==1){break na}xb(d+152|0);xb(d+120|0);$b(d+136|0);wb(f);break da}b=P()|0;break ka}b=P()|0;break ka}b=P()|0;break la}b=P()|0;break ma}b=P()|0;xb(d+152|0)}xb(d+120|0)}$b(d+136|0)}wb(f);break T}x[27524]=0;Q(192,h|0,g|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break aa}}f=0;break Z}w[d+168>>1]=1;w[d+96>>1]=f;J=a+480190|0,K=z[pe(d+168|0,d+96|0)>>1],w[J>>1]=K;if(!(z[d+488>>1]==516&b)|z[d+490>>1]!=512|(z[d+494>>1]|x[d+508>>2])){break ba}if((z[d+492>>1]&65527)!=21|y[d+496|0]!=128|(y[d+497|0]!=48|y[d+500|0]!=128)){break ba}if(y[d+501|0]|z[d+502>>1]){break ba}f=d+576|0;b=d+512|0;e=1;while(1)if((b|0)==(f|0)){b=d+640|0;while(1)if((b|0)==(f|0)){f=20;while(1){if((f|0)==26){ra:{if(!(e&1)){break ba}x[27524]=0;b=Q(1,d+152|0,9817)|0;e=x[27524];x[27524]=0;if((e|0)==1){break ra}Gb(j,b);xb(b);break ba}}else{e=!y[(d+f|0)+452|0]&e;f=f+1|0;continue}break}b=P()|0;break T}else{e=y[f|0]==64&e;f=f+1|0;continue}}else{e=(y[b|0]&127)==32&e;b=b+1|0;continue}}b=P()|0;break T}x[a+480260>>2]=0;x[a+480264>>2]=2147483647;b=tc(x[n>>2],x[n+4>>2]);w[d+168>>1]=b;r=z[Tc(d+168|0,x[a+8>>2]+10|0)>>1];w[d+118>>1]=r;sa:{ta:{ua:{va:{if((b|0)!=(r|0)){x[27524]=0;Y(424,d+96|0);b=x[27524];x[27524]=0;if((b|0)==1){break sa}b=x[n+4>>2];e=x[n>>2];x[27524]=0;J=d,K=tc(e,b),x[J+136>>2]=K;X(425,d+168|0,d+96|0,d+136|0,d+118|0);b=x[27524];x[27524]=0;if((b|0)==1){break ua}b=x[a+1298472>>2];x[27524]=0;U(380,b|0,2,d+168|0);b=x[27524];x[27524]=0;if((b|0)==1){break va}xb(d+168|0);$b(d+96|0)}if(!(c&1)){w[d+118>>1]=0;r=0}m=a+480188|0;i=0;wa:{xa:{ya:{za:{Aa:{Ba:{while(1){Ca:{if((i|0)==(r|0)){Da:{Ea:{b=x[d+252>>2];if(!b){break Ea}x[27524]=0;Q(159,h|0,b|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break Da}if(!(s&1)){break Ea}while(1){Fa:{b=x[h+8>>2];c=x[h>>2];x[27524]=0;b=W(160,c|0,b|0,4)|0;c=x[27524];x[27524]=0;if((c|0)==1){break Fa}if(!b){break Ea}x[27524]=0;b=Q(406,h|0,13823)|0;c=x[27524];x[27524]=0;if((c|0)==1){break Fa}Ga:{if(!b){x[27524]=0;b=Q(406,h|0,13828)|0;c=x[27524];x[27524]=0;if((c|0)==1){break Fa}if(!b){break Ga}}x[27524]=0;b=T(161,h|0)|0;c=x[27524];x[27524]=0;if((c|0)!=1){Gg(h,8);if(!(b&1616928864)|b&-2139062144){break Ga}break Ea}b=P()|0;break T}x[27524]=0;b=T(198,h|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break Fa}x[27524]=0;Q(192,h|0,b|0)|0;b=x[27524];x[27524]=0;if((b|0)!=1){continue}}break}b=P()|0;break T}x[27524]=0;b=Q(426,a|0,h|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break Da}b=b|y[d+447|0];v[d+447|0]=b;if(!(!(b&255)|F)){Iu(a+1074312|0);v[a+1074368|0]=0}x[27524]=0;X(427,a|0,h|0,0,d+447|0);b=x[27524];x[27524]=0;if((b|0)==1){break Da}x[27524]=0;o=a+484344|0;R(229,o|0,r|0);b=x[27524];x[27524]=0;if((b|0)==1){break Da}u=a+480188|0;I=a+480183|0;i=0;Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{while(1){Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{Za:{_a:{$a:{ab:{bb:{cb:{db:{eb:{fb:{if((i|0)!=(r|0)){b=Bb(x[n>>2],i);b=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);if(b){x[27524]=0;b=Q(159,h|0,b|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break ab}if(b){break $a}}x[27524]=0;b=W(230,o|0,i&65535,64)|0;c=x[27524];x[27524]=0;if((c|0)==1){break ab}if(b){break bb}w[d+48>>1]=i;x[27524]=0;Y(428,d+96|0);b=x[27524];x[27524]=0;if((b|0)==1){break fb}x[27524]=0;U(429,d+168|0,d+96|0,d+48|0);b=x[27524];x[27524]=0;if((b|0)==1){break eb}b=x[a+1298472>>2];x[27524]=0;U(380,b|0,2,d+168|0);b=x[27524];x[27524]=0;if((b|0)==1){break db}xb(d+168|0);$b(d+96|0)}if(!x[a+1074308>>2]){e=z[d+488>>1];if((e|0)!=2184){break Za}x[a+1074308>>2]=18284544}if(!yh(x[j+4>>2],y[j+11|0])){break _a}x[27524]=0;c=Q(1,d+96|0,17591)|0;b=x[27524];x[27524]=0;if((b|0)==1){break Ra}b=x[a+1074308>>2];x[27524]=0;R(144,d- -64|0,b|0);b=x[27524];x[27524]=0;if((b|0)==1){break Ta}x[27524]=0;U(2,d+168|0,c|0,d- -64|0);b=x[27524];x[27524]=0;if((b|0)==1){break Ua}e=d+168|0;b=Gb(j,e);xb(e);xb(d- -64|0);xb(c);if(!Qb(d+508|0,13612,4)|(z[d+488>>1]&61440)!=20480){break Ya}x[27524]=0;c=Q(1,d+168|0,16858)|0;e=x[27524];x[27524]=0;if((e|0)==1){break Va}x[27524]=0;Q(99,b|0,c|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break Wa}xb(c);break Xa}b=P()|0;break T}b=P()|0;break cb}b=P()|0;xb(d+168|0)}$b(d+96|0);break T}b=x[o>>2];x[27524]=0;R(430,Xb(b,i)|0,C|0);b=x[27524];x[27524]=0;if((b|0)!=1){break Pa}}b=P()|0;break T}x[27524]=0;b=T(198,h|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break Ha}x[27524]=0;G=T(198,h|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break Ia}x[27524]=0;c=Q(192,h|0,4)|0;e=x[27524];x[27524]=0;if((e|0)==1){break Ia}if(!c){break Pa}x[27524]=0;c=W(230,o|0,i&65535,G|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break Ia}if(!c){break Pa}x[27524]=0;U(194,d+96|0,h|0,b|0);b=x[27524];x[27524]=0;if((b|0)==1){break Ja}b=d+96|0;m=hc(d+168|0,b);yb(b);b=x[o>>2];x[27524]=0;R(430,Xb(b,i)|0,C|0);b=x[27524];x[27524]=0;if((b|0)==1){break La}b=z[u>>1];x[27524]=0;l=Q(431,d+120|0,b|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break Ma}b=z[u>>1];c=d+96|0;Jj(c);x[27524]=0;k=W(432,d+80|0,b|0,c|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break Oa}J=d,K=Cb(x[Xb(x[o>>2],i)>>2]),x[J+64>>2]=K;s=0;while(1){gb:{hb:{ib:{jb:{if(s>>>0>=G>>>0){break jb}b=x[m>>2];x[27524]=0;b=W(160,b|0,x[d+176>>2],1)|0;c=x[27524];x[27524]=0;if((c|0)==1){break Qa}if(!b){break jb}x[27524]=0;b=T(210,m|0)|0;c=x[27524];x[27524]=0;kb:{if((c|0)!=1){b=b<<24>>24;if(b){break kb}EW(d- -64|0,z[u>>1]);s=s+1|0;continue}break Qa}lb:{c=b&127;g=c?c-1&65535:0;if(cd(x[l>>2],x[d+124>>2])>>>0>g>>>0){break lb}x[27524]=0;v[d+96|0]=0;c=g+1|0;U(433,l|0,c|0,d+96|0);e=x[27524];x[27524]=0;if((e|0)==1){break Qa}e=d+96|0;Jj(e);x[27524]=0;U(434,k|0,c|0,e|0);c=x[27524];x[27524]=0;if((c|0)!=1){break lb}break Qa}if((b|0)<0){x[27524]=0;b=T(210,m|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break Qa}J=Jb(x[l>>2],g),K=b,v[J|0]=K}f=d+96|0;Jj(f);if(g>>>0<z[u>>1]){f=Hd(x[d+64>>2],g)}b=Jb(x[l>>2],g);e=y[b|0];if(e&16){J=f,K=y[Hd(x[k>>2],g)|0],v[J|0]=K;e=y[b|0]}if(e&32){J=f,K=y[Hd(x[k>>2],g)+1|0],v[J+1|0]=K;e=y[b|0]}if(e&64){c=Hd(x[k>>2],g);v[f+2|0]=y[c+2|0];v[f+4|0]=y[c+4|0];e=y[b|0]}if(e<<24>>24<0){c=Hd(x[k>>2],g);v[f+3|0]=y[c+3|0];v[f+5|0]=y[c+5|0];e=y[b|0]}if(e&1){x[27524]=0;b=T(210,m|0)|0;c=x[27524];x[27524]=0;mb:{nb:{if((c|0)!=1){b=b<<24>>24;b=(((b^-1)&128)>>>7|0)+b|0;if(!(v[I|0]&1)){break nb}c=b;break mb}break Qa}c=253;if((b-121&255)>>>0<132){break mb}c=(b&255)!=253?b:0}v[f|0]=c;J=Hd(x[k>>2],g),K=c,v[J|0]=K;b=Jb(x[l>>2],g)}if(y[b|0]&2){x[27524]=0;b=T(210,m|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break Qa}v[f+1|0]=b;J=Hd(x[k>>2],g),K=b,v[J+1|0]=K;b=Jb(x[l>>2],g)}if(!(y[b|0]&4)){break gb}x[27524]=0;b=T(210,m|0)|0;c=x[27524];x[27524]=0;ob:{pb:{if((c|0)!=1){if(b>>>0>64){break pb}v[f+4|0]=b;e=1;break ob}break Qa}if(b<<24>>24<=-64){e=2;v[f+2|0]=2;b=b^-128;v[f+4|0]=b;break hb}if(b>>>0<=74){e=5;v[f+2|0]=5;b=b-65|0;v[f+4|0]=b;break hb}if(b>>>0<=84){e=6;v[f+2|0]=6;b=b-75|0;v[f+4|0]=b;break hb}if(b>>>0<=94){e=3;v[f+2|0]=3;b=b-85|0;v[f+4|0]=b;break hb}if(b>>>0<=104){e=4;v[f+2|0]=4;b=b-95|0;v[f+4|0]=b;break hb}if(b>>>0<=114){e=13;v[f+2|0]=13;b=b-105|0;v[f+4|0]=b;break hb}if(b>>>0<=124){e=12;v[f+2|0]=12;b=b-115|0;v[f+4|0]=b;break hb}c=b+63|0;if((c&255)>>>0<=9){v[f+4|0]=c;e=11;v[f+2|0]=11;b=c;break hb}c=b+53|0;H=c&255;if(H>>>0<=9){v[f+4|0]=c;e=8;v[f+2|0]=8;if(!H){b=0;break hb}if(x[a+1074308>>2]-1>>>0>18285139){break ib}e=7;v[f+2|0]=7;break ib}b=b+33|0;if((b&255)>>>0>=10){b=y[f+4|0];e=y[f+2|0];break hb}v[f+4|0]=b;e=15}v[f+2|0]=e;break hb}Ck(k);ec(l);yb(m);break Pa}b=c}c=Hd(x[k>>2],g);v[c+4|0]=b;v[c+2|0]=e;b=Jb(x[l>>2],g)}if(!(y[b|0]&8)){continue}x[27524]=0;R(264,d+32|0,m|0);b=x[27524];x[27524]=0;if((b|0)!=1){zB(f,y[d+32|0],y[Lc(d+32|0)|0],1);b=Hd(x[k>>2],g);v[b+3|0]=y[f+3|0];v[b+5|0]=y[f+5|0];continue}break}break Qa}e=z[d+488>>1]}qb:{rb:{sb:{tb:{ub:{vb:{wb:{xb:{b=e&65535;switch(b>>>12|0){case 13:break rb;case 7:break sb;case 6:break tb;case 4:break ub;case 1:break wb;case 0:break xb;default:break Xa}}if(F){x[27524]=0;b=Q(1,d+168|0,8288)|0;c=x[27524];x[27524]=0;if((c|0)!=1){Gb(j,b);xb(b);break Xa}b=P()|0;break T}yb:{zb:{Ab:{Bb:{Cb:{Db:{Eb:{Fb:{Gb:{Hb:{Ib:{Jb:{Kb:{Lb:{if((e&65535)==532){f=z[d+490>>1];if((f|0)!=532){if((f|0)!=512){e=532;break Kb}Mb:{if(z[d+494>>1]|z[d+492>>1]!=9|(y[d+479|0]|y[d+478|0])){break Mb}if(z[d+482>>1]|z[d+480>>1]!=(z[d+486>>1]+1|0)|(y[d+496|0]!=128|y[d+497|0]!=100)){break Mb}if(y[d+498|0]!=1|y[d+500|0]!=128|(y[d+501|0]|z[d+502>>1])){break Mb}if(x[d+504>>2]|x[d+508>>2]){break Mb}x[27524]=0;b=Q(1,d+168|0,9798)|0;c=x[27524];x[27524]=0;if((c|0)!=1){Gb(j,b);xb(b);break Xa}b=P()|0;break T}e=532;if(x[d+508>>2]|(y[d+479|0]|y[d+478|0])){break Jb}x[a+1074308>>2]=16777381;x[27524]=0;b=Q(1,d+168|0,14904)|0;c=x[27524];x[27524]=0;if((c|0)!=1){Gb(j,b);xb(b);v[d+447|0]=1;break Xa}b=P()|0;break T}if(!Qb(d+508|0,14092,4)){x[27524]=0;b=Q(1,d+168|0,8326)|0;c=x[27524];x[27524]=0;if((c|0)!=1){Gb(j,b);xb(b);e=a+1074312|0;f=38;break vb}b=P()|0;break T}e=532;if(y[d+501|0]|z[d+494>>1]>1|(x[d+508>>2]|(z[d+492>>1]&4294)!=4)){break Lb}if(!z[a+480190>>1]){break Lb}x[27524]=0;e=Q(55,d+96|0,13432)|0;b=x[27524];x[27524]=0;if((b|0)==1){break Hb}b=ib-32|0;ib=b;c=ib-16|0;ib=c;Iv(c+8|0,a+484527|0);DV(b+24|0,x[c+8>>2],x[c+12>>2]);ib=c+16|0;ye(b+16|0,e);c=x[b+20>>2];x[b+8>>2]=x[b+16>>2];x[b+12>>2]=c;c=Nc(x[b+24>>2],x[b+28>>2],b+8|0);ib=b+32|0;wb(e);if(c){break Ib}e=z[d+488>>1]}if(e&65535){break Lb}if(yh(x[j+4>>2],y[j+11|0])){break Fb}}f=z[d+490>>1]}if((f&65535)>>>0>767){break Xa}}if(!yh(x[j+4>>2],y[j+11|0])){break Xa}if((f&65535)>>>0<533){break Db}x[27524]=0;b=Q(1,d- -64|0,14937)|0;c=x[27524];x[27524]=0;if((c|0)==1){break Eb}Gb(j,b);xb(b);break Cb}x[27524]=0;b=Q(1,d+168|0,8352)|0;c=x[27524];x[27524]=0;if((c|0)==1){break Gb}Gb(j,b);xb(b);break Xa}b=P()|0;break T}b=P()|0;break T}x[27524]=0;b=Q(1,d+168|0,9688)|0;c=x[27524];x[27524]=0;if((c|0)!=1){Gb(j,b);xb(b);break Xa}b=P()|0;break T}b=P()|0;break T}if((e&65535)>>>0>=533){x[27524]=0;R(435,d- -64|0,4018);b=x[27524];x[27524]=0;Nb:{if((b|0)!=1){x[27524]=0;x[d+48>>2]=z[d+488>>1]-532;U(436,d+168|0,d- -64|0,d+48|0);b=x[27524];x[27524]=0;if((b|0)==1){break Nb}b=d+168|0;Gb(j,b);xb(b);$b(d- -64|0);break Cb}b=P()|0;break T}b=P()|0;$b(d- -64|0);break T}x[27524]=0;R(270,d- -64|0,4317);b=x[27524];x[27524]=0;if((b|0)==1){break Bb}b=z[d+488>>1];x[d+32>>2]=b>>>8&15;x[27524]=0;x[d+16>>2]=b&255;R(437,d+48|0,d+16|0);b=x[27524];x[27524]=0;if((b|0)==1){break Ab}x[27524]=0;X(423,d+168|0,d- -64|0,d+32|0,d+48|0);b=x[27524];x[27524]=0;if((b|0)==1){break zb}b=d+168|0;Gb(j,b);xb(b);xb(d+48|0);$b(d- -64|0)}b=a+1298412|0;if(!pc(x[b>>2],x[a+1298416>>2])){break Xa}c=x[d+508>>2];if(!c){break Xa}c=AD(z[d+488>>1],c);e=Bo(d+168|0);x[e+32>>2]=c;x[27524]=0;R(438,b|0,e|0);b=x[27524];x[27524]=0;if((b|0)!=1){break Xa}b=P()|0;break T}b=P()|0;break T}b=P()|0;break yb}b=P()|0;xb(d+48|0)}$b(d- -64|0);break T}c=x[d+508>>2];x[27524]=0;U(439,d+168|0,b|0,x[d+508>>2]);e=x[27524];x[27524]=0;Ob:{Pb:{Qb:{Rb:{Sb:{Tb:{Ub:{Vb:{if((e|0)!=1){e=d+168|0;Gb(j,e);xb(e);b=(b|0)==8191?c:b-4176|0;if((b|0)>1915){break Vb}f=x[a+480208>>2];if(!(f&16)){break Ub}x[27524]=0;Q(269,a+1074312|0,7)|0;b=x[27524];x[27524]=0;if((b|0)!=1){break Tb}break qb}b=P()|0;break T}if(b>>>0>4200){break Rb}f=x[a+480208>>2]}if(!(f&16)){x[27524]=0;Q(269,a+1074312|0,7)|0;c=x[27524];x[27524]=0;if((c|0)==1){break qb}}if((b|0)>2385){break Sb}}x[27524]=0;Q(269,a+1074312|0,38)|0;b=x[27524];x[27524]=0;if((b|0)==1){break qb}}x[27524]=0;b=Q(269,a+1074312|0,102)|0;c=x[27524];x[27524]=0;if((c|0)==1){break qb}x[27524]=0;Q(269,b|0,48)|0;b=x[27524];x[27524]=0;if((b|0)==1){break qb}break Qb}if(b>>>0>4383){break Pb}}x[27524]=0;b=W(268,a+1074312|0,116,1)|0;c=x[27524];x[27524]=0;if((c|0)==1){break qb}x[27524]=0;Q(269,b|0,115)|0;b=x[27524];x[27524]=0;if((b|0)==1){break qb}break Ob}if(b>>>0>4563){break Xa}}x[27524]=0;b=Q(269,a+1074312|0,43)|0;c=x[27524];x[27524]=0;if((c|0)==1){break qb}x[27524]=0;e=Q(269,b|0,42)|0;b=x[27524];x[27524]=0;f=87;if((b|0)==1){break qb}}x[27524]=0;Q(269,e|0,f|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break qb}break Xa}x[27524]=0;Y(440,d+96|0);b=x[27524];x[27524]=0;Wb:{Xb:{Yb:{if((b|0)!=1){b=z[d+488>>1];x[d+48>>2]=b>>>8&15;x[27524]=0;x[d+32>>2]=b&255;R(437,d- -64|0,d+32|0);b=x[27524];x[27524]=0;if((b|0)==1){break Yb}x[27524]=0;X(423,d+168|0,d+96|0,d+48|0,d- -64|0);b=x[27524];x[27524]=0;if((b|0)==1){break Xb}b=d+168|0;Gb(j,b);xb(b);xb(d- -64|0);$b(d+96|0);break Xa}b=P()|0;break T}b=P()|0;break Wb}b=P()|0;xb(d- -64|0)}$b(d+96|0);break T}x[27524]=0;b=Q(1,d+168|0,8288)|0;c=x[27524];x[27524]=0;if((c|0)!=1){Gb(j,b);xb(b);break Xa}b=P()|0;break T}if(!((b|0)!=32767|z[d+490>>1]!=533)){x[27524]=0;b=Q(1,d+168|0,5045)|0;c=x[27524];x[27524]=0;if((c|0)!=1){Gb(j,b);xb(b);break Xa}b=P()|0;break T}x[27524]=0;R(141,d+96|0,4153);b=x[27524];x[27524]=0;Zb:{if((b|0)!=1){b=z[d+488>>1];x[d+64>>2]=b>>>8&15;x[d+48>>2]=b>>>4&15;x[27524]=0;x[d+32>>2]=b&15;ea(142,d+168|0,d+96|0,d- -64|0,d+48|0,d+32|0);b=x[27524];x[27524]=0;if((b|0)==1){break Zb}b=d+168|0;Gb(j,b);xb(b);$b(d+96|0);break Xa}b=P()|0;break T}b=P()|0;$b(d+96|0);break T}x[27524]=0;b=Q(1,d+168|0,6126)|0;c=x[27524];x[27524]=0;if((c|0)!=1){Gb(j,b);xb(b);break Xa}b=P()|0;break T}b=P()|0;break T}if(!KE(x[a+1074308>>2])){break Xa}x[27524]=0;c=Q(1,d+168|0,17094)|0;e=x[27524];x[27524]=0;_b:{if((e|0)!=1){x[27524]=0;Q(99,b|0,c|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break _b}xb(c);break Xa}b=P()|0;break T}b=P()|0;xb(c);break T}e=x[a+480180>>2];if(!((e|0)!=16777216|z[d+488>>1]<2186)){x[27524]=0;b=Q(159,h|0,B|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break Da}if(b){x[27524]=0;U(441,a|0,h|0,z[d+488>>1]);b=x[27524];x[27524]=0;if((b|0)==1){break Da}}e=x[a+480180>>2]}$b:{ac:{bc:{cc:{dc:{ec:{if((e|0)==16777216){x[27524]=0;Q(1,d+48|0,13796)|0;b=x[27524];x[27524]=0;if((b|0)!=1){break ec}b=P()|0;break T}x[27524]=0;R(270,d+32|0,4317);b=x[27524];x[27524]=0;if((b|0)==1){break dc}b=z[d+490>>1];x[d+28>>2]=b>>>8;x[27524]=0;x[d+12>>2]=b&255;R(437,d+16|0,d+12|0);b=x[27524];x[27524]=0;if((b|0)==1){break cc}x[27524]=0;X(423,d+48|0,d+32|0,d+28|0,d+16|0);b=x[27524];x[27524]=0;if((b|0)==1){break bc}}b=d+48|0;Gb(a+1298344|0,b);xb(b);if((e|0)!=16777216){xb(d+16|0);$b(d+32|0)}b=x[a+480180>>2];x[27524]=0;b=Q(1,d+48|0,((b|0)==16777216?10062:6130)|0)|0;c=x[27524];x[27524]=0;e=1;if((c|0)==1){break $b}Gb(a+1298356|0,b);xb(b);Gb(a+1298368|0,j);x[a+1298408>>2]=0;x[a+1298404>>2]=x[a+1074308>>2]?22:4;yb(E);yb(C);break w}b=P()|0;break T}b=P()|0;break ac}b=P()|0;xb(d+16|0)}$b(d+32|0);break T}b=P()|0;break T}b=P()|0;xb(c);break T}b=P()|0;break T}b=P()|0;xb(d- -64|0);break Sa}b=P()|0}xb(c);break T}b=P()|0;break T}b=P()|0;Ck(k);break Na}i=i+1|0;continue}break}b=P()|0}ec(l);break Ka}b=P()|0;break Ka}b=P()|0}yb(m);break T}b=P()|0;break T}b=P()|0;break T}b=P()|0;break T}b=P()|0;break T}fc:{b=Bb(x[n>>2],i);b=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);gc:{if(!b){break gc}x[27524]=0;b=Q(159,h|0,b|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break Ba}if(!b){break gc}x[27524]=0;b=T(198,h|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break wa}x[27524]=0;l=T(198,h|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break xa}if((l-1025&65535)>>>0<64512){break gc}x[27524]=0;c=Q(192,h|0,4)|0;e=x[27524];x[27524]=0;if((e|0)==1){break xa}if(!c){break gc}x[27524]=0;U(194,d+96|0,h|0,b|0);b=x[27524];x[27524]=0;if((b|0)==1){break ya}b=d+96|0;f=hc(d+168|0,b);yb(b);c=z[m>>1];b=0;x[27524]=0;g=Q(431,d+136|0,c|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break Aa}hc:{while(1){if(b>>>0>=l>>>0){break hc}c=x[f>>2];x[27524]=0;c=W(160,c|0,x[d+176>>2],1)|0;e=x[27524];x[27524]=0;if((e|0)==1){break fc}if(!c){break hc}x[27524]=0;c=T(210,f|0)|0;e=x[27524];x[27524]=0;ic:{if((e|0)!=1){c=c<<24>>24;if(c){break ic}b=b+1|0;continue}break Ca}jc:{e=c&127;o=e?e-1|0:0;k=o&65535;if(cd(x[g>>2],x[d+140>>2])>>>0>k>>>0){break jc}x[27524]=0;v[d+96|0]=0;U(433,g|0,k+1|0,d+96|0);e=x[27524];x[27524]=0;if((e|0)!=1){break jc}break Ca}kc:{if((c|0)<0){x[27524]=0;c=T(210,f|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break kc}J=Jb(x[g>>2],k),K=c,v[J|0]=K}e=Jb(x[g>>2],k);c=y[e|0];if(!(!(c&15)|k>>>0<z[m>>1])){w[m>>1]=o+1;c=y[e|0]}if(c&1){x[27524]=0;Q(192,f|0,1)|0;c=x[27524];x[27524]=0;if((c|0)==1){break kc}e=Jb(x[g>>2],k)}if(y[e|0]&2){x[27524]=0;Q(192,f|0,1)|0;c=x[27524];x[27524]=0;if((c|0)==1){break kc}e=Jb(x[g>>2],k)}if(y[e|0]&4){x[27524]=0;Q(192,f|0,1)|0;c=x[27524];x[27524]=0;if((c|0)==1){break kc}e=Jb(x[g>>2],k)}if(!(y[e|0]&8)){continue}x[27524]=0;Q(192,f|0,2)|0;c=x[27524];x[27524]=0;if((c|0)!=1){continue}}break}break Ca}x[d+96>>2]=x[h+8>>2];J=d,K=x[Yc(d+252|0,d+96|0)>>2],x[J+252>>2]=K;ec(g);yb(f)}i=i+1|0;continue}}break}b=P()|0;ec(g);break za}b=P()|0;break T}b=P()|0}yb(f);break T}b=P()|0;break T}b=P()|0;break T}b=P()|0;break T}b=P()|0;xb(d+168|0);break ta}b=P()|0}$b(d+96|0);break T}b=P()|0;break T}b=P()|0;break T}f=0;i=yB(d+96|0,x[g>>2]);x[27524]=0;Q(192,h|0,i|0)|0;i=x[27524];x[27524]=0;if((i|0)==1){break X}}if(y[d+99|0]!=1){break Z}b=x[g>>2]!=0|b}x[d+96>>2]=x[h+8>>2];J=d,K=x[Yc(d+252|0,d+96|0)>>2],x[J+252>>2]=K;s=(f|0)!=0}e=e+1|0;f=z[r>>1];continue}break}b=P()|0;break T}lc:{b=Bb(x[t>>2],e);b=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);mc:{if(!b){break mc}x[27524]=0;b=Q(159,h|0,b|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break lc}if(!b){break mc}b=x[h+8>>2];f=x[h>>2];x[27524]=0;b=W(160,f|0,b|0,554)|0;f=x[27524];x[27524]=0;if((f|0)==1){break lc}if(!b){break mc}x[27524]=0;b=W(255,a|0,e+1&65535,0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break W}if(!b){break mc}x[27524]=0;X(442,a|0,h|0,b|0,z[d+490>>1]);f=x[27524];x[27524]=0;if((f|0)==1){break W}v[b+33|0]=y[d+501|0]}e=e+1|0;f=z[g>>1];continue}break}b=P()|0;break T}b=P()|0}yb(E);break B}b=P()|0}yb(C);break x}b=P()|0;break x}b=P()|0;break x}}}}}b=P()|0}uc(n);uc(q);uc(t);break a}uc(n);uc(q);uc(t)}xb(j)}ib=d+640|0;return e|0}b=P()|0}xb(j);S(b|0);p()}function Ika(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;d=ib-1760|0;ib=d;yc(b);a:{if(!ii(b,d+1752|0)){break a}if(!RU(d+1752|0)){break a}if(!c){i=1;break a}o=y[d+1755|0];v[d+1751|0]=o;x[d+1744>>2]=-1;x[d+1740>>2]=1048576;if(o>>>0>=5){f=Jg(b);x[d+1744>>2]=f;if(!Ob(x[b>>2],x[b+8>>2],f)){break a}x[d+320>>2]=134217727;N=d,O=x[Hb(d+320|0,d+1744|0)>>2]<<5,x[N+1740>>2]=O}C=Nb(d+1728|0);x[d+320>>2]=x[d+1756>>2];f=x[Hb(d+1740|0,d+320|0)>>2];x[27524]=0;R(542,C|0,f|0);f=x[27524];x[27524]=0;b:{c:{d:{e:{f:{if((f|0)!=1){x[27524]=0;f=W(543,b|0,C|0,x[d+1756>>2])|0;e=x[27524];x[27524]=0;g:{if((e|0)==1){break g}if(!f){break b}if(o>>>0>=5){x[27524]=0;Q(159,b|0,x[d+1744>>2]+12|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break g}}x[27524]=0;R(250,a|0,0);f=x[27524];x[27524]=0;if((f|0)==1){break g}gg(a);he(d+1696|0,x[C>>2],x[C+4>>2]);f=Id(d+1688|0);x[27524]=0;e=x[f+4>>2];x[d+88>>2]=x[f>>2];x[d+92>>2]=e;n=Mg(544,d+1704|0,x[d+1696>>2],x[d+1700>>2],d+88|0);f=x[27524];x[27524]=0;h:{i:{j:{if((f|0)!=1){x[27524]=0;U(354,n|0,a+1298308|0,-1);f=x[27524];x[27524]=0;if((f|0)==1){break j}x[27524]=0;U(354,n|0,a+1298332|0,-1);f=x[27524];x[27524]=0;if((f|0)==1){break j}x[27524]=0;f=Q(545,n|0,d+1264|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break f}if(!f){break c}f=v[d+1264|0];if((f|0)<=0|(y[d+1273|0]|y[d+1274|0]<<8)>>>0>255|(y[d+1275|0]|y[d+1276|0]<<8)>>>0>3999){break c}E=a+480188|0;w[E>>1]=f&255;_e(Tb(x[a+484360>>2],y[a+484376|0]),y[d+1267|0]|y[d+1268|0]<<8);w[a+480192>>1]=y[d+1273|0]|y[d+1274|0]<<8;w[a+480190>>1]=y[d+1275|0]|y[d+1276|0]<<8;f=y[d+1277|0];x[a+480196>>2]=f?f:6;f=y[d+1278|0];x[a+480204>>2]=D(f?f:125,1e4);e=y[d+1279|0]|y[d+1280|0]<<8|(y[d+1281|0]<<16|y[d+1282|0]<<24);f=32;k:{if(e&256){break k}f=2;if(e&2){break k}f=1;if(e&128){break k}f=e&8?16:4}x[27524]=0;R(410,a|0,f|0);f=x[27524];x[27524]=0;if((f|0)==1){break f}g=x[a+480208>>2];e=g|16777216;x[a+480208>>2]=e;f=y[d+1279|0]|y[d+1280|0]<<8|(y[d+1281|0]<<16|y[d+1282|0]<<24);if(f&1){e=g|16777232;x[a+480208>>2]=e}g=x[a+480180>>2];k=(g|0)==32;h=k&!(f&1024);m=(g|0)==2;i=m&f>>>4;r=f&2097152;m=m&f>>>2;k=k&!(f&2048);if(h|(r|m|(k|i))){e=i?e|65536:e;e=m?e|2:e;e=k?e|4:e;x[a+480208>>2]=r>>>6|(h?e|8:e)}if(f&524288){x[27524]=0;W(268,a+1074312|0,5,1)|0;f=x[27524];x[27524]=0;if((f|0)==1){break f}g=x[a+480180>>2]}if((g|0)==2){break i}if((g|0)!=32){break h}v[d+320|0]=y[d+1283|0];v[d+240|0]=128;N=a,O=y[Ub(d+320|0,d+240|0)|0]<<1,x[N+480200>>2]=O;break h}h=P()|0;break d}h=P()|0;break e}v[d+320|0]=y[d+1283|0];v[d+240|0]=64;N=a,O=y[Ub(d+320|0,d+240|0)|0]<<2,x[N+480200>>2]=O}f=v[d+1285|0];l:{if((f|0)<0){f=f+52|0;break l}G=_r(+(f|0)*3.1/20);m:{if(G<4294967296&G>=0){f=~~G>>>0;break m}f=0}f=f+51|0}x[a+480228>>2]=f;w[d+320>>1]=64;h=z[Tc(E,d+320|0)>>1];e=0;k=(g|0)!=32;m=(g|0)==4;i=0;while(1)if((h|0)==(i|0)){i=0;k=0;while(1){if((e|0)!=16){k=y[(d+e|0)+1414|0]!=0|k;e=e+1|0;continue}break}while(1){if((i|0)!=128){k=y[((i<<1)+d|0)+1431|0]!=0|k;i=i+1|0;continue}break}n:{if(!(k&1)){break n}f=a+901692|0;i=0;while(1){if((i|0)==16){f=a+902204|0;i=0;while(1){if((i|0)!=128){e=(d+1264|0)+(i<<1)|0;o:{if(y[e+167|0]){x[27524]=0;Y(546,d+240|0);g=x[27524];x[27524]=0;p:{q:{r:{s:{t:{if((g|0)!=1){g=y[e+167|0];x[27524]=0;x[d+264>>2]=g-1;R(547,d+1208|0,d+264|0);g=x[27524];x[27524]=0;if((g|0)==1){break t}e=y[e+166|0];x[27524]=0;v[d+208|0]=e;R(548,d+1184|0,d+208|0);e=x[27524];x[27524]=0;if((e|0)==1){break s}x[27524]=0;X(549,d+320|0,d+240|0,d+1208|0,d+1184|0);e=x[27524];x[27524]=0;if((e|0)==1){break r}e=d+320|0;ye(d+1240|0,e);pf(De(f,i),x[d+1240>>2],x[d+1244>>2]);wb(e);wb(d+1184|0);wb(d+1208|0);Zb(d+240|0);break o}h=P()|0;break e}h=P()|0;break p}h=P()|0;break q}h=P()|0;wb(d+1184|0)}wb(d+1208|0)}Zb(d+240|0);break e}e=qc(d+1232|0,21631);pf(De(f,i),x[e>>2],x[d+1236>>2])}i=i+1|0;continue}break}g=x[a+480180>>2];break n}e=(d+i|0)+1414|0;u:{if(y[e|0]){x[27524]=0;Y(550,d+240|0);g=x[27524];x[27524]=0;v:{w:{x:{if((g|0)!=1){e=y[e|0];x[27524]=0;x[d+1184>>2]=e-1;R(547,d+1208|0,d+1184|0);e=x[27524];x[27524]=0;if((e|0)==1){break x}x[27524]=0;U(292,d+320|0,d+240|0,d+1208|0);e=x[27524];x[27524]=0;if((e|0)==1){break w}e=d+320|0;ye(d+1256|0,e);pf(De(f,i),x[d+1256>>2],x[d+1260>>2]);wb(e);wb(d+1208|0);Zb(d+240|0);break u}h=P()|0;break e}h=P()|0;break v}h=P()|0;wb(d+1208|0)}Zb(d+240|0);break e}e=qc(d+1248|0,21631);pf(De(f,i),x[e>>2],x[d+1252>>2])}i=i+1|0;continue}}f=y[a+484376|0];e=x[a+484360>>2];x[27524]=0;e=Tb(e,f);f=g&5;ea(344,e|0,n|0,y[d+1265|0]|y[d+1266|0]<<8,(f?65535:255)|0,(f?65535:254)|0);f=x[27524];x[27524]=0;if((f|0)!=1){x[27524]=0;U(194,d+320|0,n|0,D(y[d+1264|0],y[d+1269|0]|y[d+1270|0]<<8)<<1);f=x[27524];x[27524]=0;if((f|0)!=1){f=d+320|0;H=hc(d+1208|0,f);yb(f);x[27524]=0;U(194,f|0,n|0,(y[d+1269|0]|y[d+1270|0]<<8)<<1);f=x[27524];x[27524]=0;y:{if((f|0)!=1){f=d+320|0;I=hc(d+1184|0,f);yb(f);x[27524]=0;r=Q(222,d+1168|0,y[d+1271|0]|y[d+1272|0]<<8)|0;f=x[27524];x[27524]=0;z:{if((f|0)!=1){N=d,O=Cb(x[r>>2]),x[N+264>>2]=O;f=Cb(x[r+4>>2]);A:{B:{C:{while(1){e=x[d+264>>2];if(!Mb(e,f)){q=a+480180|0;f=x[q>>2];u=c&1;if(!u){break B}x[27524]=0;R(229,a+484344|0,y[d+1269|0]|y[d+1270|0]<<8);e=x[27524];x[27524]=0;if((e|0)!=1){break B}h=P()|0;break A}x[27524]=0;g=T(161,n|0)|0;h=x[27524];x[27524]=0;if((h|0)!=1){x[27524]=0;U(194,d+240|0,n|0,g|0);g=x[27524];x[27524]=0;if((g|0)==1){break C}h=e;e=d+240|0;g=hc(d+320|0,e);fd(h,g);yb(g);yb(e);Uf(d+264|0);continue}break}h=P()|0;break A}h=P()|0;break A}s=(f|0)==16?14:(f|0)==32?1:13;J=a+484344|0;m=1;while(1){D:{E:{F:{G:{H:{I:{if((y[d+1269|0]|y[d+1270|0]<<8)>>>0<=l>>>0){switch(x[a+480180>>2]-1|0){case 0:break G;case 3:break I;default:break F}}x[27524]=0;f=T(198,I|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break H}x[d+240>>2]=f;if(!u){break D}x[27524]=0;f=W(230,J|0,l&65535,f|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break H}j=0;if(!f){break D}while(1){g=j&65535;if(g>>>0>=y[d+1264|0]){break D}x[27524]=0;f=T(198,H|0)|0;e=x[27524];x[27524]=0;J:{if((e|0)!=1){e=x[r>>2];if(Kf(e,x[r+4>>2])>>>0<=f>>>0){break J}B=Yg(e,f);yc(B);e=0;f=Xb(x[J>>2],l);i=hd(x[f>>2],x[x[f+48>>2]+12>>2],0,g);K:while(1){if(A[d+240>>2]<=e>>>0){break J}x[27524]=0;f=T(210,B|0)|0;g=x[27524];x[27524]=0;if((g|0)!=1){if(!f){break J}t=f>>>4|0;K=f&15;k=0;g=Bg(d+320|0);while(1){L:{M:{N:{if(K>>>0>(k&255)>>>0){x[27524]=0;R(264,d+264|0,B|0);f=x[27524];x[27524]=0;if((f|0)==1){break N}O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{f=y[Jb(d+264|0,0)|0];switch(f-1|0){case 2:case 3:case 4:case 7:case 8:case 9:case 11:case 12:case 13:case 16:case 18:case 21:case 22:case 23:case 24:case 25:case 27:case 32:break O;case 33:break S;case 30:case 31:break T;case 29:break U;case 28:break V;case 26:break W;case 19:case 20:break X;case 17:break Y;case 15:break Z;case 14:break _;case 10:break $;case 6:break aa;case 5:break ba;case 1:break ca;case 0:break da;default:break ea}}switch(f-48|0){case 4:break P;case 1:case 2:break Q;case 0:break R;default:break O}}f=y[Jb(d+264|0,1)|0];fa:{if(f>>>0<=119){f=f+s|0;break fa}ga:{switch(f-254|0){case 1:f=255;break fa;case 0:f=254;break fa;default:break ga}}f=253}v[g|0]=f;m=OB(f)&m;break L}N=d,O=y[Jb(d+264|0,1)|0]+1|0,v[N+321|0]=O;break L}ha:{if(y[d+322|0]){break ha}f=x[q>>2];if((f|0)!=32){if((f|0)!=4){break ha}f=y[Jb(d+264|0,1)|0];if(f&15){break ha}v[d+322|0]=11;v[d+324|0]=f>>>4;break L}f=y[Jb(d+264|0,1)|0];h=0;while(1){if((h|0)==10){break ha}if((f|0)==y[h+43776|0]){v[d+324|0]=h;v[d+322|0]=11;break L}else{h=h+1|0;continue}}}N=d,O=y[Jb(d+264|0,1)|0],v[N+325|0]=O;v[d+323|0]=4;break L}f=Jb(d+264|0,1);ia:{if(y[d+322|0]){break ia}h=y[f|0];if(x[q>>2]!=32|h>>>0>9){break ia}v[d+324|0]=h;v[d+322|0]=8;break L}v[d+325|0]=y[f|0];v[d+323|0]=5;break L}ja:{if(y[d+322|0]){break ja}ka:{f=x[q>>2];if((f|0)!=4){if((f|0)!=32){break ja}h=Jb(d+264|0,1);f=y[h|0];if((f|0)!=255){break ka}v[d+324|0]=64;v[d+322|0]=2;break L}h=Jb(d+264|0,1);if(y[h|0]&15){break ja}break M}if(!(f&3)){break M}}N=d,O=y[Jb(d+264|0,1)|0],v[N+325|0]=O;v[d+323|0]=9;break L}h=y[d+322|0];f=Jb(d+264|0,1);la:{if(h|x[q>>2]==1){break la}h=y[f|0];if(h>>>0>64){break la}v[d+324|0]=h;v[d+322|0]=1;break L}v[d+325|0]=y[f|0];v[d+323|0]=13;break L}f=y[Jb(d+264|0,1)|0];v[d+325|0]=f;v[d+323|0]=14;if(x[q>>2]==32){break L}v[d+325|0]=D((f&240)>>>4|0,10)+(f&15);break L}f=y[Jb(d+264|0,1)|0];v[d+325|0]=f;v[d+323|0]=f>>>0<32?16:17;break L}h=y[Jb(d+264|0,1)|0];if(h>>>0>=16){v[d+324|0]=h>>>4;v[d+322|0]=(f|0)==20?3:5;break L}v[d+324|0]=h&15;v[d+322|0]=(f|0)==20?4:6;break L}f=y[Jb(d+264|0,1)|0];if(f>>>0>=16){v[d+322|0]=10;v[d+324|0]=f>>>4;break L}v[d+322|0]=9;v[d+324|0]=f&15;break L}f=y[Jb(d+264|0,1)|0];v[d+323|0]=28;v[d+325|0]=f|16;break L}f=y[Jb(d+264|0,1)|0];v[d+323|0]=28;v[d+325|0]=f|32;break L}N=d,O=y[Jb(d+264|0,1)|0],v[N+324|0]=O;v[d+322|0]=(f|0)==31?7:8;break L}f=y[d+323|0];v[d+323|0]=(f|0)==4?6:(f|0)==5?7:11;N=d,O=y[Jb(d+264|0,1)|0],v[N+325|0]=O;break L}f=Jb(d+264|0,1);v[d+324|0]=y[f|0]%10;f=y[f|0];if(f>>>0<=9){v[d+322|0]=5;break L}if(f>>>0<=19){v[d+322|0]=6;break L}if(f>>>0<=29){v[d+322|0]=3;break L}if(f>>>0>39){break L}v[d+322|0]=4;break L}N=d,O=y[Jb(d+264|0,1)|0],v[N+324|0]=O;v[d+322|0]=(f|0)==49?13:12;break L}f=y[Jb(d+264|0,1)|0]+33|0;if((f&255)>>>0>9){break L}v[d+322|0]=15;v[d+324|0]=f;break L}if(f>>>0>57){break L}N=d,O=y[Jb(d+264|0,1)|0],v[N+325|0]=O;v[d+323|0]=y[f+26832|0];break L}x[d+264>>2]=e+t;f=x[Hb(d+264|0,d+240|0)>>2];f=e>>>0>f>>>0?e:f;while(1){if((e|0)!=(f|0)){h=y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24);v[i|0]=h;v[i+1|0]=h>>>8;v[i+2|0]=h>>>16;v[i+3|0]=h>>>24;h=y[g+4|0]|y[g+5|0]<<8;v[i+4|0]=h;v[i+5|0]=h>>>8;e=e+1|0;i=D(y[d+1264|0],6)+i|0;continue}break}e=f;continue K}h=P()|0;break A}f=y[h|0];v[d+322|0]=2;v[d+324|0]=f>>>2}k=k+1|0;continue}}break}h=P()|0;break A}h=P()|0;break A}j=j+1|0;continue}}i=z[a+480192>>1];f=0;break E}h=P()|0;break A}if((m^1)&1|z[E>>1]!=4){break F}x[a+480208>>2]=x[a+480208>>2]|8454144}i=0;f=!((y[d+1279|0]|y[d+1280|0]<<8|(y[d+1281|0]<<16|y[d+1282|0]<<24))&512)}x[27524]=0;B=Q(551,d+1152|0,i|0)|0;e=x[27524];x[27524]=0;ma:{na:{oa:{pa:{qa:{if((e|0)!=1){q=a+480192|0;i=o>>>0<5;m=a+480180|0;k=1;ra:{while(1){h=k&65535;if(h>>>0>z[q>>1]){break ra}sa:{ta:{ua:{va:{if(!f){x[27524]=0;g=W(255,a|0,h|0,0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break va}if(g){break ua}}while(1){x[27524]=0;e=T(210,n|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break na}if(e){continue}break}if(!i){while(1){x[27524]=0;e=T(210,n|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){h=P()|0;break ma}if(e){continue}break}}x[27524]=0;Q(192,n|0,826)|0;e=x[27524];x[27524]=0;if((e|0)!=1){break ta}}h=P()|0;break ma}e=Kb(d+240|0);x[27524]=0;U(354,n|0,e|0,-1);l=x[27524];x[27524]=0;if((l|0)==1){break sa}Cc(g+492|0,e);if(!i){x[27524]=0;U(354,n|0,e|0,-1);l=x[27524];x[27524]=0;if((l|0)==1){break sa}Cc(g+524|0,e)}x[27524]=0;l=Q(552,n|0,d+320|0)|0;j=x[27524];x[27524]=0;if((j|0)==1){break oa}if(!l){break qa}l=x[m>>2];x[27524]=0;U(553,d+320|0,g|0,l|0);g=x[27524];x[27524]=0;if((g|0)==1){break oa}if(x[m>>2]==4){g=Bb(x[B>>2],h-1|0);h=z[d+1122>>1]|z[d+1124>>1]<<16;v[g|0]=h;v[g+1|0]=h>>>8;v[g+2|0]=h>>>16;v[g+3|0]=h>>>24}wb(e)}k=k+1|0;continue}break}break oa}if(!f){break pa}w[a+480192>>1]=0;break pa}h=P()|0;break A}wb(e)}f=z[a+480190>>1];x[27524]=0;q=Q(554,d+304|0,f|0)|0;f=x[27524];x[27524]=0;if((f|0)!=1){K=!(v[d+1279|0]&1)|o>>>0>4;u=c&2;M=a+480180|0;k=1;c=0;while(1){f=c;wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{Da:{Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{m=k&65535;if(m>>>0<=z[a+480190>>1]){i=Kb(d+288|0);x[27524]=0;U(354,n|0,i|0,-1);c=x[27524];x[27524]=0;Ra:{Sa:{if((c|0)!=1){Cc(((m<<5)+a|0)+946304|0,i);c=o>>>0<5;if(c){break Sa}x[27524]=0;U(354,n|0,i|0,-1);e=x[27524];x[27524]=0;if((e|0)!=1){break Ra}}h=P()|0;break za}Vf(i)}x[27524]=0;e=Q(555,n|0,d+320|0)|0;g=x[27524];x[27524]=0;Ta:{Ua:{if((g|0)==1){break Ua}if(!e){break Ta}g=x[M>>2];x[27524]=0;h=D(m,104)+a|0;e=h+484380|0;X(556,d+320|0,e|0,g|0,K|0);g=x[27524];x[27524]=0;if((g|0)==1){break Ua}Fe(h+484423|0,i);s=0;Va:{if((z[d+340>>1]&61440)!=28672|c){break Va}x[27524]=0;s=T(557,n|0)|0;c=x[27524];x[27524]=0;if((c|0)!=1){break Va}h=P()|0;break za}if(!u){break xa}g=y[d+355|0]|y[d+356|0]<<8|(y[d+357|0]<<16|y[d+358|0]<<24);c=z[d+340>>1];l=c&61440;if(!(g|l)){c=Zc(d+240|0,c&1?16:8,c&1024?3:1,0,0);x[27524]=0;W(223,c|0,e|0,b|0)|0;c=x[27524];x[27524]=0;if((c|0)!=1){break xa}h=P()|0;break za}if((g|0)<0){c=g+m|0;if((c|0)<=0){break xa}QU(e,(D(c,104)+a|0)+484380|0);break xa}if((g|0)<=0){break xa}if(c&1){j=h+484414|0;w[j>>1]=z[j>>1]|1}if(c&1024){j=h+484414|0;w[j>>1]=z[j>>1]|64}x[27524]=0;U(194,d+240|0,b|0,g|0);g=x[27524];x[27524]=0;Wa:{Xa:{Ya:{Za:{_a:{$a:{if((g|0)!=1){j=d+240|0;g=hc(d+264|0,j);yb(j);j=Md(z[e+34>>1]);L=(l|0)==16384;if(!L&(l|0)!=8192){break Za}t=x[g>>2];x[27524]=0;t=T(164,t|0)|0;F=x[27524];x[27524]=0;if((F|0)==1){break Wa}F=4/(j>>>0)|0;qoa(F,0,t,0);wc(e,kb?-1:D(F,t));if((l|0)==8192){break $a}if(!L){break Za}if(!Xg(e)){break Ya}c=x[h+484400>>2];e=x[e>>2];if(!(v[d+340|0]&1)){break _a}x[27524]=0;X(558,g|0,c|0,e|0,j|0);e=x[27524];x[27524]=0;c=f;if((e|0)==1){break Ba}break Xa}h=P()|0;break za}if(!Xg(e)){break Ya}c=x[h+484400>>2];e=x[e>>2];if(v[d+340|0]&1){x[27524]=0;X(559,g|0,c|0,e|0,j|0);e=x[27524];x[27524]=0;c=f;if((e|0)!=1){break Xa}break Ba}x[27524]=0;X(560,g|0,c|0,e|0,j|0);e=x[27524];x[27524]=0;c=f;if((e|0)==1){break Ba}break Xa}x[27524]=0;X(561,g|0,c|0,e|0,j|0);e=x[27524];x[27524]=0;c=f;if((e|0)==1){break Ba}break Xa}if((c&45056)==12288){c=OU(d+240|0,g,y[d+359|0]|y[d+360|0]<<8,s);N=fd(sf(x[q>>2],m-1|0),c),O=x[c+20>>2],x[N+20>>2]=O;yb(c);break Ya}if((l|0)!=32768){c=1;if((l|0)!=4096){break Xa}l=te(d+240|0,g);x[27524]=0;c=Q(562,d+232|0,g|0)|0;j=x[27524];x[27524]=0;if((j|0)!=1){ab:{bb:{if(!y[d+237|0]){break bb}s=y[d+359|0]|y[d+360|0]<<8;j=z[d+234>>1]<<1;if(s>>>0<(j&65535)>>>0){break bb}j=s-j|0;v[d+359|0]=j;v[d+360|0]=j>>>8;c=z[c>>1];x[27524]=0;Q(159,g|0,c|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break ab}x[27524]=0;c=T(206,g|0)|0;j=x[27524];x[27524]=0;if((j|0)==1){break ab}x[27524]=0;U(194,d+184|0,g|0,c|0);c=x[27524];x[27524]=0;if((c|0)==1){break ab}c=d+184|0;j=hc(d+208|0,c);fd(l,j);yb(j);yb(c)}x[27524]=0;m=W(563,a|0,m|0,l|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break ab}c=1;if(m){c=y[d+359|0]|y[d+360|0]<<8;cb:{if(!c){break cb}m=z[e+34>>1];j=Nj(x[e>>2],m);if(j>>>0<=c>>>0){break cb}m=Mk(m);h=x[h+484400>>2];Wi(h,c+h|0,j-c|0);x[e>>2]=x[e>>2]-((c>>>0)/(m>>>0)|0)}wc(e,x[d+328>>2]);c=f}yb(l);break Xa}}h=P()|0;yb(l);break Aa}x[27524]=0;c=Q(421,g|0,d+240|0)|0;h=x[27524];x[27524]=0;if((h|0)==1){break Qa}if(!c){break Ya}x[d+80>>2]=x[d+248>>2];c=x[d+244>>2];x[d+72>>2]=x[d+240>>2];x[d+76>>2]=c;Rm(e,1,d+72|0)}c=f}yb(g);break wa}h=P()|0;break Aa}h=P()|0;break za}wb(i)}db:{if(!u){break db}m=1;while(1){i=m&65535;if(i>>>0>z[a+480190>>1]){break db}b=sf(x[q>>2],i-1|0);c=x[b>>2];x[27524]=0;c=T(182,c|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break Pa}eb:{fb:{if(!c){break fb}e=z[b+22>>1];c=e+m&65535;k=z[b+20>>1];o=(e|0)!=0&(c|0)!=0&c>>>0<=z[a+480190>>1]&(k|0)!=0;gb:{if(o){e=sf(x[q>>2],c-1|0);break gb}c=x[b>>2];x[27524]=0;k=T(164,c|0)|0;c=x[27524];x[27524]=0;e=b;if((c|0)==1){break Oa}}yc(e);hb:{if(o){c=x[e+8>>2];g=x[e>>2];h=z[b+20>>1];x[27524]=0;c=W(160,g|0,c|0,h|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break Oa}if(!c){break fb}x[d+240>>2]=0;x[d+264>>2]=0;x[27524]=0;U(207,d+320|0,e|0,k|0);c=x[27524];x[27524]=0;ib:{if((c|0)!=1){g=_A(Le(d+320|0),Mi(x[d+320>>2]),d+240|0,d+264|0);x[27524]=0;Q(192,e|0,x[d+240>>2])|0;c=x[27524];x[27524]=0;if((c|0)==1){break ib}Rc(d+320|0);break hb}h=P()|0;break ya}h=P()|0;Rc(d+320|0);break ya}g=0;x[d+240>>2]=0;x[d+264>>2]=0}x[27524]=0;R(564,d+320|0,b|0);c=x[27524];x[27524]=0;jb:{kb:{if((c|0)!=1){h=Le(d+320|0);k=x[d+320>>2];if(!o){g=_A(h,Mi(k),d+240|0,d+264|0);x[27524]=0;c=x[d+240>>2];Q(192,b|0,c|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break eb}k=k-c|0;h=c+h|0}if(g){break kb}f=1;break jb}h=P()|0;break ya}c=D(i,104)+a|0;o=c+484380|0;Xg(o);s=c+484400|0;e=0;i=x[d+264>>2];while(1){lb:{if(!k|(i|0)!=1?i:0){break lb}c=x[o>>2];if(c>>>0<=e>>>0){break lb}if(!_d(c,x[o+20>>2])){break lb}x[d+208>>2]=0;x[d+184>>2]=0;l=NU(g,h,Mi(k),d+208|0,d+288|0,d+184|0);x[27524]=0;x[d+240>>2]=l;Q(192,b|0,l|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break Ca}gi(d+184|0,Mi(x[o>>2]-e|0));c=x[d+184>>2];mb:{if((c|0)<=0){break mb}i=x[d+208>>2];t=z[o+34>>1];if((Md(t)|0)!=(i|0)){break mb}j=D(e,i);u=x[s>>2];if(t&1){x[d+176>>2]=c;x[d+160>>2]=c;x[d- -64>>2]=c;x[d+48>>2]=c;x[d+156>>2]=i;x[d+152>>2]=x[d+288>>2];x[d+172>>2]=i;x[d+168>>2]=u+(j<<1);x[27524]=0;i=x[d+156>>2];x[d+40>>2]=x[d+152>>2];x[d+44>>2]=i;i=x[d+172>>2];x[d+56>>2]=x[d+168>>2];x[d+60>>2]=i;R(565,d+56|0,d+40|0);i=x[27524];x[27524]=0;if((i|0)!=1){break mb}break Ca}x[d+144>>2]=c;x[d+128>>2]=c;x[d+32>>2]=c;x[d+16>>2]=c;x[d+124>>2]=i;x[d+120>>2]=x[d+288>>2];x[d+140>>2]=i;x[d+136>>2]=j+u;x[27524]=0;i=x[d+124>>2];x[d+8>>2]=x[d+120>>2];x[d+12>>2]=i;i=x[d+140>>2];x[d+24>>2]=x[d+136>>2];x[d+28>>2]=i;R(566,d+24|0,d+8|0);i=x[27524];x[27524]=0;if((i|0)==1){break Ca}}k=k-l|0;h=h+l|0;i=MU(g);x[d+264>>2]=i;e=c+e|0;continue}break}LU(g)}Rc(d+320|0)}m=m+1|0;continue}break}break Ca}nb:{if(x[a+480180>>2]!=4){break nb}i=0;c=a+480192|0;while(1){if(z[c>>1]<=i>>>0){break nb}b=Bb(x[B>>2],i);e=y[b+3|0];g=y[b+2|0];h=y[b+1|0];b=y[b|0];x[27524]=0;i=i+1|0;ma(395,a|0,i&65535,b|0,h|0,g|0,e|0);b=x[27524];x[27524]=0;if((b|0)!=1){continue}break}h=P()|0;break ya}if(!(y[d+1281|0]&16)){break Ka}b=x[n+8>>2];c=x[n>>2];x[27524]=0;b=W(160,c|0,b|0,1)|0;c=x[27524];x[27524]=0;if((c|0)==1){break Ma}if(!b){break Ka}i=0;x[27524]=0;b=T(210,n|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break Na}if(!(b&1)){break La}while(1){if(z[E>>1]<=i>>>0){break La}x[27524]=0;b=T(161,n|0)|0;c=x[27524];x[27524]=0;if((c|0)!=1){v[((i<<5)+a|0)+480288|0]=b;i=i+1|0;continue}break}h=P()|0;break ya}h=P()|0;break Aa}h=P()|0;break ya}h=P()|0;break ya}h=P()|0;break ya}h=P()|0;break ya}e=a+906300|0;while(1){b=x[n+8>>2];c=x[n>>2];x[27524]=0;b=W(160,c|0,b|0,1)|0;c=x[27524];x[27524]=0;if((c|0)==1){break Da}if(!b){break Ka}x[27524]=0;b=T(210,n|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break Ia}if(!b){break Ka}x[27524]=0;c=T(161,n|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break Ja}x[27524]=0;U(194,d+240|0,n|0,c|0);c=x[27524];x[27524]=0;if((c|0)==1){break Ja}g=d+240|0;c=hc(d+320|0,g);yb(g);ob:{if(b>>>0<=250){x[27524]=0;R(443,c|0,Nd(e,b-1|0)|0);b=x[27524];x[27524]=0;if((b|0)==1){break ob}}yb(c);continue}break}h=P()|0;yb(c);break ya}k=a+901404|0;c=Kb(d+208|0);m=a+480180|0;o=a+484348|0;e=0;h=0;while(1){b=x[n+8>>2];g=x[n>>2];x[27524]=0;b=W(160,g|0,b|0,8)|0;g=x[27524];x[27524]=0;pb:{qb:{rb:{sb:{tb:{if((g|0)!=1){if(b){x[27524]=0;g=T(161,n|0)|0;b=x[27524];x[27524]=0;ub:{vb:{wb:{xb:{yb:{zb:{Ab:{Bb:{if((b|0)!=1){x[27524]=0;b=T(161,n|0)|0;i=x[27524];x[27524]=0;if((i|0)==1){break Bb}x[27524]=0;U(194,d+320|0,n|0,b|0);b=x[27524];x[27524]=0;if((b|0)==1){break Ab}i=d+320|0;b=hc(d+240|0,i);yb(i);if((g|0)==1229211981){break xb}if((g|0)==1229476432){break yb}if((g|0)==1397900630){break zb}if((g|0)!=1414548815){break pb}x[27524]=0;g=Q(406,b|0,13849)|0;i=x[27524];x[27524]=0;if((i|0)==1){break Ha}if(!g){break qb}x[27524]=0;g=T(161,b|0)|0;i=x[27524];x[27524]=0;if((i|0)!=1){x[27524]=0;U(194,d+320|0,b|0,g|0);g=x[27524];x[27524]=0;if((g|0)!=1){break wb}}h=P()|0;break Ga}h=P()|0;break Ea}h=P()|0;break Ea}h=P()|0;break Ea}Cb:{Db:{Eb:{g=x[m>>2];switch(g-2|0){case 1:break pb;case 0:break vb;case 2:break Db;default:break Eb}}if((g|0)==16){break Cb}if((g|0)!=32){break pb}x[27524]=0;e=T(198,b|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break Ha}x[27524]=0;h=T(198,b|0)|0;g=x[27524];x[27524]=0;if((g|0)!=1){break pb}break Ha}x[d+320>>2]=32;g=x[b>>2];x[27524]=0;g=T(164,g|0)|0;i=x[27524];x[27524]=0;if((i|0)!=1){x[d+264>>2]=g;g=x[Hb(d+320|0,d+264|0)>>2];x[27524]=0;U(567,b|0,c|0,g|0);g=x[27524];x[27524]=0;if((g|0)!=1){break pb}}h=P()|0;break Ga}x[27524]=0;g=T(210,b|0)|0;i=x[27524];x[27524]=0;if((i|0)==1){break ub}x[27524]=0;R(568,d+264|0,4214);i=x[27524];x[27524]=0;Fb:{if((i|0)!=1){x[d+288>>2]=g>>>4;x[27524]=0;x[d+104>>2]=g&15;X(306,d+320|0,d+264|0,d+288|0,d+104|0);g=x[27524];x[27524]=0;if((g|0)==1){break Fb}g=d+320|0;Gb(c,g);xb(g);$b(d+264|0);break pb}h=P()|0;break Ga}h=P()|0;$b(d+264|0);break Ga}x[27524]=0;g=T(210,b|0)|0;i=x[27524];x[27524]=0;if((i|0)==1){break Ha}x[a+480216>>2]=g;x[27524]=0;g=T(210,b|0)|0;i=x[27524];x[27524]=0;if((i|0)==1){break Ha}x[a+480220>>2]=g;break pb}x[27524]=0;Q(416,b|0,k|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break Ha}BB(k);break pb}i=d+320|0;g=hc(d+264|0,i);yb(i);i=x[g>>2];x[27524]=0;i=T(164,i|0)|0;l=x[27524];x[27524]=0;if((l|0)==1){break rb}w[d+320>>1]=i>>>5;N=d,O=Jf(x[a+484344>>2],x[o>>2]),w[N+288>>1]=O;l=z[Tc(d+320|0,d+288|0)>>1];i=0;while(1){if((i|0)==(l|0)){yb(g);break qb}x[27524]=0;R(569,g|0,d+320|0);j=x[27524];x[27524]=0;Gb:{if((j|0)==1){break Gb}j=x[J>>2];x[27524]=0;R(570,Xb(j,i)|0,d+320|0);j=x[27524];x[27524]=0;if((j|0)==1){break Gb}i=i+1|0;continue}break}break rb}x[27524]=0;e=T(198,b|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break Ha}break pb}h=P()|0;break Ga}b=x[a+480180>>2];Hb:{Ib:{Jb:{if((b|0)!=32){break Jb}g=e&65535;if(g>>>0<256){break Jb}if(g>>>0<532){break Ib}}b=(b|0)!=2;Kb:{if(b){break Kb}g=e&65535;if(g>>>0<12544){break Kb}if(g>>>0<12820){break Ib}}if(b){break Hb}b=e&65535;if(b>>>0<4864|b>>>0>4895){break Hb}}Dq(k)}i=1;Lb:{if(!(v[d+1281|0]&1)){break Lb}e=x[a+1074308>>2];if(!e){e=a+480192|0;g=a+480180|0;while(1){b=i&65535;if(b>>>0<=z[e>>1]){b=x[((b<<2)+a|0)+900380>>2];if(b){k=x[g>>2];x[27524]=0;R(571,Mh(b,2)|0,k|0);k=x[27524];x[27524]=0;if((k|0)==1){break tb}v[b+19|0]=y[b+19|0]+3>>>2}i=i+1|0;continue}break}e=x[a+1074308>>2]}if(e>>>0<=18350079){x[27524]=0;b=Q(269,a+1074312|0,27)|0;e=x[27524];x[27524]=0;if((e|0)==1){break Fa}x[27524]=0;Q(269,b|0,57)|0;b=x[27524];x[27524]=0;if((b|0)==1){break Fa}e=x[a+1074308>>2]}if(e>>>0<=19070975){x[27524]=0;Q(269,a+1074312|0,73)|0;b=x[27524];x[27524]=0;if((b|0)==1){break Fa}e=x[a+1074308>>2]}if(e>>>0>19267583){break Lb}x[27524]=0;Q(269,a+1074312|0,50)|0;b=x[27524];x[27524]=0;if((b|0)==1){break Fa}}Mb:{Nb:{Ob:{Pb:{Qb:{Rb:{Sb:{Tb:{Ub:{Vb:{Wb:{Xb:{Yb:{Zb:{if(yh(x[c+4>>2],y[c+11|0])){x[27524]=0;Y(572,d+240|0);b=x[27524];x[27524]=0;_b:{if((b|0)!=1){x[27524]=0;U(540,d+320|0,d+240|0,d+1751|0);b=x[27524];x[27524]=0;if((b|0)==1){break _b}break Zb}h=P()|0;break Ea}h=P()|0;$b(d+240|0);break Ea}x[27524]=0;Y(573,d+240|0);b=x[27524];x[27524]=0;if((b|0)==1){break Yb}x[27524]=0;X(574,d+320|0,d+240|0,d+1751|0,c|0);b=x[27524];x[27524]=0;if((b|0)==1){break Xb}}b=d+320|0;Gb(c,b);xb(b);b=d+240|0;$b(b);x[27524]=0;R(539,b|0,3980);b=x[27524];x[27524]=0;if((b|0)==1){break Vb}x[27524]=0;U(540,d+320|0,d+240|0,d+1751|0);b=x[27524];x[27524]=0;if((b|0)==1){break Ub}b=d+320|0;Gb(a+1298344|0,b);xb(b);$b(d+240|0);x[27524]=0;b=Q(1,b|0,14985)|0;e=x[27524];x[27524]=0;if((e|0)==1){break Tb}Gb(a+1298356|0,b);xb(b);b=x[a+480180>>2];switch(b-1|0){case 2:break sb;case 1:break Pb;case 3:break Qb;case 0:break Rb;default:break Wb}}h=P()|0;break Ea}h=P()|0;$b(d+240|0);break Ea}if((b|0)==16){break Sb}if((b|0)==32){break Ob}if((b|0)!=16777216){break sb}x[27524]=0;b=Q(1,d+240|0,10062)|0;e=x[27524];x[27524]=0;if((e|0)==1){break Nb}Gb(a+1298392|0,b);xb(b);x[27524]=0;b=Q(1,d+264|0,13796)|0;e=x[27524];x[27524]=0;if((e|0)==1){break Mb}Gb(a+1298380|0,b);xb(b);break sb}h=P()|0;break Ea}h=P()|0;$b(d+240|0);break Ea}h=P()|0;break Ea}x[27524]=0;b=Q(1,d+240|0,10067)|0;e=x[27524];x[27524]=0;$b:{if((e|0)!=1){Gb(a+1298392|0,b);xb(b);x[27524]=0;b=Q(1,d+264|0,8313)|0;e=x[27524];x[27524]=0;if((e|0)==1){break $b}Gb(a+1298380|0,b);xb(b);break sb}h=P()|0;break Ea}h=P()|0;break Ea}x[27524]=0;b=Q(1,d+240|0,12282)|0;e=x[27524];x[27524]=0;ac:{if((e|0)!=1){Gb(a+1298392|0,b);xb(b);x[27524]=0;b=Q(1,d+264|0,14263)|0;e=x[27524];x[27524]=0;if((e|0)==1){break ac}Gb(a+1298380|0,b);xb(b);break sb}h=P()|0;break Ea}h=P()|0;break Ea}x[27524]=0;b=Q(1,d+240|0,10040)|0;e=x[27524];x[27524]=0;bc:{if((e|0)!=1){Gb(a+1298392|0,b);xb(b);x[27524]=0;b=Q(1,d+264|0,15276)|0;e=x[27524];x[27524]=0;if((e|0)==1){break bc}Gb(a+1298380|0,b);xb(b);break sb}h=P()|0;break Ea}h=P()|0;break Ea}x[27524]=0;b=Q(1,d+240|0,10412)|0;e=x[27524];x[27524]=0;cc:{if((e|0)!=1){Gb(a+1298392|0,b);xb(b);x[27524]=0;b=Q(1,d+264|0,15031)|0;e=x[27524];x[27524]=0;if((e|0)==1){break cc}Gb(a+1298380|0,b);xb(b);break sb}h=P()|0;break Ea}h=P()|0;break Ea}x[27524]=0;b=Q(1,d+240|0,6130)|0;e=x[27524];x[27524]=0;dc:{ec:{fc:{gc:{hc:{if((e|0)!=1){Gb(a+1298392|0,b);xb(b);if(!(h&65535)){break dc}x[27524]=0;R(270,d+288|0,4317);b=x[27524];x[27524]=0;if((b|0)==1){break hc}x[d+116>>2]=(h&65280)>>>8;x[27524]=0;x[d+100>>2]=h&255;R(437,d+104|0,d+100|0);b=x[27524];x[27524]=0;if((b|0)==1){break gc}x[27524]=0;X(423,d+264|0,d+288|0,d+116|0,d+104|0);b=x[27524];x[27524]=0;if((b|0)==1){break fc}b=d+264|0;Gb(a+1298380|0,b);xb(b);xb(d+104|0);$b(d+288|0);break sb}h=P()|0;break Ea}h=P()|0;break Ea}h=P()|0;break ec}h=P()|0;xb(d+104|0)}$b(d+288|0);break Ea}x[27524]=0;b=Q(1,d+264|0,8505)|0;e=x[27524];x[27524]=0;if((e|0)!=1){Gb(a+1298380|0,b);xb(b);break sb}h=P()|0;break Ea}h=P()|0;break Ea}h=P()|0;break Ea}h=P()|0;break Ea}h=P()|0;break Ea}Gb(a+1298368|0,c);ic:{if(x[a+1074308>>2]){x[a+1298404>>2]=22;break ic}if(x[a+480180>>2]==1){x[a+1298404>>2]=28;break ic}x[a+1298404>>2]=4}i=1;jc:{kc:{if(f&1){x[27524]=0;b=Q(1,d+288|0,16606)|0;f=x[27524];x[27524]=0;if((f|0)==1){break kc}a=x[a+1298472>>2];x[27524]=0;U(380,a|0,2,b|0);a=x[27524];x[27524]=0;if((a|0)==1){break jc}xb(b)}xb(c);KU(q);uc(B);Sc(r);yb(I);yb(H);break c}h=P()|0;break Ea}h=P()|0;xb(b);break Ea}h=P()|0;yb(g);break Ga}x[27524]=0;g=Q(406,b|0,13854)|0;i=x[27524];x[27524]=0;if((i|0)==1){break Ha}lc:{if(!g){break lc}x[27524]=0;g=T(161,b|0)|0;i=x[27524];x[27524]=0;mc:{if((i|0)!=1){x[27524]=0;U(194,d+264|0,b|0,g|0);g=x[27524];x[27524]=0;if((g|0)!=1){break mc}}h=P()|0;break Ga}i=d+264|0;g=hc(d+320|0,i);yb(i);i=x[g>>2];x[27524]=0;i=T(164,i|0)|0;l=x[27524];x[27524]=0;if((l|0)!=1){w[d+264>>1]=(i>>>0)/20;w[d+288>>1]=z[E>>1];l=z[Tc(d+264|0,d+288|0)>>1];i=0;while(1){if((i|0)==(l|0)){yb(g);break lc}x[27524]=0;U(417,g|0,((i<<5)+a|0)+480289|0,20);j=x[27524];x[27524]=0;if((j|0)!=1){i=i+1|0;continue}break}}h=P()|0;yb(g);break Ga}x[27524]=0;Q(426,a|0,b|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break Ha}x[27524]=0;X(427,a|0,b|0,1,0);g=x[27524];x[27524]=0;if((g|0)==1){break Ha}if((e-2186&65535)>>>0<=117){x[m>>2]=16777216;x[27524]=0;U(441,a|0,b|0,e&65535);g=x[27524];x[27524]=0;if((g|0)==1){break Ha}}if(!x[a+1074308>>2]){break pb}x[27524]=0;g=Q(1,d+184|0,17591)|0;i=x[27524];x[27524]=0;nc:{oc:{pc:{if((i|0)!=1){i=x[a+1074308>>2];x[27524]=0;R(144,d+264|0,i|0);i=x[27524];x[27524]=0;if((i|0)==1){break pc}x[27524]=0;U(2,d+320|0,g|0,d+264|0);i=x[27524];x[27524]=0;if((i|0)==1){break oc}i=d+320|0;Gb(c,i);xb(i);xb(d+264|0);xb(g);break pb}h=P()|0;break Ga}h=P()|0;break nc}h=P()|0;xb(d+264|0)}xb(g);break Ga}yb(b);continue}}h=P()|0;break ya}h=P()|0;break ya}h=P()|0}yb(b);break Ea}h=P()|0}xb(c);break ya}h=P()|0;break ya}h=P()|0;Rc(d+320|0);break ya}h=P()|0}yb(g)}wb(i)}KU(q);break ma}c=f}wb(i);k=k+1|0;continue}}h=P()|0;break ma}h=P()|0;wb(e);break ma}h=P()|0}uc(B);break A}l=l+1|0;continue}}Sc(r);break z}h=P()|0}yb(I);break y}h=P()|0}yb(H);break e}h=P()|0;break e}h=P()|0;break e}else{qc:{rc:{if(!k){v[d+320|0]=y[(d+i|0)+1286|0];v[d+240|0]=64;N=((i<<5)+a|0)+480286|0,O=y[Ub(d+320|0,d+240|0)|0],w[N>>1]=O;break rc}if(m){break qc}}sc:{f=y[(d+i|0)+1350|0];if((f|0)!=255){if((f|0)!=127){break sc}x[((i<<5)+a|0)+480280>>2]=256;break qc}w[((i<<5)+a|0)+480284>>1]=256;break qc}w[((i<<5)+a|0)+480284>>1]=f}i=i+1|0;continue}}h=P()|0;break d}h=P()|0;break d}h=P()|0}yb(n)}ec(C);S(h|0);p()}yb(n)}ec(C)}ib=d+1760|0;return i|0}function Wka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,V=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0;e=ib-976|0;ib=e;yc(b);a:{if(!_U(b,e+920|0)){break a}if(!cV(e+920|0)){break a}if(!Ob(x[b>>2],x[b+8>>2],Ec(bV(e+920|0),kb))){break a}if(!c){d=1;break a}zd(a,8);gg(a);aa=y[e+923|0];M=aa-48|0;v[e+919|0]=M;bd(b,ac(x[e+928>>2]));f=e+608|0;ae(f,b,504);_=hc(e+896|0,f);yb(f);x[27524]=0;R(513,b|0,f|0);f=x[27524];x[27524]=0;b:{c:{d:{e:{f:{g:{if((f|0)!=1){if(y[e+891|0]>63){break b}if(Fb(z[e+608>>1])<<16>>16<0){break b}Rb(e+528|0,0,80);h:{d=ac(x[e+952>>2]);if(!d){break h}x[27524]=0;f=Q(159,b|0,d|0)|0;d=x[27524];x[27524]=0;if((d|0)!=1){if(!f){break h}x[27524]=0;R(514,b|0,e+528|0);d=x[27524];x[27524]=0;if((d|0)!=1){break h}}i=P()|0;break e}x[27524]=0;U(515,e+520|0,b|0,M&255);d=x[27524];x[27524]=0;if((d|0)!=1){ba=Ze(e+520|0);d=0;f=z[e+520>>1];if((f-128&65535)>>>0<65409){break b}w[a+480188>>1]=f;N=Nb(e+504|0);d=ac(x[e+944>>2]);i:{if(d){x[27524]=0;Q(159,b|0,d|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break g}x[27524]=0;U(516,b|0,N|0,y[e+891|0]);d=x[27524];x[27524]=0;if((d|0)==1){break g}j=y[e+891|0];break i}j=y[e+891|0];d=0;if(j){break c}}j=j&255;w[a+480192>>1]=j;w[a+480190>>1]=j;ca=(M&255)>>>0<2|v[e+872|0]>=0;q=!ca;r=c&2;A=1;E=1;while(1){j:{k:{l:{m:{n:{o:{g=E&65535;if(g>>>0<=(j&65535)>>>0){x[27524]=0;s=A&65535;f=W(255,a|0,g|0,s|0)|0;d=x[27524];x[27524]=0;p:{if((d|0)!=1){if(f){break p}break d}i=P()|0;break f}B=x[((g<<2)+a|0)+900380>>2];w[e+84>>1]=0;x[e+80>>2]=0;x[27524]=0;F=T(178,e+480|0)|0;d=x[27524];x[27524]=0;q:{if((d|0)!=1){d=Bb(x[N>>2],g-1|0);d=ac(y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24));r:{if(!d){break r}x[27524]=0;f=Q(159,b|0,d|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break k}if(!f){break r}x[27524]=0;R(517,b|0,e+80|0);d=x[27524];x[27524]=0;if((d|0)==1){break k}f=x[e+80>>2];d=w[e+84>>1];x[27524]=0;f=ac(f);d=se(d);U(194,e+120|0,b|0,f<<(d>>>5&1&(d|0)>0));d=x[27524];x[27524]=0;if((d|0)==1){break k}f=e+120|0;d=hc(e+192|0,f);fd(F,d);yb(d);yb(f)}t=se(w[e+84>>1]);d=t&15;if((t|0)>=0){break q}xu(B,0);ea=1;break o}i=P()|0;break f}if(d>>>0>6){break o}C=y[d+26710|0];if(!d){break m}w[a+480190>>1]=(z[a+480190>>1]+C|0)-1;l=B+108|0;o=B+236|0;m=C-2|0;j=4;s:while(1){g=1;if((j|0)==10){break n}k=D(j,12);d=(m<<3)+j|0;h=y[d+26716|0]+A|0;g=y[d+26764|0];d=0;while(1)if((d|0)==12){j=j+1|0;continue s}else{f=d+k|0;fa=bc(o,f),ga=h,w[fa>>1]=ga;f=Jb(l,f);v[f|0]=g+y[f|0];d=d+1|0;continue}}}t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{d=ac(x[e+532>>2]);if(!d){break D}if(!Fb(z[e+536>>1])){break D}x[27524]=0;f=Q(159,b|0,d|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break C}if(!f){break D}fa=e,ga=Fb(z[e+536>>1]),w[fa+192>>1]=ga;w[e+120>>1]=y[e+891|0];f=e+120|0;r=z[Tc(e+192|0,f)>>1];d=e+128|0;l=f|4;s=Fb(z[e+538>>1]);o=s>>>0<19;m=s>>>0<21;k=s>>>0<15;h=s>>>0<6;j=0;while(1){if((j|0)==(r|0)){break D}x[27524]=0;U(518,b|0,e+192|0,s|0);f=x[27524];x[27524]=0;E:{F:{G:{if((f|0)!=1){j=j+1|0;t=x[((j<<2)+a|0)+900380>>2];q=y[e+192|0];if(q){g=Bl(e+120|0,0,64);Bl(l,q-1&65535,64);f=y[e+193|0];if(f){f=64/(f>>>0)|0}else{f=0}Bl(d,f+q|0,0);x[27524]=0;q=t+48|0;U(519,q|0,g|0,3);f=x[27524];x[27524]=0;if((f|0)==1){break G}if(y[e+192|0]==1){g=x[Wb(e+472|0,Cb(x[q>>2]))>>2];f=Cb(x[q>>2]);f=x[q>>2]+(vu(g,f)<<2)|0;Od(q,ji(f+4|0,x[q+4>>2],f));Cb(f)}f=y[e+193|0];x[t>>2]=f?f<<9:32767;v[t+60|0]=y[t+60|0]|1;I=1}H:{if(o){break H}x[t+4>>2]=y[e+210|0]+1>>>1;if(m){break H}w[t+28>>1]=z[e+212>>1]}g=D(z[bc(t+236|0,61)>>1],104)+a|0;v[g+484417|0]=y[e+195|0]<<4;if(k){break F}f=ac(z[e+202>>1]|z[e+204>>1]<<16);x[g+484384>>2]=f;fa=g+484388|0,ga=ac(z[e+206>>1]|z[e+208>>1]<<16)+f|0,x[fa>>2]=ga;break E}i=P()|0;break f}i=P()|0;break f}if(h){continue}}f=g+484414|0;i=f;n=z[f>>1]&65529;f=y[e+197|0];w[i>>1]=n|f<<1&2|f>>>1&4;if(!(f&4)){continue}w[g+484412>>1]=0;continue}}I:{d=ac(x[e+548>>2]);if(!d){break I}if(!Fb(z[e+552>>1])){break I}x[27524]=0;f=Q(159,b|0,d|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break C}if(!f){break I}fa=e,ga=Fb(z[e+552>>1]),w[fa+192>>1]=ga;w[e+120>>1]=y[e+891|0];m=z[Tc(e+192|0,e+120|0)>>1];k=Fb(z[e+554>>1]);d=0;J:while(1){if((d|0)==(m|0)){break I}x[27524]=0;U(520,b|0,e+192|0,k|0);f=x[27524];x[27524]=0;if((f|0)==1){break t}f=e+80|0;LW(f,e+192|0);x[27524]=0;R(226,e+120|0,f|0);f=x[27524];x[27524]=0;if((f|0)==1){break u}d=d+1|0;o=((d<<2)+a|0)+900380|0;g=e+120|0;Cc(x[o>>2]+492|0,g);wb(g);f=x[o>>2];x[27524]=0;R(384,g|0,f|0);f=x[27524];x[27524]=0;if((f|0)==1){break v}fa=e,ga=Ni(x[e+120>>2]),x[fa+80>>2]=ga;h=Gf(e+120|0);while(1){f=x[e+80>>2];if(Mb(f,h)){l=(z[vo(f)>>1]<<5)+a|0;g=l+946328|0;r=x[o>>2];f=x[r+520>>2];x[g>>2]=x[r+516>>2];x[g+4>>2]=f;f=x[r+512>>2];g=l+946320|0;x[g>>2]=x[r+508>>2];x[g+4>>2]=f;f=x[r+504>>2];g=l+946312|0;x[g>>2]=x[r+500>>2];x[g+4>>2]=f;f=x[r+496>>2];g=l+946304|0;x[g>>2]=x[r+492>>2];x[g+4>>2]=f;Ug(e+80|0);continue}else{Nu(e+120|0);continue J}}}}Dq(a+901404|0);d=qc(e+464|0,4943);pf(De(a+901692|0,0),x[d>>2],x[d+4>>2]);yc(b);F=c&1;J=a+484344|0;K=a+1298332|0;da=a+1298308|0;$=a+484360|0;c=0;A=0;while(1){K:{f=c&255;if(f>>>0<y[ba|0]){x[27524]=0;X(521,b|0,e+920|0,e+528|0,e+608|0);d=x[27524];x[27524]=0;L:{M:{N:{O:{P:{if((d|0)==1){break P}Q:{if(!f){d=0;break Q}x[27524]=0;f=T(276,$|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break P}d=c;if((f|0)==255){break d}}n=Dj(x[$>>2],d&255);G=zg(e+448|0);Ic(n);L=M&255;if(L>>>0>1){break N}i=0;f=Fb(z[e+610>>1]);if(f>>>0>256|z[a+480188>>1]>16){break L}d=e+192|0;YU(d,e+608|0);x[27524]=0;U(522,n|0,d|0,f|0);d=x[27524];x[27524]=0;if((d|0)==1){break O}fa=e,ga=Cb(x[n>>2]),x[fa+192>>2]=ga;d=Cb(x[n+4>>2]);while(1){f=x[e+192>>2];if(Mb(f,d)){w[f>>1]=z[f>>1]+A;Ye(e+192|0);continue}else{uh(a,1);f=z[a+480188>>1];d=0;while(1)if((d|0)==(f|0)){d=32;break M}else{v[e+192|0]=y[(d+e|0)+874|0];v[e+120|0]=64;fa=((d<<5)+a|0)+480286|0,ga=y[Ub(e+192|0,e+120|0)|0],w[fa>>1]=ga;d=d+1|0;continue}}}}i=P()|0;break f}i=P()|0;break w}YU(e+192|0,e+608|0);R:{S:{T:{U:{d=Fb(z[e+204>>1]);if(!(!d|d>>>0>64|z[a+480188>>1]>64)){q=ac(x[e+212>>2]);d=Fb(z[e+216>>1]);if(d){w[e+120>>1]=d;w[e+80>>1]=800;f=Ec(((z[Tc(e+120|0,e+80|0)>>1]<<5)+50>>>0)/100|0,0)}else{f=32}d=x[e+200>>2];x[27524]=0;g=Q(159,b|0,ac(d)|0)|0;d=x[27524];x[27524]=0;V:{if((d|0)==1){break V}d=0;W:{if(!g){break W}while(1){if(z[a+480188>>1]<=d>>>0){break W}x[27524]=0;h=T(210,b|0)|0;g=x[27524];x[27524]=0;if((g|0)!=1){v[e+120|0]=h;v[e+80|0]=64;fa=((d<<5)+a|0)+480286|0,ga=y[Ub(e+120|0,e+80|0)|0],w[fa>>1]=ga;d=d+1|0;continue}break}i=P()|0;break w}X:{Y:{d=ac(x[e+208>>2]);if(!d){break Y}x[27524]=0;g=Q(159,b|0,d|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break V}d=0;if(!g){break Y}while(1){if(z[a+480188>>1]<=d>>>0){break X}x[27524]=0;h=T(523,b|0)|0;g=x[27524];x[27524]=0;if((g|0)!=1){fa=((d<<5)+a|0)+480284|0,ga=(Vb(h,-16,16)<<3)+128|0,w[fa>>1]=ga;d=d+1|0;continue}break}i=P()|0;break w}uh(a,1)}s=Nb(e+176|0);d=x[e+196>>2];x[27524]=0;g=Q(159,b|0,ac(d)|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break U}i=1;d=0;if(!g){break R}k=z[e+610>>1];h=x[b+8>>2];g=x[b>>2];x[27524]=0;h=W(160,g|0,h|0,Fb(k)<<1)|0;g=x[27524];x[27524]=0;if((g|0)==1){break U}if(!h){break R}g=z[e+610>>1];x[27524]=0;h=W(524,b|0,s|0,Fb(g)|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break U}if(!h){break R}fa=e,ga=Cb(x[s>>2]),x[fa+168>>2]=ga;r=Cb(x[e+180>>2]);l=x[e+192>>2];o=z[e+206>>1];while(1){d=x[e+168>>2];if(!Mb(d,r)){i=0;d=1;break R}d=Fb(y[d|0]|y[d+1|0]<<8);Z:{if(Fb(o)>>>0<d>>>0){break Z}x[27524]=0;Q(159,b|0,ac(l)+(d<<2)|0)|0;d=x[27524];x[27524]=0;_:{$:{aa:{ba:{ca:{if((d|0)==1){break ca}x[27524]=0;g=T(283,b|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break ca}x[27524]=0;g=Q(159,b|0,g|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break ca}if(!g){break Z}g=x[b+8>>2];d=x[b>>2];x[27524]=0;g=W(160,d|0,g|0,42)|0;d=x[27524];x[27524]=0;if((d|0)==1){break ca}if(!g){break Z}x[27524]=0;R(525,b|0,e+120|0);d=x[27524];x[27524]=0;da:{if((d|0)!=1){if(pc(x[n>>2],x[n+4>>2])){break da}x[27524]=0;R(526,n|0,65534);d=x[27524];x[27524]=0;if((d|0)!=1){break da}}i=P()|0;break S}h=Fb(z[e+160>>1]);x[e+116>>2]=h;g=x[b+8>>2];d=x[b>>2];x[27524]=0;g=W(160,d|0,g|0,h|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break ba}if(!g){x[27524]=0;g=T(206,b|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break ba}wc(e+116|0,g)}wc(e+116|0,65534);h=x[n+4>>2];g=x[n>>2];d=0;x[27524]=0;m=x[e+116>>2];k=Oc(g,h);R(527,n|0,m+k|0);g=x[27524];x[27524]=0;if((g|0)==1){break $}while(1){ea:{if((d|0)==(m|0)){if(y[e+120|0]){break ea}break aa}x[27524]=0;h=T(275,b|0)|0;g=x[27524];x[27524]=0;fa:{if((g|0)!=1){g=h<<16>>16;if((g|0)<0){break fa}x[27524]=0;R(526,n|0,g+A&65535);g=x[27524];x[27524]=0;if((g|0)!=1){break fa}}i=P()|0;break S}d=d+1|0;continue}break}Xm(e+104|0,e+120|0);x[27524]=0;U(528,e+56|0,x[e+104>>2],x[e+108>>2]);d=x[27524];x[27524]=0;ga:{ha:{ia:{if((d|0)!=1){x[27524]=0;U(11,e+80|0,28,e+56|0);d=x[27524];x[27524]=0;if((d|0)==1){break ia}x[27524]=0;R(277,n|0,e+80|0);d=x[27524];x[27524]=0;if((d|0)==1){break ha}xb(e+80|0);wb(e+56|0);break aa}i=P()|0;break S}i=P()|0;break ga}i=P()|0;xb(e+80|0)}wb(e+56|0);break S}i=P()|0;break S}i=P()|0;break S}d=ac(x[e+152>>2]);if(!d){break Z}x[27524]=0;g=Q(159,b|0,d|0)|0;d=x[27524];x[27524]=0;if((d|0)!=1){break _}}i=P()|0;break S}if(!g){break Z}while(1){ja:{x[27524]=0;g=Q(529,b|0,e+104|0)|0;d=x[27524];x[27524]=0;ka:{la:{ma:{na:{if((d|0)!=1){if(!g){break Z}x[27524]=0;U(194,e+56|0,b|0,y[e+107|0]);d=x[27524];x[27524]=0;if((d|0)==1){break na}d=e+56|0;m=hc(e+80|0,d);yb(d);g=Fb(z[e+104>>1]);d=Fl(g+k|0);w[e+56>>1]=d;if((g|0)==65535){break ja}i=x[n>>2];if(Oc(i,x[n+4>>2])>>>0<=d>>>0){break ja}u=65535;switch(y[e+106|0]-1|0){case 0:break la;case 1:break ma;default:break ka}}i=P()|0;break S}i=P()|0;break S}x[27524]=0;h=T(275,m|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break T}x[27524]=0;g=Q(530,G|0,e+56|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break T}w[g>>1]=h;i=x[n>>2];u=65534;d=z[e+56>>1]}fa=bc(i,d),ga=u,w[fa>>1]=ga}yb(m);continue}break}yb(m)}Ye(e+168|0);continue}}i=P()|0;break w}i=0;break L}i=P()|0;break S}i=P()|0;yb(m)}jd(s);break w}jd(s);if(d){d=f>>>(q>>>1&1)|0;break M}uu(G);if(!i){break d}break K}g=Fb(z[e+868>>1]);h=y[e+871|0];t=h&64;f=y[e+872|0];B=f&32;O=(f&31)+1|0;fa=a,ga=VU(g,t>>>6|0,B>>>5|0,O),x[fa+480204>>2]=ga;fa=a,ga=Bd(y[e+873|0],1,32),x[fa+480196>>2]=ga;if(B){x[a+480216>>2]=O;x[a+480220>>2]=O<<2}f=y[e+890|0];if(f){v[e+192|0]=f;v[e+120|0]=64;fa=a,ga=y[Ub(e+192|0,e+120|0)|0]<<2,x[fa+480200>>2]=ga}x[a+480228>>2]=d;x[a+480232>>2]=d;x[a+480208>>2]=x[a+480208>>2]&-3|(h^-1)>>>4&2;oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{d=ac(x[e+572>>2]);if(!d){break ya}x[27524]=0;f=Q(159,b|0,d|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break xa}if(!f){break ya}d=x[e+576>>2];x[27524]=0;U(272,b|0,da|0,ac(d)|0);d=x[27524];x[27524]=0;if((d|0)==1){break xa}if(y[ba|0]<2){break ya}x[27524]=0;U(11,e+192|0,28,da|0);d=x[27524];x[27524]=0;za:{if((d|0)!=1){x[27524]=0;R(277,n|0,e+192|0);d=x[27524];x[27524]=0;if((d|0)==1){break za}xb(e+192|0);break ya}i=P()|0;break w}i=P()|0;xb(e+192|0);break w}Aa:{if(ac(x[e+544>>2])>>>0<2){break Aa}d=x[e+540>>2];x[27524]=0;f=Q(159,b|0,ac(d)|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break xa}if(!f){break Aa}d=x[e+544>>2];x[27524]=0;X(335,K|0,b|0,ac(d)-1|0,4);d=x[27524];x[27524]=0;if((d|0)==1){break xa}}d=ac(x[e+584>>2]);if(!d){break oa}x[27524]=0;f=Q(159,b|0,d|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break xa}if(!f){break oa}f=x[b+8>>2];d=x[b>>2];x[27524]=0;f=W(160,d|0,f|0,12)|0;d=x[27524];x[27524]=0;if((d|0)==1){break xa}if(!f){break oa}x[27524]=0;Q(192,b|0,6)|0;d=x[27524];x[27524]=0;if((d|0)==1){break xa}x[27524]=0;f=T(275,b|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break xa}if((f|0)!=1){break oa}x[27524]=0;g=T(283,b|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break va}if(!g){break oa}f=x[b+8>>2];d=x[b>>2];x[27524]=0;f=W(160,d|0,f|0,g|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break va}if(f){break wa}break oa}i=P()|0;break w}k=ME(e+192|0,K);x[27524]=0;X(335,K|0,b|0,g|0,4);d=x[27524];x[27524]=0;if((d|0)==1){break qa}if(!Qe(k)){x[27524]=0;f=W(531,e+24|0,2,13)|0;d=x[27524];x[27524]=0;if((d|0)==1){break ua}x[27524]=0;U(532,e+120|0,k|0,f|0);d=x[27524];x[27524]=0;if((d|0)==1){break ta}x[27524]=0;U(533,e+40|0,e+120|0,K|0);d=x[27524];x[27524]=0;if((d|0)==1){break sa}d=e+40|0;Ac(K,d);wb(d);wb(e+120|0);wb(f)}wb(k);break oa}i=P()|0;break w}i=P()|0;break pa}i=P()|0;break ra}i=P()|0;wb(e+120|0)}wb(f);break pa}i=P()|0}wb(k);break w}Ba:{if(L>>>0<2){break Ba}i=0;if(!ac(x[e+596>>2])){break Ba}while(1){if(z[a+480188>>1]<=i>>>0){break Ba}d=x[e+596>>2];x[27524]=0;f=Q(159,b|0,ac(d)+(i<<2)|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break x}Ca:{if(!f){break Ca}x[27524]=0;f=T(283,b|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break x}x[27524]=0;f=Q(159,b|0,f|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break x}u=0;d=0;if(!f){break Ca}while(1){Da:{g=x[b+8>>2];f=x[b>>2];x[27524]=0;g=W(160,f|0,g|0,8)|0;f=x[27524];x[27524]=0;Ea:{Fa:{Ga:{if((f|0)!=1){if(!g){break Da}x[27524]=0;R(534,b|0,e+192|0);f=x[27524];x[27524]=0;if((f|0)==1){break Ga}f=ac(x[e+192>>2]);if(!f){break Da}switch((f&536870911)-1|0){case 1:break Ea;case 0:break Fa;default:continue}}i=P()|0;break w}i=P()|0;break w}u=ac(x[e+196>>2]);continue}d=ac(x[e+196>>2]);continue}break}if(!u|!d){break Ca}x[27524]=0;g=Q(159,b|0,u|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break y}if(!g){break Ca}x[27524]=0;U(417,b|0,((i<<5)+a|0)+480289|0,d|0);d=x[27524];x[27524]=0;if((d|0)==1){break y}}i=i+1|0;continue}}d=z[e+608>>1];x[27524]=0;H=Fb(d);R(229,J|0,A+H&65535);d=x[27524];x[27524]=0;if((d|0)==1){break z}s=h&16;q=A&65535;g=0;Ha:{Ia:{while(1){if((g|0)==(H|0)){fa=e,ga=Ni(x[G>>2]),x[fa+120>>2]=ga;g=Gf(G);while(1){d=x[e+120>>2];if(!Rg(d,g)){i=1;d=ac(x[e+528>>2]);if(!d){break L}x[27524]=0;f=Q(159,b|0,d|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break z}if(!f){break L}A=A+H|0;uu(G);break K}k=vo(d);h=Ze(k);Ja:{Ka:{La:{Ma:{d=z[k>>1];if(!d){j=0;break Ma}x[27524]=0;f=Q(315,n|0,d-1&65535)|0;d=x[27524];x[27524]=0;if((d|0)==1){break Ja}j=z[k>>1];if(!f){break Ma}x[27524]=0;j=Q(364,n|0,j-1&65535)|0;d=x[27524];x[27524]=0;if((d|0)==1){break Ja}break La}if(z[h>>1]==((j&65535)+1|0)){break Ka}x[27524]=0;j=Q(363,J|0,1)|0;d=x[27524];x[27524]=0;if((d|0)==1){break Ja}if((j|0)==65535){break Ka}fa=bc(x[n>>2],z[k>>1]),ga=j,w[fa>>1]=ga}d=Xb(x[J>>2],j);ue(d,Pm(Te(Me(e+192|0,12,Uu(z[h>>1])),x[d+12>>2]-1|0)));H=(H&65535)>>>0>j>>>0?H:j+1|0}Ug(e+120|0);continue}break}i=P()|0;break w}Na:{Oa:{if(!F){break Oa}d=x[e+936>>2];x[27524]=0;f=Q(159,b|0,ac(d)+(g<<2)|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break Ia}if(!f){break Oa}x[27524]=0;f=T(283,b|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break Ia}x[27524]=0;f=Q(159,b|0,f|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break Ia}if(!f){break Oa}V=Kb(e+56|0);x[27524]=0;Y=T(178,e|0)|0;d=x[27524];x[27524]=0;Pa:{Qa:{if((d|0)!=1){if(L){break Qa}x[27524]=0;R(535,b|0,e+192|0);d=x[27524];x[27524]=0;if((d|0)==1){break Na}w[e+104>>1]=y[e+192|0];Z=y[e+193|0]+1|0;f=48;break Pa}i=P()|0;break A}x[27524]=0;m=v[e+870|0];R(536,b|0,e+176|0);d=x[27524];x[27524]=0;Ra:{Sa:{if((d|0)!=1){k=Fb(z[e+176>>1]);w[e+104>>1]=k;Z=Fb(z[e+178>>1])+1|0;d=ac(x[e+180>>2]);if(!d){break Ra}h=x[b+8>>2];x[27524]=0;Q(159,b|0,d|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break B}x[27524]=0;R(537,b|0,e+192|0);d=x[27524];x[27524]=0;if((d|0)==1){break B}d=x[e+196>>2];x[27524]=0;f=Q(159,b|0,ac(d)|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break B}if(!f){break Sa}d=x[e+200>>2];x[27524]=0;U(272,b|0,V|0,ac(d)|0);d=x[27524];x[27524]=0;if((d|0)!=1){break Sa}break B}break B}d=ac(x[e+208>>2]);Ta:{if(!d){break Ta}x[27524]=0;f=Q(159,b|0,d|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break B}if(!f){break Ta}x[27524]=0;f=T(283,b|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break B}x[27524]=0;f=Q(159,b|0,f|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break B}if(!f){break Ta}x[27524]=0;U(194,e+80|0,b|0,D(k,Z)|0);d=x[27524];x[27524]=0;if((d|0)==1){break B}f=e+80|0;d=hc(e+120|0,f);fd(Y,d);yb(d);yb(f)}x[27524]=0;Q(159,b|0,h|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break B}}f=m+(L>>>0<3?48:24)|0}x[27524]=0;k=g+q|0;h=W(230,J|0,k&65535,Z|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break B}Ua:{if(!h){break Ua}d=x[J>>2];x[27524]=0;C=Xb(d,k);R(285,C|0,V|0);d=x[27524];x[27524]=0;if((d|0)==1){break Ha}Mf(e+104|0,z[a+480188>>1]);E=0;r=z[e+104>>1];Va:while(1){if((E|0)==(Z|0)){break Ua}i=0;d=hd(x[C>>2],x[x[C+48>>2]+12>>2],E,0);while(1){if((i&65535)>>>0>=r>>>0){E=E+1|0;continue Va}Wa:{if(!L){x[27524]=0;R(538,e+192|0,b|0);h=x[27524];x[27524]=0;if((h|0)!=1){o=y[e+192|0];m=e+192|0;h=Lc(m);v[d+1|0]=o>>>3&16|y[h|0]>>>4|o>>>1&32;k=y[h|0];fa=d,ga=y[Ze(m)|0],v[fa+5|0]=ga;h=o&63;j=h?h+f|0:0;u=k&15;break Wa}break B}x[27524]=0;R(353,e+192|0,b|0);h=x[27524];x[27524]=0;Xa:{Ya:{if((h|0)!=1){h=e+192|0;l=Lc(h);o=Ze(h);m=Si(h);x[27524]=0;k=T(210,Y|0)|0;h=x[27524];x[27524]=0;if((h|0)==1){break B}v[d+4|0]=k;k=y[e+192|0];h=k&127;if(!h){break Ya}j=f+h|0;break Xa}break B}j=0;if((k|0)!=128){break Xa}v[d|0]=254}v[d+1|0]=y[l|0]&63;u=y[o|0];v[d+5|0]=y[m|0]}if(j-1>>>0<=119){v[d|0]=j}I=(j|0)>84&ca|I;m=(t|0)!=0;k=(B|0)!=0;h=(s|0)!=0;l=ib-16|0;ib=l;v[d+3|0]=0;Za:{_a:{$a:{ab:{bb:{cb:{db:{eb:{fb:{gb:{hb:{ib:{jb:{kb:{lb:{mb:{nb:{ob:{pb:{qb:{rb:{sb:{tb:{ub:{o=u&255;switch(o-4|0){case 4:case 10:break Za;case 42:break $a;case 37:break ab;case 28:break bb;case 27:break cb;case 26:break db;case 25:break eb;case 24:break fb;case 23:break gb;case 22:break hb;case 21:break ib;case 20:break jb;case 18:break kb;case 17:break lb;case 16:break mb;case 14:break nb;case 13:break ob;case 12:break pb;case 11:break qb;case 9:break rb;case 8:break sb;case 5:break tb;case 0:break ub;default:break _a}}v[d+3|0]=5;k=y[d+5|0];v[l+15|0]=k>>>3;v[l+14|0]=15;h=y[Ub(l+15|0,l+14|0)|0];v[l+13|0]=k<<1&30;v[l+12|0]=15;fa=d,ga=y[Ub(l+13|0,l+12|0)|0]|h<<4,v[fa+5|0]=ga;break Za}if((y[d+5|0]-1&255)>>>0>19){break Za}v[d+3|0]=16;break Za}v[d+3|0]=13;k=y[d+5|0];vb:{if(!h){if(k>>>0>152){break vb}v[d+5|0]=D((k&240)>>>4|0,10)+(k&15);break Za}v[d+5|0]=(k&127)+1>>>1;break Za}v[d+3|0]=0;break Za}v[d+3|0]=11;break Za}h=y[d+5|0];if(!h){v[d+3|0]=14;break Za}if(h>>>0>240){break Za}v[d+3|0]=17;if(h>>>0<=2){v[d+5|0]=112;break Za}fa=d,ga=Ak(+(VU(h,m,k,O)>>>0)/1e4),v[fa+5|0]=ga;break Za}v[d+3|0]=31;v[d+5|0]=y[d+5|0]|128;break Za}v[d+3|0]=19;v[l+11|0]=15;fa=d,ga=y[Ub(d+5|0,l+11|0)|0]|16,v[fa+5|0]=ga;break Za}v[d+3|0]=19;v[l+10|0]=15;fa=d,ga=y[Ub(d+5|0,l+10|0)|0]|32,v[fa+5|0]=ga;break Za}v[d+3|0]=5;h=y[d+5|0];v[l+9|0]=(h>>>4|0)+1;v[l+8|0]=15;fa=d,ga=h&15|y[Ub(l+9|0,l+8|0)|0]<<4,v[fa+5|0]=ga;break Za}v[d+3|0]=19;v[d+5|0]=y[d+5|0]&15|80;break Za}v[d+3|0]=19;v[l+7|0]=15;fa=d,ga=y[Ub(d+5|0,l+7|0)|0]|96,v[fa+5|0]=ga;break Za}v[d+3|0]=19;v[l+6|0]=15;fa=d,ga=y[Ub(d+5|0,l+6|0)|0]|192,v[fa+5|0]=ga;break Za}v[d+3|0]=10;break Za}v[d+3|0]=19;v[l+5|0]=15;fa=d,ga=y[Ub(d+5|0,l+5|0)|0]|160,v[fa+5|0]=ga;break Za}v[d+3|0]=19;v[l+4|0]=15;fa=d,ga=y[Ub(d+5|0,l+4|0)|0]|176,v[fa+5|0]=ga;break Za}h=(y[d+5|0]<<24)-16777216>>24;if((h|0)<0){break Za}v[d+5|0]=h;v[d+3|0]=31;break Za}v[d+3|0]=14;break Za}v[d+3|0]=19;v[l+3|0]=15;fa=d,ga=y[Ub(d+5|0,l+3|0)|0]|224,v[fa+5|0]=ga;break Za}h=y[d+5|0];if(h>>>0>=16){v[d+3|0]=19;v[d+5|0]=h>>>4|208;break Za}if(!h){break Za}v[d+3|0]=19;v[d+5|0]=h|144;break Za}if(y[d+5|0]|y[d+4|0]){break Za}if(!Wc(y[d|0])){break Za}v[d+5|0]=159;v[d+3|0]=20;break Za}h=y[d+4|0];if(!h){break Za}v[d+3|0]=44;fa=d,ga=Nl(Ec(((y[d+5|0]<<8&65280)>>>0)/(h>>>0)|0,0)),v[fa+5|0]=ga;break Za}h=y[d+5|0];if((h+16&255)>>>0>32){break Za}v[d+3|0]=9;fa=d,ga=Ag(((h^128)<<3)-896|0),v[fa+5|0]=ga;break Za}if(o>>>0>15){break Za}Xf(d,o,y[d+5|0])}ib=l+16|0;d=d+6|0;i=i+1|0;continue}}}yb(Y);wb(V)}g=g+1|0;continue}break}break B}i=P()|0;break w}break B}uu(G);d=0;if(!i){break c}}Lj($,0);d=1;wb:{if(I&1){break wb}while(1){b=d&65535;if(b>>>0>z[a+480192>>1]){w[a+480192>>1]=0;break wb}c=((b<<2)+a|0)+900380|0;b=x[c>>2];if(b){Ib(wu(b))}x[c>>2]=0;d=d+1|0;continue}}xb:{if(!ea){break xb}x[27524]=0;c=Q(1,e+192|0,16347)|0;b=x[27524];x[27524]=0;yb:{if((b|0)!=1){b=x[a+1298472>>2];x[27524]=0;U(380,b|0,2,c|0);b=x[27524];x[27524]=0;if((b|0)==1){break yb}xb(c);break xb}i=P()|0;break f}i=P()|0;xb(c);break f}j=21631;zb:{Ab:{switch(aa-48|0){case 0:j=z[a+480188>>1]>4?17242:17228;break zb;case 1:j=17210;break zb;case 2:j=17192;break zb;case 3:break Ab;default:break zb}}j=17165}x[27524]=0;R(539,e+80|0,16780);b=x[27524];x[27524]=0;Bb:{Cb:{Db:{if((b|0)!=1){x[27524]=0;U(540,e+120|0,e+80|0,e+919|0);b=x[27524];x[27524]=0;if((b|0)==1){break Db}b=e+120|0;Gb(a+1298344|0,b);xb(b);$b(e+80|0);x[27524]=0;c=Q(1,b|0,12602)|0;b=x[27524];x[27524]=0;if((b|0)==1){break Cb}Gb(a+1298356|0,c);xb(c);x[27524]=0;R(140,a+1298368|0,j|0);b=x[27524];x[27524]=0;if((b|0)==1){break Bb}x[a+1298404>>2]=28;d=1;break c}i=P()|0;break f}i=P()|0;$b(e+80|0);break f}i=P()|0;break f}i=P()|0;break f}c=c+1|0;continue}}i=P()|0;break f}i=P()|0;yb(Y)}wb(V);break w}i=P()|0;break w}i=P()|0;break w}i=P()|0}uu(G);break f}i=P()|0;break f}i=P()|0;break f}i=P()|0;break f}C=1;if((d|0)!=7){break m}d=B+108|0;f=OA(d);while(1){if((d|0)!=(f|0)){fa=d,ga=El(y[d|0]-24|0),v[fa|0]=ga;d=d+1|0;continue}break}g=0}I=1;break l}g=0;Eb:{if(q|(t|0)<0){break Eb}m=B+108|0;j=7;Fb:while(1){if((j|0)==10){break Eb}k=D(j,12);h=D(j,-12)+72|0;d=0;while(1)if((d|0)==12){j=j+1|0;continue Fb}else{f=Jb(m,d+k|0);v[f|0]=h+y[f|0];d=d+1|0;continue}}}}x[27524]=0;R(541,_|0,e+192|0);d=x[27524];x[27524]=0;if((d|0)!=1){Gb:{d=y[e+196|0];if((d-1&255)>>>0<=15){v[B+31|0]=d;I=1}d=y[e+197|0];if((d<<24)-16777216>>24>=0){v[B+30|0]=d}d=0;Hb:{while(1){if((d|0)==(C|0)){if(!r){break j}if((t|0)>=0){break Hb}break j}x[27524]=0;h=D(d+s|0,104)+a|0;R(281,h+484380|0,8);f=x[27524];x[27524]=0;if((f|0)!=1){v[e+120|0]=y[e+198|0];v[e+56|0]=64;fa=h+484410|0,ga=y[Ub(e+120|0,e+56|0)|0]<<2,w[fa>>1]=ga;v[h+484416|0]=y[e+199|0];d=d+1|0;continue}break}break k}k=Zc(e+120|0,8,1,1,0);h=Fb(z[e+194>>1]);i=Fb(z[e+192>>1]);d=x[F>>2];x[27524]=0;j=T(164,d|0)|0;d=x[27524];x[27524]=0;if((d|0)!=1){d=se(w[e+84>>1]);if(d&16){ne(k,16);j=j>>>1|0}if(d&32){Qo(k,3);j=j>>>1|0}if(d&64){jg(k,2)}j=g?(j>>>0)/((-1<<C^-1)>>>0)|0:j;u=i+h|0;d=0;while(1){if((d|0)==(C|0)){break j}g=D(d+s|0,104)+a|0;f=g+484380|0;x[f>>2]=j;x[27524]=0;W(223,k|0,f|0,F|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break Gb}i=i<<1;u=u<<1;if(h>>>0>=2){x[g+484388>>2]=u;x[g+484384>>2]=i;f=g+484414|0;w[f>>1]=z[f>>1]|2}d=d+1|0;j=j<<1;continue}}}}}i=P()|0;yb(F);break f}yb(F);E=E+1|0;A=A+C|0;j=z[a+480192>>1];continue}}i=P()|0;break e}i=P()|0;break e}i=P()|0}uc(N)}yb(_);S(i|0);p()}d=0}uc(N)}yb(_)}ib=e+976|0;return d|0}function Aia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=E(0),k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,C=E(0),F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,V=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=E(0),ea=0,ga=0,ha=0,ia=0,ka=0,la=0;e=ib-688|0;ib=e;yc(b);a:{b:{c:{if(!ii(b,e+680|0)){break c}if(!RS(e+680|0)){break c}if((Go(b)|0)>=0){break c}if(!c){d=1;break c}zd(a,16777216);d=a+480208|0;x[d>>2]=x[d>>2]|1681e4;Hq(e+288|0,32);h=x[e+300>>2];d=a+1074320|0;x[d>>2]=x[e+296>>2];x[d+4>>2]=h;d=x[e+292>>2];x[a+1074312>>2]=x[e+288>>2];x[a+1074316>>2]=d;fg(a+1074312|0,38);q=Nb(e+664|0);r=Nb(e+648|0);u=Nb(e+632|0);l=Nb(e+616|0);Gg(b,4);i=a+480190|0;K=c&1;J=a+1298332|0;s=2500;I=!(c&2);G=a+1298472|0;d:{e:{f:{while(1){c=x[b+8>>2];d=x[b>>2];x[27524]=0;c=W(160,d|0,c|0,4)|0;d=x[27524];x[27524]=0;g:{h:{i:{j:{k:{l:{m:{if((d|0)!=1){n:{if(c){x[27524]=0;c=T(688,b|0)|0;d=x[27524];x[27524]=0;o:{if((d|0)==1){break o}n=4;d=0;p:{q:{r:{switch(c+21|0){case 20:x[27524]=0;c=T(283,b|0)|0;d=x[27524];x[27524]=0;if((d|0)!=1){d=c&65535;if(z[a+480188>>1]|d-1>>>0>126){continue}w[a+480188>>1]=c;ka=a,la=Vb(512/(d>>>0)|0,16,128),x[ka+480228>>2]=la;continue}c=P()|0;break a;case 19:x[27524]=0;M=T(283,b|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break o}if(M>>>0<=1024){continue}break m;case 16:x[27524]=0;c=T(283,b|0)|0;h=x[27524];x[27524]=0;if((h|0)!=1){if((c&65535)==4){continue}break m}c=P()|0;break a;case 15:x[27524]=0;c=T(283,b|0)|0;d=x[27524];x[27524]=0;if((d|0)!=1){x[e+288>>2]=c;x[e+184>>2]=800;ka=a,la=Xe(+A[Hb(e+288|0,e+184|0)>>2]*1.24*1e4),x[ka+480204>>2]=la;continue}c=P()|0;break a;case 31:x[27524]=0;c=T(283,b|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break o}Z=1;s=Bd(c,0,1e4);continue;case 32:case 33:x[27524]=0;c=T(283,b|0)|0;d=x[27524];x[27524]=0;s:{t:{if((d|0)!=1){Z=1;if(!c){continue}x[27524]=0;d=Q(1,e+600|0,12511)|0;c=x[27524];x[27524]=0;if((c|0)==1){break t}c=x[G>>2];x[27524]=0;U(380,c|0,2,d|0);c=x[27524];x[27524]=0;if((c|0)==1){break s}xb(d);continue}c=P()|0;break a}c=P()|0;break a}c=P()|0;xb(d);break a;case 14:x[27524]=0;Q(192,b|0,4)|0;c=x[27524];x[27524]=0;if((c|0)==1){break o}g=!z[i>>1]|g;continue;case 11:if(!K){break q}if(!pc(x[q>>2],x[q+4>>2])){break q}x[27524]=0;R(689,e+288|0,b|0);c=x[27524];x[27524]=0;if((c|0)!=1){if(x[q>>2]){Ic(q);c=x[q>>2];oo(q);Ib(c);ka=Db(q),la=0,x[ka>>2]=la;x[q>>2]=0;x[q+4>>2]=0}c=e+288|0;x[q>>2]=x[c>>2];x[q+4>>2]=x[c+4>>2];d=Db(c);ka=Db(q),la=x[d>>2],x[ka>>2]=la;x[d>>2]=0;x[c>>2]=0;x[c+4>>2]=0;Li(c);continue}c=P()|0;break a;case 3:case 4:case 10:h=Gh(x[l>>2],x[l+4>>2]);d=z[i>>1];if(h>>>0<=d>>>0){continue}if((g|I)&1){break q}if(!bi(d)){break q}d=d+1|0;w[i>>1]=d;t=Nb(e+584|0);x[27524]=0;n=T(178,e+560|0)|0;g=x[27524];x[27524]=0;u:{v:{w:{if((g|0)!=1){if((c|0)==-17){break w}if((c|0)!=-11){break v}x[27524]=0;c=T(283,b|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break u}x[27524]=0;U(194,e+184|0,b|0,c|0);c=x[27524];x[27524]=0;if((c|0)==1){break u}c=e+184|0;g=hc(e+288|0,c);fd(n,g);yb(g);break g}c=P()|0;break d}x[27524]=0;R(690,e+288|0,b|0);c=x[27524];x[27524]=0;x:{if((c|0)!=1){c=e+288|0;g=Om(t,c);ec(c);he(e+528|0,x[g>>2],x[e+588>>2]);c=Id(e+520|0);x[27524]=0;g=x[c+4>>2];x[e+16>>2]=x[c>>2];x[e+20>>2]=g;c=Mg(332,e+536|0,x[e+528>>2],x[e+532>>2],e+16|0);g=x[27524];x[27524]=0;if((g|0)==1){break x}fd(n,c);break g}c=P()|0;break e}c=P()|0;break e}x[27524]=0;R(691,e+288|0,b|0);c=x[27524];x[27524]=0;y:{if((c|0)!=1){c=e+288|0;g=Om(t,c);ec(c);he(e+488|0,x[g>>2],x[e+588>>2]);c=Id(e+480|0);x[27524]=0;g=x[c+4>>2];x[e+8>>2]=x[c>>2];x[e+12>>2]=g;c=Mg(332,e+496|0,x[e+488>>2],x[e+492>>2],e+8|0);g=x[27524];x[27524]=0;if((g|0)==1){break y}fd(n,c);break g}c=P()|0;break e}c=P()|0;break e}c=P()|0;break e;case 9:c=z[i>>1];if(!bi(c)){continue}w[i>>1]=c+1;continue;case 8:if(!K){break q}if(!pc(x[u>>2],x[u+4>>2])){break q}x[27524]=0;R(692,e+288|0,b|0);c=x[27524];x[27524]=0;if((c|0)!=1){c=e+288|0;QS(u,c);uc(c);continue}c=P()|0;break a;case 7:if(!pc(x[l>>2],x[l+4>>2])){break q}x[27524]=0;R(693,e+288|0,b|0);c=x[27524];x[27524]=0;if((c|0)!=1){if(x[l>>2]){Ic(l);c=x[l>>2];yA(l);Ib(c);ka=Db(l),la=0,x[ka>>2]=la;x[l>>2]=0;x[l+4>>2]=0}c=e+288|0;x[l>>2]=x[c>>2];x[l+4>>2]=x[c+4>>2];d=Db(c);ka=Db(l),la=x[d>>2],x[ka>>2]=la;x[d>>2]=0;x[c>>2]=0;x[c+4>>2]=0;fu(c);continue}c=P()|0;break a;case 6:if(!K){break q}if(!pc(x[r>>2],x[r+4>>2])){break q}x[27524]=0;R(694,e+288|0,b|0);c=x[27524];x[27524]=0;if((c|0)!=1){if(x[r>>2]){Ic(r);c=x[r>>2];du(r);Ib(c);ka=Db(r),la=0,x[ka>>2]=la;x[r>>2]=0;x[r+4>>2]=0}c=e+288|0;x[r>>2]=x[c>>2];x[r+4>>2]=x[c+4>>2];d=Db(c);ka=Db(r),la=x[d>>2],x[ka>>2]=la;x[d>>2]=0;x[c>>2]=0;x[c+4>>2]=0;Gm(c);continue}c=P()|0;break a;case 17:case 18:break p;case 0:case 1:case 2:break q;case 5:break r;default:break m}}x[27524]=0;R(695,e+288|0,b|0);c=x[27524];x[27524]=0;if((c|0)==1){break n}z:{c=x[e+288>>2];d=x[e+292>>2];if(pc(c,d)){break z}x[27524]=0;X(341,J|0,c|0,cd(c,d)|0,1);c=x[27524];x[27524]=0;if((c|0)!=1){break z}c=P()|0;ec(e+288|0);break a}ec(e+288|0);continue}x[27524]=0;n=T(283,b|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break o}}x[27524]=0;Q(192,b|0,n|0)|0;c=x[27524];x[27524]=0;if((c|0)!=1){continue}}c=P()|0;break a}d=0;if(!z[a+480188>>1]|!M){break m}b=x[l>>2];c=x[l+4>>2];if(pc(b,c)){break m}if(K){if(pc(x[q>>2],x[q+4>>2])){break m}if(pc(x[u>>2],x[u+4>>2])){break m}if(pc(x[r>>2],x[r+4>>2])){break m}}b=Gh(b,c);if(b>>>0>=256){x[27524]=0;R(696,l|0,255);b=x[27524];x[27524]=0;if((b|0)==1){break b}b=Gh(x[l>>2],x[l+4>>2])}w[a+480192>>1]=b;m=a+480190|0;n=a+480192|0;ka=m,la=z[pe(i,n)>>1],w[ka>>1]=la;if(g&1){x[27524]=0;b=Q(1,e+584|0,16436)|0;c=x[27524];x[27524]=0;if((c|0)==1){break h}c=x[a+1298472>>2];x[27524]=0;U(380,c|0,2,b|0);c=x[27524];x[27524]=0;if((c|0)==1){break i}xb(b)}g=0;A:while(1){if((g|0)!=2){d=1;while(1){f=d&65535;if(f>>>0>z[n>>1]){g=g+1|0;continue A}B:{h=Em(x[l>>2],f-1|0);if(!y[h|0]|v[h+128|0]<0){break B}if((au(h)|0)==((g|0)!=1|0)){break B}C:{D:{E:{c=0;F:{if(!au(h)){break F}if(Fb(y[h+6|0]|y[h+7|0]<<8)){break F}if(Fb(y[h+14|0]|y[h+15|0]<<8)>>>0>20){break F}c=(Fb(y[h+18|0]|y[h+19|0]<<8)|0)==4}G:{H:{if(c){c=y[h+23|0];b=y[h+140|0];x[27524]=0;b=ja(697,h|0,a|0,(b&2)>>>1|0,(D(f,104)+a|0)+484380|0,s&65535)|0;k=x[27524];x[27524]=0;I:{J:{if((k|0)!=1){if(!b){break I}x[27524]=0;b=Q(55,e+416|0,10664)|0;k=x[27524];x[27524]=0;if((k|0)==1){break J}Cc(((f<<5)+a|0)+946304|0,b);wb(b);k=x[l>>2];b=d;if(Gh(k,x[l+4>>2])>>>0<=c>>>0){break G}ka=h,la=y[h+143|0]+y[Em(k,c)+143|0]|0,v[ka+143|0]=la;break H}c=P()|0;break a}c=P()|0;break a}b=c+1|0;break G}c=0;K:{if(!au(h)){break K}if((Fb(y[h+6|0]|y[h+7|0]<<8)|0)!=1){break K}if((Fb(y[h+14|0]|y[h+15|0]<<8)|0)!=2){break K}c=(Fb(y[h+18|0]|y[h+19|0]<<8)|0)==10}b=d;if(!c){break G}IS(e+288|0,h);b=Fb(z[e+308>>1]);if(b>>>0>=z[i>>1]){break H}x[27524]=0;c=T(687,e+184|0)|0;k=x[27524];x[27524]=0;if((k|0)==1){break E}k=z[e+324>>1];o=z[m>>1];x[27524]=0;t=D(b,104);b=a+484380|0;k=Fb(k);b=fa(698,e+288|0,(t+b|0)+104|0,(k>>>0<o>>>0?(b+D(k,104)|0)+104|0:c)|0,b+D(f,104)|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break D}if(!b){break H}x[27524]=0;b=Q(55,e+168|0,11149)|0;c=x[27524];x[27524]=0;if((c|0)==1){break C}Cc(((f<<5)+a|0)+946304|0,b);wb(b);v[h+139|0]=y[h+139|0]+12}b=d}x[27524]=0;b=b&65535;c=W(255,a|0,f|0,b|0)|0;f=x[27524];x[27524]=0;if((f|0)!=1){if(!c|b>>>0>z[i>>1]){break B}x[27524]=0;X(699,h|0,c|0,(D(b,104)+a|0)+484380|0,a|0);b=x[27524];x[27524]=0;if((b|0)!=1){break B}}c=P()|0;break a}c=P()|0;break a}c=P()|0;break a}c=P()|0;break a}d=d+1|0;continue}}break}J=zg(e+152|0);t=zg(e+136|0);b=tc(x[u>>2],x[u+4>>2]);_=D(z[a+480188>>1],M);$=Fl((b>>>0)/(_>>>0)|0);x[27524]=0;O=a+484344|0;R(229,O|0,$|0);b=x[27524];x[27524]=0;if((b|0)==1){break k}aa=a+484376|0;Ic(Tb(x[a+484360>>2],y[aa|0]));b=z[a+480188>>1];x[27524]=0;G=Q(700,e+120|0,b|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break l}ka=e,la=Cb(x[r>>2]),x[ka+64>>2]=la;ea=a+902204|0;ga=Cb(x[r+4>>2]);ha=a+480208|0;while(1){L:{M:{N:{k=x[e+64>>2];if(!Mb(k,ga)){break N}b=se((y[k+6|0]|y[k+7|0]<<8)<<16>>16);if((b|0)==1){break L}if((b&65535)==65535){break N}g=Fb(y[k|0]|y[k+1|0]<<8);b=x[q>>2];h=x[q+4>>2];c=xg(b,h);if(g>>>0>=c>>>0){break L}d=Fb(y[k+2|0]|y[k+3|0]<<8);if(d>>>0>c>>>0|!d|g>>>0>c-d>>>0){break L}c=b+(xg(b,h)<<5)|0;x[e+288>>2]=b;x[e+292>>2]=c-b>>5;b=x[e+288>>2];dc(e+96|0,b+(Fb(y[k|0]|y[k+1|0]<<8)<<5)|0,Fb(y[k+2|0]|y[k+3|0]<<8));O:{I=Tb(x[a+484360>>2],y[aa|0]);if(pc(x[I>>2],x[I+4>>2])){break O}x[27524]=0;R(526,I|0,65534);b=x[27524];x[27524]=0;if((b|0)!=1){break O}break M}b=x[e+96>>2];ia=De(b,x[e+100>>2]);while(1){if((b|0)==(ia|0)){break L}c=se(se((y[k+8|0]|y[k+9|0]<<8)<<16>>16)+se((y[b+16|0]|y[b+17|0]<<8)<<16>>16)<<16>>16);v[b+16|0]=c;v[b+17|0]=c>>>8;h=b;b=Td(J);while(1){P:{c=0;if(!b){break P}d=b+14|0;if(!Yt(h,d)){c=1;if(!Yt(d,h)){break P}b=b+4|0}b=x[b>>2];continue}break}Q:{R:{S:{if(c){x[27524]=0;b=Q(701,J|0,h|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break M}F=z[b>>1];break S}F=0;if(!K){break S}b=y[h+12|0]|y[h+13|0]<<8;x[27524]=0;F=Q(363,O|0,Fb(b)|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break M}if((F|0)==65535){break L}x[27524]=0;b=Q(701,J|0,h|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break M}w[b>>1]=F;if(Fb(y[h+8|0]|y[h+9|0]<<8)>>>0>=$>>>0){break R}if(Fb(y[h+10|0]|y[h+11|0]<<8)>>>0>=M>>>0){break R}m=Fb(y[h+14|0]|y[h+15|0]<<8);c=Dm(Cb(x[u>>2]),D(Fb(y[h+8|0]|y[h+9|0]<<8),_));b=z[a+480188>>1];ka=e,la=Dm(c,D(b,Fb(y[h+10|0]|y[h+11|0]<<8))),x[ka+48>>2]=la;N=0;x[e+32>>2]=0;o=Bg(e+80|0);T:while(1){U:{d=Fb(y[h+12|0]|y[h+13|0]<<8);c=Xb(x[O>>2],F);if(d>>>0<=N>>>0){break U}n=0;V=hd(x[c>>2],x[x[c+48>>2]+12>>2],N,0);c=0;while(1){if((b&65535)>>>0<=n>>>0){N=N+1|0;continue T}b=Cb(x[u+4>>2]);d=x[e+48>>2];i=Mb(d,b)?d:e+32|0;b=Cb(x[u+4>>2]);if(Mb(x[e+48>>2],b)){OS(e+48|0)}d=D(n,6)+V|0;g=y[i+1|0];b=(g>>>0>=85?-1:g+25|0)<<24>>24;s=0;f=x[l>>2];L=Gh(f,x[l+4>>2]);H=y[i+3|0];V:{if(L>>>0<=H>>>0){break V}s=H+1|0;if(v[Em(f,H)+142|0]&1|(b|0)<0){break V}b=El(se((y[h+16|0]|y[h+17|0]<<8)<<16>>16)+b<<24>>24)}W:{if(!y[d|0]|!(H|(y[i|0]|(g|0)!=255)|y[i+2|0])){break W}g=y[d+1|0];if(!g|g>>>0>L>>>0){break W}if(y[Em(f,g-1|0)+132|0]!=2){break W}mo(d)}f=eu(x[G>>2],n);X:{Y:{if(!(c&1)){g=y[i|0];break Y}c=y[o|0]|y[o+1|0]<<8|(y[o+2|0]<<16|y[o+3|0]<<24);v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;c=y[o+4|0]|y[o+5|0]<<8;v[d+4|0]=c;v[d+5|0]=c>>>8;Z:{if(y[d+3|0]){break Z}g=y[f+21|0];c=y[eu(x[G>>2],n-1|0)+21|0];if((g|0)==(c|0)){break Z}v[d+3|0]=21;v[f+21|0]=c;v[d+5|0]=c}c=0;g=y[i|0];if(!(g-24>>>0<2|(g|0)==9|!g&(y[i+2|0]+7&255)>>>0<2)){break X}}_:{$:{aa:{ba:{ca:{da:{switch(g|0){case 5:c=y[f+17|0];break ca;case 0:ea:{c=y[i+2|0];if(c>>>0>=201){g=0;fa:{switch(c-242|0){case 11:v[d+4|0]=1;v[d+2|0]=14;v[f+16|0]=0;break $;case 9:if(!y[d|0]){v[d|0]=y[f+17|0]}v[d+4|0]=1;v[d+2|0]=15;break $;case 8:if((m&255)>>>0<2){break $}m=m-1|0;break aa;case 7:if((m&255)==255){m=255;break $}m=m+1|0;break aa;case 6:v[f+17|0]=b;if(y[f+18|0]!=(s&255)){break $}v[d|0]=b;v[d+5|0]=255;v[d+3|0]=4;w[f+32>>1]=0;x[f+8>>2]=0;break $;case 5:v[d+5|0]=242;v[d+3|0]=2;break $;case 4:v[d+5|0]=242;v[d+3|0]=3;break $;case 3:v[d+5|0]=244;v[d+3|0]=2;break $;case 2:v[d+5|0]=244;v[d+3|0]=3;break $;case 1:v[d+5|0]=248;v[d+3|0]=2;break $;case 12:break ea;case 0:break fa;default:break $}}v[d+5|0]=248;v[d+3|0]=3;break $}g=0;L=v[i+1|0];if((L|0)<0&c>>>0>99){break $}if((L|0)>=0){v[f+17|0]=b;v[d|0]=b;v[f+18|0]=s;v[d+1|0]=s;w[f+32>>1]=0;x[f+8>>2]=0;c=y[i+2|0]}b=c&255;if(!b){break $}ka=f,la=Ak(+(b>>>0)*.64),v[ka+19|0]=la;j=B[f>>2];x[f>>2]=0;g=j!=E(0);break $}v[d+4|0]=0;v[d+2|0]=14;v[f+16|0]=1;break $;case 1:x[f+4>>2]=0;B[f>>2]=E(y[i+2|0])*E(.0333000011742115);break _;case 2:x[f+4>>2]=0;B[f>>2]=E(y[i+2|0])*E(-.0333000011742115);break _;case 12:v[e+288|0]=15;v[e+116|0]=y[i+3|0]>>>3;b=y[Ub(e+288|0,e+116|0)|0];v[e+288|0]=15;v[e+116|0]=y[i+2|0]>>>3;ka=f,la=y[Ub(e+288|0,e+116|0)|0]|b<<4,v[ka+24|0]=la;break _;case 3:x[f+12>>2]=0;b=y[i+2|0];w[f+32>>1]=0;B[f+8>>2]=E(b>>>0)*E(.0333000011742115);break _;case 4:x[f+12>>2]=0;b=y[i+2|0];w[f+32>>1]=0;B[f+8>>2]=E(b>>>0)*E(-.0333000011742115);break _;case 15:if(!y[i+2|0]|(b|0)<0){break _}g=b-y[f+17|0]<<5;c=g>>31;c=(c^g)-c|0;x[e+288>>2]=c;v[f+17|0]=b;x[f+8>>2]=0;v[d|0]=b;v[d+3|0]=4;b=Ag((c>>>0)/(y[i+2|0]<<1>>>0)|0);v[d+5|0]=b;v[f+27|0]=b;x[e+116>>2]=D(b,(m&255)-1|0);ka=f,la=c-x[rd(e+288|0,e+116|0)>>2]|0,w[ka+32>>1]=la;break _;case 13:v[e+288|0]=15;v[e+116|0]=y[i+3|0]>>>3;b=y[Ub(e+288|0,e+116|0)|0];v[e+288|0]=15;v[e+116|0]=y[i+2|0];ka=f,la=y[Ub(e+288|0,e+116|0)|0]|b<<4,v[ka+23|0]=la;break _;case 18:b=y[i+2|0]+y[f+17|0]&255;b=b?b>>>0>=120?120:b:1;v[f+17|0]=b;v[d|0]=b;v[d+5|0]=255;v[d+3|0]=4;break ba;case 23:case 24:case 25:b=Td(t);while(1){ga:{c=0;if(!b){break ga}g=b+13|0;if(!_t(i,g)){c=1;if(!_t(g,i)){break ga}b=b+4|0}b=x[b>>2];continue}break};if(c){v[d+3|0]=31;x[27524]=0;b=Q(702,t|0,i|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break M}v[d+5|0]=y[b|0];break _}b=x[Db(t)>>2];if(b>>>0>127){break _}x[e+112>>2]=y[i|0]|y[i+1|0]<<8|(y[i+2|0]<<16|y[i+3|0]<<24);c=x[ha>>2];x[27524]=0;x[e+28>>2]=x[e+112>>2];c=W(703,e+28|0,De(ea,b&255)|0,c|0)|0;g=x[27524];x[27524]=0;ha:{if((g|0)==1){break ha}if(!c){break _}v[d+3|0]=31;x[27524]=0;c=Q(702,t|0,i|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break ha}b=b|-128;v[c|0]=b;v[d+5|0]=b;ba=(y[i|0]&254)==24|ba;break _}break M;case 16:if(!y[i+2|0]){break _}v[d+3|0]=15;x[e+288>>2]=15;x[e+116>>2]=y[i+3|0]+1;ka=d,la=x[rd(e+288|0,e+116|0)>>2],v[ka+5|0]=la;w[f+30>>1]=D(y[i+2|0],y[i+3|0]+1|0);break _;case 9:v[d+3|0]=16;b=y[i+2|0];m=b?b:4;v[d+5|0]=m;break _;case 19:ia:{b=y[i+1|0];switch(b|0){case 0:case 4:break ia;default:break _}}g=128;g=(b|0)==4?y[i+3|0]:g;v[e+111|0]=g;v[e+288|0]=y[i+2|0];v[e+116|0]=100;b=e+288|0;s=e+116|0;c=y[Ub(b,s)|0];x[e+288>>2]=128;x[e+116>>2]=256-(g&255);g=x[rd(b,s)>>2];v[e+288|0]=128;b=y[Ub(b,e+111|0)|0];g=(D(c,g)|0)/128|0;s=g&255;if((s|0)!=y[f+20|0]){v[f+20|0]=g;v[d+3|0]=21;g=Ec(((D(s,y[f+19|0])+50&65535)>>>0)/100|0,0);v[f+21|0]=g;v[d+5|0]=g}if(y[i+1|0]!=4|(z[a+480188>>1]-1|0)<=(n|0)){break _}g=n+1|0;i=eu(x[G>>2],g);b=D(b,c)>>>7|0;if(y[i+20|0]==(b&255)){break _}v[i+20|0]=b;b=D(g,6)+V|0;v[b+3|0]=21;c=Ec(((D(y[f+20|0],y[f+19|0])+50&65535)>>>0)/100|0,0);v[f+21|0]=c;v[b+5|0]=c;break _;case 10:case 11:case 17:case 20:v[d+3|0]=0;break _;case 7:b=y[i+2|0];v[f+25|0]=0;v[f+26|0]=0;v[f+22|0]=b;break _;case 8:v[f+22|0]=y[f+22|0]+y[i+2|0];break _;case 14:v[f+25|0]=y[i+3|0];v[f+26|0]=y[i+2|0];break _;case 6:break da;default:break _}}v[f+18|0]=s;v[f+17|0]=b;v[d+1|0]=s;c=b}v[d|0]=c;if((b|0)>=0){v[f+18|0]=s;v[d+1|0]=s}if(y[i|0]==5){v[d+4|0]=1;v[d+2|0]=11}b=y[f+26|0];c=y[f+22|0];if(!(b|(c|y[i+2|0]))){break ba}if(b){ca=(Ki(+z[f+28>>1]*.006135923151542565+4.71238898038469)+-1)*+(b>>>0)*.25}else{ca=0}v[d+3|0]=44;ka=d,la=Ak(ca+ +(c+y[i+2|0]|0)),v[ka+5|0]=la}w[f+32>>1]=0;break _}v[d+5|0]=m;v[d+3|0]=16}b=Ec(((D(y[f+20|0],y[f+19|0])+50&65535)>>>0)/100|0,0);if(!(!g&y[f+21|0]==(b&255))){v[f+21|0]=b;v[d+5|0]=b;v[d+3|0]=21}if(n&1|v[i+1|0]<=0|(z[a+480188>>1]-1|0)<=(n|0)){break _}b=x[l>>2];if(Gh(b,x[l+4>>2])>>>0<=H>>>0){break _}if(y[Em(b,H)+132|0]!=1){break _}g=n+1|0;b=D(g,6)+V|0;c=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);v[b|0]=c;v[b+1|0]=c>>>8;v[b+2|0]=c>>>16;v[b+3|0]=c>>>24;c=y[d+4|0]|y[d+5|0]<<8;v[b+4|0]=c;v[b+5|0]=c>>>8;v[b+1|0]=y[b+1|0]+1;b=eu(x[G>>2],g);v[b+19|0]=y[f+19|0];B[b>>2]=B[f>>2];B[b+4>>2]=B[f+4>>2];B[b+8>>2]=B[f+8>>2];B[b+12>>2]=B[f+12>>2];w[b+30>>1]=z[f+30>>1]}ja:{if(y[d|0]){v[f+16|0]=0;break ja}c=0;if(y[f+16|0]){break X}}ka:{if(!z[f+30>>1]){break ka}b=m&255;w[e+288>>1]=b;c=f+30|0;ka=c,la=z[pe(c,e+288|0)>>1]-b|0,w[ka>>1]=la;if(y[d+3|0]){break ka}v[d+3|0]=15;v[d+5|0]=0}j=B[f>>2];la:{if(j==E(0)){break la}b=m&255;j=E(E(j*E(b>>>0))+B[f+4>>2]);B[f+4>>2]=j;if(y[d+3|0]){break la}ma:{na:{oa:{pa:{if(b>>>0>=2){g=b-1|0;C=E(g|0);if(!(C<=j)){break pa}v[e+288|0]=15;ka=e,la=qh(E(j/C)),v[ka+116|0]=la;b=y[Ub(e+288|0,e+116|0)|0];B[f+4>>2]=j-E(D(b,g)|0);v[d+3|0]=22;c=b<<4;break ma}if(!(j>=E(1))){break oa}break na}if(j>=E(1)){break na}if(!(j<=E(1-b|0))){break oa}v[e+288|0]=15;ka=e,la=qh(E(E(-j)/C)),v[ka+116|0]=la;c=y[Ub(e+288|0,e+116|0)|0];B[f+4>>2]=j+E(D(g,c)|0);v[d+3|0]=22;break ma}if(!(j<=E(-1))){break la}v[e+288|0]=14;ka=e,la=qh(E(-j)),v[ka+116|0]=la;b=y[Ub(e+288|0,e+116|0)|0];B[f+4>>2]=j+E(b>>>0);v[d+3|0]=22;c=b|-16;break ma}v[e+288|0]=15;ka=e,la=qh(j),v[ka+116|0]=la;b=y[Ub(e+288|0,e+116|0)|0];B[f+4>>2]=j-E(b>>>0);v[d+3|0]=22;c=b<<4|15}v[d+5|0]=c}j=B[f+8>>2];qa:{if(j==E(0)){break qa}b=m&255;j=E(E(j*E(b>>>0))+B[f+12>>2]);B[f+12>>2]=j;ra:{if(!y[d+3|0]){sa:{ta:{if(b>>>0>=2){c=b-1|0;C=E(c|0);if(!(C<=j)){break ta}v[e+288|0]=223;ka=e,la=qh(E(j/C)),v[ka+116|0]=la;b=y[Ub(e+288|0,e+116|0)|0];B[f+12>>2]=j-E(D(b,c)|0);v[d+3|0]=2;v[d+5|0]=b;break qa}if(!(j>=E(1))){break sa}break ra}if(j>=E(1)){break ra}if(!(j<=E(1-b|0))){break sa}v[e+288|0]=223;ka=e,la=qh(E(E(-j)/C)),v[ka+116|0]=la;b=y[Ub(e+288|0,e+116|0)|0];B[f+12>>2]=j+E(D(b,c)|0);v[d+3|0]=3;v[d+5|0]=b;break qa}if(!(j<=E(-1))){break qa}v[e+288|0]=14;ka=e,la=qh(E(-j)),v[ka+116|0]=la;b=y[Ub(e+288|0,e+116|0)|0];B[f+12>>2]=j+E(b>>>0);v[d+3|0]=3;v[d+5|0]=b|240;break qa}if(y[d+2|0]|b>>>0<2){break qa}da=E(j*E(.25));c=b-1|0;C=E(c|0);if(da>=C){v[e+288|0]=9;ka=e,la=qh(E(j/C))>>>2|0,v[ka+116|0]=la;b=y[Ub(e+288|0,e+116|0)|0];B[f+12>>2]=j-E(D(b,c)<<2);v[d+2|0]=12;v[d+4|0]=b;break qa}if(!(E(1-b|0)>=da)){break qa}v[e+288|0]=9;ka=e,la=qh(E(E(-j)/C))>>>2|0,v[ka+116|0]=la;b=y[Ub(e+288|0,e+116|0)|0];B[f+12>>2]=j+E(D(b,c)<<2);v[d+2|0]=13;v[d+4|0]=b;break qa}v[e+288|0]=15;ka=e,la=qh(j),v[ka+116|0]=la;b=y[Ub(e+288|0,e+116|0)|0];B[f+12>>2]=j-E(b>>>0);v[d+3|0]=2;v[d+5|0]=b|240}ua:{va:{wa:{xa:{ya:{za:{Aa:{b=y[d+3|0];switch(b|0){case 4:break ua;case 0:break Aa;default:break za}}Ba:{b=y[f+23|0];if(!b){b=y[f+24|0];if(b){break Ba}if(!z[f+32>>1]){break ua}c=f+32|0;break ya}v[d+3|0]=5;v[d+5|0]=b;if(!z[f+32>>1]){break ua}break xa}v[d+3|0]=8;v[d+5|0]=b;if(z[f+32>>1]){break xa}break ua}if(!z[f+32>>1]){break ua}c=f+32|0;if(b){break wa}}v[d+3|0]=4;break va}c=f+32|0}v[d+2|0]=11}w[e+288>>1]=D(y[f+27|0],(m&255)-1|0);ka=f,la=z[f+32>>1]-z[Tc(c,e+288|0)>>1]|0,w[ka+32>>1]=la}w[f+28>>1]=z[f+28>>1]+D(y[f+25|0],m&255)&1023;c=0;if(n&1){break X}b=y[f+18|0];if(!b){break X}g=x[l>>2];if(Gh(g,x[l+4>>2])>>>0<b>>>0){break X}g=Em(g,b-1|0);if(!(y[g+142|0]&4)){break X}b=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);v[o|0]=b;v[o+1|0]=b>>>8;v[o+2|0]=b>>>16;v[o+3|0]=b>>>24;b=y[d+4|0]|y[d+5|0]<<8;v[o+4|0]=b;v[o+5|0]=b>>>8;c=1;b=y[e+81|0];if(!b|y[g+132|0]!=1){break X}v[e+81|0]=b+1}n=n+1|0;b=z[a+480188>>1];continue}}break}ue(c,Kh(Te(Me(e+288|0,16,Fb(y[h+14|0]|y[h+15|0]<<8)&255),0)))}b=Gl(x[I>>2],x[I+4>>2]);ka=e,la=Fb(y[h+4|0]|y[h+5|0]<<8),w[ka+288>>1]=la;w[e+80>>1]=1;c=z[pe(e+288|0,e+80|0)>>1];x[27524]=0;X(704,I|0,b|0,c|0,F&65535);b=x[27524];x[27524]=0;if((b|0)==1){break Q}b=se((y[k+8|0]|y[k+9|0]<<8)<<16>>16);b=se(se((y[h+16|0]|y[h+17|0]<<8)<<16>>16)-b<<16>>16);v[h+16|0]=b;v[h+17|0]=b>>>8}b=h+32|0;continue}break}break M}d=ba&1;if(d){x[27524]=0;g=a+906300|0;b=Nd(g,0);Y(288,b|0);c=x[27524];x[27524]=0;if((c|0)==1){break M}x[b+16>>2]=1299020115;x[b+20>>2]=1869112133;x[b+24>>2]=655376;x[b+28>>2]=0;x[e+288>>2]=0;h=b+48|0;c=e+288|0;SX(b+32|0,h,c);x[27524]=0;c=Q(55,c|0,9504)|0;f=x[27524];x[27524]=0;if((f|0)==1){break M}qC(h,c);wb(c);x[27524]=0;c=Q(55,e+96|0,9497)|0;h=x[27524];x[27524]=0;if((h|0)==1){break M}cv(b+80|0,c);wb(c);x[27524]=0;b=Q(55,e+80|0,9489)|0;c=x[27524];x[27524]=0;if((c|0)==1){break M}qC(Nd(g,1)+48|0,b);wb(b)}b=0;while(1){if(z[a+480188>>1]>b>>>0){bC(a,b&65535);c=(b<<5)+a|0;v[c+480288|0]=d;w[c+480284>>1]=b<<8&256;b=b+1|0;continue}break}x[27524]=0;b=Q(1,e- -64|0,12061)|0;c=x[27524];x[27524]=0;Ca:{Da:{Ea:{if((c|0)!=1){Gb(a+1298344|0,b);xb(b);x[27524]=0;b=Q(1,e+48|0,12279)|0;c=x[27524];x[27524]=0;if((c|0)==1){break M}Gb(a+1298356|0,b);xb(b);if(Z){break Ea}x[27524]=0;b=Q(1,e+32|0,12061)|0;c=x[27524];x[27524]=0;if((c|0)==1){break M}break Da}break M}if(Gh(x[l>>2],x[l+4>>2])>>>0<=128){x[27524]=0;b=Q(1,e+32|0,9246)|0;c=x[27524];x[27524]=0;if((c|0)!=1){break Da}break M}x[27524]=0;b=Q(1,e+32|0,14795)|0;c=x[27524];x[27524]=0;if((c|0)==1){break Ca}}Gb(a+1298368|0,b);xb(b);x[a+1298404>>2]=28;NS(G);ES(t);DS(J);d=1;break m}}c=P()|0;NS(G);break j}qq(e- -64|0);continue}}c=P()|0;break a}c=P()|0;break a}fu(l);uc(u);Gm(r);Li(q);break c}c=P()|0;break j}c=P()|0}ES(t);DS(J);break a}c=P()|0;xb(b);break a}c=P()|0;break a}yb(c);x[27524]=0;c=d&65535;d=W(705,a|0,c|0,n|0)|0;g=x[27524];x[27524]=0;Fa:{Ga:{Ha:{Ia:{if((g|0)==1){break Ia}if(d){break Fa}x[27524]=0;d=W(706,a|0,c|0,n|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break Ia}if(d){break Fa}x[27524]=0;d=W(707,a|0,c|0,n|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break Ia}if(d){break Fa}x[27524]=0;d=Q(708,(D(c,104)+a|0)+484380|0,n|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break Ia}if(d){break Fa}x[27524]=0;d=Q(1,e+464|0,16142)|0;g=x[27524];x[27524]=0;if((g|0)==1){break Ha}g=x[G>>2];x[27524]=0;U(380,g|0,2,d|0);g=x[27524];x[27524]=0;if((g|0)==1){break Ga}xb(d);break Fa}c=P()|0;break e}c=P()|0;break e}c=P()|0;xb(d);break e}Ja:{Ka:{La:{F=D(c,104)+a|0;if(y[F+484414|0]&64){d=z[i>>1];if(bi(d)){break La}}d=x[l>>2];if(Gh(d,x[l+4>>2])>>>0<=c>>>0){break Ka}if(y[Em(d,c)+132|0]!=2){break Ka}c=z[i>>1];if(!bi(c)){break Ka}w[i>>1]=c+1;break Ka}c=d+1|0;w[i>>1]=c;H=D(c&65535,104)+a|0;o=H+484380|0;f=F+484380|0;d=x[f>>2];g=x[f+20>>2];Ma:{if(!_d(d,g)){break Ma}h=z[f+34>>1];if((f|0)==(o|0)|(Md(h)|0)!=2){break Ma}c=(f|0)==(o|0);if(!(_d(x[o>>2],x[o+20>>2])?c:1)){break Ma}_d(x[f>>2],x[f+20>>2]);if(!c){g=$t(d,an(h))}h=x[f+20>>2];if(!(h?g:0)){if(!c){iA(g)}break Ma}Na:{Oa:{switch(an(z[f+34>>1])-1|0){case 1:d=g;c=h;m=x[f+20>>2];k=x[f>>2];while(1){if(k){w[d>>1]=z[m>>1];w[c>>1]=z[m+2>>1];m=m+4|0;c=c+2|0;d=d+2|0;k=k-1|0;continue}break};break Na;case 0:break Oa;default:break Na}}d=g;c=h;m=x[f+20>>2];k=x[f>>2];while(1){if(k){v[d|0]=y[m|0];v[c|0]=y[m+1|0];m=m+2|0;c=c+1|0;d=d+1|0;k=k-1|0;continue}break}}d=no(o,f);w[d+34>>1]=z[d+34>>1]&65471;x[o+20>>2]=g;g=no(f,f);w[g+34>>1]=z[g+34>>1]&65471;x[f+20>>2]=h;h=a+1298224|0;c=a+1074992|0;while(1){if((c|0)!=(h|0)){f=x[c+104>>2];if(!((f|0)!=(d|0)&(f|0)!=(g|0))){x[c+88>>2]=x[c+88>>2]&-65}c=c+872|0;continue}break}yj(d,a);yj(g,a)}x[27524]=0;c=Q(55,e+448|0,6323)|0;d=x[27524];x[27524]=0;if((d|0)==1){break Ja}Fe(H+484423|0,c);wb(c);x[27524]=0;c=Q(55,e+432|0,6226)|0;d=x[27524];x[27524]=0;if((d|0)==1){break f}Fe(F+484423|0,c);wb(c)}yb(n);ec(t);g=0;continue}break}c=P()|0;break e}c=P()|0}yb(n)}ec(t);break a}ib=e+688|0;return d|0}c=P()|0}fu(l);uc(u);Gm(r);Li(q);S(c|0);p()}function ru(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,k=0,l=0,m=0,n=0,q=0,r=0,s=0,t=0,u=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,T=0,V=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,fa=0,ga=0,ha=0,ka=0,la=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,za=0,Aa=0,Ba=E(0),Ca=0,Da=0,Ea=0,Fa=E(0);f=ib-192|0;ib=f;Z=Nb(a);r=f+160|0;v[r+26|0]=0;w[r+24>>1]=0;x[r+16>>2]=0;x[r+20>>2]=-1;x[r+8>>2]=-1;x[r+12>>2]=-1;x[r>>2]=0;x[r+4>>2]=0;M=x[d+16>>2];a=y[d+6|0];la=b+484360|0;i=x[la>>2];na=(Ca=a,Da=y[b+484376|0],Ea=wj(i,x[b+484364>>2])>>>0>a>>>0,Ea?Ca:Da);a=na&255;J=Dj(i,a);x[27524]=0;s=Q(586,f+128|0,b|0)|0;i=x[27524];x[27524]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((i|0)!=1){k=x[s+4>>2];x[27524]=0;K=W(587,f+88|0,b|0,a|0)|0;a=x[27524];x[27524]=0;if((a|0)==1){break i}ba=c&7;e=x[d>>2];a=z[d+4>>1];while(1){i=a&65535;if(Oc(x[J>>2],x[J+4>>2])>>>0<=i>>>0){break g}x[27524]=0;i=Q(315,J|0,i|0)|0;n=x[27524];x[27524]=0;if((n|0)==1){break h}if(i){break g}a=a+1|0;e=0;continue}}a=P()|0;break d}a=P()|0;break e}a=P()|0;break f}x[d>>2]=e;w[d+4>>1]=a;x[k+52>>2]=e;L=k+48|0;x[L>>2]=e;x[r+16>>2]=e;w[k+74>>1]=a;w[k+72>>1]=a;w[r+24>>1]=a;oa=Id(f+80|0);j:{if((ba|0)!=7){break j}a=ib-16|0;ib=a;i=a+8|0;Ab(i,oa,1);uo(i);ib=a+16|0;if((M|0)!=2){break j}a=x[J>>2];n=Oc(a,x[J+4>>2]);i=z[d+12>>1];if(n>>>0<=i>>>0){break j}n=x[b+484344>>2];_=x[b+484348>>2];a=z[bc(a,i)>>1];if(!Ce(n,_,a)){break j}i=Xb(n,a);n=x[d+8>>2];if(A[i+12>>2]<=n>>>0){break j}a=0;l=hd(x[i>>2],x[x[i+48>>2]+12>>2],n,0);i=z[b+480188>>1];n=x[s+8>>2];e=z[b+480192>>1];while(1){if((a|0)==(i|0)){break j}k:{l:{m:{n:{h=y[l|0];switch(h-253|0){case 1:case 2:break l;case 0:break n;default:break m}}if(e){break l}}if(!Wc(h)){break k}if(ok(y[l+2|0],y[l+3|0])){break k}}Ca=We(n,a),Da=-1,x[Ca>>2]=Da}l=l+6|0;a=a+1|0;continue}}$=c&1;if($){sQ(k+223860|0)}O=k+74|0;ua=k+223872|0;va=(M|0)!=3;N=k+80|0;wa=b+901692|0;xa=b+902204|0;fa=k+44|0;aa=k+20|0;H=b+1074312|0;pa=k+616|0;ca=32768;qa=C[d+8>>3];o(+qa);a=j(1)|0;za=j(0)|0;_=a;V=b+480188|0;G=b+480180|0;ga=b+484348|0;ra=(M|0)!=2;Aa=k+223884|0;sa=(ba|0)!=7;ha=b+480192|0;h=0;n=0;o:{p:{q:{r:{s:while(1){i=_;while(1){rQ(f+16|0,x[G>>2],z[V>>1],k,h&1);t:{u:{v:{w:{if(!(!(C[s+24>>3]>=qa)|va)){break w}g=y[f+16|0];a=65535;d=x[J>>2];t=Oc(d,x[J+4>>2]);q=z[k+72>>1];if(t>>>0>q>>>0){a=z[bc(d,q)>>1]}w[k+70>>1]=a;d=x[b+484344>>2];e=x[ga>>2];l=a&65535;if(!(Ce(d,e,l)|(l|0)==65535|ra)&(q|0)==(i&65535)){break w}x:{y:{while(1){a=a&65535;if(Jf(d,e)>>>0>a>>>0){break x}q=z[k+72>>1];z:{A:{if((a|0)!=65535){m=x[J>>2];u=Oc(m,x[J+4>>2]);if(q>>>0<u>>>0){break A}}a=z[J+28>>1];if((q|0)==(a|0)){break x}m=x[J>>2];u=Oc(m,x[J+4>>2]);break z}a=q+1|0}w[k+72>>1]=a;l=65535;q=a&65535;if(q>>>0<u>>>0){l=z[bc(m,q)>>1]}w[k+74>>1]=a;w[k+70>>1]=l;B:{if(!Ce(d,e,l&65535)){d=eq(f+16|0,pa);x[27524]=0;a=ja(588,K|0,a&65535,0,d|0,(g|0)!=0|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break B}if(a){break y}e=x[ga>>2];d=x[b+484344>>2]}a=z[k+70>>1];continue}break}a=P()|0;break f}if(M>>>0<=1){a=z[k+72>>1];x[r+8>>2]=0;w[r+20>>1]=a;if(!M){break x}}x[27524]=0;a=W(589,K|0,O|0,L|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break p}if(!a){break x}C[r>>3]=C[s+24>>3];x[27524]=0;R(590,Z|0,r|0);a=x[27524];x[27524]=0;if((a|0)==1){break p}x[r+16>>2]=x[L>>2];w[r+24>>1]=z[O>>1];x[27524]=0;Y(591,s|0);a=x[27524];x[27524]=0;if((a|0)==1){break p}a=z[k+74>>1];w[k+72>>1]=a;Ca=k,Da=z[bc(x[J>>2],a)>>1],w[Ca+70>>1]=Da;x[k+52>>2]=x[k+48>>2]}if(z[O>>1]==65535){break o}a=x[b+484344>>2];e=z[k+70>>1];if(!Ce(a,x[ga>>2],e)){a=z[k+72>>1];if((a|0)==z[J+28>>1]){if(!M){break o}x[27524]=0;a=W(589,K|0,O|0,L|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break p}if(!a){break o}C[r>>3]=C[s+24>>3];x[27524]=0;R(590,Z|0,r|0);a=x[27524];x[27524]=0;if((a|0)==1){break p}x[r+16>>2]=x[L>>2];w[r+24>>1]=z[O>>1];x[27524]=0;Y(591,s|0);a=x[27524];x[27524]=0;if((a|0)==1){break p}x[k+52>>2]=x[k+48>>2];continue}w[O>>1]=a+1;continue}d=x[L>>2];if(d>>>0>=A[Xb(a,e)+12>>2]){x[L>>2]=0;d=0}if(ra){break v}if(z[k+72>>1]!=(i&65535)|(d|0)!=(za|0)){break u}}v[r+26|0]=1;break o}a=0;if((M|0)==3){break t}}a=0;if(A[K+28>>2]<ca>>>0){break t}x[s+24>>2]=0;x[s+28>>2]=2146435072;x[K+28>>2]=0;ca=ca>>>(ca>>>0>256)|0;d=x[L>>2];a=1}e=z[k+72>>1];q=eq(f+16|0,pa);x[27524]=0;d=ja(588,K|0,e|0,d|0,q|0,(g|0)!=0|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break r}if((a|d)==1){if(M>>>0<=1){w[r+20>>1]=z[k+72>>1];x[r+8>>2]=x[k+48>>2];if(!M){break o}}x[27524]=0;a=W(589,K|0,O|0,L|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break q}if(!a){break o}C[r>>3]=C[s+24>>3];x[27524]=0;R(590,Z|0,r|0);a=x[27524];x[27524]=0;if((a|0)==1){break q}x[r+16>>2]=x[L>>2];w[r+24>>1]=z[O>>1];x[27524]=0;Y(591,s|0);a=x[27524];x[27524]=0;if((a|0)==1){break q}x[k+52>>2]=x[k+48>>2];continue}w[r+22>>1]=z[k+72>>1];x[r+12>>2]=x[k+48>>2];qQ(b,k,0);l=x[k+48>>2];d=Xb(x[b+484344>>2],z[k+70>>1]);if(l>>>0>=A[d+12>>2]){x[L>>2]=0;l=0}if(g){continue}break}a=0;l=hd(x[d>>2],x[x[d+48>>2]+12>>2],l,0);Ab(f+16|0,H,77);h=zb(x[x[f+16>>2]>>2],x[f+20>>2]);C:{while(1){if(z[V>>1]>a>>>0){D:{if(!(!Iz(l)&(!h|!(y[((a<<5)+b|0)+480281|0]&4)))){mo((k+D(a,872)|0)+1404|0);break D}if(oh(y[l|0])){E:{if(!Qd(y[Aa|0])){break E}d=y[l+1|0];if(d-251>>>0<5|!d){break E}e=y[l+5|0];g=y[l+3|0];q=nk(y[l+2|0],y[l+4|0]);i=f+16|0;v[i|0]=d-1;x[i+4>>2]=q&65535;x[27524]=0;d=Q(592,ua|0,i|0)|0;i=x[27524];x[27524]=0;if((i|0)==1){break C}Ca=d,Fa=E(E(nk(g,e)>>>0)/E(999)),B[Ca>>2]=Fa}mo((k+D(a,872)|0)+1404|0);break D}d=k+D(a,872)|0;i=d+1408|0;e=y[l+4|0]|y[l+5|0]<<8;v[i|0]=e;v[i+1|0]=e>>>8;i=d+1404|0;e=y[l|0]|y[l+1|0]<<8|(y[l+2|0]<<16|y[l+3|0]<<24);v[i|0]=e;v[i+1|0]=e>>>8;v[i+2|0]=e>>>16;v[i+3|0]=e>>>24;F:{G:{H:{I:{switch(y[l+3|0]-16|0){case 0:e=y[l+5|0];break H;case 3:break F;case 4:break G;case 1:break I;default:break D}}Ab(f+16|0,H,5);if(!zb(x[x[f+16>>2]>>2],x[f+20>>2])){break D}e=y[l+5|0];if(!e){break D}}oQ(b,k,e&255);break D}i=d+1409|0;e=y[i|0];J:{if(!(e|!(x[G>>2]&16777250))){v[i|0]=y[d+1449|0];break J}v[d+1449|0]=e}d=y[l+5|0];i=d&240;if((i|0)!=224){if((i|0)!=96){break D}x[k+24>>2]=x[k+24>>2]+(d&15);break D}if(x[aa>>2]){break D}d=d&15;if(d?0:y[G|0]&2){break D}x[aa>>2]=d+1;break D}d=y[l+5|0];if((d&240)!=224){break D}x[aa>>2]=(d&15)+1}l=l+6|0;a=a+1|0;continue}break}i=nl(k);x[f+16>>2]=1;a=x[Yc(aa,f+16|0)>>2];w[k+68>>1]=65535;x[k+60>>2]=-1;x[k+64>>2]=-1;F=i-1|0;a=i-a|0;ka=D(a,1e4);l=0;while(1){if(z[V>>1]<=l>>>0){if(x[G>>2]==4&x[k+40>>2]==65535){break o}x[k+32>>2]=x[b+480216>>2];a=Xb(x[b+484344>>2],z[k+70>>1]);d=x[a+16>>2];if(nQ(d,x[a+20>>2])){x[k+32>>2]=d}d=mQ(b,k);a=D(d,i);C[s+24>>3]=C[s+24>>3]+ +(a>>>0)/+A[b+24620>>2];x[k>>2]=a+x[k>>2];K:{L:{if(sa){break L}l=0;ka=(n|0)!=0&(d|0)!=(n|0);while(1){if(z[V>>1]<=l>>>0){break L}F=We(x[s+8>>2],l);M:{if(x[F>>2]==-1){break M}m=k+D(l,872)|0;u=m+1404|0;T=x[m+1316>>2];if(!T){if(Iz(u)){break M}}a=m+1409|0;t=y[a|0];e=ok(y[u+2|0],y[u+3|0]);if(y[m+1405|0]){x[m+1276>>2]=0}g=m+616|0;q=t&15;h=0;N:{if(!Wc(y[u|0])){break N}if(!(!e|!y[F+4|0])){Hz(f+16|0,b,g,T,0);h=x[f+20>>2];x[m+624>>2]=x[f+16>>2];x[m+628>>2]=h}v[m+1418|0]=y[m+1415|0];T=m+1308|0;da=x[T>>2];h=y[m+1419|0];if(h){cq(b,g,h,e,1,1)}h=y[u|0];x[27524]=0;ia(593,b|0,g|0,h|0,e|0,1,0,65535);h=x[27524];x[27524]=0;O:{P:{Q:{if((h|0)!=1){t=t>>>4|0;lQ(x[G>>2],z[V>>1],k,l&65535);I=We(x[s+8>>2],l);v[I+4|0]=1;F=y[m+1407|0];R:{if(!((y[a|0]&240)!=208|(F-19&255)>>>0>1)){h=q;if(h>>>0<i>>>0){break R}}h=(F|0)==33?i>>>0>t>>>0?t:0:0}ta=x[aa>>2];if(!(!(x[G>>2]&16777250)|(!h|ta>>>0<2))){h=D(ta-1|0,x[k+24>>2]+x[k+40>>2]|0)+h|0}if(!e){x[I>>2]=0}if((F|0)==9){break O}if((F|0)==19){break Q}if((F|0)!=20|(t|0)!=8){break P}break O}a=P()|0;break f}if((t|0)==8){break O}}if(y[m+1406|0]!=2){break N}}x[T>>2]=da}S:{if(!Wc(y[u|0])){Ab(f+16|0,H,114);if(!zb(x[x[f+16>>2]>>2],x[f+20>>2])){break S}}T:{U:{V:{W:{e=y[m+1407|0];switch(e-42|0){case 1:break T;case 0:break U;case 2:break V;default:break W}}if((e|0)!=10){break T}e=z[k+70>>1];t=x[k+48>>2];x[27524]=0;ea(594,b|0,g|0,l&65535,t|0,e|0);e=x[27524];x[27524]=0;if((e|0)!=1){break S}break K}F=qoa(y[a|0],0,x[m+692>>2],0);t=kb;e=t>>>8|0;bo(b,g,Ec((t&255)<<24|F>>>8,e));break S}if(!x[m+720>>2]){break T}x[27524]=0;X(595,s|0,l&65535,n|0,-1);e=x[27524];x[27524]=0;if((e|0)==1){break K}jQ(g,y[a|0]);h=x[k+40>>2]-1|0;break S}if(y[m+1406|0]!=15){break S}t=x[m+720>>2];if(!t){break S}e=y[m+1408|0];if(e>>>0>9){break S}X:{if(!e){e=x[m+1280>>2];break X}e=x[Bb(t+68|0,e-1|0)>>2];x[m+1280>>2]=e}bo(b,g,e)}Y:{Z:{_:{switch(y[u|0]-253|0){case 0:if(z[ha>>1]){break Z}break;case 1:case 2:break Z;default:break _}}e=y[m+1407|0];if(!((y[a|0]&240)!=192|(e-19&255)>>>0>1)&i>>>0>q>>>0){break Z}t=0;F=e&255;if((F|0)==33&(q|0)!=0&i>>>0>h+q>>>0){break Z}if((F|0)!=25){break Y}}e=y[m+1407|0];t=1}I=m+1304|0;F=e&255;$:{if((F|0)!=13){if(y[m+1406|0]!=1){break $}q=m+1408|0}else{q=a}x[I>>2]=y[q|0]<<2}q=m+1407|0;aa:{ba:{ca:{if((!x[m+720>>2]|t)==1|F>>>0>45){break ca}Ab(f+16|0,oa,F);if(zb(x[x[f+16>>2]>>2],x[f+20>>2])){break ba}e=y[q|0];if((e|0)!=19){break ca}F=y[a|0]&240;if((F|0)==16){break ba}e=19;if((F|0)==32){break ba}}if(!t){break aa}}YR(g);Ca=We(x[s+8>>2],l),Da=0,x[Ca>>2]=Da;break M}if(ka){x[27524]=0;X(595,s|0,l&65535,n|0,-1);e=x[27524];x[27524]=0;if((e|0)==1){break K}e=y[q|0]}da:{ea:{fa:{ga:{ha:{e=e&255;if(e-6>>>0>=2){ia:{switch(e-19|0){case 1:break ga;case 0:break ha;default:break ia}}if(e-35>>>0<2){break ea}if((e|0)==45){break fa}if((e|0)!=11){break da}}if(!y[a|0]&x[G>>2]==1){break da}q=m+1467|0;e=0;while(1){if((e|0)==(i|0)){break da}v[q|0]=!e|y[q|0]&254;ao(b,g,y[a|0]);e=e+1|0;continue}}e=y[a|0];a=e&15;if(!(a|x[G>>2]&1048580)){break da}q=m+1467|0;v[q|0]=y[q|0]|1;e=e&240;if((e|0)!=176){if((e|0)!=160){break da}$n(b,g,a,0);break da}_n(b,g,a,0);break da}ja:{ka:{la:{a=y[a|0];switch(a-158|0){case 1:break ka;case 0:break la;default:break ja}}x[27524]=0;X(595,s|0,l&65535,n|0,-1);a=x[27524];x[27524]=0;if((a|0)==1){break K}x[m+704>>2]=x[m+704>>2]&-129;break da}x[27524]=0;X(595,s|0,l&65535,n|0,-1);a=x[27524];x[27524]=0;if((a|0)==1){break K}a=x[m+704>>2];x[m+704>>2]=a|128;if(x[g+4>>2]){break da}e=x[m+692>>2];if(!e){break da}if(!(Ca=Wc(y[u|0]),Da=1,Ea=a&2,Ea?Ca:Da)){break da}x[g>>2]=-1;x[g+4>>2]=e-1;break da}if((a&240)!=112|a>>>0<115){break da}VR(g,a,x[G>>2]);break da}iQ(g,y[a|0]);break da}x[27524]=0;a=l&65535;X(595,s|0,a|0,n|0,-1);e=x[27524];x[27524]=0;if((e|0)==1){break K}hQ(b,a,k,0)}e=m+1467|0;a=y[e|0]|1;v[e|0]=a;ma:{na:{oa:{pa:{qa:{q=m+1406|0;switch(y[q|0]-3|0){case 11:break na;case 0:case 1:break oa;case 3:break pa;case 2:break qa;default:break ma}}a=y[m+1408|0];Ab(f+16|0,H,41);$n(b,g,a,zb(x[x[f+16>>2]>>2],x[f+20>>2]));break ma}a=y[m+1408|0];Ab(f+16|0,H,41);_n(b,g,a,zb(x[x[f+16>>2]>>2],x[f+20>>2]));break ma}t=y[m+1408|0];ra:{if(t){break ra}Ab(f+16|0,H,41);t=0;if(!zb(x[x[f+16>>2]>>2],x[f+20>>2])){break ra}t=y[m+1450|0];if(!t){break ma}}q=y[q|0]==3?t<<4:t;a=0;while(1){if((a|0)==(i|0)){break ma}v[e|0]=!a|y[e|0]&254;ao(b,g,q&255);a=a+1|0;continue}}g=y[m+1408|0];if(g>>>0>1){break ma}v[e|0]=a&247|!g<<3}if(y[e|0]&8){break M}a=1;sa:{ta:{ua:{e=y[u+3|0];if(e>>>0>28){break ua}g=1<<e;if(g&92){break sa}if(!(g&268959744)){break ua}if((y[u+5|0]-16&255)>>>0<32){break sa}break ta}if(e-38>>>0<4){break sa}}a=(y[u+2|0]-11&255)>>>0<3}if(a){e=We(x[s+8>>2],l);a=x[e>>2];x[e>>2]=a+i;x[27524]=0;X(595,s|0,l&65535,d|0,a+h|0);a=x[27524];x[27524]=0;if((a|0)!=1){break M}a=P()|0;break f}a=We(x[s+8>>2],l);x[a>>2]=x[a>>2]+(i-h|0)}l=l+1|0;continue}}h=gQ(b,k,J,0);n=d;continue s}a=P()|0;break f}g=k+D(l,872)|0;m=g+1404|0;va:{if(Iz(m)){break va}q=g+616|0;T=g+1409|0;e=y[T|0];da=g+1407|0;u=y[da|0];wa:{xa:{if(!$){break xa}t=y[m|0];d=t;h=g+1405|0;I=y[h|0];if(I){v[g+1415|0]=0;v[g+1419|0]=I;Ca=We(x[s+8>>2],l),Da=255,v[Ca+5|0]=Da;d=y[m|0]}ya:{if(!Wc(d)){break ya}v[g+1415|0]=t;XR(q);if(!sa){if(x[We(x[s+8>>2],l)>>2]!=-1){break ya}}I=g+1272|0;d=y[g+1419|0];d=x[(d?d>>>0>z[ha>>1]?I:((d<<2)+b|0)+900380|0:I)>>2];if(!d){break ya}I=y[d+21|0];if(Ue(I)){Ca=g+1453|0,Da=Wm(I),v[Ca|0]=Da}d=y[d+22|0];if(!Ue(d)){break ya}Ca=g+1454|0,Da=Wm(d),v[Ca|0]=Da}za:{if(!(Wc(y[m|0])|y[h|0])){break za}I=g+1419|0;h=y[I|0];Aa:{if(!h){h=0;break Aa}if(z[ha>>1]<h>>>0){break Aa}d=x[((h<<2)+b|0)+900380>>2];if(!d|!(v[d+15|0]&1)){break Aa}lq(q,x[d+8>>2],b);h=y[I|0]}d=Gq(b,t,h&255);if(!d){break za}d=D(d,104)+b|0;if(!(y[d+484414|0]&32)){break za}lq(q,z[d+484408>>1],b)}Ba:{Ca:{Da:{d=y[g+1406|0];switch(d-1|0){case 1:break xa;case 2:case 3:break Ca;case 0:break Da;default:break Ba}}Ca=We(x[s+8>>2],l),Da=y[g+1408|0],v[Ca+5|0]=Da;break xa}d=y[g+1408|0];if(!d){break xa}v[g+1450|0]=d;break xa}if((d|0)!=11){break xa}d=y[g+1408|0];if(!d){break xa}h=f+16|0;Fz(h,b,y[m+3|0],d,0);w[g+1384>>1]=z[f+16>>1];if(y[Ze(h)|0]){break wa}}Ea:{Fa:{Ga:{Ha:{Ia:{switch(u-12|0){case 0:fQ(b,k,l&65535);break Ea;case 2:d=eQ(b,k,l&65535,e);if((d|0)==-1){break Ea}x[k+60>>2]=d;break Ea;case 5:Ab(f+16|0,H,5);if(zb(x[x[f+16>>2]>>2],x[f+20>>2])){break Ea}d=D(Zn(b,z[k+70>>1],x[k+48>>2],l&65535,0),1e4);Ja:{if(!$|!(x[G>>2]&16777250)){break Ja}if(d>>>0>=1e4){v[g+1451|0]=(d>>>0)/1e4;break Ja}d=D(y[g+1451|0],1e4)}Ka:{if(d>>>0>319999){break Ka}m=(d>>>0)/1e4|0;h=D(ka,m&15);d=x[fa>>2];if((m&240)==16){d=d+h|0;break Ka}h=d-h|0;d=d>>>0>=h>>>0?h:0}x[fa>>2]=d;d=x[b+8>>2];h=x[d+20>>2];d=x[d+24>>2];Ab(f+16|0,H,8);Xo(fa,D(h,1e4),zb(x[x[f+16>>2]>>2],x[f+20>>2])?255e4:D(d,1e4));break Ea;case 8:La:{switch((e&240)-144>>>4|0){case 0:if(e>>>0>145){break Ea}x[g+704>>2]=x[g+704>>2]&-257|((e|0)==145)<<8;break Ea;case 1:v[g+1452|0]=e&15;break Ea;case 2:break Ha;case 6:break La;default:break Ea}}v[g+1460|0]=e&15;break Ea;case 1:case 3:case 4:case 6:break Ea;case 7:break Ia;default:break Fa}}d=e&240;if((d|0)==240){break Ga}if((d|0)!=96){break Ea}}Ez(b,k,q,e&15);break Ea}v[g+1460|0]=e&15;break Ea}if((u|0)!=28|(e&240)!=160){break Ea}Ab(f+16|0,H,58);if(zb(x[x[f+16>>2]>>2],x[f+20>>2])){break Ea}v[g+1452|0]=e&15}if(!$){break va}Ma:{Na:{Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{switch(u-2|0){case 0:if(!e){break Ma}Ab(f+16|0,H,90);if(!zb(x[x[f+16>>2]>>2],x[f+20>>2])){v[g+1428|0]=e}v[g+1427|0]=e;break wa;case 1:if(!e){break Ma}Ab(f+16|0,H,90);if(!zb(x[x[f+16>>2]>>2],x[f+20>>2])){v[g+1427|0]=e}v[g+1428|0]=e;break wa;case 2:if(!e){break Ma}w[g+1384>>1]=e;break wa;case 8:if(!e){break Ma}x[g+1280>>2]=e<<8;break wa;case 4:case 9:if(!e){break Ma}v[g+1425|0]=e;break wa;case 11:Ca=We(x[s+8>>2],l),Da=e,v[Ca+5|0]=Da;break wa;case 21:d=x[G>>2];e=e<<(!(d&59593760)&e<<24>>24>=0);h=e&255;if(h>>>0<=128){x[N>>2]=h<<1;break wa}if(d&16777250){break wa}x[N>>2]=256;break wa;case 22:Ab(f+16|0,H,9);Va:{if(zb(x[x[f+16>>2]>>2],x[f+20>>2])){d=g+1433|0;if(e){v[d|0]=e;break Va}e=y[d|0];break Va}if(e){v[k+1433|0]=e;break Va}e=y[k+1433|0]}d=e&15;h=e&255;Wa:{if(!((d|0)!=15|h>>>0<16)){e=(e&240)>>>4<<!(x[G>>2]&59593760);d=x[N>>2]+(e<<1)|0;break Wa}h=h&240;if(!(!d|(h|0)!=240)){e=d<<(x[G>>2]&59593760?1:2);d=x[N>>2]-e|0;break Wa}if(h){e=(e>>>3&30)<<!(x[G>>2]&59593760);d=x[N>>2]+D(a,e)|0;break Wa}e=d<<(x[G>>2]&59593760?1:2);d=x[N>>2]-D(a,e)|0}x[N>>2]=d;re(N,0,256);break wa;case 19:if(e>>>0>64){break wa}x[g+1364>>2]=e;break wa;case 20:d=g+1432|0;Xa:{if(e){v[d|0]=e;break Xa}e=y[d|0]}u=g+1364|0;d=x[u>>2];h=e&15;m=e&255;Ya:{if(!((h|0)!=15|m>>>0<16)){x[f+16>>2]=d+(m>>>4|0);break Ya}if(!(!h|(m&240)!=240)){x[f+16>>2]=d-h;break Ya}if(h){x[f+16>>2]=d-D(a,h);break Ya}x[f+16>>2]=d+D(a,m>>>4|0)}re(f+16|0,0,64);x[u>>2]=x[f+16>>2];break wa;case 7:zm(b,q,e,8);break wa;case 29:case 30:break Na;case 25:break Oa;case 6:break Pa;case 24:break Qa;case 3:break Ra;case 5:break Sa;case 18:break Ta;case 17:break Ua;default:break wa}}if(e>>>0>15){break Ta}h=(e&1)<<14;m=z[V>>1];d=0;while(1){if((d|0)==(m|0)){break Ta}u=k+D(d,872)|0;x[u+704>>2]=(h|x[u+704>>2]&-16385)^16384;d=d+1|0;continue}}if((e&240)!=128){break wa}zm(b,q,e&15,4);break wa}if(e){v[g+1425|0]=e}e=0}ml(q,e);break wa}dQ(b,q,e);break wa}cQ(q,e);break wa}bQ(q,e);break wa}Za:{if(e<<24>>24>=0){d=De(wa,y[g+1460|0]);break Za}d=De(xa,e&127)}h=y[T|0];x[27524]=0;ma(596,b|0,k|0,l&65535,0,d|0,h|0);d=x[27524];x[27524]=0;if((d|0)!=1){break wa}a=P()|0;break f}e=0}_a:{$a:{switch(y[g+1406|0]-2|0){case 0:zm(b,q,y[g+1408|0],6);break _a;case 5:Ab(f+16|0,H,53);d=y[g+1408|0];if(zb(x[x[f+16>>2]>>2],x[f+20>>2])){v[g+1439|0]=d&15;break _a}ml(q,d<<4);break _a;case 6:break $a;default:break _a}}ml(q,y[g+1408|0])}ab:{bb:{cb:{db:{eb:{d=y[da|0];switch(d-5|0){case 1:break ab;case 3:break cb;case 0:case 2:break db;default:break eb}}switch(d-26|0){case 1:break bb;case 0:break db;default:break ab}}fb:{if(x[G>>2]&16777248){d=i;if(!(y[b+480208|0]&4)){break fb}}d=a}h=y[g+1439|0];Ab(f+16|0,H,21);g=g+1435|0;m=y[g|0];d=D(d,h);Ca=g,Da=(zb(x[x[f+16>>2]>>2],x[f+20>>2])?d<<2:d)+m|0,v[Ca|0]=Da;break ab}gb:{if(x[G>>2]&16777248){d=i;if(!(y[b+480208|0]&4)){break gb}}d=a}h=y[g+1442|0];Ab(f+16|0,H,21);g=g+1436|0;m=y[g|0];d=D(d,h);Ca=g,Da=(zb(x[x[f+16>>2]>>2],x[f+20>>2])?d<<2:d)+m|0,v[Ca|0]=Da;break ab}d=g+1437|0;v[d|0]=y[d|0]+D(F,y[g+1445|0]);$P(b,q)}Ab(f+16|0,H,78);if(!zb(x[x[f+16>>2]>>2],x[f+20>>2])){break va}d=e&255;if(!d){break va}_P(q,d)}l=l+1|0;continue}}break}a=P()|0;break f}a=P()|0;break f}a=P()|0;break f}a=P()|0;break f}hb:{if((ba|0)!=7){break hb}a=0;d=b+480188|0;while(1){if(z[d>>1]<=a>>>0){break hb}ib:{if(x[We(x[s+8>>2],a)>>2]==-1){break ib}x[27524]=0;X(595,s|0,a&65535,n|0,-1);i=x[27524];x[27524]=0;if((i|0)!=1){break ib}a=P()|0;break f}a=a+1|0;continue}}if(y[r+26|0]){w[r+20>>1]=z[k+72>>1];x[r+8>>2]=x[k+48>>2]}a=k+223860|0;C[r>>3]=C[s+24>>3];x[27524]=0;R(590,Z|0,r|0);d=x[27524];x[27524]=0;if((d|0)!=1){if(!$){break a}if(!(M?y[r+26|0]:1)){break c}e=sz(f+48|0);if(Qd(y[a+24|0])){OP(e,a)}Dz(a);a=rc(b+1074376|0,k,614);n=0;while(1){if((n|0)==256){Om(a+223848|0,k+223848|0);d=a+223860|0;n=y[d+24|0];i=k+223860|0;jb:{if((Qd(y[i+24|0])|0)==(n|0)){if(!n){break jb}n=gc(d);At(d,x[n>>2]);x[d>>2]=x[i>>2];x[d+4>>2]=x[i+4>>2];x[d+8>>2]=x[i+8>>2];kb:{if(!x[Db(d)>>2]){x[d>>2]=n;break kb}x[x[n>>2]+8>>2]=n;n=gc(i);x[i>>2]=n;x[n>>2]=0;Ca=Db(i),Da=0,x[Ca>>2]=Da}d=d+12|0;n=gc(d);zt(d,x[n>>2]);i=i+12|0;x[d>>2]=x[i>>2];x[d+4>>2]=x[i+4>>2];x[d+8>>2]=x[i+8>>2];lb:{if(!x[Db(d)>>2]){x[d>>2]=n;break lb}x[x[n>>2]+8>>2]=n;d=gc(i);x[i>>2]=d;x[d>>2]=0;Ca=Db(i),Da=0,x[Ca>>2]=Da}break jb}if(n){Dz(d);break jb}OP(d,i)}}else{d=D(n,872);aq((d+a|0)+616|0,(d+k|0)+616|0);n=n+1|0;continue}break}Cz(a);a=0;x[b+1074400>>2]=0;v[b+1074476|0]=1;d=b+1074392|0;x[d>>2]=-2;x[d+4>>2]=0;x[b+1074428>>2]=x[b+1074424>>2];mb:{nb:{d=x[b+1298300>>2];if(!Ed(d)){break nb}x[27524]=0;Y(597,d|0);d=x[27524];x[27524]=0;if((d|0)!=1){break nb}break mb}while(1){if(z[b+480188>>1]<=a>>>0){a=JA(f+16|0);Ca=f,Da=Ni(x[e+12>>2]),x[Ca+8>>2]=Da;i=b+906300|0;g=Gf(e+12|0);while(1){d=x[f+8>>2];if(!Rg(d,g)){ob:{h=250;d=a;pb:{while(1){if(h>>>0>=32){if(x[a>>2]){a=1;break pb}else{h=h-32|0;a=a+4|0;continue}}break}a=(x[d+28>>2]&67108863)!=0}if(!a){break ob}a=0;while(1){if((a|0)==250){break ob}Ab(f,d,a);qb:{if(!zb(x[x[f>>2]>>2],x[f+4>>2])){break qb}n=x[Nd(i,a)>>2];h=x[x[n>>2]+180>>2];x[27524]=0;Y(h|0,n|0);n=x[27524];x[27524]=0;if((n|0)!=1){break qb}break mb}a=a+1|0;continue}}Ca=f,Da=Ni(x[e>>2]),x[Ca>>2]=Da;a=Gf(e);while(1){d=x[f>>2];if(Rg(d,a)){d=ud(d);n=gc(d);Ca=Nd(i,y[d|0]),Fa=B[n>>2],B[Ca+144>>2]=Fa;Ug(f);continue}else{bq(e);break b}}}n=ud(d);N=Db(n);rb:{h=y[n|0];d=x[Nd(i,h)>>2];if(d){Ab(f,a,h);if(!zb(x[x[f>>2]>>2],x[f+4>>2])){x[27524]=0;Q(598,a|0,h|0)|0;h=x[27524];x[27524]=0;if((h|0)==1){break rb}h=x[x[d>>2]+176>>2];x[27524]=0;R(h|0,d|0,-1);h=x[27524];x[27524]=0;if((h|0)==1){break rb}}Ba=B[N>>2];n=x[n+4>>2];h=x[x[d>>2]+44>>2];x[27524]=0;ya(h|0,d|0,n|0,E(Ba));d=x[27524];x[27524]=0;if((d|0)==1){break rb}}Ug(f+8|0);continue}break}break mb}d=D(a,872)+b|0;i=y[d+1075791|0];if(i){v[d+1075794|0]=i}d=We(x[s+8>>2],a);if(!((ba|0)==7|y[d+5|0]==255)){v[f+16|0]=64;Ca=(D(a,872)+b|0)+1075680|0,Da=y[Ub(d+5|0,f+16|0)|0]<<2,x[Ca>>2]=Da}sb:{i=D(a,872)+b|0;d=x[i+1075096>>2];tb:{if(!d|!(y[d+35|0]&2)){break tb}n=x[b+1298300>>2];if(!Ed(n)){break tb}x[27524]=0;_=n;n=a&65535;U(599,_|0,n|0,d+68|0);d=x[27524];x[27524]=0;if((d|0)==1){break sb}d=x[b+1298300>>2];x[27524]=0;U(600,d|0,n|0,1);d=x[27524];x[27524]=0;if((d|0)==1){break sb}}x[i+1075008>>2]=0;a=a+1|0;continue}break}}a=P()|0;bq(e);break f}a=P()|0}Ft(K)}ZP(s)}Li(Z);S(a|0);p()}if((c|0)==3){break b}x[b+1074416>>2]=x[b+480196>>2];x[b+1074420>>2]=x[b+480204>>2];x[b+1074456>>2]=x[b+480200>>2]}a=na&255;if((a|0)==y[b+484376|0]){break a}Lj(la,a)}if(c&9){a=b+1298264|0;if(x[a>>2]){TQ(a);b=x[a>>2];ak(a);Ib(b);Ca=Db(a),Da=0,x[Ca>>2]=Da;x[a>>2]=0;x[a+4>>2]=0}x[a>>2]=x[K>>2];x[a+4>>2]=x[K+4>>2];b=Db(K);Ca=Db(a),Da=x[b>>2],x[Ca>>2]=Da;x[b>>2]=0;x[K>>2]=0;x[K+4>>2]=0;a=a+12|0;c=gc(a);gq(a,x[c>>2]);b=K+12|0;x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];x[a+8>>2]=x[b+8>>2];ub:{if(!x[Db(a)>>2]){x[a>>2]=c;break ub}x[x[c>>2]+8>>2]=c;a=gc(b);x[b>>2]=a;x[a>>2]=0;Ca=Db(b),Da=0,x[Ca>>2]=Da}}Ft(K);ZP(s);ib=f+192|0}function NU(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=0,m=E(0),n=0,o=0,q=0,r=E(0),s=E(0),t=0,u=0,C=0,F=0,G=0,H=0,I=E(0),J=E(0),K=0,L=E(0),M=E(0),N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=E(0),_=E(0),$=0,ba=0,ca=E(0),da=E(0),ea=E(0),fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0;ba=ib-16|0;ib=ba;a:{if(x[a+1420>>2]>=0){x[f>>2]=0;P=x[a+1420>>2];d=(P|0)>0?P:0;while(1){if((d|0)!=(h|0)){x[(D(h,20)+a|0)+1436>>2]=0;h=h+1|0;continue}break}b:{c:{d:{if((P|0)>3){break d}h=0;if((c|0)<4){break c}c=c-3|0;d=0;while(1){if((c|0)==(d|0)){break d}e:{f:{k=b+d|0;if(y[k|0]!=79){break f}if(Qb(k,109124,4)){break f}g=d+26|0;if((g|0)>=(c|0)){break e}l=d+27|0;i=b+g|0;f=y[i|0];if((l+f|0)>=(c|0)){break e}j=f+27|0;h=0;e=0;while(1)if((e|0)==(f|0)){e=0;while(1){f=22;if((h|0)!=22){e=Dx(e,y[(d+h|0)+b|0]);h=h+1|0;continue}break}while(1){if((f|0)!=26){f=f+1|0;e=Dx(e,0);continue}break}x[a+1420>>2]=P+1;f=D(P,20)+a|0;x[f+1432>>2]=e;x[f+1428>>2]=j-26;x[f+1424>>2]=y[k+22|0]|y[k+23|0]<<8|(y[k+24|0]<<16|y[k+25|0]<<24);e=y[(g+y[i|0]|0)+b|0]==255?-1:y[k+6|0]|y[k+7|0]<<8|(y[k+8|0]<<16|y[k+9|0]<<24);x[f+1436>>2]=g;x[f+1440>>2]=e;P=x[a+1420>>2];if((P|0)!=4){break f}P=4;break d}else{j=y[(e+l|0)+b|0]+j|0;e=e+1|0;continue}}d=d+1|0;continue}break}c=d}d=0;g:while(1){i=(d|0)>(P|0)?d:P;while(1){if((d|0)==(i|0)){break b}h=0;f=D(d,20)+a|0;n=f+1428|0;k=x[n>>2];l=x[f+1436>>2];j=c-l|0;g=(j|0)>(k|0)?k:j;S=(g|0)>0?g:0;o=f+1432|0;e=x[o>>2];while(1){if((h|0)!=(S|0)){e=Dx(e,y[(h+l|0)+b|0]);h=h+1|0;continue}break}x[n>>2]=k-g;x[o>>2]=e;if((j|0)>=(k|0)){h=e;e=f+1424|0;if((h|0)==x[e>>2]){x[a+1380>>2]=-1;x[a+992>>2]=0;x[a+1420>>2]=-1;b=x[(D(d,20)+a|0)+1440>>2];x[a+1060>>2]=b;x[a+1064>>2]=(b|0)!=-1;h=g+l|0;break c}f=P-1|0;x[a+1420>>2]=f;f=D(f,20)+a|0;x[e+16>>2]=x[f+1440>>2];h=f+1432|0;k=x[h+4>>2];x[e+8>>2]=x[h>>2];x[e+12>>2]=k;f=f+1424|0;h=x[f+4>>2];x[e>>2]=x[f>>2];x[e+4>>2]=h;P=x[a+1420>>2];continue g}else{d=d+1|0;continue}}}}c=h}break a}x[a+100>>2]=0;x[a+32>>2]=b;x[a+40>>2]=b+c;if(!TI(a)){x[f>>2]=0;c=0;break a}ha=ib-16|0;ib=ha;ja=ba+4|0;x[a+1504>>2]=0;x[a+1508>>2]=0;h:{if(x[a+96>>2]){break h}i:{j:{k:{if(x[a+1380>>2]!=-1){break k}c=df(a);if(x[a+96>>2]){break i}if((c|0)!=79){break j}if((df(a)|0)!=103){break j}if((df(a)|0)!=103){break j}if((df(a)|0)!=83){break j}if(!RI(a)){break i}if(!(v[a+1375|0]&1)){break k}v[a+1376|0]=0;x[a+1384>>2]=0;fc(a,32);break i}k=Ax(a);break i}fc(a,30)}if(!k){break h}if(nc(a,1)){fc(a,35);break h}l:{m:{if(!(x[a+84>>2]!=x[a+92>>2]?x[a+80>>2]:0)){c=nc(a,mm(x[a+408>>2]-1|0));if((c|0)==-1|(c|0)>=x[a+408>>2]){break h}x[ha+12>>2]=c;j=D(c,6)+a|0;if(!y[j+412|0]){h=x[a+112>>2];k=h>>1;break m}h=x[a+116>>2];k=h>>1;c=nc(a,1);l=nc(a,1);if(c|!y[j+412|0]){break m}x[ja>>2]=h-x[a+112>>2]>>2;c=x[a+112>>2]+h>>2;break l}aa(6328,13154,3152,10672);p()}x[ja>>2]=0;c=k}x[ha+8>>2]=c;n:{if(!(!y[j+412|0]|l)){c=D(h,3);x[ba+8>>2]=c-x[a+112>>2]>>2;h=c+x[a+112>>2]>>2;break n}x[ba+8>>2]=k}x[ha+4>>2]=h;h=1}if(h){S=x[ja>>2];la=x[ba+8>>2];ka=x[ha+4>>2];N=ib-2368|0;ib=N;G=x[a+404>>2];oa=D(x[ha+12>>2],6)+a|0;C=y[oa+413|0];Q=G+D(C,40)|0;V=x[((y[oa+412|0]<<2)+a|0)+104>>2];fa=V>>1;ra=0-fa|0;o:{while(1){c=x[a+4>>2];if((c|0)>(g|0)){c=y[(x[Q+4>>2]+D(g,3)|0)+2|0];O=(N+1344|0)+(g<<2)|0;x[O>>2]=0;h=y[(c+Q|0)+9|0];if(z[((h<<1)+a|0)+132>>1]){k=x[a+260>>2];p:{q:{if(!nc(a,1)){break q}c=2;j=x[((g<<2)+a|0)+996>>2];k=k+D(h,1596)|0;F=x[(y[k+1588|0]<<2)+87948>>2];h=mm(F)-1|0;ta=j,ua=nc(a,h),w[ta>>1]=ua;ta=j,ua=nc(a,h),w[ta+2>>1]=ua;H=k+82|0;W=k+65|0;T=k+49|0;R=k+33|0;K=k+1|0;t=0;while(1){if(y[k|0]>t>>>0){o=y[t+K|0];u=y[o+T|0];i=-1<<u;n=y[o+R|0];r:{if(!u){l=0;break r}h=x[a+124>>2]+D(y[o+W|0],2096)|0;if(x[a+1396>>2]<=9){dl(a)}l=x[a+1392>>2];X=w[(h+((l&1023)<<1)|0)+36>>1];s:{if((X|0)>=0){q=l;X=X&65535;l=y[X+x[h+8>>2]|0];x[a+1392>>2]=q>>>l;l=x[a+1396>>2]-l|0;x[a+1396>>2]=(l|0)>0?l:0;l=(l|0)<0?-1:X;break s}l=lm(a,h)}if(!y[h+23|0]){break r}l=x[x[h+2088>>2]+(l<<2)>>2]}X=i^-1;h=c+n|0;while(1){if((c|0)!=(h|0)){n=0;i=w[(H+(o<<4)|0)+((l&X)<<1)>>1];t:{if((i|0)<0){break t}i=x[a+124>>2]+D(i&65535,2096)|0;if(x[a+1396>>2]<=9){dl(a)}n=x[a+1392>>2];Y=w[(i+((n&1023)<<1)|0)+36>>1];u:{if((Y|0)>=0){q=n;Y=Y&65535;n=y[Y+x[i+8>>2]|0];x[a+1392>>2]=q>>>n;n=x[a+1396>>2]-n|0;x[a+1396>>2]=(n|0)>0?n:0;n=(n|0)<0?-1:Y;break u}n=lm(a,i)}if(!y[i+23|0]){break t}n=x[x[i+2088>>2]+(n<<2)>>2]}l=l>>u;w[j+(c<<1)>>1]=n;c=c+1|0;continue}break}t=t+1|0;c=h;continue}break}if(x[a+1396>>2]==-1){break q}w[N+320>>1]=257;h=k+338|0;t=k+1088|0;c=2;while(1){n=x[k+1592>>2];if((n|0)<=(c|0)){c=0;while(1){if((c|0)>=(n|0)){break p}if(!y[(N+320|0)+c|0]){w[j+(c<<1)>>1]=65535;n=x[k+1592>>2]}c=c+1|0;continue}}else{l=c<<1;n=l+t|0;u=y[n|0];o=u<<1;i=z[o+h>>1];O=y[n+1|0];H=O<<1;W=w[j+o>>1];n=w[H+j>>1]-W|0;o=n>>31;i=(D((n^o)-o|0,z[h+l>>1]-i|0)|0)/(z[h+H>>1]-i|0)|0;n=W+((n|0)<0?0-i|0:i)|0;H=j+l|0;i=z[H>>1];v:{w:{if(i){l=N+320|0;v[l+O|0]=1;v[l+u|0]=1;v[c+l|0]=1;l=i<<16>>16;o=F-n|0;if((l|0)>=((n|0)>(o|0)?o:n)<<1){if((n|0)<(o|0)){break v}n=F+(i^-1)|0;break w}if(l&1){n=n-(l+1>>>1|0)|0;break w}n=(l>>1)+n|0;break w}v[(N+320|0)+c|0]=0}w[H>>1]=n}c=c+1|0;continue}}}x[O>>2]=1}g=g+1|0;continue}else{fc(a,21);c=0;break o}}break}if(!(x[a+84>>2]!=x[a+92>>2]?x[a+80>>2]:0)){rc(N+320|0,N+1344|0,c<<2);k=z[Q>>1];c=0;while(1){if((c|0)==(k|0)){X=G+D(C,40)|0}else{g=x[Q+4>>2]+D(c,3)|0;h=y[g+1|0];n=N+1344|0;g=n+(y[g|0]<<2)|0;if(!(x[(h<<2)+n>>2]?x[g>>2]:0)){x[(N+1344|0)+(h<<2)>>2]=0;x[g>>2]=0}c=c+1|0;continue}break}l=0;while(1){x:{if(y[X+8|0]>l>>>0){n=0;c=x[a+4>>2];g=(c|0)>0?c:0;c=0;while(1){if((c|0)==(g|0)){break x}if(y[(x[Q+4>>2]+D(c,3)|0)+2|0]==(l|0)){j=n+N|0;k=c<<2;y:{if(x[k+(N+1344|0)>>2]){k=0;h=1;break y}k=x[(a+k|0)+800>>2];h=0}v[j|0]=h;x[(N+256|0)+(n<<2)>>2]=k;n=n+1|0}c=c+1|0;continue}}if(!(x[a+84>>2]!=x[a+92>>2]?x[a+80>>2]:0)){g=(fa|0)>0?fa:0;h=z[Q>>1];k=a+800|0;z:while(1){if((h|0)<=0){O=fa<<2;n=0;c=0;while(1){l=x[a+4>>2];if((l|0)<=(c|0)){while(1){if((n|0)<(l|0)){O=y[oa+412|0];Q=V>>1;h=Q<<2;X=x[a+92>>2];F=V>>3;W=V>>2;k=x[((n<<2)+a|0)+800>>2];c=Q<<2;u=k+c|0;A:{if(x[a+80>>2]){l=Kn(a,h);break A}l=Gd(h)}h=(l+c|0)-8|0;j=x[((O<<2)+a|0)+1068>>2];i=j;c=k;while(1){if((c|0)!=(u|0)){B[h+4>>2]=E(B[c>>2]*B[i>>2])-E(B[i+4>>2]*B[c+8>>2]);B[h>>2]=E(B[c>>2]*B[i+4>>2])+E(B[c+8>>2]*B[i>>2]);c=c+16|0;i=i+8|0;h=h-8|0;continue}break}c=((Q<<2)+k|0)-12|0;while(1){if(h>>>0>=l>>>0){B[h+4>>2]=E(B[c>>2]*B[i+4>>2])-E(B[c+8>>2]*B[i>>2]);B[h>>2]=E(E(-B[c+8>>2])*B[i+4>>2])-E(B[i>>2]*B[c>>2]);c=c-16|0;i=i+8|0;h=h-8|0;continue}break}c=W<<2;t=c+k|0;h=c+l|0;i=(j+(Q<<2)|0)-32|0;c=l;g=k;while(1){if(i>>>0>=j>>>0){m=B[c>>2];r=B[h>>2];s=B[h+4>>2];I=B[c+4>>2];B[t+4>>2]=s+I;B[t>>2]=B[h>>2]+B[c>>2];s=E(s-I);m=E(r-m);B[g+4>>2]=E(s*B[i+16>>2])-E(B[i+20>>2]*m);B[g>>2]=E(m*B[i+16>>2])+E(s*B[i+20>>2]);m=B[c+8>>2];r=B[h+8>>2];s=B[h+12>>2];I=B[c+12>>2];B[t+12>>2]=s+I;B[t+8>>2]=B[h+8>>2]+B[c+8>>2];s=E(s-I);m=E(r-m);B[g+12>>2]=E(s*B[i>>2])-E(B[i+4>>2]*m);B[g+8>>2]=E(m*B[i>>2])+E(s*B[i+4>>2]);c=c+16|0;h=h+16|0;g=g+16|0;t=t+16|0;i=i-32|0;continue}break}h=mm(V);c=V>>4;o=Q-1|0;g=0-F|0;OI(c,k,o,g,j);OI(c,k,o-W|0,g,j);H=V>>5;c=0-c|0;Ap(H,k,o,c,j,16);Ap(H,k,o-F|0,c,j,16);Ap(H,k,o-(F<<1)|0,c,j,16);Ap(H,k,o+D(F,-3)|0,c,j,16);c=h-4>>1;t=(c|0)<=2?2:c;c=2;while(1){B:{C:{D:{if((c|0)==(t|0)){Y=h-7|0;break D}i=0;g=2<<c;g=(g|0)>0?g:0;F=8<<c;C=V>>c+4;G=V>>c+2;T=0-(G>>1)|0;while(1){if((g|0)==(i|0)){break C}Ap(C,k,o-D(i,G)|0,T,j,F);i=i+1|0;continue}}while(1){E:{if((t|0)<(Y|0)){ma=32<<t;F=2<<t;T=8<<t;i=V>>t+6;$=V>>t+2;ga=0-($>>1)|0;h=o;c=j;while(1){if((i|0)<=0){break E}g=F;C=(h<<2)+k|0;G=C+(ga<<2)|0;R=D(T,12)+c|0;m=B[R>>2];K=(T<<3)+c|0;r=B[K>>2];q=(T<<2)+c|0;s=B[q>>2];I=B[R+4>>2];L=B[K+4>>2];Z=B[q+4>>2];_=B[c+4>>2];ea=B[c>>2];R=0-$<<2;while(1){if((g|0)>0){K=G-4|0;M=B[K>>2];ca=B[C>>2];da=B[G>>2];B[C>>2]=ca+da;q=C-4|0;J=B[q>>2];B[q>>2]=J+B[K>>2];J=E(J-M);M=E(ca-da);B[K>>2]=E(J*ea)+E(_*M);B[G>>2]=E(M*ea)-E(_*J);K=G-12|0;ca=B[K>>2];q=C-8|0;J=B[q>>2];U=q;q=G-8|0;da=B[q>>2];B[U>>2]=J+da;U=C-12|0;M=B[U>>2];B[U>>2]=M+B[K>>2];M=E(M-ca);J=E(J-da);B[K>>2]=E(M*s)+E(Z*J);B[q>>2]=E(J*s)-E(Z*M);K=G-20|0;ca=B[K>>2];q=C-16|0;J=B[q>>2];U=q;q=G-16|0;da=B[q>>2];B[U>>2]=J+da;U=C-20|0;M=B[U>>2];B[U>>2]=M+B[K>>2];M=E(M-ca);J=E(J-da);B[K>>2]=E(M*r)+E(L*J);B[q>>2]=E(J*r)-E(L*M);K=G-28|0;ca=B[K>>2];q=C-24|0;J=B[q>>2];U=q;q=G-24|0;da=B[q>>2];B[U>>2]=J+da;U=C-28|0;M=B[U>>2];B[U>>2]=M+B[K>>2];M=E(M-ca);J=E(J-da);B[K>>2]=E(M*m)+E(I*J);B[q>>2]=E(J*m)-E(I*M);g=g-1|0;G=G+R|0;C=C+R|0;continue}break}i=i-1|0;h=h-8|0;c=(ma<<2)+c|0;continue}}c=(o<<2)+k|0;g=c-(H<<6)|0;m=B[j+(V>>3<<2)>>2];ea=E(-m);while(1){if(c>>>0>g>>>0){L=B[c>>2];h=c-32|0;Z=B[h>>2];B[c>>2]=L+Z;j=c-4|0;r=B[j>>2];q=j;j=c-36|0;_=B[j>>2];B[q>>2]=r+_;i=c-8|0;s=B[i>>2];q=i;i=c-40|0;J=B[i>>2];B[q>>2]=s+J;o=c-12|0;I=B[o>>2];q=o;o=c-44|0;M=B[o>>2];B[q>>2]=I+M;B[h>>2]=L-Z;B[j>>2]=r-_;j=c-16|0;r=B[j>>2];q=j;j=c-48|0;ca=B[j>>2];B[q>>2]=r+ca;s=E(s-J);I=E(I-M);B[i>>2]=m*E(s+I);B[o>>2]=m*E(I-s);i=c-28|0;s=B[i>>2];o=c-60|0;I=B[o>>2];F=c-24|0;L=B[F>>2];t=c-56|0;Z=B[t>>2];C=c-20|0;_=B[C>>2];q=C;C=c-52|0;J=B[C>>2];B[q>>2]=_+J;B[F>>2]=L+Z;B[i>>2]=s+I;B[j>>2]=_-J;B[C>>2]=-E(r-ca);r=E(s-I);s=E(L-Z);B[t>>2]=m*E(r-s);B[o>>2]=E(s+r)*ea;NI(c);NI(h);c=c+-64|0;continue}break}o=Q-4|0;h=l+(o<<2)|0;i=(l+(W<<2)|0)-16|0;c=x[((O<<2)+a|0)+1100>>2];while(1){if(i>>>0>=l>>>0){g=(z[c>>1]<<2)+k|0;B[h+12>>2]=B[g>>2];B[h+8>>2]=B[g+4>>2];B[i+12>>2]=B[g+8>>2];B[i+8>>2]=B[g+12>>2];g=(z[c+2>>1]<<2)+k|0;B[h+4>>2]=B[g>>2];B[h>>2]=B[g+4>>2];B[i+4>>2]=B[g+8>>2];B[i>>2]=B[g+12>>2];c=c+4|0;h=h-16|0;i=i-16|0;continue}break}c=x[((O<<2)+a|0)+1084>>2];i=l;h=i+(Q<<2)|0;j=h;while(1){g=j-16|0;if(g>>>0>i>>>0){m=B[i+4>>2];F=j-4|0;r=B[F>>2];s=E(m-r);I=B[c+4>>2];m=E(m+r);r=B[i>>2];t=j-8|0;L=B[t>>2];Z=E(r-L);_=B[c>>2];ea=E(E(I*m)-E(Z*_));B[i+4>>2]=s+ea;r=E(r+L);m=E(E(I*Z)+E(m*_));B[i>>2]=r+m;B[F>>2]=ea-s;B[t>>2]=r-m;m=B[i+8>>2];r=B[g>>2];s=E(m+r);I=B[c+12>>2];m=E(m-r);r=B[i+12>>2];j=j-12|0;L=B[j>>2];Z=E(r+L);_=B[c+8>>2];ea=E(E(I*m)+E(Z*_));B[i+8>>2]=s+ea;r=E(r-L);m=E(E(I*Z)-E(m*_));B[i+12>>2]=r+m;B[g>>2]=s-ea;B[j>>2]=m-r;i=i+16|0;c=c+16|0;j=g;continue}break}i=x[((O<<2)+a|0)+1076>>2]+(Q<<2)|0;c=(o<<2)+k|0;j=((V<<2)+k|0)-16|0;while(1){g=h-32|0;if(g>>>0>=l>>>0){m=B[h-8>>2];r=B[i-4>>2];s=B[i-8>>2];I=B[h-4>>2];L=E(E(m*r)-E(s*I));B[k>>2]=L;B[c+12>>2]=-L;m=E(E(s*E(-m))-E(r*I));B[u>>2]=m;B[j+12>>2]=m;m=B[h-16>>2];r=B[i-12>>2];s=B[i-16>>2];I=B[h-12>>2];L=E(E(m*r)-E(s*I));B[k+4>>2]=L;B[c+8>>2]=-L;m=E(E(s*E(-m))-E(r*I));B[u+4>>2]=m;B[j+8>>2]=m;m=B[h-24>>2];r=B[i-20>>2];s=B[i-24>>2];I=B[h-20>>2];L=E(E(m*r)-E(s*I));B[k+8>>2]=L;B[c+4>>2]=-L;m=E(E(s*E(-m))-E(r*I));B[u+8>>2]=m;B[j+4>>2]=m;m=B[g>>2];r=B[i-28>>2];i=i-32|0;s=B[i>>2];I=B[h-28>>2];L=E(E(m*r)-E(s*I));B[k+12>>2]=L;B[c>>2]=-L;m=E(E(s*E(-m))-E(r*I));B[u+12>>2]=m;B[j>>2]=m;j=j-16|0;c=c-16|0;u=u+16|0;k=k+16|0;h=g;continue}break}if(!x[a+80>>2]){Ib(l)}x[a+92>>2]=X;break B}t=t+1|0;continue}}c=c+1|0;continue}break}n=n+1|0;l=x[a+4>>2];continue}break}}else{h=c<<2;k=h+a|0;i=x[k+800>>2];F:{if(x[h+(N+320|0)>>2]){Rb(i,0,O);break F}G=x[k+996>>2];G:{h=y[(y[(x[Q+4>>2]+D(c,3)|0)+2|0]+Q|0)+9|0];if(!z[((h<<1)+a|0)+132>>1]){fc(a,21);break G}o=V>>1;F=x[a+260>>2]+D(h,1596)|0;H=F+338|0;W=F+838|0;k=D(y[F+1588|0],w[G>>1]);t=1;h=0;while(1){if(x[F+1592>>2]>(t|0)){g=y[t+W|0]<<1;l=w[g+G>>1];if((l|0)>=0){j=D(y[F+1588|0],l&65535);l=z[g+H>>1];if((l|0)!=(h|0)){g=j-k|0;u=l-h|0;C=(g|0)/(u|0)|0;H:{T=(l|0)<(o|0)?l:o;if((T|0)<=(h|0)){break H}q=g;g=g>>31;R=C>>31;R=((q^g)-g|0)-D(u,(R^C)-R|0)|0;K=g|1;g=i+(h<<2)|0;B[g>>2]=B[((k&255)<<2)+87968>>2]*B[g>>2];T=T-1|0;g=0;while(1){if((h|0)==(T|0)){break H}h=h+1|0;X=i+(h<<2)|0;g=g+R|0;Y=(g|0)<(u|0);k=(k+C|0)+(Y?0:K)|0;B[X>>2]=B[((k&255)<<2)+87968>>2]*B[X>>2];g=g-(Y?0:u)|0;continue}}h=l}k=j}t=t+1|0;continue}break}if((h|0)>=(o|0)){break G}k=(k<<2)+87968|0;while(1){if((h|0)==(o|0)){break G}g=i+(h<<2)|0;B[g>>2]=B[k>>2]*B[g>>2];h=h+1|0;continue}}}c=c+1|0;continue}break}QI(a);I:{if(y[a+1377|0]){x[a+1060>>2]=ra;v[a+1377|0]=0;x[a+1064>>2]=1;x[a+1412>>2]=V-ka;break I}c=x[a+1412>>2];if(!c){break I}h=la-S|0;if((h|0)<=(c|0)){x[a+1412>>2]=c-h;x[ja>>2]=la;S=la;break I}S=c+S|0;x[ja>>2]=S;x[a+1412>>2]=0}c=x[a+1064>>2];J:{K:{L:{M:{if(x[a+1388>>2]==x[a+1404>>2]){N:{if(!c|!(y[a+1375|0]&4)){break N}c=x[a+1408>>2];h=x[a+1060>>2];if(c>>>0>=h+(ka-S|0)>>>0){break N}h=c-h|0;c=(c>>>0>=h>>>0?h:0)+S|0;c=(c|0)<(ka|0)?c:ka;x[ba+12>>2]=c;x[a+1060>>2]=c+x[a+1060>>2];break K}x[a+1064>>2]=1;c=x[a+1408>>2]+(S-fa|0)|0;break M}if(!c){break L}c=x[a+1060>>2]}x[a+1060>>2]=c+(la-S|0)}if(x[a+84>>2]!=x[a+92>>2]?x[a+80>>2]:0){break J}x[ba+12>>2]=ka}c=1;break o}aa(6328,13154,3451,5637);p()}h=h-1|0;c=x[Q+4>>2]+D(h,3)|0;l=x[k+(y[c+1|0]<<2)>>2];j=x[k+(y[c|0]<<2)>>2];c=0;while(1){if((c|0)==(g|0)){continue z}i=c<<2;n=i+l|0;s=B[n>>2];i=i+j|0;m=B[i>>2];O:{if(m>E(0)){if(s>E(0)){r=E(m-s);break O}r=m;m=E(m+s);break O}if(s>E(0)){r=E(m+s);break O}r=m;m=E(m-s)}B[i>>2]=m;B[n>>2]=r;c=c+1|0;continue}}}aa(6328,13154,3335,5637);p()}W=N+256|0;i=0;t=ib-16|0;ib=t;u=x[a+4>>2];G=x[a+396>>2];C=y[(l+X|0)+24|0];F=G+D(C,24)|0;h=x[F+4>>2];Y=z[((C<<1)+a|0)+268>>1];c=fa<<((Y|0)==2);g=c>>>0>h>>>0?h:c;h=x[F>>2];O=(g-(c>>>0>h>>>0?h:c)>>>0)/A[F+8>>2]|0;k=O<<2;c=D(u,k+4|0);K=x[x[a+124>>2]+D(y[F+13|0],2096)>>2];U=x[a+92>>2];P:{if(x[a+80>>2]){h=Kn(a,c);u=x[a+4>>2];break P}h=Gd(c)}o=(n|0)>0?n:0;H=fa<<2;g=0;c=(u|0)>0?u:0;j=(u<<2)+h|0;while(1){if((c|0)!=(g|0)){x[(g<<2)+h>>2]=j;g=g+1|0;j=j+k|0;continue}break}k=h;c=0;while(1){if((c|0)!=(o|0)){if(!y[c+N|0]){Rb(x[W+(c<<2)>>2],0,H)}c=c+1|0;continue}break}Q:{if(!((n|0)==1|(Y|0)!=2)){c=0;while(1){R:{if((c|0)!=(o|0)){if(y[c+N|0]){break R}}else{c=o}if((c|0)==(n|0)){break Q}u=G+D(C,24)|0;C=(n|0)!=2;G=(n|0)<3;while(1){if((i|0)==8){break Q}S:{if(!C){h=0;j=0;while(1){if((j|0)>=(O|0)){break S}c=x[F>>2]+D(x[F+8>>2],j)|0;x[t+12>>2]=c&1;x[t+8>>2]=c>>1;c=0;if(!i){o=x[a+124>>2]+D(y[F+13|0],2096)|0;if(x[a+1396>>2]<=9){dl(a)}g=x[a+1392>>2];H=w[(o+((g&1023)<<1)|0)+36>>1];T:{if((H|0)>=0){q=g;H=H&65535;g=y[H+x[o+8>>2]|0];x[a+1392>>2]=q>>>g;g=x[a+1396>>2]-g|0;x[a+1396>>2]=(g|0)>0?g:0;g=(g|0)<0?-1:H;break T}g=lm(a,o)}g=y[o+23|0]?x[x[o+2088>>2]+(g<<2)>>2]:g;if((g|0)==-1){break Q}x[x[k>>2]+(h<<2)>>2]=x[x[u+16>>2]+(g<<2)>>2]}while(1){if(!((c|0)>=(K|0)|(j|0)>=(O|0))){g=x[F+8>>2];o=w[(x[u+20>>2]+(y[x[x[k>>2]+(h<<2)>>2]+c|0]<<4)|0)+(i<<1)>>1];U:{if((o|0)>=0){if(!PI(a,x[a+124>>2]+D(o&65535,2096)|0,W,2,t+12|0,t+8|0,fa,g)){break Q}j=j+1|0;break U}j=j+1|0;g=x[F>>2]+D(g,j)|0;x[t+8>>2]=g>>1;x[t+12>>2]=g&1}c=c+1|0;continue}break}h=h+1|0;continue}}if(G){break S}h=0;j=0;while(1){if((j|0)>=(O|0)){break S}g=x[F>>2]+D(x[F+8>>2],j)|0;c=(g|0)/(n|0)|0;x[t+12>>2]=g-D(c,n);x[t+8>>2]=c;c=0;if(!i){o=x[a+124>>2]+D(y[F+13|0],2096)|0;if(x[a+1396>>2]<=9){dl(a)}g=x[a+1392>>2];H=w[(o+((g&1023)<<1)|0)+36>>1];V:{if((H|0)>=0){q=g;H=H&65535;g=y[H+x[o+8>>2]|0];x[a+1392>>2]=q>>>g;g=x[a+1396>>2]-g|0;x[a+1396>>2]=(g|0)>0?g:0;g=(g|0)<0?-1:H;break V}g=lm(a,o)}g=y[o+23|0]?x[x[o+2088>>2]+(g<<2)>>2]:g;if((g|0)==-1){break Q}x[x[k>>2]+(h<<2)>>2]=x[x[u+16>>2]+(g<<2)>>2]}while(1){if(!((c|0)>=(K|0)|(j|0)>=(O|0))){g=x[F+8>>2];o=w[(x[u+20>>2]+(y[x[x[k>>2]+(h<<2)>>2]+c|0]<<4)|0)+(i<<1)>>1];W:{if((o|0)>=0){if(!PI(a,x[a+124>>2]+D(o&65535,2096)|0,W,n,t+12|0,t+8|0,fa,g)){break Q}j=j+1|0;break W}j=j+1|0;g=x[F>>2]+D(g,j)|0;o=(g|0)/(n|0)|0;x[t+8>>2]=o;x[t+12>>2]=g-D(n,o)}c=c+1|0;continue}break}h=h+1|0;continue}}i=i+1|0;continue}}c=c+1|0;continue}}ma=G+D(C,24)|0;n=0;while(1){if((n|0)==8){break Q}i=0;T=0;X:while(1){if((i|0)<(O|0)){h=0;c=0;Y:{if(n){break Y}while(1){if((c|0)==(o|0)){break Y}if(!y[c+N|0]){j=x[a+124>>2]+D(y[F+13|0],2096)|0;if(x[a+1396>>2]<=9){dl(a)}g=x[a+1392>>2];u=w[(j+((g&1023)<<1)|0)+36>>1];Z:{if((u|0)>=0){q=g;u=u&65535;g=y[u+x[j+8>>2]|0];x[a+1392>>2]=q>>>g;g=x[a+1396>>2]-g|0;x[a+1396>>2]=(g|0)>0?g:0;g=(g|0)<0?-1:u;break Z}g=lm(a,j)}g=y[j+23|0]?x[x[j+2088>>2]+(g<<2)>>2]:g;if((g|0)==-1){break Q}x[x[k+(c<<2)>>2]+(T<<2)>>2]=x[x[ma+16>>2]+(g<<2)>>2]}c=c+1|0;continue}}while(1){_:{$:{if((h|0)>=(K|0)){break $}c=0;if((i|0)>=(O|0)){break $}while(1){if((c|0)==(o|0)){break _}aa:{if(y[c+N|0]){break aa}g=c<<2;j=w[(x[ma+20>>2]+(y[x[x[g+k>>2]+(T<<2)>>2]+h|0]<<4)|0)+(n<<1)>>1];if((j|0)<0){break aa}G=x[a+124>>2]+D(j&65535,2096)|0;$=x[g+W>>2];R=x[F+8>>2];H=x[F>>2]+D(R,i)|0;ba:{ca:{if(Y){u=0;while(1){g=1;if((u|0)>=(R|0)){break ba}ga=$+(H<<2)|0;g=R-u|0;C=0;m=E(0);da:{q=MI(a,G);if((q|0)<0){break da}j=x[G>>2];g=(g|0)>(j|0)?j:g;q=D(j,q);if(y[G+22|0]){j=0;g=(g|0)>0?g:0;C=1;while(1){if((g|0)==(j|0)){break da}ia=ga+(j<<2)|0;m=E(m+B[x[G+28>>2]+(j+q<<2)>>2]);B[ia>>2]=B[ia>>2]+m;j=j+1|0;m=E(m+B[G+12>>2]);continue}}j=0;g=(g|0)>0?g:0;C=1;while(1){if((g|0)==(j|0)){break da}ia=ga+(j<<2)|0;B[ia>>2]=B[ia>>2]+E(B[x[G+28>>2]+(j+q<<2)>>2]+E(0));j=j+1|0;continue}}if(!C){break ca}g=x[G>>2];H=g+H|0;u=g+u|0;continue}}u=0;ga=(R|0)/x[G>>2]|0;q=(ga|0)>0?ga:0;ia=$+(H<<2)|0;g=1;while(1){if((u|0)==(q|0)){break ba}j=u+H|0;C=u<<2;u=u+1|0;sa=C+ia|0;$=R-j|0;j=0;m=E(0);ea:{na=MI(a,G);if((na|0)<0){break ea}C=0;j=x[G>>2];$=(j|0)<($|0)?j:$;$=($|0)>0?$:0;na=D(j,na);j=1;while(1){if((C|0)==($|0)){break ea}qa=sa+(D(C,ga)<<2)|0;r=E(m+B[x[G+28>>2]+(C+na<<2)>>2]);B[qa>>2]=B[qa>>2]+r;m=y[G+22|0]?r:m;C=C+1|0;continue}}if(j){continue}break}}g=0}if(!g){break Q}}c=c+1|0;continue}}T=T+1|0;continue X}i=i+1|0;h=h+1|0;continue}}break}n=n+1|0;continue}}if(!x[a+80>>2]){Ib(k)}x[a+92>>2]=U;ib=t+16|0;l=l+1|0;continue}}aa(6328,13154,3302,5637);p()}ib=N+2368|0}else{c=0}ib=ha+16|0;if(!c){fa:{ga:{ha:{c=x[a+100>>2];switch(c-32|0){case 0:break ga;case 3:break ha;default:break fa}}x[a+100>>2]=0;while(1){if((Ch(a)|0)!=-1&!x[a+96>>2]){continue}break}x[f>>2]=0;c=x[a+32>>2]-b|0;break a}if(x[a+992>>2]){break fa}x[a+100>>2]=0;while(1){if((Ch(a)|0)!=-1&!x[a+96>>2]){continue}break}x[f>>2]=0;c=x[a+32>>2]-b|0;break a}x[a+1420>>2]=0;x[a+992>>2]=0;x[a+1504>>2]=0;x[a+1508>>2]=0;x[a+1412>>2]=0;x[a+1416>>2]=0;v[a+1377|0]=0;x[a+1064>>2]=0;x[a+100>>2]=c;x[f>>2]=0;c=1;break a}g=x[ba+12>>2];j=x[ba+4>>2];k=x[ba+8>>2];ia:{ja:{l=x[a+992>>2];if(l){h=l<<1;ka:{if((h|0)==x[a+112>>2]){c=a+1092|0}else{c=0;if((h|0)!=x[a+116>>2]){break ka}c=a+1096|0}c=x[c>>2]}if(!c){break ja}n=(l|0)>0?l:0;while(1){if(x[a+4>>2]>(P|0)){i=(P<<2)+a|0;h=0;while(1){if((h|0)!=(n|0)){S=x[i+800>>2]+(h+j<<2)|0;q=S;m=B[S>>2];S=h<<2;B[q>>2]=E(m*B[S+c>>2])+E(B[S+x[i+928>>2]>>2]*B[c+(l+(h^-1)<<2)>>2]);h=h+1|0;continue}break}P=P+1|0;continue}break}P=x[a+992>>2]}x[a+992>>2]=g-k;l=(g|0)<(k|0);i=(l?k:g)-k|0;while(1){if(x[a+4>>2]>(pa|0)){c=(pa<<2)+a|0;h=0;while(1){if((h|0)!=(i|0)){B[x[c+928>>2]+(h<<2)>>2]=B[x[c+800>>2]+(h+k<<2)>>2];h=h+1|0;continue}break}pa=pa+1|0;continue}break}if(!P){break ja}c=(l?g:k)-j|0;x[a+1416>>2]=c+x[a+1416>>2];break ia}c=0}h=c;c=0;k=x[a+4>>2];g=(k|0)>0?k:0;while(1){if((c|0)!=(g|0)){l=(c<<2)+a|0;x[l+864>>2]=x[l+800>>2]+(j<<2);c=c+1|0;continue}break}if(d){x[d>>2]=k}x[f>>2]=h;x[e>>2]=a+864;c=x[a+32>>2]-b|0}ib=ba+16|0;return c}function Tja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0;d=ib-1760|0;ib=d;yc(b);f=ib-16|0;ib=f;h=d+1632|0;iU(f+8|0,h);g=x[f+12>>2];k=b;kc(f,x[b>>2],x[b+8>>2],x[f+8>>2],x[f+12>>2]);b=x[f+4>>2];if((b|0)==(g|0)){Yb(k,x[f+12>>2])}ib=f+16|0;b=(b|0)==(g|0);if(!b){hU(h)}a:{if(!b){break a}if(!jU(d+1632|0)){break a}if(!Ob(x[k>>2],x[k+8>>2],Ec(256,0))){break a}b:{if(!c){break b}zd(a,1048576);gg(a);b=ib-16|0;ib=b;e=xc(b,4233);$c(d+1376|0,e);xb(e);ib=b+16|0;b=z[d+1640>>1];x[d+160>>2]=b>>>8;x[27524]=0;x[d+16>>2]=b&255;R(437,d+88|0,d+16|0);b=x[27524];x[27524]=0;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{if((b|0)!=1){x[27524]=0;X(423,d+272|0,d+1376|0,d+160|0,d+88|0);b=x[27524];x[27524]=0;if((b|0)==1){break m}b=d+272|0;Gb(a+1298344|0,b);xb(b);e=d+88|0;xb(e);f=d+1376|0;$b(f);g=xc(b,15120);Gb(a+1298356|0,g);xb(g);Se(e,2,d+1642|0);Fc(f,e);x[27524]=0;U(11,b|0,22,f|0);b=x[27524];x[27524]=0;if((b|0)==1){break i}b=d+272|0;Gb(a+1298368|0,b);xb(b);e=d+1376|0;wb(e);x[a+1298404>>2]=22;KA(e,2,d+1674|0);Fc(b,e);Ac(a+1298308|0,b);wb(b);w[a+480188>>1]=z[d+1744>>1];f=y[d+1748|0];x[a+480204>>2]=125e4;x[a+480208>>2]=32792;H=a,I=Bd(f,1,31),x[H+480196>>2]=I;w[a+480192>>1]=z[d+1754>>1];w[a+480190>>1]=z[d+1756>>1];f=Bd(y[d+1749|0],1,32);x[a+480216>>2]=f;x[a+480228>>2]=96;x[a+480232>>2]=48;x[a+480220>>2]=f<<2;yv(k,e);f=a+484360|0;g=a+484376|0;er(Tb(x[f>>2],y[g|0]),e,z[d+1738>>1],65535,65535);_e(Tb(x[f>>2],y[g|0]),z[d+1740>>1]);q=_g(k);ae(b,k,q?274:0);B=hc(d+1352|0,b);yb(b);x[27524]=0;b=T(161,k|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break k}x[27524]=0;U(194,d+272|0,k|0,b|0);b=x[27524];x[27524]=0;if((b|0)==1){break k}b=d+272|0;t=hc(d+1328|0,b);yb(b);b=a+480188|0;o=z[b>>1];if(q){w[b>>1]=o+8}u=c&1;if(!u){break j}x[27524]=0;R(229,a+484344|0,z[d+1742>>1]);b=x[27524];x[27524]=0;if((b|0)!=1){break j}g=P()|0;break e}g=P()|0;break l}g=P()|0;xb(d+88|0)}$b(d+1376|0);break c}g=P()|0;break d}r=a+484344|0;C=a+480188|0;g=0;while(1){n:{o:{p:{q:{r:{s:{if(z[d+1742>>1]<=s>>>0){b=z[d+1746>>1];if((b-2&65535)>>>0>=4998){break q}if(!(g&1)){break s}i=0;b=Dc(((b>>>1|0)+11025e5>>>0)/(b>>>0)|0,0);break r}x[27524]=0;b=T(198,k|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break f}x[d+160>>2]=b;x[27524]=0;b=T(161,k|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break g}x[27524]=0;U(194,d+88|0,k|0,b+1&-2);b=x[27524];x[27524]=0;if((b|0)==1){break g}b=d+88|0;m=hc(d+272|0,b);yb(b);wc(d+160|0,1024);if(!u){break o}l=x[d+160>>2];if(!l){break o}x[27524]=0;b=W(230,r|0,s&65535,l|0)|0;e=x[27524];x[27524]=0;if((e|0)!=1){if(!b){break o}h=0;e=0;if(v[d+1750|0]&1){break p}t:while(1){if((h|0)==(l|0)){break o}e=0;b=Xb(x[r>>2],s);b=qf(x[b>>2],x[x[b+48>>2]+12>>2],h);while(1){if((e|0)==(o|0)){h=h+1|0;continue t}x[27524]=0;R(607,m|0,d+88|0);f=x[27524];x[27524]=0;if((f|0)!=1){g=gU(b+D(e,6)|0,d+88|0)|g;e=e+1|0;continue}break}break}break h}break h}i=2;b=Xe(2646e3/+(D(b,D(x[a+480216>>2],x[a+480196>>2]))>>>0)*1e4)}v[a+480224|0]=i;x[a+480204>>2]=b}h=a+480188|0;b=z[h>>1];x[27524]=0;v[d+272|0]=0;s=W(608,d+1312|0,b|0,d+272|0)|0;b=x[27524];x[27524]=0;if((b|0)!=1){i=a+1298320|0;l=a+1298332|0;n=a+484348|0;m=0;u:{v:{w:{x:{y:{z:{while(1){b=x[t+8>>2];e=x[t>>2];x[27524]=0;b=W(160,e|0,b|0,8)|0;e=x[27524];x[27524]=0;A:{if((e|0)!=1){if(b){break A}f=a+906300|0;g=x[s>>2];h=0;i=a+480188|0;while(1){e=z[i>>1];if(e>>>0<=h>>>0){x[d+264>>2]=0;x[d+268>>2]=0;x[d+256>>2]=0;x[d+260>>2]=0;x[d+248>>2]=0;x[d+252>>2]=0;x[d+240>>2]=0;x[d+244>>2]=0;B:{C:{if(!q){break C}e=0;x[27524]=0;R(609,B|0,d+272|0);b=x[27524];x[27524]=0;if((b|0)==1){break B}while(1){if((e|0)==8){e=0;x[27524]=0;h=Q(222,d+224|0,z[d+272>>1])|0;b=x[27524];x[27524]=0;if((b|0)!=1){D:{E:{F:{G:{while(1){if(z[d+272>>1]<=e>>>0){x[27524]=0;l=W(610,d+208|0,z[d+1742>>1],26940)|0;b=x[27524];x[27524]=0;if((b|0)==1){break E}j=a+484376|0;u=a+484348|0;C=a+480188|0;f=0;break F}x[27524]=0;b=T(198,k|0)|0;f=x[27524];x[27524]=0;if((f|0)!=1){x[27524]=0;U(194,d+160|0,k|0,b<<5);b=x[27524];x[27524]=0;if((b|0)==1){break G}f=d+160|0;b=hc(d+88|0,f);fd(Yg(x[h>>2],e),b);yb(b);e=e+1|0;yb(f);continue}break}g=P()|0;break D}g=P()|0;break D}while(1){if(z[d+1738>>1]<=f>>>0){jd(l);Sc(h);break C}H:{g=d+f|0;e=y[g+290|0];if(e>>>0>=z[d+272>>1]){break H}b=z[bc(x[Tb(x[a+484360>>2],y[j|0])>>2],f)>>1];if(b>>>0>=z[d+1742>>1]){break H}I:{i=bc(x[l>>2],b);n=z[i>>1];J:{if((n|0)==65535){w[i>>1]=e;break J}if((e|0)==(n|0)){break J}x[27524]=0;e=Q(611,r|0,b|0)|0;i=x[27524];x[27524]=0;if((i|0)==1){break I}if((e|0)==65535){break J}H=bc(x[Tb(x[a+484360>>2],y[j|0])>>2],f),I=e,w[H>>1]=I;b=e}if(!Ce(x[a+484344>>2],x[u>>2],b)){break H}q=Yg(x[h>>2],y[g+290|0]);yc(q);e=x[q>>2];x[27524]=0;e=T(164,e|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break I}E=e>>>5|0;i=0;K:while(1){e=Xb(x[r>>2],b);if(A[e+12>>2]<=i>>>0){break H}g=0;e=hd(x[e>>2],x[x[e+48>>2]+12>>2],i,z[C>>1]-8&65535);while(1){if((g|0)==8){i=i+1|0;continue K}Jj(d+88|0);n=z[d+92>>1];v[e+4|0]=n;v[e+5|0]=n>>>8;n=x[d+88>>2];v[e|0]=n;v[e+1|0]=n>>>8;v[e+2|0]=n>>>16;v[e+3|0]=n>>>24;L:{if(i>>>0>=E>>>0){break L}x[27524]=0;Q(612,q|0,d+88|0)|0;n=x[27524];x[27524]=0;if((n|0)==1){break I}if(v[d+88|0]>=0){break L}v[e|0]=61;v[e+1|0]=y[(d+256|0)+(g<<1)|0];n=y[d+88|0]&31;v[d+160|0]=n;if(n){Ff(d+160|0,15);v[e+3|0]=20;v[e+5|0]=y[d+160|0]|208}v[e+2|0]=1;v[e+4|0]=y[d+89|0]+3>>>2}e=e+6|0;g=g+1|0;continue}}}g=P()|0;jd(l);break D}f=f+1|0;continue}}g=P()|0}Sc(h);break u}g=P()|0;break u}f=e<<1;g=f+(d+256|0)|0;b=z[a+480192>>1]+1&65535;h=z[x[a+8>>2]+58>>1];while(1){M:{N:{i=b&65535;if(i>>>0<=h>>>0){if(x[((i<<2)+a|0)+900380>>2]){break N}}else{b=65535}b=b&65535;break M}b=b+1|0;continue}break}w[g>>1]=b;h=f+(d+240|0)|0;f=z[(d+f|0)+274>>1];w[h>>1]=f;O:{if((b|0)!=65535){x[27524]=0;b=W(255,a|0,b|0,f+1&65535)|0;f=x[27524];x[27524]=0;P:{Q:{if((f|0)!=1){if(!b){break O}x[27524]=0;R(290,d+160|0,4478);f=x[27524];x[27524]=0;if((f|0)==1){break Q}x[27524]=0;x[d+16>>2]=e+1;U(613,d+88|0,d+160|0,d+16|0);f=x[27524];x[27524]=0;if((f|0)==1){break P}f=b+492|0;b=d+88|0;Cc(f,b);wb(b);Zb(d+160|0);break O}g=P()|0;break u}g=P()|0;break u}g=P()|0;Zb(d+160|0);break u}w[g>>1]=0}e=e+1|0;continue}}R:{S:{b=z[d+1750>>1]|z[d+1752>>1]<<16;if(!(b&2)){break S}b=(((b&8?z[a+480188>>1]:o)&65535)+(z[d+1640>>1]>591?m:0)|0)+(b>>>4&1)|0;f=0;T:while(1){e=0;if(z[d+1742>>1]<=f>>>0){break S}while(1){U:{if((b|0)!=(e|0)){g=x[k+8>>2];h=x[k>>2];x[27524]=0;g=W(160,h|0,g|0,4)|0;h=x[27524];x[27524]=0;if((h|0)==1){break R}if(g){break U}}f=f+1|0;continue T}x[27524]=0;R(614,z[d+1640>>1],k|0);g=x[27524];x[27524]=0;if((g|0)==1){break R}e=e+1|0;continue}}}x[27524]=0;r=Q(222,d+192|0,255)|0;b=x[27524];x[27524]=0;if((b|0)!=1){n=a+480208|0;f=0;while(1){V:{b=f;W:{if((b|0)==255){m=JA(d+88|0);l=JA(d+160|0);g=0;while(1){X:{Y:{Z:{if((g|0)==256){h=0;break Z}x[27524]=0;R(615,k|0,d+272|0);b=x[27524];x[27524]=0;if((b|0)==1){break Y}x[27524]=0;b=T(161,k|0)|0;e=x[27524];x[27524]=0;_:{$:{aa:{if((e|0)!=1){x[27524]=0;U(194,d+16|0,k|0,b|0);e=x[27524];x[27524]=0;if((e|0)==1){break aa}e=d+16|0;h=hc(d- -64|0,e);yb(e);if(z[d+1756>>1]>g>>>0){e=d+48|0;Se(e,2,d+272|0);x[27524]=0;R(226,d+16|0,e|0);e=x[27524];x[27524]=0;if((e|0)==1){break _}e=d+16|0;Cc(((g<<5)+a|0)+946336|0,e);wb(e)}if(!b){break X}if(z[d+1756>>1]>g>>>0){break $}break X}g=P()|0;break W}g=P()|0;break W}x[27524]=0;b=D(g+1|0,104)+a|0;e=b+484380|0;R(281,e|0,32);f=x[27524];x[27524]=0;ba:{ca:{da:{if((f|0)!=1){Ro(e);x[27524]=0;R(616,h|0,d+16|0);f=x[27524];x[27524]=0;if((f|0)==1){break _}f=x[d+16>>2];x[e>>2]=f;x[b+484404>>2]=x[d+20>>2];if(y[d+24|0]>=2){i=b+484414|0;w[i>>1]=z[i>>1]|1;f=f>>>1|0;x[e>>2]=f}if(y[d+25|0]>=2){i=b+484414|0;w[i>>1]=z[i>>1]|64;x[e>>2]=f>>>1}i=2;switch(y[d+27|0]-1|0){case 0:break ca;case 1:break da;default:break ba}}break _}i=6}e=b+484414|0;w[e>>1]=z[e>>1]|i}x[b+484384>>2]=x[d+28>>2];x[b+484388>>2]=x[d+32>>2];w[b+484410>>1]=z[d+36>>1]>>>7;e=y[d+38|0];ea:{if((e|0)==128){e=b+484414|0;f=z[e>>1]|256;w[e>>1]=f;break ea}w[b+484408>>1]=(e<<24>>24)+128;f=z[b+484414>>1]}i=b+484414|0;w[i>>1]=f|32;v[b+484416|0]=y[d+39|0];e=y[d+26|0];if(e&2){b=d+48|0;Ab(b,l,g);uo(b);e=y[d+26|0]}if(e&5){w[i>>1]=z[i>>1]|16384}if(!(e&8)){break X}b=d+48|0;Ab(b,m,g);uo(b);e=0;while(1){if((e|0)==8){break X}b=e<<1;fa:{if(z[b+(d+240|0)>>1]!=(g|0)){break fa}b=x[((z[b+(d+256|0)>>1]<<2)+a|0)+900380>>2];if(!b){break fa}v[b+14|0]=0}e=e+1|0;continue}}g=P()|0;yb(h);break W}while(1){ga:{ha:{if(z[d+1754>>1]<=h>>>0){if(!(c&2)){break ha}e=a+1298404|0;f=a+1298472|0;g=0;ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{while(1){if(z[a+480190>>1]<=g>>>0){break ha}g=g+1|0;c=D(g,104)+a|0;h=c+484380|0;b=c+484416|0;Cl(h,(+(v[b|0]-49|0)+ +v[c+484417|0]*-.0078125)/-12);w[b>>1]=0;b=z[c+484414>>1];if(!(b&16384)){b=Zc(d+272|0,b&1?16:8,b&64?3:1,0,11);x[27524]=0;W(223,b|0,h|0,k|0)|0;b=x[27524];x[27524]=0;if((b|0)!=1){continue}g=P()|0;break W}x[27524]=0;h=T(161,k|0)|0;b=x[27524];x[27524]=0;qa:{if((b|0)==1){break qa}x[27524]=0;Q(192,k|0,12)|0;b=x[27524];x[27524]=0;if((b|0)==1){break qa}b=Kb(d+272|0);x[27524]=0;U(272,k|0,b|0,h|0);h=x[27524];x[27524]=0;if((h|0)==1){break pa}Fe(c+484423|0,b);x[27524]=0;R(378,d- -64|0,16394);c=x[27524];x[27524]=0;if((c|0)==1){break oa}x[d+12>>2]=g;c=x[e>>2];x[27524]=0;U(11,d+48|0,c|0,b|0);c=x[27524];x[27524]=0;if((c|0)==1){break na}x[27524]=0;X(423,d+16|0,d- -64|0,d+12|0,d+48|0);c=x[27524];x[27524]=0;if((c|0)==1){break ma}c=x[f>>2];x[27524]=0;U(380,c|0,2,d+16|0);c=x[27524];x[27524]=0;if((c|0)==1){break la}xb(d+16|0);xb(d+48|0);$b(d- -64|0);wb(b);continue}break}g=P()|0;break W}g=P()|0;break ia}g=P()|0;break ia}g=P()|0;break ja}g=P()|0;break ka}g=P()|0;xb(d+16|0)}xb(d+48|0)}$b(d- -64|0)}wb(b);break W}b=x[Yg(x[r>>2],h)>>2];x[27524]=0;b=T(164,b|0)|0;e=x[27524];x[27524]=0;ra:{sa:{if((e|0)!=1){if(!b){h=h+1|0;continue}b=Yg(x[r>>2],h);yc(b);x[27524]=0;R(617,b|0,d+272|0);b=x[27524];x[27524]=0;if((b|0)==1){break sa}i=Nb(d+16|0);x[27524]=0;U(618,k|0,i|0,z[d+272>>1]);b=x[27524];x[27524]=0;if((b|0)==1){break ra}h=h+1|0;b=x[((h<<2)+a|0)+900380>>2];if(!b|y[b+34|0]){break ga}x[b+4>>2]=32;e=0;xu(b,0);n=b+108|0;j=b+236|0;while(1){if((e|0)==96){break ga}f=y[(d+e|0)+274|0];ta:{if(f>>>0>=z[d+272>>1]){break ta}g=We(x[i>>2],f);q=e+12|0;u=bc(j,q);f=y[g|0];o=f+1|0;w[u>>1]=o;if(f>>>0>=z[a+480190>>1]){break ta}f=D(o,104)+a|0;v[f+484418|0]=y[d+370|0]&3;v[f+484419|0]=y[d+371|0];v[f+484420|0]=y[d+372|0];v[f+484421|0]=y[d+373|0];w[f+484412>>1]=y[g+1|0]<<1;v[f+484417|0]=y[g+2|0];f=o-1|0;Ab(d- -64|0,m,f);if(zb(x[x[d+64>>2]>>2],x[d+68>>2])){v[b+14|0]=0}Ab(d- -64|0,l,f);if(!zb(x[x[d+64>>2]>>2],x[d+68>>2])){break ta}H=Jb(n,q),I=61,v[H|0]=I}e=e+1|0;continue}}g=P()|0;break W}g=P()|0;break W}g=P()|0;we(i);break W}Sc(r);ec(s);yb(t);yb(B);break b}we(i);continue}}g=P()|0;break W}yb(h);g=g+1|0;continue}}x[27524]=0;R(615,k|0,d+160|0);e=x[27524];x[27524]=0;ua:{va:{wa:{xa:{if((e|0)!=1){x[27524]=0;e=T(161,k|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break xa}x[27524]=0;e=(e|0)==32?428:e;h=e?z[d+1640>>1]>513?e+4|0:e:e;U(194,d+88|0,k|0,h|0);e=x[27524];x[27524]=0;if((e|0)==1){break wa}g=d+88|0;e=hc(d+272|0,g);i=te(d+16|0,fd(Yg(x[r>>2],b),e));yb(e);f=b+1|0;yb(g);if(b>>>0>=z[d+1754>>1]){break V}x[27524]=0;b=f&65535;g=W(255,a|0,b|0,b|0)|0;b=x[27524];x[27524]=0;if((b|0)!=1){break va}break ua}g=P()|0;break W}g=P()|0;break W}g=P()|0;break W}if(!g){break V}b=d+88|0;Se(b,2,d+160|0);x[27524]=0;R(226,d+272|0,b|0);b=x[27524];x[27524]=0;ya:{if((b|0)!=1){b=d+272|0;Cc(g+492|0,b);wb(b);if(!h){break V}x[27524]=0;R(617,i|0,d+272|0);b=x[27524];x[27524]=0;if((b|0)!=1){m=3;h=0;if(z[d+1640>>1]<513){l=0;break ya}x[27524]=0;l=T(198,i|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break ua}if(z[d+1640>>1]<514){break ya}x[27524]=0;m=T(161,i|0)|0;b=x[27524];x[27524]=0;if((b|0)!=1){break ya}break ua}break ua}break ua}x[g>>2]=z[d+374>>1];v[g+16|0]=y[(z[d+376>>1]&3)+26942|0];v[g+17|0]=y[(y[d+377|0]&3)+26942|0];v[g+18|0]=y[(z[d+376>>1]>>>12&3)+26946|0];while(1){za:{Aa:{if((h|0)==4){if(!(v[g+60|0]&1|y[g+16|0]==3)){x[g>>2]=32767}Tj(g,127,1);Sj(g,0,1);if(!l){break V}x[27524]=0;R(619,i|0,d+88|0);b=x[27524];x[27524]=0;if((b|0)==1){break ua}if(l&2){Tj(g,KB(x[n>>2],+z[d+90>>1]),1);Sj(g,y[d+92|0],1)}v[g+25|0]=y[d+89|0]==1;if(!(l&4)){break V}v[g+31|0]=y[d+95|0]+1;b=v[d+96|0];v[g+34|0]=b+1;if((b|0)<0){v[g+30|0]=y[d+103|0]+1}if(!y[d+100|0]){break Aa}h=g+108|0;e=0;while(1){if((e|0)==128){break Aa}b=e+1|0;x[d+64>>2]=b+v[d+100|0];dU(d- -64|0);H=Jb(h,e),I=x[d+64>>2],v[H|0]=I;e=b;continue}}if(!(m&1)){break za}x[27524]=0;R(620,i|0,d+88|0);b=x[27524];x[27524]=0;Ba:{if((b|0)!=1){b=Mh(g,y[h+26950|0]);Ca:{if((h|0)!=3){e=y[d+88|0];o=y[b+12|0]&-17;break Ca}e=y[d+88|0];o=e<<4&16|y[b+12|0]&-17}v[b+12|0]=e>>>1&2|(e<<1&4|(o&248|e&1));v[d+64|0]=y[d+89|0];v[d+48|0]=16;e=y[Ub(d- -64|0,d+48|0)|0];x[27524]=0;R(295,b|0,e|0);e=x[27524];x[27524]=0;if((e|0)==1){break Ba}e=y[d+90|0];v[b+15|0]=e;v[b+16|0]=e;v[b+13|0]=y[d+91|0];v[b+14|0]=y[d+92|0];e=0;o=x[b>>2];j=$d(o,x[b+4>>2]);while(1){if((e|0)==(j|0)){break za}q=Bb(o,e);b=(d+88|0)+(e<<2)|0;w[q>>1]=y[b+8|0]|y[b+9|0]<<8;H=q,I=Bd(y[b+10|0]|y[b+11|0]<<8,0,64),v[H+2|0]=I;e=e+1|0;continue}}break ua}break ua}xu(g,0);break V}h=h+1|0;m=m>>>1|0;continue}}g=P()|0;yb(i)}Sc(r);break u}yb(i);continue}}g=P()|0;break u}g=P()|0;break u}g=P()|0;break u}else{b=v[Jb(g,h)|0];Da:{if((b|0)<=(h|0)|(b|0)>=(e|0)){break Da}b=y[((b<<5)+a|0)+480288|0];if(!b){break Da}e=((h<<5)+a|0)+480288|0;l=y[e|0];if(!l){v[e|0]=b;break Da}e=l-1|0;while(1){l=Nd(f,e&255);e=$m(x[l+28>>2]);if((e|0)!=255){continue}break}b=b-1&255;x[l+28>>2]=b>>>0<250?b+128|0:0}h=h+1|0;continue}}}g=P()|0;break u}x[27524]=0;f=T(161,t|0)|0;b=x[27524];x[27524]=0;Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{La:{Ma:{if((b|0)!=1){x[27524]=0;b=T(161,t|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break Ma}x[27524]=0;U(194,d+272|0,t|0,b|0);b=x[27524];x[27524]=0;if((b|0)==1){break Ma}e=d+272|0;b=hc(d+88|0,e);yb(e);if((f|0)==4674381){break Ia}if((f|0)==5068115){break Ha}if((f|0)==726487106){break La}if((f|0)==844387158){break Ga}e=0;if((f|0)==1280004692){break Ka}if((f|0)==1314144592){break Ja}if((f|0)!=1397445204){break Fa}x[27524]=0;e=T(198,b|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break w}e=e>>>0<256?48:e>>>8|0;x[a+480228>>2]=e;x[a+480232>>2]=e>>>1;e=0;while(1){if(z[h>>1]<=e>>>0){break Fa}x[27524]=0;f=Q(621,b|0,d+272|0)|0;j=x[27524];x[27524]=0;if((j|0)==1){break z}if(f){w[((e<<5)+a|0)+480286>>1]=z[d+272>>1]>>>10;H=Jb(x[s>>2],e),I=y[d+275|0],v[H|0]=I}e=e+1|0;continue}}g=P()|0;break u}g=P()|0;break u}if(g&1){break Fa}v[a+480224|0]=2;x[27524]=0;F=+la(622,b|0);e=x[27524];x[27524]=0;if((e|0)==1){break Ea}if(!(F>1e-8)){break Fa}H=a,I=Xe(2646e3/(F*+(D(x[a+480216>>2],x[a+480196>>2])>>>0))*1e4),x[H+480204>>2]=I;break Fa}while(1){Na:{if(z[h>>1]<=e>>>0){break Fa}f=x[b>>2];x[27524]=0;f=W(160,f|0,x[d+96>>2],1)|0;j=x[27524];x[27524]=0;if((j|0)==1){break y}if(!f){break Fa}f=Kb(d+272|0);x[27524]=0;U(354,b|0,f|0,-1);j=x[27524];x[27524]=0;if((j|0)!=1){j=d+16|0;ig(j,3,Jc(f),Eb(f));x[27524]=0;R(226,d+160|0,j|0);j=x[27524];x[27524]=0;if((j|0)==1){break Na}j=d+160|0;Il(((e<<5)+a|0)+480289|0,j);wb(j);wb(f);e=e+1|0;continue}}break}g=P()|0;wb(f);break v}while(1){if(z[d+1742>>1]<=e>>>0){break Fa}f=x[b>>2];x[27524]=0;f=W(160,f|0,x[d+96>>2],1)|0;j=x[27524];x[27524]=0;if((j|0)==1){break x}if(!f){break Fa}if(!Sm(x[a+484344>>2],x[n>>2],e&65535)){break Fa}f=Kb(d+272|0);x[27524]=0;U(354,b|0,f|0,-1);j=x[27524];x[27524]=0;Oa:{if((j|0)==1){break Oa}j=x[r>>2];x[27524]=0;R(285,Xb(j,e)|0,f|0);j=x[27524];x[27524]=0;if((j|0)==1){break Oa}wb(f);e=e+1|0;continue}break}g=P()|0;wb(f);break v}x[27524]=0;Q(192,b|0,1)|0;e=x[27524];x[27524]=0;if((e|0)==1){break w}x[27524]=0;e=T(206,b|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break w}x[27524]=0;X(335,l|0,b|0,e|0,2);e=x[27524];x[27524]=0;if((e|0)!=1){break Fa}break w}x[27524]=0;Q(623,b|0,d+16|0)|0;e=x[27524];x[27524]=0;Pa:{if((e|0)!=1){e=Kb(d+272|0);x[27524]=0;U(354,b|0,e|0,-1);f=x[27524];x[27524]=0;if((f|0)==1){break Pa}if(Jq(e,12578)){x[27524]=0;U(11,d+160|0,22,e|0);f=x[27524];x[27524]=0;if((f|0)==1){break Pa}f=d+160|0;Gb(i,f);xb(f)}wb(e);break Fa}g=P()|0;break v}g=P()|0;wb(e);break v}x[27524]=0;m=T(161,b|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break w}}yb(b);continue}break}g=P()|0;break v}g=P()|0;break v}g=P()|0;break v}g=P()|0;break v}g=P()|0}yb(b)}ec(s);break e}g=P()|0;break e}while(1){b=x[m>>2];x[27524]=0;b=W(160,b|0,x[d+280>>2],1)|0;f=x[27524];x[27524]=0;Qa:{if((f|0)!=1){if(!b){break o}x[27524]=0;i=T(210,m|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break h}n=0;if((i|0)!=255){break Qa}x[27524]=0;n=T(210,m|0)|0;b=x[27524];x[27524]=0;if((b|0)!=1){x[27524]=0;i=T(210,m|0)|0;b=x[27524];x[27524]=0;if((b|0)!=1){break Qa}}break h}break h}if(i&127){b=Xb(x[r>>2],s);f=hd(x[b>>2],x[x[b+48>>2]+12>>2],e,h&65535);jv(d+88|0);if(i&1){x[27524]=0;b=T(210,m|0)|0;j=x[27524];x[27524]=0;if((j|0)==1){break n}v[d+88|0]=b}if(i&2){x[27524]=0;b=T(210,m|0)|0;j=x[27524];x[27524]=0;if((j|0)==1){break n}v[d+89|0]=b}if(i&4){x[27524]=0;b=T(210,m|0)|0;j=x[27524];x[27524]=0;if((j|0)==1){break n}v[d+90|0]=b}if(i&8){x[27524]=0;b=T(210,m|0)|0;j=x[27524];x[27524]=0;if((j|0)==1){break n}v[d+91|0]=b}if(i&16){x[27524]=0;b=T(210,m|0)|0;j=x[27524];x[27524]=0;if((j|0)==1){break n}v[d+92|0]=b}if(i&32){x[27524]=0;b=T(210,m|0)|0;j=x[27524];x[27524]=0;if((j|0)==1){break n}v[d+93|0]=b}if(i&64){x[27524]=0;b=T(210,m|0)|0;i=x[27524];x[27524]=0;if((i|0)==1){break n}v[d+94|0]=b}E=gU(f,d+88|0);x[d+16>>2]=n;x[d+64>>2]=l+(e^-1);G=x[Hb(d+16|0,d- -64|0)>>2];i=0;b=f;while(1){if((i|0)!=(G|0)){b=D(z[C>>1],6)+b|0;j=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);v[b|0]=j;v[b+1|0]=j>>>8;v[b+2|0]=j>>>16;v[b+3|0]=j>>>24;j=y[f+4|0]|y[f+5|0]<<8;v[b+4|0]=j;v[b+5|0]=j>>>8;i=i+1|0;continue}break}g=g|E}e=(e+n|0)+1|0;while(1){if(e>>>0>=l>>>0){h=h+1|0;e=e-l|0;continue}break}if(o>>>0>(h&65535)>>>0){continue}break}}yb(m);s=s+1|0;continue}break}break h}g=P()|0;wb(d+1376|0);break c}g=P()|0;yb(m);break e}g=P()|0;break e}g=P()|0}yb(t)}yb(B)}S(g|0);p()}e=1}ib=d+1760|0;return e|0}function Mma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0;d=ib-1184|0;ib=d;yc(b);e=ib-16|0;ib=e;g=d+944|0;rW(e+8|0,g);m=x[e+12>>2];kc(e,x[b>>2],x[b+8>>2],x[e+8>>2],x[e+12>>2]);j=x[e+4>>2];if((j|0)==(m|0)){Yb(b,x[e+12>>2])}ib=e+16|0;e=(j|0)==(m|0);if(!e){qW(g)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{if(!e){break o}if(!tW(d+944|0)){break o}if(!Ob(x[b>>2],x[b+8>>2],Ec(sW(x[d+948>>2]),kb))){break o}if(!c){f=1;break o}zd(a,16777216);gg(a);e=a+480208|0;x[e>>2]=x[e>>2]|16809984;f=d+480|0;Hq(f,32);m=x[d+492>>2];e=a+1074320|0;x[e>>2]=x[d+488>>2];x[e+4>>2]=m;e=x[d+484>>2];x[a+1074312>>2]=x[d+480>>2];x[a+1074316>>2]=e;Lb(Lb(a+1074312|0,57,y[d+947|0]>5),114,1);e=Bo(d+904|0);I=e,J=Bd(y[d+1144|0],1,31),x[I+8>>2]=J;I=e,J=Bd(y[d+1145|0],1,12),x[I+4>>2]=J;I=e,J=Fb(z[d+1146>>1]),x[I>>2]=J;kC(a+1298412|0,e);w[a+480188>>1]=32;e=d+376|0;pW(e,3,d+1148|0);m=d+56|0;Fc(m,e);x[27524]=0;U(11,f|0,1,m|0);e=x[27524];x[27524]=0;p:{q:{if((e|0)!=1){e=d+480|0;Gb(a+1298368|0,e);xb(e);wb(d+56|0);r:{if(y[d+947|0]<=5){_f(d+56|0,3927);break r}e=ib-16|0;ib=e;f=xc(e,3996);$c(d+56|0,f);xb(f);ib=e+16|0}x[27524]=0;U(366,d+480|0,d+56|0,y[d+947|0]);e=x[27524];x[27524]=0;if((e|0)==1){break q}e=d+480|0;Gb(a+1298344|0,e);xb(e);f=d+56|0;$b(f);m=xc(e,15124);Gb(a+1298356|0,m);xb(m);x[a+1298404>>2]=26;Se(f,3,d+952|0);Fc(e,f);Ac(a+1298308|0,e);wb(e);x[a+480228>>2]=256;x[a+480200>>2]=384/(z[a+480188>>1]+3>>>0);if(y[d+947|0]>5){break p}I=d,J=Fb(z[d+1172>>1]),w[I+480>>1]=J;w[d+56>>1]=1;e=d+480|0;f=d+56|0;I=a,J=z[pe(e,f)>>1],x[I+480196>>2]=J;I=d,J=Fb(z[d+1174>>1]),w[I+480>>1]=J;w[d+56>>1]=1;I=a,J=D(z[pe(e,f)>>1],1e4),x[I+480204>>2]=J;I=d,J=Ec(((Fb(z[d+1176>>1])<<8)+2047>>>0)/4095|0,0),x[I+480>>2]=J;x[d+56>>2]=256;I=a,J=x[Hb(e,f)>>2],x[I+480200>>2]=J;I=d,J=Fb(z[d+1178>>1]),w[I+480>>1]=J;Mf(e,127);f=0;e=z[d+480>>1];while(1){if((e|0)==(f|0)){break p}I=d,J=Ec(((Mj(b)<<8)+2047>>>0)/4095|0,0),w[I+56>>1]=J;w[d+376>>1]=256;I=((f<<5)+a|0)+480284|0,J=z[Tc(d+56|0,d+376|0)>>1],w[I>>1]=J;f=f+1|0;continue}}a=P()|0;wb(d+56|0);break a}a=P()|0;$b(d+56|0);break a}bd(b,ac(x[d+948>>2]));m=te(d+880|0,b);x[27524]=0;R(370,d+864|0,m|0);b=x[27524];x[27524]=0;s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{if((b|0)!=1){x[27524]=0;U(371,d+480|0,d+864|0,1346458707);b=x[27524];x[27524]=0;if((b|0)==1){break I}x[27524]=0;b=W(160,x[d+480>>2],x[d+488>>2],2)|0;e=x[27524];x[27524]=0;if((e|0)==1){break L}if(!b){break J}x[27524]=0;b=T(275,d+480|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break L}if((b-1&65535)>>>0>126){break J}w[a+480188>>1]=b;b=d+480|0;yb(b);x[27524]=0;U(371,b|0,d+864|0,1397706311);b=x[27524];x[27524]=0;if((b|0)!=1){break M}a=P()|0;break c}a=P()|0;break b}x[27524]=0;b=W(160,x[d+480>>2],x[d+488>>2],2)|0;e=x[27524];x[27524]=0;if((e|0)==1){break G}if(!b){break J}x[27524]=0;b=T(275,d+480|0)|0;e=x[27524];x[27524]=0;N:{if((e|0)==1){break N}w[d+56>>1]=b;b=y[a+484376|0];e=x[a+484360>>2];x[27524]=0;f=T(275,d+480|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break N}_e(Tb(e,b),f);x[27524]=0;b=T(206,d+480|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break N}Mf(d+56|0,Fl(b>>>1|0));b=y[a+484376|0];e=x[a+484360>>2];x[27524]=0;U(278,Tb(e,b)|0,d+480|0,z[d+56>>1]);b=x[27524];x[27524]=0;if((b|0)!=1){break K}}break G}a=P()|0;yb(d+480|0);break c}b=d+480|0;yb(b);x[27524]=0;U(371,b|0,d+864|0,1480806221);b=x[27524];x[27524]=0;if((b|0)==1){break H}x[27524]=0;b=W(160,x[d+480>>2],x[d+488>>2],3)|0;e=x[27524];x[27524]=0;if((e|0)!=1){if(b){break F}b=160;while(1){O:{f=b;if(!b){f=0;break O}b=f-1|0;if(y[(d+b|0)+984|0]==32){continue}}break}x[27524]=0;X(341,a+1298332|0,d+984|0,f|0,4);b=x[27524];x[27524]=0;if((b|0)!=1){break E}break D}break D}yb(d+480|0);f=0;break s}a=P()|0;break c}a=P()|0;break c}a=P()|0;yb(d+480|0);break c}x[27524]=0;b=T(275,d+480|0)|0;e=x[27524];x[27524]=0;if((e|0)!=1){x[27524]=0;X(335,a+1298332|0,d+480|0,b|0,4);b=x[27524];x[27524]=0;if((b|0)!=1){break E}}break D}b=d+480|0;yb(b);x[27524]=0;U(371,b|0,d+864|0,1413697073);b=x[27524];x[27524]=0;if((b|0)==1){break C}x[27524]=0;b=T(210,d+480|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break A}if(b){break B}x[27524]=0;b=Q(159,d+480|0,2648)|0;e=x[27524];x[27524]=0;if((e|0)==1){break A}if(!b){break B}f=0;x[27524]=0;b=T(283,d+480|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break A}while(1){if((f|0)==32){break B}e=((f<<5)+a|0)+480280|0;x[e>>2]=x[e>>2]&-1025|!(b>>>f&1)<<10;f=f+1|0;continue}}a=P()|0;yb(d+480|0);break c}a=P()|0;break c}b=d+480|0;yb(b);x[27524]=0;U(371,b|0,d+864|0,1413697074);b=x[27524];x[27524]=0;if((b|0)==1){break z}x[27524]=0;b=W(160,x[d+480>>2],x[d+488>>2],12)|0;e=x[27524];x[27524]=0;if((e|0)==1){break y}P:{if(!b){break P}x[27524]=0;R(372,d+56|0,d+480|0);b=x[27524];x[27524]=0;if((b|0)==1){break y}b=d+56|0;e=Ze(b);f=gc(b);g=oW(b);j=Db(b);n=nW(b);e=D(Bd(Fb(y[e|0]|y[e+1|0]<<8),32,999),1e4);b=qoa(Fb(y[f|0]|y[f+1|0]<<8),0,1e4,0)+32768|0;f=kb;f=b>>>0<32768?f+1|0:f;I=a,J=e+((Ec((f&65535)<<16|b>>>16,f>>>16|0)>>>0)%1e4|0)|0,x[I+480204>>2]=J;I=a,J=Bd(Fb(y[g|0]|y[g+1|0]<<8),1,255),x[I+480196>>2]=J;b=16/(Bd(Fb(y[n|0]|y[n+1|0]<<8),1,16)>>>0)|0;x[a+480216>>2]=b;I=a,J=D(Bd(Fb(y[j|0]|y[j+1|0]<<8),1,16),b),x[I+480220>>2]=J;if(!Fb(z[d+56>>1])){break P}x[27524]=0;b=T(275,d+480|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break y}e=a+480208|0;x[e>>2]=x[e>>2]&-17|!b<<4}b=d+480|0;yb(b);x[27524]=0;U(371,b|0,d+864|0,1414942540);b=x[27524];x[27524]=0;if((b|0)==1){break x}x[27524]=0;b=W(160,x[d+480>>2],x[d+488>>2],2)|0;e=x[27524];x[27524]=0;if((e|0)==1){break v}if(!b){break w}x[27524]=0;b=T(275,d+480|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break v}w[d+56>>1]=b;w[d+376>>1]=z[a+480188>>1];b=z[Tc(d+56|0,d+376|0)>>1];f=0;while(1){if((b|0)==(f|0)){break w}x[27524]=0;e=T(275,d+480|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break v}w[d+56>>1]=e;w[d+376>>1]=4096;I=((f<<5)+a|0)+480286|0,J=z[Tc(d+56|0,d+376|0)>>1]>>>6&255,w[I>>1]=J;f=f+1|0;continue}}a=P()|0;yb(d+480|0);break c}a=P()|0;break c}a=P()|0;yb(d+480|0);break c}a=P()|0;break c}yb(d+480|0);x[27524]=0;U(371,d+56|0,d+864|0,1296652368);b=x[27524];x[27524]=0;if((b|0)==1){break u}x[27524]=0;b=W(160,x[d+56>>2],x[d+64>>2],56)|0;e=x[27524];x[27524]=0;if((e|0)==1){break d}if(!b){break t}x[27524]=0;R(373,d+56|0,d+480|0);b=x[27524];x[27524]=0;if((b|0)==1){break d}if((Fb(z[d+514>>1])|0)!=4){break t}if((Fb(z[d+528>>1])|0)!=257){break t}I=d,J=Fb(z[d+520>>1]),w[I+376>>1]=J;w[d+848>>1]=16384;e=z[Tc(d+376|0,d+848|0)>>1];b=e>>>24|0;e=(e<<8)+2048|0;b=e>>>0<2048?b+1|0:b;I=a,J=Ec((b&4095)<<20|e>>>12,b>>>12|0),x[I+480200>>2]=J;g=a+480188|0;f=0;while(1){if(Fb(z[d+518>>1])>>>0<=(f&65535)>>>0){break t}x[27524]=0;R(374,d+56|0,d+376|0);b=x[27524];x[27524]=0;if((b|0)==1){break d}Q:{if(y[d+376|0]){break Q}b=Fb(z[d+378>>1]);if(b>>>0>=z[g>>1]){break Q}b=(b<<5)+a|0;I=b+480284|0,J=Ec(((Fb(z[d+382>>1])<<8)+2047>>>0)/4095|0,0),w[I>>1]=J;h=b+480286|0;e=Fb(z[d+380>>1]);b=e>>>26|0;e=(e<<6)+2048|0;b=e>>>0<2048?b+1|0:b;I=h,J=Ec((b&4095)<<20|e>>>12,b>>>12|0)&255,w[I>>1]=J}f=f+1|0;continue}}a=P()|0;yb(d+480|0);break c}a=P()|0;break c}b=d+56|0;yb(b);x[27524]=0;U(375,b|0,d+864|0,1396788530);b=x[27524];x[27524]=0;if((b|0)==1){break e}I=d,J=Cb(x[d+56>>2]),x[I+800>>2]=J;f=c&2;j=d+480|2;n=Cb(x[d+60>>2]);g=a+480190|0;l=a+1298472|0;R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{while(1){e=x[d+800>>2];if(!Mb(e,n)){b=d+56|0;Sc(b);x[27524]=0;U(375,b|0,d+864|0,1396788560);b=x[27524];x[27524]=0;if((b|0)==1){break f}I=d,J=Cb(x[d+56>>2]),x[I+832>>2]=J;j=d+480|2;n=Cb(x[d+60>>2]);e=a+480190|0;break R}x[27524]=0;b=Q(376,e|0,d+480|0)|0;k=x[27524];x[27524]=0;if((k|0)==1){break T}$:{aa:{if(!b){break aa}b=Fb(z[d+480>>1]);if((b-4e3&65535)>>>0<61537){break aa}if(Fb(z[d+528>>1])>>>0>1){break aa}if(Fb(z[d+510>>1])>>>0>1){break aa}if(b>>>0>z[g>>1]){w[g>>1]=b}x[27524]=0;k=D(b,104)+a|0;b=k+484380|0;R(377,d+480|0,b|0);h=x[27524];x[27524]=0;ba:{ca:{da:{if((h|0)==1){break da}h=d+848|0;Pi(h,3,j);x[27524]=0;R(226,d+376|0,h|0);h=x[27524];x[27524]=0;if((h|0)==1){break ca}h=d+376|0;Cc(((Fb(z[d+480>>1])<<5)+a|0)+946304|0,h);wb(h);if(!f){break aa}h=z[d+554>>1]|z[d+556>>1]<<16;x[27524]=0;h=Q(159,e|0,ac(h)-8|0)|0;q=x[27524];x[27524]=0;if((q|0)==1){break da}if(!h){break aa}if(Fb(z[d+510>>1])){break ba}h=d+376|0;Zc(h,(Fb(y[d+512|0]|y[d+513|0]<<8)|0)==8?8:16,(Fb(y[d+516|0]|y[d+517|0]<<8)|0)==1?1:2,!Fb(y[d+514|0]|y[d+515|0]<<8),0);x[27524]=0;W(223,h|0,b|0,e|0)|0;b=x[27524];x[27524]=0;if((b|0)!=1){break ba}a=P()|0;break S}a=P()|0;break S}a=P()|0;break S}b=Kb(d+376|0);h=z[d+530>>1];x[27524]=0;U(272,e|0,b|0,Fb(h)|0);e=x[27524];x[27524]=0;if((e|0)==1){break V}Fe(k+484423|0,b);if((Fb(z[d+510>>1])|0)==1){x[27524]=0;R(378,d+832|0,16394);e=x[27524];x[27524]=0;if((e|0)==1){break $}x[27524]=0;U(11,d+816|0,0,b|0);e=x[27524];x[27524]=0;if((e|0)==1){break _}x[27524]=0;X(379,d+848|0,d+832|0,z[d+480>>1],d+816|0);e=x[27524];x[27524]=0;if((e|0)==1){break Z}e=x[l>>2];x[27524]=0;U(380,e|0,2,d+848|0);e=x[27524];x[27524]=0;if((e|0)==1){break Y}xb(d+848|0);xb(d+816|0);$b(d+832|0)}wb(b)}Uf(d+800|0);continue}break}a=P()|0;break U}a=P()|0;break W}a=P()|0;break X}a=P()|0;xb(d+848|0)}xb(d+816|0)}$b(d+832|0);break U}a=P()|0}wb(b);break S}a=P()|0}Sc(d+56|0);break c}ea:{while(1){fa:{g=x[d+832>>2];if(!Mb(g,n)){Sc(d+56|0);x[27524]=0;U(375,d+848|0,d+864|0,1447382614);b=x[27524];x[27524]=0;if((b|0)!=1){break ea}a=P()|0;break c}x[27524]=0;b=Q(381,g|0,d+480|0)|0;l=x[27524];x[27524]=0;if((l|0)==1){break fa}ga:{ha:{if(!b){break ha}b=Fb(z[d+480>>1]);if((b-4e3&65535)>>>0<61537){break ha}if(Fb(z[d+534>>1])){break ha}if(b>>>0>z[e>>1]){w[e>>1]=b}x[27524]=0;b=(D(b,104)+a|0)+484380|0;R(382,d+480|0,b|0);l=x[27524];x[27524]=0;if((l|0)==1){break fa}l=d+848|0;Pi(l,3,j);x[27524]=0;R(226,d+376|0,l|0);l=x[27524];x[27524]=0;if((l|0)==1){break fa}l=d+376|0;Cc(((Fb(z[d+480>>1])<<5)+a|0)+946304|0,l);wb(l);if(!f){break ha}l=z[d+510>>1];k=d+376|0;Zc(k,(Fb(z[d+514>>1])|0)==8?8:16,Fb(l)&1?2:1,1,0);x[27524]=0;W(223,k|0,b|0,g|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break ga}}Uf(d+832|0);continue}}break}a=P()|0;Sc(d+56|0);break c}x[27524]=0;U(375,d+832|0,d+864|0,1413828182);b=x[27524];x[27524]=0;if((b|0)==1){break h}x[27524]=0;U(375,d+816|0,d+864|0,1346719318);b=x[27524];x[27524]=0;if((b|0)==1){break j}x[27524]=0;U(375,d+800|0,d+864|0,1229869908);b=x[27524];x[27524]=0;if((b|0)==1){break l}I=d,J=Cb(x[d+800>>2]),x[I+24>>2]=J;n=d+426|0;l=d+376|2;k=d+480|2;h=Cb(x[d+804>>2]);q=a+480190|0;r=a+480208|0;while(1){ia:{ja:{ka:{la:{g=x[d+24>>2];if(!Mb(g,h)){Sc(d+800|0);x[27524]=0;U(375,d+376|0,d+864|0,1346458692);b=x[27524];x[27524]=0;if((b|0)!=1){break la}a=P()|0;break k}x[27524]=0;b=Q(383,g|0,d+480|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break n}if(!b){break ia}if(Fb(z[d+510>>1])){break ia}b=z[d+480>>1];x[27524]=0;e=W(255,a|0,Fb(b)|0,0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break n}if(!e){break ia}b=Fb(z[d+480>>1]);if(b>>>0>z[a+480192>>1]){w[a+480192>>1]=b}b=d+376|0;Pi(b,3,k);x[27524]=0;R(226,d+56|0,b|0);b=x[27524];x[27524]=0;if((b|0)==1){break ka}b=d+56|0;Cc(e+492|0,b);wb(b);v[e+33|0]=2;if((se(w[d+514>>1])|0)>0){v[e+15|0]=y[e+15|0]|1;f=se(w[d+514>>1]);b=f>>>24|0;j=(f<<8&-256)+2047|0;f=b&255;I=e,J=Ec(soa(j,j>>>0<2047?f+1|0:f,4095,0),kb),x[I+8>>2]=J}j=e+108|0;i=e+236|0;b=0;while(1){ma:{x[d+56>>2]=128;x[d+376>>2]=128;f=b&255;if(f>>>0>=A[Hb(d+56|0,d+376|0)>>2]){x[27524]=0;R(384,d+56|0,e|0);b=x[27524];x[27524]=0;if((b|0)==1){break ma}I=d,J=Ni(x[d+56>>2]),x[I+376>>2]=J;f=Gf(d+56|0);while(1){b=x[d+376>>2];if(Mb(b,f)){b=z[vo(b)>>1];if(!(!b|b>>>0>z[q>>1])){I=(D(b,104)+a|0)+484410|0,J=Fb(z[d+512>>1]),w[I>>1]=J}Ug(d+376|0);continue}break}Nu(d+56|0);Tj(e,127,1);Sj(e,0,1);b=Fb(z[d+530>>1]);if(!b){x[e>>2]=0;b=z[d+516>>1];x[27524]=0;X(385,e|0,0,Fb(b)|0,d+848|0);b=x[27524];x[27524]=0;if((b|0)==1){break n}b=z[d+520>>1];x[27524]=0;X(385,e|0,1,Fb(b)|0,d+816|0);b=x[27524];x[27524]=0;if((b|0)==1){break n}b=z[d+518>>1];x[27524]=0;X(385,e|0,2,Fb(b)|0,d+832|0);b=x[27524];x[27524]=0;if((b|0)!=1){break ia}break n}x[27524]=0;U(386,g|0,d+376|0,((b|0)==1?98:102)|0);b=x[27524];x[27524]=0;na:{oa:{pa:{if((b|0)!=1){b=Fb(z[d+376>>1]);j=b&1;if(!j){break ja}f=b&24;if(f){break pa}f=0;break oa}a=P()|0;break m}if((f|0)!=8){break na}f=1}v[e+25|0]=f}qa:{ra:{sa:{ta:{if(!(b&2)){break ta}x[27524]=0;b=W(387,d+360|0,l|0,24)|0;f=x[27524];x[27524]=0;if((f|0)==1){break sa}x[27524]=0;u=+la(388,b|0);f=x[27524];x[27524]=0;if((f|0)==1){break ra}wb(b);if(!(u>20)){break ta}Tj(e,KB(x[r>>2],u),1)}if(Fb(z[d+376>>1])&4){break qa}break ja}a=P()|0;break m}a=P()|0;wb(b);break m}x[27524]=0;b=W(387,d+344|0,n|0,24)|0;f=x[27524];x[27524]=0;ua:{if((f|0)!=1){x[27524]=0;u=+la(388,b|0);f=x[27524];x[27524]=0;if((f|0)==1){break ua}wb(b);Sj(e,Ak(u*127/24),1);break ja}a=P()|0;break m}a=P()|0;wb(b);break m}else{o=(d+480|0)+(f<<1)|0;I=bc(i,f),J=y[o+52|0],w[I>>1]=J;f=Jb(j,f);I=f,J=El(v[o+53|0]+y[f|0]|0),v[I|0]=J;b=b+1|0;continue}}break}a=P()|0;break m}b=x[d+380>>2];e=x[d+376>>2];x[27524]=0;g=a+484344|0;R(229,g|0,Kf(e,b)&65535);b=x[27524];x[27524]=0;va:{if((b|0)!=1){x[d+48>>2]=x[a+480204>>2];x[d+40>>2]=x[a+480196>>2];I=d,J=Cb(x[d+376>>2]),x[I+8>>2]=J;o=c&1;b=d+56|0;s=b|4;B=b|2;C=b|1;E=Cb(x[d+380>>2]);F=a+480188|0;while(1){wa:{xa:{ya:{za:{Aa:{Ba:{b=x[d+8>>2];if(!Mb(b,E)){x[27524]=0;U(371,d+56|0,d+864|0,1414414669);b=x[27524];x[27524]=0;if((b|0)!=1){break Ba}a=P()|0;break va}if(!o){break wa}c=x[b+8>>2];e=x[b>>2];x[27524]=0;c=W(160,e|0,c|0,24)|0;e=x[27524];x[27524]=0;if((e|0)==1){break Aa}if(!c){break wa}x[27524]=0;j=T(275,b|0)|0;c=x[27524];x[27524]=0;Ca:{Da:{Ea:{Fa:{if((c|0)!=1){v[d+496|0]=0;x[d+488>>2]=0;x[d+492>>2]=0;x[d+480>>2]=0;x[d+484>>2]=0;x[27524]=0;R(389,b|0,d+480|0);c=x[27524];x[27524]=0;if((c|0)==1){break Fa}x[27524]=0;q=T(275,b|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break Ea}x[27524]=0;n=T(275,b|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break Da}x[27524]=0;l=T(275,b|0)|0;c=x[27524];x[27524]=0;Ga:{if((c|0)==1){break Ga}c=x[b+8>>2];e=x[b>>2];x[27524]=0;c=W(160,e|0,c|0,D(D(l,n),5)|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break Ga}if(!(c&q>>>0<2)){break wa}x[27524]=0;c=W(230,g|0,j|0,n|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break Ga}if(!c){break wa}c=x[g>>2];x[27524]=0;R(390,Xb(c,j)|0,d+480|0);c=x[27524];x[27524]=0;if((c|0)!=1){break Ca}}a=P()|0;break va}a=P()|0;break va}a=P()|0;break va}a=P()|0;break va}a=P()|0;break va}v[d+24|0]=0;c=fe(d+56|0,0,d+24|0);x[27524]=0;c=W(367,d+800|0,l|0,c|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break xa}e=0;Ha:while(1){if((e|0)==(n|0)){jd(c);break wa}f=0;k=Xb(x[g>>2],j);G=qf(x[k>>2],x[x[k+48>>2]+12>>2],e);while(1){if((f|0)==(l|0)){e=e+1|0;continue Ha}h=Bg(d+56|0);r=z[F>>1];x[27524]=0;R(391,b|0,d+24|0);k=x[27524];x[27524]=0;Ia:{if((k|0)==1){break Ia}k=D(f,6)+G|0;i=h;h=f>>>0<r>>>0;r=h?k:i;i=y[d+24|0];if((i-1&255)>>>0<=119){i=i+1|0;v[r|0]=i;I=bc(x[c>>2],f),J=i,v[I|0]=J}i=y[d+25|0];if(i){v[(h?k+1|0:C)|0]=i;I=bc(x[c>>2],f),J=i,v[I+1|0]=J}i=y[d+28|0];if(i){v[(h?k+2|0:B)|0]=1;v[(h?k+4|0:s)|0]=q?i-16|0:i>>>2|0}k=y[d+947|0];h=y[d+27|0];i=y[d+26|0];t=bc(x[c>>2],f);H=y[t+1|0];t=y[t|0];x[27524]=0;Aa(369,a|0,r|0,i|0,h|0,k|0,t|0,H|0,d+48|0,d+40|0);k=x[27524];x[27524]=0;if((k|0)==1){break Ia}f=f+1|0;continue}break}break}a=P()|0;jd(c);break va}x[27524]=0;b=W(160,x[d+56>>2],x[d+64>>2],38)|0;c=x[27524];x[27524]=0;if((c|0)!=1){if(!b){break ya}x[27524]=0;b=T(275,d+56|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break za}c=d+480|4;e=a+480188|0;f=0;Ja:{while(1){if(b>>>0<=(f&65535)>>>0){break ya}x[27524]=0;g=W(160,x[d+56>>2],x[d+64>>2],36)|0;j=x[27524];x[27524]=0;Ka:{if((j|0)!=1){if(g){break Ka}break ya}break za}x[27524]=0;R(392,d+56|0,d+480|0);g=x[27524];x[27524]=0;if((g|0)!=1){La:{if(Fb(z[d+480>>1])){break La}if(Fb(z[d+482>>1])>>>0>=z[e>>1]){break La}g=d+8|0;Se(g,3,c);x[27524]=0;R(226,d+24|0,g|0);g=x[27524];x[27524]=0;if((g|0)==1){break Ja}g=d+24|0;Il(((Fb(z[d+482>>1])<<5)+a|0)+480289|0,g);wb(g)}f=f+1|0;continue}break}break za}break za}break za}a=P()|0;break va}a=P()|0;yb(d+56|0);break va}yb(d+56|0);Sc(d+376|0);Sc(d+816|0);Sc(d+832|0);Sc(d+848|0);f=1;break s}a=P()|0;break va}Uf(d+8|0);continue}}a=P()|0}Sc(d+376|0);break k}a=P()|0;break m}f=0;while(1){if(y[d+477|0]<=f>>>0){break ia}x[27524]=0;R(393,g|0,d+56|0);b=x[27524];x[27524]=0;Ma:{Na:{if((b|0)!=1){x[d+8>>2]=33620480;I=d,J=(Fb(z[d+516>>1])|0)!=0,v[I+48|0]=J;I=d,J=(Fb(z[d+518>>1])|0)!=0,v[I+49|0]=J;I=d,J=(Fb(z[d+520>>1])|0)!=0,v[I+50|0]=J;I=d,J=j&(Fb(z[d+522>>1])|0)!=0,v[I+51|0]=J;if(!y[(d+48|0)+f|0]|f>>>0>3){break Ma}b=(f|0)!=3;if(!b&(v[e+100|0]&1)){break Ma}x[27524]=0;i=y[(d+8|0)+f|0];U(394,d+56|0,e|0,i|0);o=x[27524];x[27524]=0;if((o|0)==1){break Na}if(!b){v[e+100|0]=y[e+100|0]|16}Oa:{switch(i|0){case 0:if(Fb(z[d+68>>1])&1){b=Fb(z[d+66>>1])&32767}else{b=0}x[e>>2]=b;break Ma;case 2:break Oa;default:break Ma}}if(!(Fb(z[d+68>>1])&2)){break Ma}I=d,J=Fb(z[d+62>>1]),w[I+40>>1]=J;w[d+46>>1]=1;b=z[pe(d+40|0,d+46|0)>>1];i=Nl(Ec(((Fb(z[d+58>>1])<<6|48)>>>0)/100|0,0));I=d,J=Fb(z[d+60>>1]),w[I+40>>1]=J;w[d+46>>1]=1;o=Ag(256/z[pe(d+40|0,d+46|0)>>1]|0);s=z[d+480>>1];B=z[d+64>>1];x[27524]=0;t=Fb(s);s=Fb(B);ma(395,a|0,t|0,y[(s>>>0<6?s:0)+26608|0],255/(b>>>0)|0,i|0,o|0);b=x[27524];x[27524]=0;if((b|0)!=1){break Ma}a=P()|0;break m}a=P()|0;break m}a=P()|0;break m}f=f+1|0;continue}}Uf(d+24|0);continue}}Zd(d+864|0);yb(m)}ib=d+1184|0;return f|0}a=P()|0}Sc(d+800|0);break k}a=P()|0}Sc(d+816|0);break i}a=P()|0}Sc(d+832|0);break g}a=P()|0}Sc(d+848|0);break c}a=P()|0;break c}a=P()|0;break c}a=P()|0;yb(d+56|0)}Zd(d+864|0)}yb(m)}S(a|0);p()}function Mda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,Q=0,R=0,T=0,U=0,V=0,X=0,Y=0,Z=0,_=0,$=0,ba=0,ca=0,da=0;m=ib-1168|0;ib=m;yc(b);a:{if(!Cr(b,m+1144|0)){break a}if(!iO(m+1144|0)){break a}if(x[m+1152>>2]!=(bh(x[b>>2])|0)){break a}if(x[m+1160>>2]!=(jf(b)|0)){break a}if(!c){d=1;break a}e=m+1088|0;Rb(e,0,56);j=-2;b:{if(!e){break b}x[e+44>>2]=0;x[e+48>>2]=0;x[e+52>>2]=0;x[e+20>>2]=0;x[e+24>>2]=0;x[e+8>>2]=0;j=x[e+32>>2];if(!j){x[e+32>>2]=1116;j=1116}if(!x[e+36>>2]){x[e+36>>2]=1117}f=lb[j|0](x[e+40>>2],1,43784)|0;j=-4;if(!f){break b}x[e+28>>2]=f;x[f+43780>>2]=1;x[f+10992>>2]=0;x[f+10996>>2]=0;x[f>>2]=0;x[f+11008>>2]=15;x[f+11e3>>2]=1;x[f+11004>>2]=0;j=0}if(j){break a}d=x[m+1160>>2];x[m+1084>>2]=d;K=x[m+1164>>2];T=aC(m+1072|0,K);c:{d:{while(1){if(!(!d|!K|(h|0)==1)){x[m+32>>2]=1024;d=m+32|0;U=x[Hb(d,m+1084|0)>>2];h=dc(m+40|0,m+48|0,U);e=x[h+4>>2];h=x[h>>2];x[27524]=0;tn(169,d,b,h,e);d=x[27524];x[27524]=0;if((d|0)==1){break d}e=m+48|0;h=e;d=U;f=$^-1;while(1){if(d>>>0<4){while(1){if(d){f=x[(((y[h|0]^f)&255)<<2)+78384>>2]^f>>>8;d=d-1|0;h=h+1|0;continue}break}$=f^-1}else{f=x[(((y[h|0]^f)&255)<<2)+78384>>2]^f>>>8;f=f>>>8^x[(((f^y[h+1|0])&255)<<2)+78384>>2];f=f>>>8^x[(((f^y[h+2|0])&255)<<2)+78384>>2];f=f>>>8^x[(((f^y[h+3|0])&255)<<2)+78384>>2];d=d-4|0;h=h+4|0;continue}break}x[m+1092>>2]=U;x[m+1088>>2]=e;x[m+1104>>2]=K;x[m+1100>>2]=x[T>>2]+ba;B=ib-16|0;ib=B;h=-2;q=m+1088|0;e:{if(!q){break e}g=x[q+28>>2];if(!g){break e}da=x[q+4>>2];x[g+11e3>>2]=0;f:{if(x[g+43780>>2]<0){break f}if(x[g+11004>>2]){break e}e=x[g+11008>>2];h=0;x[g+11004>>2]=0;d=x[g+10996>>2];if(!d){X=(e|0)>0?11:10;I=g+11012|0;j=x[q+4>>2];f=x[g+10992>>2];while(1){x[B+12>>2]=j;x[B+8>>2]=32768-f;F=x[q>>2];d=0;j=0;C=0;E=0;J=0;L=0;V=0;M=0;Y=0;Z=ib-144|0;ib=Z;g:{h:{N=f+I|0;if(N>>>0>=I>>>0){G=x[B+8>>2]+N|0;r=G-I|0;_=(I^-1)+G|0;if(!(r&_)){break h}}x[B+8>>2]=0;x[B+12>>2]=0;o=-3;break g}n=x[B+12>>2];t=n+F|0;O=x[g+60>>2];s=x[g+40>>2];h=x[g+36>>2];u=x[g+32>>2];f=x[g+56>>2];e=x[g+4>>2];o=-1;l=N;k=F;i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{i=x[g>>2];switch(i|0){case 36:break k;case 39:break m;case 10:break n;case 35:break o;case 17:break p;case 21:break q;case 34:break r;case 2:break w;case 53:break A;case 26:break C;case 25:break D;case 24:break E;case 23:break F;case 18:break G;case 16:break H;case 14:break I;case 51:break L;case 6:break M;case 3:break N;case 37:break O;case 42:break P;case 41:break Q;case 32:break R;case 27:break S;case 11:break T;case 38:break U;case 9:break V;case 52:break W;case 7:break X;case 5:break Y;case 1:break Z;case 0:break _;default:break j}}x[g+28>>2]=1;f=0;x[g+8>>2]=0;x[g+12>>2]=0;x[g+16>>2]=1;s=0;h=0;u=0;e=0;if(X&1){break Z}break v}if((n|0)<=0){o=1;x[g>>2]=1;break i}x[g+8>>2]=y[F|0];k=F+1|0;break w}if((n|0)<=0){break x}V=e+8|0;k=F+1|0;f=y[F|0]<<e|f;d=2;break u}d=4;break u}M=f;break K}d=7;break u}d=8;break u}C=h;break J}E=f;break B}o=1;if((n|0)<=0){break y}e=e+8|0;k=F+1|0;break t}j=h;d=e;break z}i=2;break s}i=37;break k}d=1;break u}d=3;break u}d=5;break u}d=6;break u}d=9;break u}d=10;break u}d=11;break u}d=12;break u}d=13;break u}d=14;break u}d=15;break u}d=16;break u}d=17;break u}d=18;break u}i=1;break s}x[g>>2]=32;break i}x[g>>2]=5;o=1;break i}if(k>>>0>=t>>>0){x[g>>2]=2;o=1;break i}d=y[k|0];x[g+12>>2]=d;n=1;h=x[g+8>>2];if(!(((d|h<<8)>>>0)%31|d&32)){n=(h&15)!=8}k=k+1|0;i=36;d=256<<(h>>>4);if(d>>>0>32768|d>>>0>r>>>0){break l}h=0;if(n){break l}}d=0}$:while(1){aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{Da:{Ea:{Fa:{Ga:{Ha:{switch(d|0){case 0:if(e>>>0>2){break Ga}d=1;continue;case 4:break Da;case 3:break Ea;case 2:break Fa;case 1:break Ha;case 9:break la;case 10:break ma;case 11:break na;case 12:break oa;case 13:break pa;case 14:break qa;case 15:break ra;case 16:break sa;case 17:break ta;case 8:break za;case 7:break Aa;case 6:break Ba;case 5:break Ca;default:break ua}}while(1){if(k>>>0>=t>>>0){x[g>>2]=3;o=1;break i}f=y[k|0]<<e|f;k=k+1|0;e=e+8|0;if(e>>>0<3){continue}break}}d=f&7;x[g+20>>2]=d;j=d>>>1|0;x[g+24>>2]=j;e=e-3|0;f=f>>>3|0;if(d>>>0>=2){break ya}V=e;break va}e=V&-8;f=f>>>(V&7)|0;h=0;d=0;break xa}while(1){if(k>>>0>=t>>>0){x[g>>2]=6;o=1;break i}f=y[k|0]<<e|f;d=e>>>0>4294967287;k=k+1|0;e=e+8|0;if(d){continue}break}d=1;break xa}if(k>>>0>=t>>>0){x[g>>2]=7;o=1;break i}v[(g+h|0)+10528|0]=y[k|0];k=k+1|0;d=2;break xa}while(1){if(k>>>0>=t>>>0){x[g>>2]=51;o=1;break i}f=y[k|0]<<e|f;d=e>>>0>4294967287;k=k+1|0;e=e+8|0;if(d){continue}break}break da}if(l>>>0<G>>>0){v[l|0]=u;h=h-1|0;l=l+1|0;f=M;break ea}o=2;i=52;f=M;break k}if(l>>>0<G>>>0){break wa}o=2;i=9;break k}if(k>>>0<t>>>0){d=G-l|0;j=t-k|0;d=d>>>0<j>>>0?d:j;d=d>>>0<h>>>0?d:h;h=h-d|0;l=rc(l,k,d)+d|0;k=d+k|0;break ca}x[g>>2]=38;o=1;break i}C=0;Ia:{switch(j-1|0){case 0:x[g+44>>2]=288;x[g+48>>2]=32;d=g+3552|0;x[d>>2]=84215045;x[d+4>>2]=84215045;d=g+3560|0;x[d>>2]=84215045;x[d+4>>2]=84215045;d=g+3568|0;x[d>>2]=84215045;x[d+4>>2]=84215045;d=g+3576|0;x[d>>2]=84215045;x[d+4>>2]=84215045;d=g- -64|0;j=0;while(1){i=144;if((j|0)==144){while(1){j=256;if((i|0)==256){while(1){i=280;if((j|0)==280){while(1){if((i|0)==288){break ia}v[d|0]=8;i=i+1|0;d=d+1|0;continue}}else{v[d|0]=7;j=j+1|0;d=d+1|0;continue}}}else{v[d|0]=9;i=i+1|0;d=d+1|0;continue}}}else{v[d|0]=8;j=j+1|0;d=d+1|0;continue}};case 2:break n;default:break Ia}}d=0;break ka}while(1){Ja:{Ka:{La:{Ma:{Na:{Oa:{switch(d|0){case 0:if(h>>>0>3){break Na}if(!e){e=0;break Ma}if(e>>>0>7){break Ka}d=3;continue $;case 1:v[(g+h|0)+10528|0]=f;e=e-8|0;f=f>>>8|0;break Ja;default:break Oa}}h=h+1|0;break La}h=z[g+10528>>1];if((h|0)==(z[g+10530>>1]^65535)){break ea}break m}d=4;continue $}d=0;continue}d=1;continue}d=2;continue}}d=8;continue}d=2;continue}if(l>>>0<G>>>0){v[l|0]=y[(O-u&_)+I|0];l=l+1|0;O=O+1|0;d=7;break fa}o=2;i=53;break k}while(1){if(k>>>0>=t>>>0){x[g>>2]=27;o=1;f=E;break i}E=y[k|0]<<e|E;k=k+1|0;e=e+8|0;if(s>>>0>e>>>0){continue}break}d=6;break fa}if(k>>>0>=t>>>0){x[g>>2]=26;o=1;break i}f=y[k|0]<<e|f;k=k+1|0;e=e+8|0;d=4;if(e>>>0<15){break fa}d=5;break fa}while(1){if(k>>>0>=t>>>0){x[g>>2]=25;o=1;break i}f=y[k|0]<<e|f;k=k+1|0;e=e+8|0;if(s>>>0>e>>>0){continue}break}d=3;break fa}if(l>>>0>=G>>>0){o=2;i=24;break k}v[l|0]=h;l=l+1|0;break ga}if(k>>>0>=t>>>0){x[g>>2]=23;o=1;break i}f=y[k|0]<<e|f;k=k+1|0;e=e+8|0;d=0;if(e>>>0<15){break fa}d=1;break fa}while(1){if(k>>>0>=t>>>0){x[g>>2]=18;o=1;break i}f=y[k|0]<<e|f;k=k+1|0;e=e+8|0;if(s>>>0>e>>>0){continue}break}Y=u-16|0;d=3;break ha}if(k>>>0>=t>>>0){x[g>>2]=16;o=1;break i}f=y[k|0]<<e|f;k=k+1|0;e=e+8|0;d=1;if(e>>>0<15){break ha}d=2;break ha}while(1){if(k>>>0>=t>>>0){x[g>>2]=14;o=1;break i}f=y[k|0]<<e|f;k=k+1|0;e=e+8|0;if(e>>>0<3){continue}break}d=1;break ja}d=C+21612|0;while(1){if(k>>>0>=t>>>0){x[g>>2]=11;o=1;h=C;break i}f=y[k|0]<<e|f;k=k+1|0;e=e+8|0;L=v[d|0];if(e>>>0<L>>>0){continue}break}d=1}while(1){Pa:{Qa:{Ra:{if(!d){if(C>>>0>2){break Ra}L=v[C+21612|0];if(L>>>0<=e>>>0){break Pa}d=9;continue $}d=C<<2;x[(d+g|0)+44>>2]=x[d+79920>>2]+((-1<<L^-1)&f);C=C+1|0;e=e-L|0;f=f>>>L|0;break Qa}h=0;Rb(g+7040|0,0,288);d=0;break ja}d=0;continue}d=1;continue}}while(1){Sa:{Ta:{Ua:{if(!d){if(A[g+52>>2]<=h>>>0){break Ua}if(e>>>0>2){break Sa}d=10;continue $}v[(y[h+79936|0]+g|0)+7040|0]=f&7;h=h+1|0;e=e-3|0;f=f>>>3|0;break Ta}x[g+52>>2]=19;break ia}d=0;continue}d=1;continue}}J=x[g+24>>2];d=0}while(1){Va:{Wa:{Xa:{Ya:{Za:{_a:{$a:{ab:{bb:{switch(d|0){case 0:d=0;if((J|0)<0){break ga}Q=Rb(Z,0,64);j=D(J,3488)+g|0;Rb(j+352|0,0,3200);ca=j- -64|0;H=x[g+24>>2];i=x[((H<<2)+g|0)+44>>2];while(1){if((d|0)!=(i|0)){j=(y[d+ca|0]<<2)+Q|0;x[j>>2]=x[j>>2]+1;d=d+1|0;continue}break};x[Q+64>>2]=0;x[Q+68>>2]=0;r=0;d=1;j=0;while(1){if((d|0)!=16){n=d<<2;d=d+1|0;n=x[n+Q>>2];j=n+j<<1;x[(Q- -64|0)+(d<<2)>>2]=j;r=n+r|0;continue}break};R=0;n=-1;if((j|0)!=65536&r>>>0>=2){break o}while(1){if(i>>>0>R>>>0){r=y[R+ca|0];cb:{if(!r){break cb}d=(Q- -64|0)+(r<<2)|0;j=x[d>>2];x[d>>2]=j+1;d=0;i=r;while(1){if(i){d=j&1|d<<1;j=j>>>1|0;i=i-1|0;continue}break}if(r>>>0<=10){j=1<<r;r=r<<9|R;i=D(J,3488)+g|0;while(1){if(d>>>0>1023){break cb}w[(i+(d<<1)|0)+352>>1]=r;d=d+j|0;continue}}H=D(J,3488)+g|0;j=H+((d&1023)<<1)|0;i=w[j+352>>1];db:{if(i){j=n;n=i;break db}w[j+352>>1]=n;j=n-2|0}d=d>>>9|0;while(1){d=d>>>1|0;i=d&1;if(r>>>0>=12){i=(H+(i+(n^-1)<<1)|0)+2400|0;n=w[i>>1];if(!n){w[i>>1]=j;n=j;j=j-2|0}r=r-1|0;continue}break}w[((D(J,3488)+g|0)+(i+(n^-1)<<1)|0)+2400>>1]=R;n=j}R=R+1|0;H=x[g+24>>2];i=x[((H<<2)+g|0)+44>>2];continue}break};d=0;if((H|0)!=2){break Wa}break _a;case 1:d=w[(((f&1023)<<1)+g|0)+7328>>1];eb:{if((d|0)>=0){if(d>>>0<512|d>>>9>>>0>e>>>0){break eb}break Za}if(e>>>0<11){break eb}i=10;while(1){d=w[(((f>>>i&1)+(d^-1)<<1)+g|0)+9376>>1];if((d|0)<0){j=i+2|0;i=i+1|0;if(e>>>0>=j>>>0){continue}}break}if((d|0)>=0){break Za}}d=11;continue $;case 2:i=w[(((f&1023)<<1)+g|0)+7328>>1];if((i|0)>=0){break ab}d=10;while(1){j=f>>>d|0;d=d+1|0;i=w[(((j&1)+(i^-1)<<1)+g|0)+9376>>1];if((i|0)<0){continue}break};u=i&65535;break $a;default:break bb}}d=v[Y+17821|0]+((-1<<s^-1)&f)|0;e=e-s|0;f=f>>>s|0;j=g+h|0;Rb(j+10532|0,(u|0)==16?y[j+10531|0]:0,d);d=d+h|0;break _a}d=i>>>9|0;u=i&511}e=e-d|0;f=f>>>d|0;if(u>>>0>15){break Ya}v[(g+h|0)+10532|0]=u;d=h+1|0}j=x[g+48>>2];h=x[g+44>>2];n=j+h|0;if(n>>>0<=d>>>0){break Xa}if(e>>>0<=14){if((t-k|0)<=1){h=d;d=1;continue}f=y[k|0]<<e|y[k+1|0]<<e+8|f;k=k+2|0;e=e+16|0}h=d}d=2;continue}if(!((u|0)!=16|h)){h=0;u=16;break p}Y=u-16|0;s=v[u+21587|0];if(s>>>0<=e>>>0){break Va}d=12;continue $}if((d|0)!=(n|0)){h=d;break q}n=g+10532|0;rc(g- -64|0,n,h);rc(g+3552|0,h+n|0,j);H=x[g+24>>2];h=d}J=H-1|0;x[g+24>>2]=J;d=0;continue}d=3;continue}}d=2}fb:while(1){gb:{hb:{ib:{jb:{kb:{lb:{mb:{nb:{ob:{pb:{qb:{rb:{sb:{tb:{ub:{vb:{switch(d|0){case 0:d=w[(((f&1023)<<1)+g|0)+352>>1];wb:{if((d|0)>=0){if(d>>>0<512|d>>>9>>>0>e>>>0){break wb}break gb}if(e>>>0<11){break wb}i=10;while(1){d=w[(((f>>>i&1)+(d^-1)<<1)+g|0)+2400>>1];if((d|0)<0){j=i+2|0;i=i+1|0;if(e>>>0>=j>>>0){continue}}break}if((d|0)>=0){break gb}}d=13;continue $;case 1:i=w[(((f&1023)<<1)+g|0)+352>>1];if((i|0)>=0){break ub}d=10;while(1){h=f>>>d|0;d=d+1|0;i=w[(((h&1)+(i^-1)<<1)+g|0)+2400>>1];if((i|0)<0){continue}break};h=i&65535;break tb;case 3:break jb;case 4:break kb;case 5:break pb;case 6:break qb;case 2:break vb;default:break rb}}while(1){d=t-k|0;if(!((G-l|0)>1&(d|0)>=4)){if(e>>>0>14){break gb}if((d|0)<=1){d=0;continue fb}f=y[k|0]<<e|y[k+1|0]<<e+8|f;e=e+16|0;k=k+2|0;break gb}if(!(e>>>0>14)){f=(y[k|0]|y[k+1|0]<<8)<<e|f;k=k+2|0;e=e+16|0}r=e;h=w[(((f&1023)<<1)+g|0)+352>>1];xb:{if((h|0)<0){d=10;while(1){e=f>>>d|0;d=d+1|0;h=w[(((e&1)+(h^-1)<<1)+g|0)+2400>>1];if((h|0)<0){continue}break}h=h&65535;break xb}d=h>>>9|0}e=r-d|0;f=f>>>d|0;if(h&256){break sb}if(!(e>>>0>14)){f=(y[k|0]|y[k+1|0]<<8)<<e|f;k=k+2|0;e=e+16|0}r=e;i=w[(((f&1023)<<1)+g|0)+352>>1];yb:{if((i|0)<0){d=10;while(1){e=f>>>d|0;d=d+1|0;i=w[(((e&1)+(i^-1)<<1)+g|0)+2400>>1];if((i|0)<0){continue}break}i=i&65535;break yb}d=i>>>9|0}v[l|0]=h;e=r-d|0;f=f>>>d|0;if(!(i&256)){v[l+1|0]=i;l=l+2|0;continue}break}l=l+1|0;h=i;break sb}d=i>>>9|0;h=i&511}e=e-d|0;f=f>>>d|0;if(h>>>0>255){break sb}d=14;continue $}j=h&511;h=256;if((j|0)==256){break ba}d=j-257<<2;h=x[d+79408>>2];s=0;if(j-285>>>0<4294967276){break ib}s=x[d+79536>>2];if(s>>>0>e>>>0){d=15;continue $}d=3;continue}if(!h){h=-1;break nb}h=h-1|0;d=18;continue $}e=e-s|0;f=E>>>s|0;u=((-1<<s^-1)&E)+u|0;break ob}i=w[(((f&1023)<<1)+g|0)+3840>>1];zb:{if((i|0)<0){d=10;while(1){j=f>>>d|0;d=d+1|0;i=w[(((j&1)+(i^-1)<<1)+g|0)+5888>>1];if((i|0)<0){continue}break}j=i&65535;break zb}d=i>>>9|0;j=i&511}e=e-d|0;E=f>>>d|0;d=j<<2;u=x[d+79664>>2];s=0;if(j-30>>>0<4294967270){f=E;break ob}s=x[d+79792>>2];if(s>>>0<=e>>>0){break mb}d=17;continue $}O=l-I|0;d=(O-u&_)+I|0;if((d>>>0<l>>>0?l:d)+h>>>0>G>>>0){break lb}while(1){if(h>>>0>=3){v[l|0]=y[d|0];v[l+1|0]=y[d+1|0];v[l+2|0]=y[d+2|0];h=h-3|0;d=d+3|0;l=l+3|0;continue}break}if(!h){h=0;break nb}v[l|0]=y[d|0];if((h|0)!=1){v[l+1|0]=y[d+1|0]}l=h+l|0}d=2;continue}d=6;continue}d=7;continue}d=w[(((f&1023)<<1)+g|0)+3840>>1];Ab:{if((d|0)>=0){if(d>>>0<512|d>>>9>>>0>e>>>0){break Ab}break hb}if(e>>>0<11){break Ab}i=10;while(1){d=w[(((f>>>i&1)+(d^-1)<<1)+g|0)+5888>>1];if((d|0)<0){j=i+2|0;i=i+1|0;if(e>>>0>=j>>>0){continue}}break}if((d|0)>=0){break hb}}d=16;continue $}e=e-s|0;h=((-1<<s^-1)&f)+h|0;f=f>>>s|0}if(e>>>0>14){break hb}if((t-k|0)<=1){d=4;continue}f=y[k|0]<<e|y[k+1|0]<<e+8|f;e=e+16|0;k=k+2|0}d=5;continue}d=1;continue}}if(!h|!e){break ca}if(e>>>0>7){break da}d=5;continue}e=e-8|0;M=f>>>8|0;u=f&255;d=6;continue}if(h){break aa}h=0}if(v[g+20|0]&1){break t}d=0;continue}d=7;continue}}f=0;j=e&-8;d=e>>>3|0;e=k-F|0;e=e>>>0<=k>>>0?e:0;d=d>>>0<e>>>0?d:e;if((j|0)==d<<3){k=k-d|0;j=0;d=0;e=0;if(!(X&1)){break r}i=0;break s}aa(6842,13132,2797,6852);p()}while(1){Bb:{Cb:{Db:{Eb:{Fb:{switch(i|0){case 0:if(j>>>0>3){h=j;e=d;break r}e=0;if(!d){h=j;break Bb}if(d>>>0>7){break Eb}i=1;continue;case 1:break Fb;default:break Db}}while(1){if(k>>>0>=t>>>0){x[g>>2]=41;o=1;h=j;e=d;break i}f=y[k|0]<<d|f;n=d>>>0>4294967287;k=k+1|0;d=d+8|0;if(n){continue}break}}i=f&255;f=f>>>8|0;d=d-8|0;break Cb}if(k>>>0>=t>>>0){x[g>>2]=42;o=1;break i}i=y[k|0];k=k+1|0;j=h;d=e}x[g+16>>2]=x[g+16>>2]<<8|i;j=j+1|0;i=0;continue}i=2;continue}}o=0;i=34;break k}i=21;break k}i=17;break k}i=35;break k}i=10;break k}i=39;break k}h=1}x[g>>2]=i}d=e>>>3|0;j=k-F|0;j=k>>>0>=j>>>0?j:0;d=d>>>0<j>>>0?d:j;k=k-d|0;e=e-(d<<3)|0}x[g+4>>2]=e;x[g+60>>2]=O;x[g+40>>2]=s;x[g+36>>2]=h;x[g+32>>2]=u;x[g+56>>2]=(((e&63)>>>0<32?-1<<e:0)^-1)&f;x[B+12>>2]=k-F;e=l-N|0;x[B+8>>2]=e;if((o|0)<0){break g}k=(e>>>0)%5552|0;d=x[g+28>>2];f=d>>>16|0;i=d&65535;while(1){j=0;if(e){d=N;while(1){if((j|7)>>>0<k>>>0){h=y[d|0]+i|0;n=h+y[d+1|0]|0;r=n+y[d+2|0]|0;E=r+y[d+3|0]|0;M=E+y[d+4|0]|0;C=M+y[d+5|0]|0;l=C+y[d+6|0]|0;i=l+y[d+7|0]|0;f=i+(l+(C+(M+(E+(r+(n+(f+h|0)|0)|0)|0)|0)|0)|0)|0;d=d+8|0;j=j+8|0;continue}break}j=k&8184;while(1){if((k|0)!=(j|0)){j=j+1|0;i=y[d|0]+i|0;f=i+f|0;d=d+1|0;continue}break}e=e-k|0;f=(f>>>0)%65521|0;i=(i>>>0)%65521|0;N=k+N|0;k=5552;continue}break}d=f<<16|i;x[g+28>>2]=d;if(o){break g}o=0;if(!(X&1)){break g}o=(d|0)!=x[g+16>>2]?-2:0}ib=Z+144|0;x[g+43780>>2]=o;d=x[B+12>>2];x[q>>2]=d+x[q>>2];x[q+4>>2]=x[q+4>>2]-d;x[q+8>>2]=d+x[q+8>>2];x[q+48>>2]=x[g+28>>2];d=x[B+8>>2];x[g+10996>>2]=d;h=x[q+16>>2];d=d>>>0<h>>>0?d:h;rc(x[q+12>>2],x[g+10992>>2]+I|0,d);x[q+12>>2]=d+x[q+12>>2];x[q+16>>2]=x[q+16>>2]-d;x[q+20>>2]=d+x[q+20>>2];e=x[g+10996>>2];x[g+10996>>2]=e-d;f=d+x[g+10992>>2]&32767;x[g+10992>>2]=f;if((o|0)<0){break f}if(!((o|0)!=1|da)){h=-5;break e}if(o){h=0;j=x[q+4>>2];if(!j|!x[q+16>>2]){break e}if((d|0)==(e|0)){continue}break e}break}h=(d|0)==(e|0);break e}e=x[q+16>>2];d=d>>>0<e>>>0?d:e;rc(x[q+12>>2],(x[g+10992>>2]+g|0)+11012|0,d);x[q+12>>2]=d+x[q+12>>2];x[q+16>>2]=x[q+16>>2]-d;x[q+20>>2]=d+x[q+20>>2];e=x[g+10996>>2];x[g+10996>>2]=e-d;x[g+10992>>2]=d+x[g+10992>>2]&32767;if(x[g+43780>>2]){break e}h=(d|0)==(e|0);break e}h=-3}ib=B+16|0;d=x[m+1084>>2]-U|0;x[m+1084>>2]=d;j=K+ba|0;K=x[m+1104>>2];ba=j-K|0;continue}break}b=m+1088|0;Gb:{if(!b){break Gb}d=x[b+28>>2];if(!d){break Gb}lb[x[b+36>>2]](x[b+40>>2],d);x[b+28>>2]=0}d=0;Hb:{Ib:{if(!(x[m+1156>>2]!=($|0)|K|(h|0)!=1)){he(m+24|0,x[T>>2],x[T+4>>2]);b=Id(m+16|0);x[27524]=0;d=x[b+4>>2];x[m+8>>2]=x[b>>2];x[m+12>>2]=d;b=Mg(544,m+48|0,x[m+24>>2],x[m+28>>2],m+8|0);d=x[27524];x[27524]=0;if((d|0)==1){break Ib}x[27524]=0;d=W(876,a|0,b|0,c|0)|0;a=x[27524];x[27524]=0;if((a|0)==1){break Hb}yb(b)}ec(T);break a}a=P()|0;break c}a=P()|0;yb(b);break c}a=P()|0}ec(T);S(a|0);p()}ib=m+1168|0;return d|0}function pka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=E(0),C=0,F=0,G=0,H=0,I=0,J=0,K=0,L=E(0),M=0,N=0,O=E(0),Q=0,R=E(0),U=0,X=0,Y=0,$=0,aa=0,ba=0,ca=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=E(0);n=ib-96|0;ib=n;yc(c);a:{while(1){b:{if(!Ob(x[c>>2],x[c+8>>2],4)){break b}d=n+72|0;g=ib-16|0;ib=g;c:{if(!Ob(x[c>>2],x[c+8>>2],3)){F=0;while(1){if((F|0)!=3){Jh(d+F|0);F=F+1|0;continue}break}break c}Sv(g+8|0,d);sd(g,c,x[g+8>>2],x[g+12>>2])}ib=g+16|0;d:{e:{if(!Qb(d,15017,3)){d=n+24|0;g=ib-16|0;ib=g;f:{if(!Ob(x[c>>2],x[c+8>>2],7)){F=0;while(1){if((F|0)!=7){Jh(d+F|0);F=F+1|0;continue}break}break f}Lo(g+8|0,d);sd(g,c,x[g+8>>2],x[g+12>>2])}ib=g+16|0;F=0;g=3;while(1){if((g|0)==7){break d}d=v[(n+24|0)+g|0];if((d|0)<0){break e}g=g+1|0;F=d&255|F<<7;continue}}g:{if(Qb(n+72|0,14196,3)){break g}if(!vU(c,13518)){break g}Yb(c,Jg(c)+16|0);continue}if(!Qb(n+72|0,30238,3)){continue}if(!Qb(n+72|0,30242,3)){continue}if(!y[n+72|0]){Gg(c,2);continue}if(bS(n+72|0)){break b}}g=0;break a}Yb(c,F);continue}break}yc(c);g=n+72|0;tB(g,c);Y=x[n+72>>2];fa=Le(g);M=Nb(n+56|0);x[27524]=0;aa=T(578,n+48|0)|0;c=x[27524];x[27524]=0;h:{i:{j:{if((c|0)!=1){Pz(Rb(x[aa>>2],0,6668));x[n+40>>2]=0;x[n+44>>2]=0;x[n+32>>2]=0;x[n+36>>2]=0;x[n+24>>2]=0;x[n+28>>2]=0;x[27524]=0;ba=T(579,n+8|0)|0;c=x[27524];x[27524]=0;k:{if((c|0)!=1){F=0;c=0;while(1){G=x[aa>>2];j=fa;e=Dc(Y,$);U=x[ba>>2];d=0;m=0;r=ib-17168|0;ib=r;x[r+17164>>2]=0;l:{m:{n:{if(y[G+6152|0]!=255|(e|0)<5){break n}if(!Cp(G+6152|0,j)){break n}g=Ix(y[j+1|0],y[j+2|0],x[G+6148>>2])+Bp(j)|0;x[r+17164>>2]=g;if((e|0)==(g|0)){g=e;break m}o:{if((e|0)>=(g+4|0)){if(Cp(j,g+j|0)){break o}}x[r+17164>>2]=0;break n}if(g){break m}}h=j;C=Rb(G,0,6668)+6148|0;I=r+17164|0;s=e-4|0;k=(s|0)>0?s:0;while(1){p:{q:{r:{s:{if((k|0)==(m|0)){m=e;break s}if(!ZI(h)){break q}i=Ix(y[h+1|0],y[h+2|0],x[C>>2]);g=i+Bp(h)|0;f=4;o=m+4|0;t:{while(1){if(!(f>>>0>2303|i)){if((s|0)<=((f<<1)+m|0)){break t}i=0;q=f+h|0;u:{if(!Cp(h,q)){break u}l=f-Bp(h)|0;u=Bp(q)+l|0;if((e|0)<(u+(f+o|0)|0)){break u}if(!Cp(h,q+u|0)){break u}x[C>>2]=l;i=l;g=f}f=f+1|0;continue}break}if(!i|(e|0)<(g+m|0)){break t}q=e-m|0;f=0;o=0;while(1){v:{w:{if((o|0)!=10){l=(o|0)!=0;J=f;f=f+h|0;f=(J+Ix(y[f+1|0],y[f+2|0],i)|0)+Bp(f)|0;if((q|0)<(f+4|0)){break v}if(Cp(h,f+h|0)){break w}l=0}else{l=1}break v}o=o+1|0;continue}break}if(!l){break t}d=g;break s}if((e|0)!=(g|0)|m){break r}m=0;d=e}x[I>>2]=d;d=m;break p}x[C>>2]=0}h=h+1|0;m=m+1|0;continue}break}g=x[r+17164>>2];if((e|0)>=(d+g|0)?g:0){break m}x[n+24>>2]=d;o=0;break l}u=d+j|0;x[G+6152>>2]=y[u|0]|y[u+1|0]<<8|(y[u+2|0]<<16|y[u+3|0]<<24);x[n+28>>2]=d;x[n+24>>2]=d+g;x[n+32>>2]=y[u+3|0]>191?1:2;ra=n,sa=aJ(y[u+1|0],y[u+2|0]),x[ra+36>>2]=sa;x[n+40>>2]=4-(y[u+1|0]>>>1&3);ra=n,sa=Hx(y[u+1|0],y[u+2|0]),x[ra+44>>2]=sa;if(!U){o=Gx(y[u+1|0]);break l}$I(r+17152|0,u+4|0,g-4|0);if(!(v[u+1|0]&1)){je(r+17152|0,16)}x:{if(x[n+40>>2]==3){o=0;d=r+17152|0;ja=r+3740|0;g=ja;h=0;e=y[u+1|0];f=D((e>>>3&1)+(e>>>4&1)|0,3)+(y[u+2|0]>>>2&3)|0;f=f-((f|0)!=0)|0;m=y[u+3|0]>191?1:2;y:{if(e&8){i=je(d,9);m=m<<1;h=je(d,m+7|0);break y}i=je(d,m|8)>>>m|0}e=D(f,40);C=e+80256|0;s=e+80576|0;q=D(f,23)+80064|0;j=-1;l=0;z:{while(1){e=y[u+3|0];I=je(d,12);w[g+4>>1]=I;f=je(d,9);w[g+6>>1]=f;if((f&65535)>>>0>288){break z}f=e>>>0>191?h<<4:h;ra=g,sa=je(d,8),v[ra+10|0]=sa;e=je(d,y[u+1|0]&8?4:9);v[g+13|0]=22;v[g+14|0]=0;x[g>>2]=q;w[g+8>>1]=e;A:{if(je(d,1)){e=je(d,2);v[g+11|0]=e;if(!(e&255)){break z}e=je(d,1);w[g+18>>1]=65287;v[g+12|0]=e;if(y[g+11|0]==2){B:{if(!(e&255)){x[g>>2]=C;v[g+18|0]=8;h=0;e=39;break B}x[g>>2]=s;h=y[u+1|0]&8?8:6;e=30}v[g+14|0]=e;v[g+13|0]=h;f=f&3855}e=je(d,10);ra=g,sa=je(d,3),v[ra+21|0]=sa;ra=g,sa=je(d,3),v[ra+22|0]=sa;ra=g,sa=je(d,3),v[ra+23|0]=sa;h=e<<5;break A}v[g+11|0]=0;v[g+12|0]=0;h=je(d,15);ra=g,sa=je(d,4),v[ra+18|0]=sa;e=je(d,3);v[g+20|0]=255;v[g+19|0]=e}v[g+17|0]=h&31;v[g+15|0]=h>>>10;v[g+16|0]=h>>>5&31;l=(I&65535)+l|0;C:{if(y[u+1|0]&8){e=je(d,1);break C}e=z[g+8>>1]>499}v[g+24|0]=e;ra=g,sa=je(d,1),v[ra+25|0]=sa;e=je(d,1);v[g+27|0]=f>>>12&15;v[g+26|0]=e;g=g+28|0;h=f<<4;m=m-1|0;if(m){continue}break}j=(x[d+4>>2]+l|0)>(x[d+8>>2]+(i<<3)|0)?-1:i}if(!((j|0)<0|x[r+17156>>2]>x[r+17160>>2])){g=r+17152|0;f=x[g+4>>2];m=x[g+8>>2];h=r+912|0;d=x[G+6144>>2];e=d-j|0;d=(d|0)<(j|0)?d:j;e=rc(h+12|0,(((e|0)>0?e:0)+G|0)+6156|0,d);i=x[g>>2]+(x[g+4>>2]/8|0)|0;g=(m-f|0)/8|0;rc(d+e|0,i,g);$I(h,e,d+g|0);D:{g=x[G+6144>>2]>=(j|0);if(!g){break D}ma=G+2304|0;na=r+8620|0;oa=r+3852|0;while(1){if((y[u+1|0]&8?2:1)>>>0<=o>>>0){break D}pa=Rb(oa,0,4608);e=x[n+32>>2];m=D(D(e,o),28)+ja|0;d=0;ka=(e|0)>0?e:0;C=r+912|0;I=C+7548|0;X=G+6152|0;while(1){if((d|0)!=(ka|0)){j=D(d,28)+m|0;J=z[j+4>>1];Q=x[C+4>>2];t=(C+D(d,39)|0)+16156|0;e=I;s=d;f=ib-48|0;ib=f;d=j;K=y[d+25|0];H=D(!y[d+13|0]+(y[d+14|0]!=0)|0,28)+80896|0;E:{if(y[X+1|0]&8){i=y[d+27|0];j=y[z[d+8>>1]+80992|0];h=j&3;v[f+47|0]=h;v[f+46|0]=h;j=j>>>2|0;v[f+45|0]=j;v[f+44|0]=j;break E}j=(y[X+3|0]&16)>>>4&(s|0)!=0;k=j?12:0;h=z[d+8>>1]>>>j|0;while(1){if((h|0)>=0){i=3;j=1;while(1){if((i|0)>=0){l=y[(i+k|0)+81008|0];v[(f+44|0)+i|0]=((h|0)/(j|0)|0)%(l|0);i=i-1|0;j=D(j,l);continue}break}k=k+4|0;h=h-j|0;continue}break}H=k+H|0;i=-16}j=f;ca=f+44|0;h=0;while(1){F:{G:{H:{if((h|0)==4){break H}q=y[h+H|0];if(!q){break H}if(i&8){rc(j,t,q);break G}k=y[h+ca|0];if(!k){Rb(j,0,q);Rb(t,0,q);break G}ea=(i|0)>=0?-1:-1<<k^-1;l=0;while(1){if((l|0)==(q|0)){break G}N=je(C,k);v[l+t|0]=(N|0)==(ea|0)?-1:N;v[j+l|0]=N;l=l+1|0;continue}}v[j+2|0]=0;v[j|0]=0;v[j+1|0]=0;break F}i=i<<1;h=h+1|0;j=j+q|0;t=q+t|0;continue}break}I:{j=y[d+14|0];if(j){h=2-K|0;l=y[d+23|0]<<h;q=y[d+22|0]<<h;k=y[d+21|0]<<h;t=y[d+13|0];i=0;while(1){if(i>>>0>=j>>>0){break I}h=f+(i+t|0)|0;v[h|0]=k+y[h|0];v[h+1|0]=q+y[h+1|0];v[h+2|0]=l+y[h+2|0];i=i+3|0;continue}}if(!y[d+24|0]){break I}i=0;while(1){if((i|0)==10){break I}h=f+i|0;v[h+11|0]=y[h+11|0]+y[i+81032|0];i=i+1|0;continue}}h=K+1|0;i=0;A=Fx(E(2048),((((y[X+3|0]&224)==96)<<1)-y[d+10|0]|0)+258|0);while(1){if(y[d+13|0]+(j&255)>>>0>i>>>0){ra=e+(i<<2)|0,ta=Fx(A,y[f+i|0]<<h),B[ra>>2]=ta;i=i+1|0;j=y[d+14|0];continue}break}ib=f+48|0;l=(C+D(s,2304)|0)+2940|0;i=e;ca=J+Q|0;A=E(0);j=x[C+4>>2];e=x[C>>2]+((j|0)/8|0)|0;f=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);f=(f<<24|f<<8&16711680|(f>>>8&65280|f>>>24))<<(j&7);k=j|-8;t=e+4|0;q=d;H=x[d>>2];K=z[d+6>>1];e=0;while(1){J:{K:{if((K|0)>0){j=e+1|0;e=e+q|0;d=y[e+15|0];ea=(w[(d<<1)+85456>>1]<<1)+81072|0;N=y[e+18|0];if(d>>>0>=16){ga=y[d+85520|0];qa=32-ga|0;while(1){ha=y[H|0]>>>1|0;ia=(K|0)<(ha|0)?K:ha;A=B[i>>2];while(1){e=f>>>27|0;d=5;while(1){e=w[ea+(e<<1)>>1];if((e|0)<0){f=f<<d;h=e&7;e=(f>>>32-h|0)-(e>>3)|0;k=d+k|0;d=h;continue}break}h=e&65535;d=h>>>8|0;k=d+k|0;f=f<<d;d=0;while(1){if((d|0)!=2){J=h&15;L:{if((J|0)==15){k=k+ga|0;e=f<<ga;while(1){if((k|0)>=0){e=y[t|0]<<k|e;t=t+1|0;k=k-8|0;continue}break}L=A;J=(f>>>qa|0)+15|0;f=J;M:{if((f|0)<=128){R=B[(f<<2)+85616>>2];break M}la=f>>>0<1024;f=la?f<<3:f;Q=f<<1&64;O=E(E((f&63)-Q|0)/E(Q+(f&-64)|0));R=E((la?E(16):E(256))*E(E(E(O*E(E(O*E(.2222222238779068))+E(1.3333333730697632)))+E(1))*B[(f+Q>>6<<2)+85616>>2]))}L=E(E(L*R)*E(e>>31|1));break L}e=f;L=E(A*B[(((e>>>27&16|J)^16)<<2)+85552>>2])}B[l>>2]=L;h=h>>>4|0;l=l+4|0;d=d+1|0;f=(J|0)!=0;k=f+k|0;f=e<<f;continue}break}while(1){if((k|0)>=0){f=y[t|0]<<k|f;t=t+1|0;k=k-8|0;continue}break}ia=ia-1|0;if(ia){continue}break}i=i+4|0;H=H+1|0;K=K-ha|0;if((K|0)<=0){break K}d=(N|0)>0;N=N-1|0;if(d){continue}break}break K}while(1){Q=y[H|0]>>>1|0;J=(K|0)<(Q|0)?K:Q;A=B[i>>2];while(1){e=f>>>27|0;d=5;while(1){e=w[ea+(e<<1)>>1];if((e|0)<0){f=f<<d;h=e&7;e=(f>>>32-h|0)-(e>>3)|0;k=d+k|0;d=h;continue}break}d=e&65535;e=d>>>8|0;k=e+k|0;f=f<<e;e=0;while(1){if((e|0)!=2){h=d&15;B[l>>2]=A*B[(((h|f>>>27&16)^16)<<2)+85552>>2];d=d>>>4|0;l=l+4|0;e=e+1|0;h=(h|0)!=0;k=h+k|0;f=f<<h;continue}break}while(1){if((k|0)>=0){f=y[t|0]<<k|f;t=t+1|0;k=k-8|0;continue}break}J=J-1|0;if(J){continue}break}i=i+4|0;H=H+1|0;K=K-Q|0;if((K|0)<=0){break K}d=(N|0)>0;N=N-1|0;if(d){continue}break}break K}d=1-K|0;while(1){N:{j=y[q+26|0]?85440:85408;e=y[j+(f>>>28|0)|0];if(!(e&8)){e=y[j+((f<<4>>>32-(e&3))+(e>>>3)|0)|0]}j=e&7;k=j+k|0;if((ca|0)<((k+(t-x[C>>2]<<3)|0)-24|0)){break N}d=d-1|0;if(!d){d=y[H|0];if(d>>>0<2){break N}H=H+1|0;A=B[i>>2];i=i+4|0;d=d>>>1|0}f=f<<j;if(e>>>0>=128){B[l>>2]=(f|0)<0?E(-A):A;k=k+1|0;f=f<<1}if(e&64){B[l+4>>2]=(f|0)<0?E(-A):A;k=k+1|0;f=f<<1}d=d-1|0;if(!d){d=y[H|0];if(d>>>0<2){break N}H=H+1|0;A=B[i>>2];i=i+4|0;d=d>>>1|0}if(e&32){B[l+8>>2]=(f|0)<0?E(-A):A;k=k+1|0;f=f<<1}if(e&16){B[l+12>>2]=(f|0)<0?E(-A):A;k=k+1|0;f=f<<1}while(1){if((k|0)>=0){f=y[t|0]<<k|f;t=t+1|0;k=k-8|0;continue}break}l=l+16|0;continue}break}x[C+4>>2]=ca;break J}e=j;continue}break}d=s+1|0;continue}break}d=y[G+6155|0];O:{if(d&16){s=C+16195|0;d=0;l=ib-16|0;ib=l;j=C+2940|0;i=j+2304|0;I=x[m>>2];k=y[m+14|0];q=k+y[m+13|0]|0;e=l+4|0;x[e+8>>2]=-1;x[e>>2]=-1;x[e+4>>2]=-1;while(1){if((d|0)!=(q|0)){t=d+I|0;h=y[t|0];f=0;P:{while(1){if(f>>>0>=h>>>0){break P}H=f<<2;if(B[H+i>>2]==E(0)){f=f+2|0;if(B[(H|4)+i>>2]==E(0)){continue}}break}x[e+((d>>>0)%3<<2)>>2]=d;h=y[t|0]}d=d+1|0;i=(h<<2)+i|0;continue}break}if(y[m+13|0]){d=x[l+4>>2];e=x[l+8>>2];d=(d|0)>(e|0)?d:e;e=x[l+12>>2];d=(d|0)>(e|0)?d:e;x[l+12>>2]=d;x[l+8>>2]=d;x[l+4>>2]=d}e=k?3:1;h=q-e|0;d=0;while(1){if((d|0)!=(e|0)){i=d+h|0;f=i-e|0;if((f|0)<=x[(l+4|0)+(d<<2)>>2]){f=y[X+1|0]<<28>>31&3}else{f=y[f+s|0]}v[i+s|0]=f;d=d+1|0;continue}break}h=x[m>>2];q=l+4|0;I=w[m+36>>1]&1;i=0;k=y[X+1|0]&8?7:64;while(1){t=h+i|0;e=y[t|0];if(e){f=y[X+3|0]&32;Q:{R:{if(x[q+((i>>>0)%3<<2)>>2]>=(i|0)){break R}d=y[i+s|0];if(d>>>0>=k>>>0){break R}L=f?E(1.4142135381698608):E(1);S:{if(y[X+1|0]&8){d=d<<3;A=B[d+86148>>2];R=B[d+86144>>2];break S}O=Fx(E(1),d+1>>>1<<I);d=d&1;A=d?E(1):O;R=d?O:E(1)}O=E(L*R);L=E(L*A);d=0;while(1){if((d|0)!=(e|0)){f=(d<<2)+j|0;A=B[f>>2];B[f+2304>>2]=A*L;B[f>>2]=A*O;d=d+1|0;continue}break}break Q}if(!f){break Q}YI(j,e)}i=i+1|0;j=(y[t|0]<<2)+j|0;continue}break}ib=l+16|0;break O}if((d&224)!=96){break O}YI(C+2940|0,576)}j=C+7708|0;d=0;while(1){if((d|0)!=(ka|0)){e=y[G+6153|0];s=(y[m+12|0]!=0)<<1<<((D((e>>>3&1)+(e>>>4&1)|0,3)+(y[G+6154|0]>>>2&3)|0)==2);l=(C+D(d,2304)|0)+2940|0;i=l;if(y[m+14|0]){h=x[m>>2]+y[m+13|0]|0;t=((C+D(d,2304)|0)+D(s,72)|0)+2940|0;e=t;f=j;while(1){q=y[h|0];if(q){k=q<<1;I=0;while(1){if((q|0)!=(I|0)){B[f>>2]=B[e>>2];B[f+4>>2]=B[(q<<2)+e>>2];B[f+8>>2]=B[(k<<2)+e>>2];e=e+4|0;I=I+1|0;f=f+12|0;continue}break}h=h+3|0;e=(k<<2)+e|0;continue}break}rc(t,j,f-j|0);f=s-1|0}else{f=31}while(1){e=0;if((f|0)>0){while(1){if((e|0)!=8){h=e<<2;q=h+i|0;A=B[q+72>>2];O=B[h+86208>>2];L=B[h+86240>>2];h=(17-e<<2)+i|0;R=B[h>>2];B[q+72>>2]=E(A*O)-E(L*R);B[h>>2]=E(A*L)+E(R*O);e=e+1|0;continue}break}i=i+72|0;f=f-1|0;continue}break}e=l;f=D(d,1152)+G|0;h=y[m+11|0];if(s){XI(e,f,86272,s);f=D(s,36)+f|0;e=D(s,72)+e|0}T:{if((h|0)==2){i=32-s|0;h=ib-80|0;ib=h;q=h|8;I=h|4;while(1){if((i|0)>0){s=rc(h,e,72);k=x[f+20>>2];x[e+16>>2]=x[f+16>>2];x[e+20>>2]=k;k=x[f+12>>2];x[e+8>>2]=x[f+8>>2];x[e+12>>2]=k;k=x[f+4>>2];x[e>>2]=x[f>>2];x[e+4>>2]=k;J=s;s=f+24|0;Ex(J,e+24|0,s);Ex(I,e+48|0,s);Ex(q,f,s);e=e+72|0;f=f+36|0;i=i-1|0;continue}break}ib=h+80|0;break T}XI(e,f,D((h|0)==3,72)+86272|0,32-s|0)}h=0;i=l+72|0;while(1){e=1;if(h>>>0<=31){while(1){if(e>>>0<=17){f=(e<<2)+i|0;B[f>>2]=-B[f>>2];e=e+2|0;continue}break}i=i+144|0;h=h+2|0;continue}break}m=m+28|0;d=d+1|0;continue}break}_I(ma,pa,18,x[n+32>>2],U,na);o=o+1|0;U=D(x[n+32>>2],1152)+U|0;continue}}e=r+912|0;m=x[e+8>>2]>>>3|0;j=x[e+4>>2]+7>>>3|0;d=m-j|0;f=(d|0)>=511?511:d;if((d|0)>0){Wi(G+6156|0,(e+(d>>>0>511?m-511|0:j)|0)+12|0,f)}x[G+6144>>2]=f;break x}Pz(G);break l}j=r+17152|0;o=0;m=0;i=0;e=r;d=0;U:{V:{W:{g=y[u+3|0];h=g>>>6|0;switch(h-1|0){case 2:break U;case 0:break W;default:break V}}d=(g>>>2&12)+4|0;break U}d=32}g=y[u+1|0];X:{if((g&6)==6){g=32;f=87676;break X}if(!(g&8)){g=30;f=87679;break X}l=y[u+2|0];f=l>>>2&3;g=Hx(g,l)>>>((h|0)!=3)|0;g=g?g:192;if(g>>>0<=55){g=(f|0)==2?12:8;f=87700;break X}g=g>>>0<=95?27:(f|0)!=1?30:27;f=87688}v[e+768|0]=g;v[e+769|0]=(d|0)<(g|0)?d:g;g=f;f=87584;while(1){d=y[e+768|0];if(o>>>0>=d>>>0){o=0;while(1){f=d<<1&510;if(f>>>0>o>>>0){f=e+o|0;Y:{if(!y[f+770|0]){g=6;break Y}g=2;if((y[u+1|0]&6)==6){break Y}g=je(j,2);d=y[e+768|0]}v[f+834|0]=g;o=o+1|0;continue}break}m=e+770|0;h=e+834|0;g=0;i=f;while(1){if((g|0)!=(i|0)){l=y[m|0];f=l?19>>>y[g+h|0]&3|4:0;m=m+1|0;l=D(l,3)-6|0;A=E(0);d=4;while(1){if(d){if(d&f){C=je(j,6);s=(C|0)/3|0;A=E(B[(l+(D(s,-3)+C|0)<<2)+87712>>2]*E(2097152>>>s|0))}B[e>>2]=A;d=d>>>1|0;e=e+4|0;continue}break}g=g+1|0;continue}break}o=y[r+769|0];g=y[r+768|0];g=g>>>0<o>>>0?o:g;while(1){if((g|0)!=(o|0)){v[((o<<1)+r|0)+771|0]=0;o=o+1|0;continue}break}}else{if((i|0)==(o|0)){f=y[g|0]+87584|0;i=y[g+2|0]+o|0;m=y[g+1|0];g=g+3|0}h=o<<1;d=y[je(j,m)+f|0];v[(h+e|0)+770|0]=d;l=y[e+769|0];if(l>>>0>o>>>0){d=y[je(j,m)+f|0];l=y[e+769|0]}v[((h|1)+e|0)+770|0]=l?d:0;o=o+1|0;continue}break}g=0;e=Rb(r+3852|0,0,4608);I=G+2304|0;k=r+8620|0;o=0;Z:{while(1){if((o|0)==3){break Z}u=e+(g<<2)|0;C=r+17152|0;h=0;l=x[n+40>>2]|1;s=(l|0)>0?l:0;j=576;while(1){if((h|0)!=4){m=u+(D(h,l)<<2)|0;f=0;while(1){if(y[r+768|0]<<1>>>0>f>>>0){_:{i=y[(f+r|0)+770|0];if(!i){break _}if(i>>>0<=16){q=(-1<<i-1)+1|0;d=0;while(1){if((d|0)==(s|0)){break _}ra=(d<<2)+m|0,ta=E(je(C,i)+q|0),B[ra>>2]=ta;d=d+1|0;continue}}d=2<<i-17;i=je(C,(d-(d>>>3|0)|0)+3|0);t=d>>>1|0;q=d|1;d=0;while(1){if((d|0)==(s|0)){break _}J=i;i=(i>>>0)/(q>>>0)|0;B[(d<<2)+m>>2]=J-(t+D(q,i)|0)|0;d=d+1|0;continue}}f=f+1|0;m=(j<<2)+m|0;j=18-j|0;continue}break}h=h+1|0;continue}break}g=(l<<2)+g|0;if((g|0)==12){d=(o<<2)+r|0;g=e;f=y[r+769|0];m=e+D(f,72)|0;rc(m+2304|0,m,D(y[r+768|0]-f|0,72));m=0;while(1){if(y[r+768|0]>m>>>0){h=0;while(1){if((h|0)!=12){f=(h<<2)+g|0;B[f>>2]=B[d>>2]*B[f>>2];f=f+2304|0;B[f>>2]=B[d+12>>2]*B[f>>2];h=h+1|0;continue}break}d=d+24|0;g=g+72|0;m=m+1|0;continue}break}_I(I,e,12,x[n+32>>2],U,k);Rb(e,0,4608);U=D(x[n+32>>2],768)+U|0;g=0}o=o+1|0;if(x[r+17156>>2]<=x[r+17160>>2]){continue}break}Pz(G);o=0;break l}g=1}o=D(Gx(y[G+6153|0]),g)}ib=r+17168|0;g=x[n+24>>2];if((g|0)<0|!g&(o|0)!=0|!(g|o)){break h}if(g){d=x[n+36>>2];if((d|0)!=(F|0)?F:0){break h}g=x[n+32>>2];if((g|0)!=(c|0)?c:0){break h}if(g-3>>>0<4294967294|(d|0)<=0){break i}x[n+4>>2]=0;ra=n,sa=Dc(Y,$),x[ra>>2]=sa;c=x[Oj(n+24|0,n+4|0,n)>>2];x[n+4>>2]=0;ra=n,sa=Dc(Y,$),x[ra>>2]=sa;fa=c+fa|0;c=Y;e=x[Oj(n+24|0,n+4|0,n)>>2];Y=c-e|0;$=$-((e>>31)+(c>>>0<e>>>0)|0)|0;$:{if(!o){break $}c=x[ba>>2];x[27524]=0;W(580,M|0,c|0,c+(D(g,o)<<1)|0)|0;c=x[27524];x[27524]=0;if((c|0)!=1){break $}F=V(108196)|0;if((jb|0)==(da(108196)|0)){_(F|0)|0;x[27524]=0;Z(18);e=x[27524];x[27524]=0;c=g;F=d;if((e|0)!=1){break h}F=P()|0}jd(ba);break k}F=d;c=g}if((Oc(x[M>>2],x[M+4>>2])>>>0)/(c>>>0)>>>0>268435456){break h}if(!!Y&($|0)>=0|($|0)>0){continue}break}break h}F=P()|0}EQ(aa);break j}F=P()|0}jd(M);Rc(n+72|0);S(F|0);p()}c=g;F=d}g=0;aa:{if(!F|!c){break aa}d=x[M>>2];e=x[M+4>>2];if(pc(d,e)){break aa}if((Oc(d,e)>>>0)/(c>>>0)>>>0>268435456){break aa}Kt(a,b);b=D(b,104)+a|0;a=b+484380|0;ra=a,sa=(Oc(x[M>>2],x[M+4>>2])>>>0)/(c>>>0)|0,x[ra>>2]=sa;d=b+484414|0;g=z[d>>1];w[d>>1]=(c|0)==2?g|65:g&65470|1;Xg(a);b=b+484400|0;g=_d(x[a>>2],x[b>>2]);if(!g){break aa}co(Cb(x[M>>2]),Cb(x[M+4>>2]),x[b>>2]);g=_d(x[a>>2],x[a+20>>2])}jd(ba);EQ(aa);jd(M);Rc(n+72|0)}ib=n+96|0;return g|0}function _A(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=E(0),u=0,C=0,G=0,H=0,I=E(0),K=0,L=0,M=0,N=0,O=E(0);s=ib-1520|0;ib=s;e=s+8|0;M=Rb(e,0,1512),N=-1,x[M+1420>>2]=N;v[s+56|0]=1;x[s+48>>2]=a+b;x[s+40>>2]=a;m=ib-1024|0;ib=m;v[e+1377|0]=1;a:{if(!Cs(e)){break a}b=y[e+1375|0];if(!(b&2)){fc(e,34);break a}if(b&4){fc(e,34);break a}if(b&1){fc(e,34);break a}if(x[e+1116>>2]!=1){fc(e,34);break a}b=y[e+1120|0];if((b|0)!=30){b:{if((b|0)!=64){break b}if(!Bx(e,m+1018|0,6)|y[m+1018|0]!=102|(y[m+1019|0]!=105|y[m+1020|0]!=115)){break b}if(y[m+1021|0]!=104|y[m+1022|0]!=101|y[m+1023|0]!=97){break b}if((df(e)|0)!=100){break b}if(df(e)){break b}fc(e,38);break a}fc(e,34);break a}if((df(e)|0)!=1){fc(e,34);break a}if(!Bx(e,m+1018|0,6)){fc(e,10);break a}if(!zx(m+1018|0)){fc(e,34);break a}if(mj(e)){fc(e,34);break a}b=df(e);x[e+4>>2]=b;if(!b){fc(e,34);break a}if(b>>>0>=17){fc(e,5);break a}b=mj(e);x[e>>2]=b;if(!b){fc(e,34);break a}mj(e);mj(e);mj(e);b=df(e);j=b>>>4|0;x[e+116>>2]=1<<j;h=b&15;x[e+112>>2]=1<<h;if(h-14>>>0<=4294967287){fc(e,20);break a}if((b<<24)+536870912>>24>=0){fc(e,20);break a}c:{if(h>>>0>j>>>0){fc(e,20);break c}if(!(df(e)&1)){fc(e,34);break c}if(!Cs(e)){break a}if(!Ax(e)){break a}if(!Cx(e)){break a}if((Ch(e)|0)==3){while(1){if((f|0)!=6){M=(m+1018|0)+f|0,N=Ch(e),v[M|0]=N;f=f+1|0;continue}break}if(!zx(m+1018|0)){fc(e,20);break c}b=yx(e);f=ie(e,b+1|0);x[e+20>>2]=f;if(f){f=0;h=(b|0)>0?b:0;while(1){if((f|0)!=(h|0)){j=Ch(e);v[x[e+20>>2]+f|0]=j;f=f+1|0;continue}break}v[b+x[e+20>>2]|0]=0;b=yx(e);x[e+28>>2]=0;x[e+24>>2]=b;d:{if((b|0)<=0){break d}b=ie(e,b<<2);x[e+28>>2]=b;if(b){break d}fc(e,3);break c}while(1){e:{f:{if(x[e+24>>2]>(g|0)){b=yx(e);f=ie(e,b+1|0);h=g<<2;x[h+x[e+28>>2]>>2]=f;if(!x[h+x[e+28>>2]>>2]){break f}f=0;j=(b|0)>0?b:0;while(1){if((f|0)==(j|0)){break e}i=Ch(e);v[x[h+x[e+28>>2]>>2]+f|0]=i;f=f+1|0;continue}}if(!(Ch(e)&1)){fc(e,20);break c}LI(e,y[e+1376|0]);v[e+1376|0]=0;while(1){b=Cx(e);LI(e,b);v[e+1376|0]=0;if(b){continue}break}f=0;if(!Ax(e)){break a}if(!TI(e)){if(x[e+100>>2]!=21){break a}x[e+100>>2]=20;break a}b=0;while(1){if((b|0)!=256){j=b<<24;h=0;while(1){if((h|0)!=8){j=j>>31&79764919^j<<1;h=h+1|0;continue}break}x[(b<<2)+478976>>2]=j;b=b+1|0;continue}break}if((Ch(e)|0)==5){while(1){if((f|0)!=6){M=(m+1018|0)+f|0,N=Ch(e),v[M|0]=N;f=f+1|0;continue}break}if(!zx(m+1018|0)){fc(e,20);break c}b=nc(e,8)+1|0;x[e+120>>2]=b;b=ie(e,D(b,2096));x[e+124>>2]=b;if(!b){fc(e,3);break c}Rb(b,0,D(x[e+120>>2],2096));g:{h:{while(1){i:{if(x[e+120>>2]>(C|0)){b=x[e+124>>2];if((nc(e,8)&255)!=66){fc(e,20);break c}if((nc(e,8)&255)!=67){fc(e,20);break c}if((nc(e,8)&255)!=86){fc(e,20);break c}h=b+D(C,2096)|0;M=h,N=nc(e,8)&255|nc(e,8)<<8,x[M>>2]=N;M=h,N=nc(e,8)&255|(nc(e,8)<<8&65280|nc(e,8)<<16),x[M+4>>2]=N;n=h+4|0;f=0;k=nc(e,1);if(!k){f=nc(e,1)}v[h+23|0]=f;g=x[n>>2];if(x[h>>2]){b=g;break i}b=0;if(!g){break i}fc(e,20);break c}b=nc(e,6)+1&255;f=0;j:{while(1){if((b|0)==(f|0)){break j}f=f+1|0;if(!nc(e,16)){continue}break}fc(e,20);break c}b=nc(e,6)+1|0;x[e+128>>2]=b;b=ie(e,D(b,1596));x[e+260>>2]=b;k:{if(b){C=0;k=0;l:while(1){if(x[e+128>>2]<=(k|0)){break k}b=nc(e,16);w[((k<<1)+e|0)+132>>1]=b;b=b&65535;if(b>>>0>=2){fc(e,20);break c}if(!b){b=x[e+260>>2]+D(k,1596)|0;M=b,N=nc(e,8),v[M|0]=N;M=b,N=nc(e,16),w[M+2>>1]=N;M=b,N=nc(e,16),w[M+4>>1]=N;M=b,N=nc(e,6),v[M+6|0]=N;M=b,N=nc(e,8),v[M+7|0]=N;j=nc(e,4)+1|0;v[b+8|0]=j;g=b+9|0;f=0;while(1){if((j&255)>>>0>f>>>0){M=f+g|0,N=nc(e,8),v[M|0]=N;f=f+1|0;j=y[b+8|0];continue}break}fc(e,4);break c}f=x[e+260>>2]+D(k,1596)|0;b=nc(e,5);v[f|0]=b;n=f+1|0;j=0;h=-1;while(1)if((b&255)>>>0<=j>>>0){g=h+1|0;h=f+82|0;i=f+65|0;o=f+49|0;l=f+33|0;b=0;m:{while(1){if((b|0)!=(g|0)){M=b+l|0,N=nc(e,3)+1|0,v[M|0]=N;r=b+o|0;q=nc(e,2);v[r|0]=q;j=0;if(q&255){q=nc(e,8);v[b+i|0]=q;if(x[e+120>>2]<=(q&255)){break m}}while(1){if(1<<y[r|0]>(j|0)){q=nc(e,8)-1|0;w[(h+(b<<4)|0)+(j<<1)>>1]=q;j=j+1|0;if(x[e+120>>2]>q<<16>>16){continue}break m}break}b=b+1|0;continue}break}h=2;M=f,N=nc(e,2)+1|0,v[M+1588|0]=N;b=nc(e,4);x[f+1592>>2]=2;g=0;w[f+338>>1]=0;v[f+1589|0]=b;w[f+340>>1]=1<<b;b=f+338|0;i=0;while(1){if(y[f|0]>i>>>0){o=l+y[i+n|0]|0;j=0;while(1){if(y[o|0]>j>>>0){h=nc(e,y[f+1589|0]);w[b+(x[f+1592>>2]<<1)>>1]=h;h=x[f+1592>>2]+1|0;x[f+1592>>2]=h;j=j+1|0;continue}break}i=i+1|0;continue}break}while(1){if((h|0)>(g|0)){h=z[b+(g<<1)>>1];j=(m+16|0)+(g<<2)|0;w[j+2>>1]=g;w[j>>1]=h;g=g+1|0;h=x[f+1592>>2];continue}break}KI(m+16|0,h,1118);h=x[f+1592>>2];g=((h|0)<=1?1:h)-1|0;j=0;while(1){if((g|0)==(j|0)){g=f+838|0;j=0;while(1)if((h|0)<=(j|0)){r=f+1088|0;j=2;while(1){if((h|0)>(j|0)){x[m+12>>2]=0;x[m+8>>2]=0;h=0;q=(j|0)>0?j:0;i=b+(j<<1)|0;n=65536;l=-1;while(1){if((h|0)!=(q|0)){o=b+(h<<1)|0;g=z[o>>1];if(!((l|0)>=(g|0)|z[i>>1]<=g>>>0)){x[m+12>>2]=h;g=z[o>>1];l=g}if(!((g|0)>=(n|0)|z[i>>1]>=g>>>0)){x[m+8>>2]=h;n=z[o>>1]}h=h+1|0;continue}break}g=r+(j<<1)|0;v[g|0]=x[m+12>>2];v[g+1|0]=x[m+8>>2];j=j+1|0;h=x[f+1592>>2];continue}break}C=(h|0)>(C|0)?h:C;k=k+1|0;continue l}else{v[g+j|0]=y[((m+16|0)+(j<<2)|0)+2|0];j=j+1|0;h=x[f+1592>>2];continue}}i=m+16|0;l=z[i+(j<<2)>>1];j=j+1|0;if((l|0)!=z[i+(j<<2)>>1]){continue}break}}fc(e,20);break c}else{b=nc(e,4);v[j+n|0]=b;b=b&255;h=(b|0)>(h|0)?b:h;j=j+1|0;b=y[f|0];continue}}}fc(e,3);break c}b=nc(e,6)+1|0;x[e+264>>2]=b;b=ie(e,D(b,24));x[e+396>>2]=b;if(!b){fc(e,3);break c}k=0;Rb(b,0,D(x[e+264>>2],24));n:{o:{while(1){if(x[e+264>>2]>(k|0)){b=x[e+396>>2];g=nc(e,16);w[((k<<1)+e|0)+268>>1]=g;h=20;if((g&65535)>>>0>2){break n}i=b+D(k,24)|0;M=i,N=nc(e,24),x[M>>2]=N;b=nc(e,24);x[i+4>>2]=b;if(b>>>0<A[i>>2]){break n}M=i,N=nc(e,24)+1|0,x[M+8>>2]=N;M=i,N=nc(e,6)+1|0,v[M+12|0]=N;b=nc(e,8);v[i+13|0]=b;if(x[e+120>>2]<=(b&255)){break n}f=0;while(1){b=y[i+12|0];if(b>>>0>f>>>0){g=(m+16|0)+f|0;b=nc(e,3);if(nc(e,1)){l=nc(e,5)}else{l=0}v[g|0]=b+(l<<3);f=f+1|0;continue}break}b=ie(e,b<<4);x[i+20>>2]=b;if(!b){break o}g=0;while(1){if(y[i+12|0]>g>>>0){b=y[(m+16|0)+g|0];f=0;while(1){if((f|0)!=8){p:{if(b>>>f&1){j=nc(e,8);l=f<<1;n=g<<4;w[l+(n+x[i+20>>2]|0)>>1]=j;if(x[e+120>>2]<=w[l+(n+x[i+20>>2]|0)>>1]){break n}break p}w[(x[i+20>>2]+(g<<4)|0)+(f<<1)>>1]=65535}f=f+1|0;continue}break}g=g+1|0;continue}break}g=ie(e,x[(x[e+124>>2]+D(y[i+13|0],2096)|0)+4>>2]<<2);x[i+16>>2]=g;if(!g){break o}b=0;Rb(g,0,x[(x[e+124>>2]+D(y[i+13|0],2096)|0)+4>>2]<<2);while(1){g=x[e+124>>2]+D(y[i+13|0],2096)|0;if(x[g+4>>2]>(b|0)){f=x[g>>2];h=ie(e,f);g=b<<2;x[g+x[i+16>>2]>>2]=h;j=b;if(!x[g+x[i+16>>2]>>2]){break o}while(1){if((f|0)>0){f=f-1|0;v[f+x[g+x[i+16>>2]>>2]|0]=(j|0)%y[i+12|0];j=(j|0)/y[i+12|0]|0;continue}break}b=b+1|0;continue}break}k=k+1|0;continue}break}b=nc(e,6)+1|0;x[e+400>>2]=b;b=ie(e,D(b,40));x[e+404>>2]=b;if(!b){fc(e,3);break c}Rb(b,0,D(x[e+400>>2],40));i=0;while(1){if(x[e+400>>2]>(i|0)){b=x[e+404>>2];if(nc(e,16)){fc(e,20);break c}g=b+D(i,40)|0;b=ie(e,D(x[e+4>>2],3));x[g+4>>2]=b;if(!b){fc(e,3);break c}if(nc(e,1)){b=nc(e,4)+1|0}else{b=1}v[g+8|0]=b;q:{if(nc(e,1)){b=nc(e,8)+1|0;w[g>>1]=b;f=0;h=x[e+4>>2];if((h|0)<(b&65535)){fc(e,20);break c}while(1){if(z[g>>1]<=f>>>0){break q}h=nc(e,mm(h-1|0));b=D(f,3);v[b+x[g+4>>2]|0]=h;h=nc(e,mm(x[e+4>>2]-1|0));v[(b+x[g+4>>2]|0)+1|0]=h;h=x[e+4>>2];b=b+x[g+4>>2]|0;j=y[b|0];if((h|0)<=(j|0)){fc(e,20);break c}b=y[b+1|0];if((b|0)>=(h|0)){fc(e,20);break c}f=f+1|0;if((b|0)!=(j|0)){continue}break}fc(e,20);break c}w[g>>1]=0}if(nc(e,2)){fc(e,20);break c}h=0;b=0;f=0;r:{if(y[g+8|0]>=2){while(1){if(x[e+4>>2]<=(b|0)){break r}f=nc(e,4);j=D(b,3);v[(j+x[g+4>>2]|0)+2|0]=f;b=b+1|0;if(y[(j+x[g+4>>2]|0)+2|0]<y[g+8|0]){continue}break}fc(e,20);break c}while(1){if(x[e+4>>2]<=(f|0)){break r}v[(x[g+4>>2]+D(f,3)|0)+2|0]=0;f=f+1|0;continue}}s:{while(1){if(y[g+8|0]<=h>>>0){break s}nc(e,8);b=h+g|0;M=b,N=nc(e,8),v[M+9|0]=N;f=nc(e,8);v[b+24|0]=f;if(x[e+128>>2]<=y[b+9|0]){fc(e,20);break c}h=h+1|0;if(x[e+264>>2]>(f&255)){continue}break}fc(e,20);break c}i=i+1|0;continue}break}M=e,N=nc(e,6)+1|0,x[M+408>>2]=N;g=e+412|0;j=0;t:{while(1){if(x[e+408>>2]<=(j|0)){break t}b=g+D(j,6)|0;M=b,N=nc(e,1),v[M|0]=N;M=b,N=nc(e,16),w[M+2>>1]=N;M=b,N=nc(e,16),w[M+4>>1]=N;f=nc(e,8);v[b+1|0]=f;if(z[b+2>>1]){fc(e,20);break c}if(z[b+4>>1]){fc(e,20);break c}j=j+1|0;if(x[e+400>>2]>(f&255)){continue}break}fc(e,20);break c}QI(e);x[e+992>>2]=0;g=C<<1;f=0;while(1){if(x[e+4>>2]>(f|0)){b=(f<<2)+e|0;M=b,N=ie(e,x[e+116>>2]<<2),x[M+800>>2]=N;M=b,N=ie(e,x[e+116>>2]<<1&2147483646),x[M+928>>2]=N;h=ie(e,g);x[b+996>>2]=h;j=x[b+800>>2];if(h?!j|!x[b+928>>2]:1){fc(e,3);break c}Rb(j,0,x[e+116>>2]<<2);f=f+1|0;continue}break}f=0;if(!JI(e,0,x[e+112>>2])){break a}if(!JI(e,1,x[e+116>>2])){break a}x[e+104>>2]=x[e+112>>2];g=x[e+116>>2];x[e+108>>2]=g;b=x[e+264>>2];i=(b|0)>0?b:0;b=(g|0)/2|0;h=0;while(1){if((f|0)!=(i|0)){j=x[e+396>>2]+D(f,24)|0;k=x[j+4>>2];l=b>>>0>k>>>0?k:b;k=x[j>>2];j=(l-(b>>>0>k>>>0?k:b)>>>0)/A[j+8>>2]|0;h=(h|0)<(j|0)?j:h;f=f+1|0;continue}break}b=g<<1&2147483646;g=D(x[e+4>>2],(h<<2)+4|0);b=b>>>0>g>>>0?b:g;x[e+12>>2]=b;u:{v:{if(!x[e+80>>2]){break v}g=x[e+92>>2];if((g|0)!=x[e+84>>2]){break u}if(g>>>0>=(b+x[e+88>>2]|0)+1512>>>0){break v}fc(e,3);break c}w:{if(x[e+1380>>2]==-1){x[e+52>>2]=y[e+48|0]?0:x[e+32>>2]-x[e+36>>2]|0;break w}x[e+52>>2]=0}f=1;break a}aa(7292,13154,4196,8777);p()}h=3}fc(e,h);break c}x:{if(f&255){j=Kn(e,b);break x}j=ie(e,b);x[h+8>>2]=j}if(!j){fc(e,3);break c}i=0;y:{if(!k){f=0;while(1){b=x[n>>2];if((f|0)>=(b|0)){break y}z:{A:{if(y[h+23|0]){if(!nc(e,1)){break A}}b=nc(e,5)+1|0;v[f+j|0]=b;if((b&255)!=32){i=i+1|0;break z}fc(e,20);break c}v[f+j|0]=255}f=f+1|0;continue}}g=nc(e,5);f=0;while(1){b=x[n>>2];if((f|0)>=(b|0)){break y}k=nc(e,mm(b-f|0));g=g+1|0;if((g|0)>=32){fc(e,20);break c}b=f+k|0;if((b|0)>x[n>>2]){fc(e,20);break c}else{Rb(f+j|0,g,k);f=b;continue}}}B:{C:{D:{if(y[h+23|0]){if(b>>2>(i|0)){break D}if(x[e+16>>2]<(b|0)){x[e+16>>2]=b;b=x[n>>2]}b=ie(e,b);x[h+8>>2]=b;if(!b){fc(e,3);break c}rc(b,j,x[n>>2]);lj(e,j,x[n>>2]);j=x[h+8>>2];v[h+23|0]=0;b=x[n>>2]}g=0;i=(b|0)>0?b:0;f=0;while(1){if((f|0)!=(i|0)){g=((y[f+j|0]-11&255)>>>0<244)+g|0;f=f+1|0;continue}break}x[h+2092>>2]=g;b=ie(e,b<<2);x[h+32>>2]=b;if(b){k=h+2092|0;f=0;break C}fc(e,3);break c}x[h+2092>>2]=i;k=h+2092|0;E:{if(!i){f=0;g=0;break E}b=ie(e,i);x[h+8>>2]=b;if(!b){fc(e,3);break c}b=Kn(e,x[k>>2]<<2);x[h+32>>2]=b;if(!b){fc(e,3);break c}f=Kn(e,x[k>>2]<<2);if(!f){break B}b=x[n>>2];g=x[k>>2]}b=(g<<3)+b|0;if(b>>>0<=A[e+16>>2]){break C}x[e+16>>2]=b}l=x[n>>2];b=0;g=ib-128|0;ib=g;o=Rb(g,0,128);g=(l|0)>0?l:0;while(1){F:{G:{if((b|0)!=(g|0)){if(y[b+j|0]==255){break G}g=b}if((g|0)==(l|0)){b=1;if(!x[h+2092>>2]){break F}aa(15710,13154,1103,7536);p()}b=g+j|0;i=y[b|0];if(i>>>0<32){HI(h,0,g,0,i,f);r=1;i=y[b|0]+1|0;b=1;H:{while(1){if((b|0)==(i|0)){I:while(1){J:{b=1;g=g+1|0;if((l|0)<=(g|0)){break F}G=g+j|0;i=y[G|0];if((i|0)==255){continue}b=i;if(b>>>0>=32){break J}while(1){if((b|0)<=0){b=0;break F}H=o+(b<<2)|0;q=x[H>>2];if(!q){b=b-1|0;continue}break}x[H>>2]=0;HI(h,km(q),g,r,i,f);r=r+1|0;i=y[G|0];if((i|0)==(b|0)){continue}while(1){if((b|0)>=(i|0)){continue I}G=o+(i<<2)|0;if(x[G>>2]){break H}x[G>>2]=q+(1<<32-i);i=i-1|0;continue}}break}}else{x[o+(b<<2)>>2]=1<<32-b;b=b+1|0;continue}break}aa(15213,13154,1118,7536);p()}aa(15754,13154,1133,7536);p()}aa(15220,13154,1104,7536);p()}b=b+1|0;continue}break}ib=o+128|0;if(!b){if(y[h+23|0]){lj(e,f,0)}fc(e,20);break c}b=x[k>>2];if(b){b=ie(e,(b<<2)+4|0);x[h+2084>>2]=b;if(!b){fc(e,3);break c}b=ie(e,(x[k>>2]<<2)+4|0);x[h+2088>>2]=b;if(!b){fc(e,3);break c}x[h+2088>>2]=b+4;x[b>>2]=-1;b=0;i=0;K:{L:{M:{if(y[h+23|0]){while(1){i=x[h+2092>>2];if((i|0)<=(b|0)){break M}g=b<<2;M=g+x[h+2084>>2]|0,N=km(x[g+x[h+32>>2]>>2]),x[M>>2]=N;b=b+1|0;continue}}while(1){if(x[h+4>>2]>(b|0)){if(GI(y[h+23|0],y[b+j|0])){M=x[h+2084>>2]+(i<<2)|0,N=km(x[x[h+32>>2]+(b<<2)>>2]),x[M>>2]=N;i=i+1|0}b=b+1|0;continue}break}if(x[h+2092>>2]!=(i|0)){break L}}KI(x[h+2084>>2],i,1119);x[x[h+2084>>2]+(x[h+2092>>2]<<2)>>2]=-1;g=0;b=x[h+(y[h+23|0]?2092:4)>>2];q=(b|0)>0?b:0;N:{while(1){if((g|0)!=(q|0)){b=g;i=y[h+23|0];b=i?x[(b<<2)+f>>2]:b;G=y[b+j|0];O:{if(!GI(i,G)){break O}H=g<<2;l=km(x[H+x[h+32>>2]>>2]);b=x[h+2092>>2];i=0;while(1){if((b|0)>=2){o=b>>>1|0;K=o+i|0;r=l>>>0<A[x[h+2084>>2]+(K<<2)>>2];b=r?o:b-o|0;i=r?i:K;continue}break}b=i<<2;if((l|0)!=x[b+x[h+2084>>2]>>2]){break N}if(y[h+23|0]){x[b+x[h+2088>>2]>>2]=x[f+H>>2];v[x[h+8>>2]+i|0]=G;break O}x[b+x[h+2088>>2]>>2]=g}g=g+1|0;continue}break}break K}aa(12195,13154,1230,9920);p()}aa(7477,13154,1200,9920);p()}}if(y[h+23|0]){lj(e,f,x[k>>2]<<2);lj(e,x[h+32>>2],x[k>>2]<<2);lj(e,j,x[n>>2]);x[h+32>>2]=0}i=h;b=0;f=0;while(1){if((b|0)!=1024){w[(i+(b<<1)|0)+36>>1]=65535;b=b+1|0;continue}break}b=x[i+(y[i+23|0]?2092:4)>>2];b=(b|0)>=32767?32767:b;g=(b|0)>0?b:0;while(1){if((f|0)!=(g|0)){P:{if(y[x[i+8>>2]+f|0]>10){break P}Q:{if(y[i+23|0]){b=km(x[x[i+2084>>2]+(f<<2)>>2]);break Q}b=x[x[i+32>>2]+(f<<2)>>2]}while(1){if(b>>>0>1023){break P}w[(i+(b<<1)|0)+36>>1]=f;b=(1<<y[x[i+8>>2]+f|0])+b|0;continue}}f=f+1|0;continue}break}b=nc(e,4);v[i+21|0]=b;b=b&255;if(b>>>0>=3){fc(e,20);break c}if(b){M=i,O=II(nc(e,32)),B[M+12>>2]=O;M=i,O=II(nc(e,32)),B[M+16>>2]=O;M=i,N=nc(e,4)+1|0,v[M+20|0]=N;M=i,N=nc(e,1),v[M+22|0]=N;f=x[i>>2];g=x[n>>2];R:{if(y[i+21|0]==1){u=J(_r(+E(E(xp(+E(g|0)))/E(f|0))));S:{if(F(u)<2147483648){b=~~u;break S}b=-2147483648}u=+(f|0);L=J(ck(+E(E(b|0)+E(1)),u));T:{if(F(L)<2147483648){f=~~L;break T}f=-2147483648}b=((f|0)<=(g|0))+b|0;t=E(b|0);if(ck(+E(t+E(1)),u)<=+(g|0)){f=-1}else{u=J(ck(+t,u));U:{if(F(u)<2147483648){f=~~u;break U}f=-2147483648}f=(f|0)>(g|0)?-1:b}if((f|0)>=0){break R}fc(e,20);break c}f=D(f,g)}x[i+24>>2]=f;if(!f){fc(e,20);break c}l=Kn(e,f<<1);if(!l){break h}f=0;while(1){j=x[i+24>>2];if((j|0)>(f|0)){b=nc(e,y[i+20|0]);if((b|0)==-1){lj(e,l,x[i+24>>2]<<1);fc(e,20);break c}else{w[l+(f<<1)>>1]=b;f=f+1|0;continue}}break}V:{W:{if(y[i+21|0]==1){o=y[i+23|0];X:{if(o){f=x[k>>2];if(f){break X}break V}f=x[n>>2]}b=ie(e,D(x[i>>2],f)<<2);x[i+28>>2]=b;if(!b){lj(e,l,x[i+24>>2]<<1);fc(e,3);break c}g=0;b=x[(o?k:n)>>2];n=(b|0)>0?b:0;r=i+2088|0;t=E(0);while(1){if((g|0)==(n|0)){break W}h=g;h=o?x[x[r>>2]+(h<<2)>>2]:h;j=x[i>>2];f=0;b=1;while(1){if((f|0)<(j|0)){I=E(t+E(E(E(z[l+(((h>>>0)/(b>>>0)>>>0)%A[i+24>>2]<<1)>>1])*B[i+16>>2])+B[i+12>>2]));B[x[i+28>>2]+(D(g,j)+f<<2)>>2]=I;t=y[i+22|0]?I:t;f=f+1|0;j=x[i>>2];if((f|0)>=(j|0)){continue}k=x[i+24>>2];qoa(k,0,b,0);if(kb){lj(e,l,k<<1);fc(e,20);break c}else{b=D(b,k);continue}}break}g=g+1|0;continue}}b=ie(e,j<<2);x[i+28>>2]=b;if(!b){break g}f=0;t=E(0);while(1){j=x[i+24>>2];if((j|0)<=(f|0)){break V}I=E(t+E(E(E(z[l+(f<<1)>>1])*B[i+16>>2])+B[i+12>>2]));B[x[i+28>>2]+(f<<2)>>2]=I;t=y[i+22|0]?I:t;f=f+1|0;continue}}v[i+21|0]=2;j=x[i+24>>2]}lj(e,l,j<<1)}C=C+1|0;continue}break}fc(e,3);break c}fc(e,3);break c}lj(e,l,x[i+24>>2]<<1);fc(e,3);break c}fc(e,20);break c}fc(e,3);break c}v[b+x[x[e+28>>2]+(g<<2)>>2]|0]=0;g=g+1|0;continue}}fc(e,3);break c}fc(e,20)}f=0}ib=m+1024|0;Y:{Z:{if(!f){x[d>>2]=x[s+104>>2]?1:x[s+108>>2];break Z}b=ie(s+8|0,1512);if(b){M=c,N=x[rc(b,s+8|0,1512)+32>>2]-a|0,x[M>>2]=N;x[d>>2]=0;break Y}}UI(s+8|0);b=0}ib=s+1520|0;return b}function CH(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,w=0,z=0,B=0,C=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;s=ib-48|0;ib=s;a:{if(c>>>0<=2){c=c<<2;I=x[c+94780>>2];J=x[c+94768>>2];while(1){c=x[b+4>>2];b:{if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break b}c=qd(b)}if(_k(c)){continue}break}o=1;c:{d:{switch(c-43|0){case 0:case 2:break d;default:break c}}o=(c|0)==45?-1:1;c=x[b+4>>2];if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break c}c=qd(b)}e:{f:{while(1){if(v[g+4955|0]==(c|32)){g:{if(g>>>0>6){break g}c=x[b+4>>2];if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break g}c=qd(b)}g=g+1|0;if((g|0)!=8){continue}break f}break}if((g|0)!=3){if((g|0)==8){break f}if(!d|g>>>0<4){break e}if((g|0)==8){break f}}c=x[b+116>>2];if((c|0)>0|(c|0)>=0){x[b+4>>2]=x[b+4>>2]-1}if(!d|g>>>0<4){break f}c=(c|0)<0;while(1){if(!c){x[b+4>>2]=x[b+4>>2]-1}g=g-1|0;if(g>>>0>3){continue}break}}i=ib-16|0;ib=i;l=(q(E(E(o|0)*E(O))),j(2));b=l&2147483647;h:{if(b-8388608>>>0<=2130706431){r=b<<25;c=(b>>>7|0)+1065353216|0;break h}r=l<<25;c=l>>>7|2147418112;if(b>>>0>=2139095040){break h}r=0;c=0;if(!b){break h}c=b;b=G(b);Sf(i,c,0,0,0,b+81|0);k=x[i>>2];h=x[i+4>>2];r=x[i+8>>2];c=x[i+12>>2]^65536|16265-b<<16}x[s>>2]=k;x[s+4>>2]=h;x[s+8>>2]=r;x[s+12>>2]=l&-2147483648|c;ib=i+16|0;k=x[s+8>>2];h=x[s+12>>2];i=x[s>>2];l=x[s+4>>2];break a}i:{j:{k:{if(g){break k}g=0;while(1){if(v[g+9916|0]!=(c|32)){break k}l:{if(g>>>0>1){break l}c=x[b+4>>2];if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break l}c=qd(b)}g=g+1|0;if((g|0)!=3){continue}break}break j}m:{switch(g|0){case 0:n:{if((c|0)!=48){break n}g=x[b+4>>2];o:{if((g|0)!=x[b+104>>2]){x[b+4>>2]=g+1;g=y[g|0];break o}g=qd(b)}if((g&-33)==88){g=d;c=0;f=ib-432|0;ib=f;p:{q:{d=x[b+4>>2];if((d|0)!=x[b+104>>2]){x[b+4>>2]=d+1;c=y[d|0];break q}d=0;break p}d=1}while(1){r:{s:{t:{u:{v:{w:{x:{y:{if(!d){c=qd(b);break y}if((c|0)!=48){l=1073676288;if((c|0)==46){break w}break v}d=x[b+4>>2];if((d|0)==x[b+104>>2]){break x}n=1;x[b+4>>2]=d+1;c=y[d|0]}d=1;continue}n=1;break s}c=x[b+4>>2];z:{if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break z}c=qd(b)}if((c|0)==48){break u}w=1}break t}while(1){c=r;r=c-1|0;t=t-!c|0;w=1;c=x[b+4>>2];A:{if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break A}c=qd(b)}if((c|0)==48){continue}break}n=1}while(1){e=c|32;B:{C:{M=c-48|0;if(M>>>0<10){break C}if(!((c|0)==46|e-97>>>0<6)){d=c;break r}d=46;if((c|0)!=46){break C}if(w){break r}w=1;r=k;t=h;break B}c=(c|0)>57?e-87|0:M;D:{if((h|0)<=0&k>>>0<=7|(h|0)<0){z=c+(z<<4)|0;break D}if(!h&k>>>0<=28){ch(f+48|0,c);Jd(f+32|0,F,H,i,l,0,0,0,1073414144);F=x[f+32>>2];H=x[f+36>>2];i=x[f+40>>2];l=x[f+44>>2];Jd(f+16|0,x[f+48>>2],x[f+52>>2],x[f+56>>2],x[f+60>>2],F,H,i,l);Ng(f,x[f+16>>2],x[f+20>>2],x[f+24>>2],x[f+28>>2],m,p,B,C);B=x[f+8>>2];C=x[f+12>>2];m=x[f>>2];p=x[f+4>>2];break D}if(!c|u){break D}Jd(f+80|0,F,H,i,l,0,0,0,1073610752);Ng(f- -64|0,x[f+80>>2],x[f+84>>2],x[f+88>>2],x[f+92>>2],m,p,B,C);B=x[f+72>>2];C=x[f+76>>2];u=1;m=x[f+64>>2];p=x[f+68>>2]}c=k+1|0;h=c?h:h+1|0;k=c;n=1}c=x[b+4>>2];if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0]}else{c=qd(b)}continue}}d=0;continue}break}E:{if(!n){c=x[b+116>>2];F:{G:{if((c|0)>0|(c|0)>=0){c=x[b+4>>2];x[b+4>>2]=c-1;if(!g){break G}x[b+4>>2]=c-2;if(!w){break F}x[b+4>>2]=c-3;break F}if(g){break F}}ti(b,0,0)}Vi(f+96|0,+(o|0)*0);m=x[f+96>>2];p=x[f+100>>2];c=x[f+108>>2];b=x[f+104>>2];break E}if((h|0)<=0&k>>>0<=7|(h|0)<0){i=k;l=h;while(1){z=z<<4;c=i+1|0;l=c?l:l+1|0;i=c;if((c|0)!=8|l){continue}break}}H:{I:{J:{if((d&-33)==80){i=BH(b,g);c=kb;l=c;if(i|(c|0)!=-2147483648){break H}if(g){c=x[b+116>>2];if((c|0)>0|(c|0)>=0){break J}break I}m=0;p=0;ti(b,0,0);c=0;b=0;break E}i=0;l=0;if(x[b+116>>2]<0){break H}}x[b+4>>2]=x[b+4>>2]-1}i=0;l=0}if(!z){Vi(f+112|0,+(o|0)*0);m=x[f+112>>2];p=x[f+116>>2];c=x[f+124>>2];b=x[f+120>>2];break E}b=w?r:k;h=(w?t:h)<<2|b>>>30;b=i+(b<<2)|0;d=h+l|0;d=b>>>0<i>>>0?d+1|0:d;k=b-32|0;h=d-(b>>>0<32)|0;b=h;if(k>>>0>0-I>>>0&(b|0)>=0|(b|0)>0){x[12e4]=68;ch(f+160|0,o);Jd(f+144|0,x[f+160>>2],x[f+164>>2],x[f+168>>2],x[f+172>>2],-1,-1,-1,2147418111);Jd(f+128|0,x[f+144>>2],x[f+148>>2],x[f+152>>2],x[f+156>>2],-1,-1,-1,2147418111);m=x[f+128>>2];p=x[f+132>>2];c=x[f+140>>2];b=x[f+136>>2];break E}b=I-226|0;c=b>>31;if((h|0)>=(c|0)&b>>>0<=k>>>0|(c|0)<(h|0)){if((z|0)>=0){while(1){Ng(f+416|0,m,p,B,C,0,0,0,-1073807360);c=kR(m,p,B,C,1073610752);b=(c|0)<0;Ng(f+400|0,m,p,B,C,b?m:x[f+416>>2],b?p:x[f+420>>2],b?B:x[f+424>>2],b?C:x[f+428>>2]);b=k;k=b-1|0;h=h-!b|0;B=x[f+408>>2];C=x[f+412>>2];m=x[f+400>>2];p=x[f+404>>2];z=z<<1|(c|0)>=0;if((z|0)>=0){continue}break}}d=h-((I>>31)+(k>>>0<I>>>0)|0)|0;b=(k-I|0)+32|0;d=b>>>0<32?d+1|0:d;c=b>>>0<J>>>0&(d|0)<=0|(d|0)<0?(b|0)>0?b:0:J;K:{if((c|0)>=113){ch(f+384|0,o);r=x[f+392>>2];t=x[f+396>>2];F=x[f+384>>2];H=x[f+388>>2];h=0;b=0;break K}Vi(f+352|0,$j(1,144-c|0));ch(f+336|0,o);F=x[f+336>>2];H=x[f+340>>2];r=x[f+344>>2];t=x[f+348>>2];EH(f+368|0,x[f+352>>2],x[f+356>>2],x[f+360>>2],x[f+364>>2],F,H,r,t);K=x[f+376>>2];L=x[f+380>>2];h=x[f+372>>2];b=x[f+368>>2]}c=!(z&1)&((Cm(m,p,B,C,0,0,0,0)|0)!=0&(c|0)<32);nn(f+320|0,c+z|0);Jd(f+304|0,F,H,r,t,x[f+320>>2],x[f+324>>2],x[f+328>>2],x[f+332>>2]);d=b;Ng(f+272|0,x[f+304>>2],x[f+308>>2],x[f+312>>2],x[f+316>>2],b,h,K,L);b=c;Jd(f+288|0,F,H,r,t,b?0:m,b?0:p,b?0:B,b?0:C);Ng(f+256|0,x[f+288>>2],x[f+292>>2],x[f+296>>2],x[f+300>>2],x[f+272>>2],x[f+276>>2],x[f+280>>2],x[f+284>>2]);lx(f+240|0,x[f+256>>2],x[f+260>>2],x[f+264>>2],x[f+268>>2],d,h,K,L);b=x[f+240>>2];c=x[f+244>>2];d=x[f+248>>2];h=x[f+252>>2];if(!Cm(b,c,d,h,0,0,0,0)){x[12e4]=68}DH(f+224|0,b,c,d,h,k);m=x[f+224>>2];p=x[f+228>>2];c=x[f+236>>2];b=x[f+232>>2];break E}x[12e4]=68;ch(f+208|0,o);Jd(f+192|0,x[f+208>>2],x[f+212>>2],x[f+216>>2],x[f+220>>2],0,0,0,65536);Jd(f+176|0,x[f+192>>2],x[f+196>>2],x[f+200>>2],x[f+204>>2],0,0,0,65536);m=x[f+176>>2];p=x[f+180>>2];c=x[f+188>>2];b=x[f+184>>2]}x[s+16>>2]=m;x[s+20>>2]=p;x[s+24>>2]=b;x[s+28>>2]=c;ib=f+432|0;k=x[s+24>>2];h=x[s+28>>2];i=x[s+16>>2];l=x[s+20>>2];break a}if(x[b+116>>2]<0){break n}x[b+4>>2]=x[b+4>>2]-1}g=b;f=o;w=d;d=0;o=0;e=ib-8976|0;ib=e;L=0-I|0;K=L-J|0;L:{M:{while(1){if((c|0)!=48){N:{if((c|0)!=46){break L}b=x[g+4>>2];if((b|0)==x[g+104>>2]){break N}x[g+4>>2]=b+1;c=y[b|0];break M}}else{b=x[g+4>>2];if((b|0)!=x[g+104>>2]){d=1;x[g+4>>2]=b+1;c=y[b|0]}else{d=1;c=qd(g)}continue}break}c=qd(g)}n=1;if((c|0)!=48){break L}while(1){b=k;k=b-1|0;h=h-!b|0;b=x[g+4>>2];O:{if((b|0)!=x[g+104>>2]){x[g+4>>2]=b+1;c=y[b|0];break O}c=qd(g)}if((c|0)==48){continue}break}d=1}x[e+784>>2]=0;P:{Q:{b=(c|0)==46;m=c-48|0;R:{S:{T:{U:{if(b|m>>>0<=9){while(1){V:{if(b&1){if(!n){k=i;h=l;n=1;break V}b=!d;break U}b=i+1|0;l=b?l:l+1|0;i=b;if((o|0)<=2044){z=(c|0)==48?z:i;b=(e+784|0)+(o<<2)|0;if(u){m=(D(x[b>>2],10)+c|0)-48|0}x[b>>2]=m;d=1;c=u+1|0;b=(c|0)==9;u=b?0:c;o=b+o|0;break V}if((c|0)==48){break V}x[e+8960>>2]=x[e+8960>>2]|1;z=18396}b=x[g+4>>2];W:{if((b|0)!=x[g+104>>2]){x[g+4>>2]=b+1;c=y[b|0];break W}c=qd(g)}b=(c|0)==46;m=c-48|0;if(b|m>>>0<10){continue}break}}k=n?k:i;h=n?h:l;if(!(!d|(c&-33)!=69)){m=BH(g,w);b=kb;p=b;X:{if(m|(b|0)!=-2147483648){break X}if(!w){break R}m=0;p=0;if(x[g+116>>2]<0){break X}x[g+4>>2]=x[g+4>>2]-1}if(!d){break S}h=h+p|0;b=k+m|0;h=b>>>0<m>>>0?h+1|0:h;k=b;break Q}b=!d;if((c|0)<0){break T}}if(x[g+116>>2]<0){break T}x[g+4>>2]=x[g+4>>2]-1}if(!b){break Q}}x[12e4]=28}i=0;l=0;ti(g,0,0);c=0;b=0;break P}b=x[e+784>>2];if(!b){Vi(e,+(f|0)*0);i=x[e>>2];l=x[e+4>>2];c=x[e+12>>2];b=x[e+8>>2];break P}if(!((k|0)!=(i|0)|(h|0)!=(l|0)|(i>>>0>9&(l|0)>=0|(l|0)>0)|(b>>>J|0?(J|0)<=30:0))){ch(e+48|0,f);nn(e+32|0,b);Jd(e+16|0,x[e+48>>2],x[e+52>>2],x[e+56>>2],x[e+60>>2],x[e+32>>2],x[e+36>>2],x[e+40>>2],x[e+44>>2]);i=x[e+16>>2];l=x[e+20>>2];c=x[e+28>>2];b=x[e+24>>2];break P}if(k>>>0>L>>>1>>>0&(h|0)>=0|(h|0)>0){x[12e4]=68;ch(e+96|0,f);Jd(e+80|0,x[e+96>>2],x[e+100>>2],x[e+104>>2],x[e+108>>2],-1,-1,-1,2147418111);Jd(e- -64|0,x[e+80>>2],x[e+84>>2],x[e+88>>2],x[e+92>>2],-1,-1,-1,2147418111);i=x[e+64>>2];l=x[e+68>>2];c=x[e+76>>2];b=x[e+72>>2];break P}b=I-226|0;c=k>>>0<b>>>0;b=b>>31;if(c&(h|0)<=(b|0)|(b|0)>(h|0)){x[12e4]=68;ch(e+144|0,f);Jd(e+128|0,x[e+144>>2],x[e+148>>2],x[e+152>>2],x[e+156>>2],0,0,0,65536);Jd(e+112|0,x[e+128>>2],x[e+132>>2],x[e+136>>2],x[e+140>>2],0,0,0,65536);i=x[e+112>>2];l=x[e+116>>2];c=x[e+124>>2];b=x[e+120>>2];break P}if(u){if((u|0)<=8){b=(e+784|0)+(o<<2)|0;g=x[b>>2];while(1){g=D(g,10);u=u+1|0;if((u|0)!=9){continue}break}x[b>>2]=g}o=o+1|0}Y:{n=k;if((z|0)>(k|0)|(z|0)>8|(k|0)>17){break Y}if((n|0)==9){ch(e+192|0,f);nn(e+176|0,x[e+784>>2]);Jd(e+160|0,x[e+192>>2],x[e+196>>2],x[e+200>>2],x[e+204>>2],x[e+176>>2],x[e+180>>2],x[e+184>>2],x[e+188>>2]);i=x[e+160>>2];l=x[e+164>>2];c=x[e+172>>2];b=x[e+168>>2];break P}if((n|0)<=8){ch(e+272|0,f);nn(e+256|0,x[e+784>>2]);Jd(e+240|0,x[e+272>>2],x[e+276>>2],x[e+280>>2],x[e+284>>2],x[e+256>>2],x[e+260>>2],x[e+264>>2],x[e+268>>2]);ch(e+224|0,x[(0-n<<2)+94768>>2]);GN(e+208|0,x[e+240>>2],x[e+244>>2],x[e+248>>2],x[e+252>>2],x[e+224>>2],x[e+228>>2],x[e+232>>2],x[e+236>>2]);i=x[e+208>>2];l=x[e+212>>2];c=x[e+220>>2];b=x[e+216>>2];break P}b=(J+D(n,-3)|0)+27|0;c=x[e+784>>2];if(c>>>b|0?(b|0)<=30:0){break Y}ch(e+352|0,f);nn(e+336|0,c);Jd(e+320|0,x[e+352>>2],x[e+356>>2],x[e+360>>2],x[e+364>>2],x[e+336>>2],x[e+340>>2],x[e+344>>2],x[e+348>>2]);ch(e+304|0,x[(n<<2)+94696>>2]);Jd(e+288|0,x[e+320>>2],x[e+324>>2],x[e+328>>2],x[e+332>>2],x[e+304>>2],x[e+308>>2],x[e+312>>2],x[e+316>>2]);i=x[e+288>>2];l=x[e+292>>2];c=x[e+300>>2];b=x[e+296>>2];break P}while(1){c=o;o=c-1|0;if(!x[(e+784|0)+(o<<2)>>2]){continue}break}b=(n|0)%9|0;Z:{if(!b){u=0;b=0;break Z}u=0;d=(n|0)<0?b+9|0:b;_:{if(!c){b=0;c=0;break _}k=x[(0-d<<2)+94768>>2];l=1e9/(k|0)|0;m=0;g=0;b=0;while(1){h=m;i=(e+784|0)+(g<<2)|0;o=x[i>>2];m=(o>>>0)/(k>>>0)|0;h=h+m|0;x[i>>2]=h;h=!h&(b|0)==(g|0);b=h?b+1&2047:b;n=h?n-9|0:n;m=D(l,o-D(k,m)|0);g=g+1|0;if((g|0)!=(c|0)){continue}break}if(!m){break _}x[(e+784|0)+(c<<2)>>2]=m;c=c+1|0}n=(n-d|0)+9|0}while(1){o=(e+784|0)+(b<<2)|0;g=(n|0)<36;$:{while(1){aa:{if(g){break aa}if((n|0)!=36){break $}if(A[o>>2]<=10384592){break aa}n=36;break $}d=c+2047|0;m=0;while(1){i=d&2047;w=(e+784|0)+(i<<2)|0;d=x[w>>2];l=d>>>3|0;h=d<<29;k=h+m|0;d=l;d=h>>>0>k>>>0?d+1|0:d;h=d;if(!h&k>>>0<1000000001){m=0}else{m=soa(k,h,1e9,0);d=qoa(m,kb,-1e9,-1)+k|0;k=d}x[w>>2]=k;c=(i|0)!=(c-1&2047)?c:(b|0)==(i|0)?c:k?c:i;d=i-1|0;if((b|0)!=(i|0)){continue}break}u=u-29|0;if(!m){continue}break}b=b-1&2047;if((c|0)==(b|0)){d=e+784|0;k=d+((c+2046&2047)<<2)|0;c=c-1&2047;x[k>>2]=x[k>>2]|x[d+(c<<2)>>2]}n=n+9|0;x[(e+784|0)+(b<<2)>>2]=m;continue}break}ba:{ca:while(1){k=c+1&2047;l=(e+784|0)+((c-1&2047)<<2)|0;while(1){h=(n|0)>45?9:1;da:{while(1){d=b;g=0;ea:{while(1){fa:{b=d+g&2047;if((b|0)==(c|0)){break fa}b=x[(e+784|0)+(b<<2)>>2];i=x[(g<<2)+94720>>2];if(b>>>0<i>>>0){break fa}if(b>>>0>i>>>0){break ea}g=g+1|0;if((g|0)!=4){continue}}break}if((n|0)!=36){break ea}k=0;h=0;g=0;i=0;l=0;while(1){b=d+g&2047;if((b|0)==(c|0)){c=c+1&2047;x[((c<<2)+e|0)+780>>2]=0}nn(e+768|0,x[(e+784|0)+(b<<2)>>2]);Jd(e+752|0,k,h,i,l,0,0,1342177280,1075633366);Ng(e+736|0,x[e+752>>2],x[e+756>>2],x[e+760>>2],x[e+764>>2],x[e+768>>2],x[e+772>>2],x[e+776>>2],x[e+780>>2]);i=x[e+744>>2];l=x[e+748>>2];k=x[e+736>>2];h=x[e+740>>2];g=g+1|0;if((g|0)!=4){continue}break}ch(e+720|0,f);Jd(e+704|0,k,h,i,l,x[e+720>>2],x[e+724>>2],x[e+728>>2],x[e+732>>2]);i=x[e+712>>2];l=x[e+716>>2];k=0;h=0;m=x[e+704>>2];p=x[e+708>>2];w=u+113|0;o=w-I|0;n=(o|0)<(J|0);b=n?(o|0)>0?o:0:J;if((b|0)<=112){break da}break ba}u=h+u|0;b=c;if((d|0)==(b|0)){continue}break}o=1e9>>>h|0;m=-1<<h^-1;g=0;b=d;while(1){i=g;g=(e+784|0)+(d<<2)|0;w=x[g>>2];i=i+(w>>>h|0)|0;x[g>>2]=i;i=!i&(b|0)==(d|0);b=i?b+1&2047:b;n=i?n-9|0:n;g=D(o,m&w);d=d+1&2047;if((d|0)!=(c|0)){continue}break}if(!g){continue}if((b|0)!=(k|0)){x[(e+784|0)+(c<<2)>>2]=g;c=k;continue ca}x[l>>2]=x[l>>2]|1;continue}break}break}Vi(e+656|0,$j(1,225-b|0));EH(e+688|0,x[e+656>>2],x[e+660>>2],x[e+664>>2],x[e+668>>2],m,p,i,l);F=x[e+696>>2];H=x[e+700>>2];B=x[e+688>>2];C=x[e+692>>2];Vi(e+640|0,$j(1,113-b|0));hN(e+672|0,m,p,i,l,x[e+640>>2],x[e+644>>2],x[e+648>>2],x[e+652>>2]);k=x[e+672>>2];h=x[e+676>>2];r=x[e+680>>2];t=x[e+684>>2];lx(e+624|0,m,p,i,l,k,h,r,t);Ng(e+608|0,B,C,F,H,x[e+624>>2],x[e+628>>2],x[e+632>>2],x[e+636>>2]);i=x[e+616>>2];l=x[e+620>>2];m=x[e+608>>2];p=x[e+612>>2]}g=d+4&2047;ga:{if((g|0)==(c|0)){break ga}g=x[(e+784|0)+(g<<2)>>2];ha:{if(g>>>0<=499999999){if(!g&(d+5&2047)==(c|0)){break ha}Vi(e+496|0,+(f|0)*.25);Ng(e+480|0,k,h,r,t,x[e+496>>2],x[e+500>>2],x[e+504>>2],x[e+508>>2]);r=x[e+488>>2];t=x[e+492>>2];k=x[e+480>>2];h=x[e+484>>2];break ha}if((g|0)!=5e8){Vi(e+592|0,+(f|0)*.75);Ng(e+576|0,k,h,r,t,x[e+592>>2],x[e+596>>2],x[e+600>>2],x[e+604>>2]);r=x[e+584>>2];t=x[e+588>>2];k=x[e+576>>2];h=x[e+580>>2];break ha}N=+(f|0);if((d+5&2047)==(c|0)){Vi(e+528|0,N*.5);Ng(e+512|0,k,h,r,t,x[e+528>>2],x[e+532>>2],x[e+536>>2],x[e+540>>2]);r=x[e+520>>2];t=x[e+524>>2];k=x[e+512>>2];h=x[e+516>>2];break ha}Vi(e+560|0,N*.75);Ng(e+544|0,k,h,r,t,x[e+560>>2],x[e+564>>2],x[e+568>>2],x[e+572>>2]);r=x[e+552>>2];t=x[e+556>>2];k=x[e+544>>2];h=x[e+548>>2]}if((b|0)>111){break ga}hN(e+464|0,k,h,r,t,0,0,0,1073676288);if(Cm(x[e+464>>2],x[e+468>>2],x[e+472>>2],x[e+476>>2],0,0,0,0)){break ga}Ng(e+448|0,k,h,r,t,0,0,0,1073676288);r=x[e+456>>2];t=x[e+460>>2];k=x[e+448>>2];h=x[e+452>>2]}Ng(e+432|0,m,p,i,l,k,h,r,t);lx(e+416|0,x[e+432>>2],x[e+436>>2],x[e+440>>2],x[e+444>>2],B,C,F,H);i=x[e+424>>2];l=x[e+428>>2];m=x[e+416>>2];p=x[e+420>>2];ia:{if((K-2|0)>=(w&2147483647)){break ia}x[e+408>>2]=i;x[e+412>>2]=l&2147483647;x[e+400>>2]=m;x[e+404>>2]=p;Jd(e+384|0,m,p,i,l,0,0,0,1073610752);d=kR(x[e+400>>2],x[e+404>>2],x[e+408>>2],x[e+412>>2],1081081856);c=(d|0)<0;i=c?i:x[e+392>>2];l=c?l:x[e+396>>2];m=c?m:x[e+384>>2];p=c?p:x[e+388>>2];u=((d|0)>=0)+u|0;if(!((Cm(k,h,r,t,0,0,0,0)|0)!=0&(c?n:n&(b|0)!=(o|0)))&(u+110|0)<=(K|0)){break ia}x[12e4]=68}DH(e+368|0,m,p,i,l,u);i=x[e+368>>2];l=x[e+372>>2];c=x[e+380>>2];b=x[e+376>>2]}x[s+40>>2]=b;x[s+44>>2]=c;x[s+32>>2]=i;x[s+36>>2]=l;ib=e+8976|0;k=x[s+40>>2];h=x[s+44>>2];i=x[s+32>>2];l=x[s+36>>2];break a;case 3:break j;default:break m}}c=x[b+116>>2];if((c|0)>0|(c|0)>=0){x[b+4>>2]=x[b+4>>2]-1}break i}ja:{c=x[b+4>>2];ka:{if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break ka}c=qd(b)}if((c|0)==40){g=1;break ja}h=2147450880;if(x[b+116>>2]<0){break a}x[b+4>>2]=x[b+4>>2]-1;break a}while(1){c=x[b+4>>2];la:{if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break la}c=qd(b)}if(!(!(c-48>>>0<10|c-65>>>0<26|(c|0)==95)&c-97>>>0>=26)){g=g+1|0;continue}break}h=2147450880;if((c|0)==41){break a}c=x[b+116>>2];if((c|0)>0|(c|0)>=0){x[b+4>>2]=x[b+4>>2]-1}ma:{if(d){if(g){break ma}break a}break i}while(1){g=g-1|0;if((c|0)>0|(c|0)>=0){x[b+4>>2]=x[b+4>>2]-1}if(g){continue}break}break a}x[12e4]=28;ti(b,0,0)}h=0}x[a>>2]=i;x[a+4>>2]=l;x[a+8>>2]=k;x[a+12>>2]=h;ib=s+48|0}function mja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0;d=ib-384|0;ib=d;yc(b);a:{if(!yo(b,d+368|0)){break a}if(!NT(d+368|0)){break a}r=te(d+344|0,b);o=Nb(d+328|0);b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{if(!c){x[27524]=0;R(643,d+40|0,r|0);b=x[27524];x[27524]=0;if((b|0)==1){break z}break B}x[27524]=0;R(644,d+40|0,r|0);b=x[27524];x[27524]=0;if((b|0)==1){break A}}b=d+40|0;lu(o,b);Zd(b);x[27524]=0;U(645,b|0,o|0,1413891155);b=x[27524];x[27524]=0;C:{D:{if((b|0)!=1){x[27524]=0;e=Q(646,d+40|0,14125)|0;b=x[27524];x[27524]=0;if((b|0)==1){break D}yb(d+40|0);if(!c){break b}if(!(e^1)){break C}break b}b=P()|0;break c}b=P()|0;yb(d+40|0);break c}x[27524]=0;R(250,a|0,4194304);b=x[27524];x[27524]=0;if((b|0)==1){break d}x[a+480208>>2]=12;x[27524]=0;U(645,d+304|0,o|0,1280592212);b=x[27524];x[27524]=0;if((b|0)==1){break e}x[27524]=0;b=T(164,x[d+304>>2])|0;e=x[27524];x[27524]=0;if((e|0)==1){break g}x[27524]=0;U(448,d+304|0,a+1298308|0,b|0);b=x[27524];x[27524]=0;if((b|0)==1){break g}i=a+484360|0;j=a+484376|0;Ic(Tb(x[i>>2],y[j|0]));k=Nb(d+288|0);v[d+287|0]=0;x[27524]=0;U(647,d+272|0,o|0,1196314451);b=x[27524];x[27524]=0;if((b|0)==1){break i}B=d,C=Cb(x[d+272>>2]),x[B+264>>2]=C;q=d+252|0;s=Cb(x[d+276>>2]);E:{F:{while(1){b=x[d+264>>2];if(!Mb(b,s)){break F}l=te(d+40|0,b);x[27524]=0;e=Q(648,l|0,d+24|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break E}b=1;if(!(!e|y[d+33|0]!=1)){B=a,C=Bd(y[d+34|0],z[a+480188>>1],127),w[B+480188>>1]=C;x[27524]=0;h=T(649,d+208|0)|0;b=x[27524];x[27524]=0;G:{H:{I:{J:{K:{if((b|0)!=1){b=d+192|0;yf(b,d+24|0,9,1);x[27524]=0;R(226,d+160|0,b|0);b=x[27524];x[27524]=0;if((b|0)==1){break K}b=d+8|0;dc(b,q,10);e=b;b=d+160|0;Ol(e,b);wb(b);b=Tb(x[a+484360>>2],y[j|0]);if(pc(x[b>>2],x[b+4>>2])){break H}x[27524]=0;b=T(276,i|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break J}if((b|0)!=255){break I}b=2;break G}b=P()|0;break k}b=P()|0;break l}b=P()|0;break l}b=Tb(x[a+484360>>2],y[j|0])}x[27524]=0;U(5,d+160|0,4,q|0);e=x[27524];x[27524]=0;if((e|0)==1){break n}x[27524]=0;R(277,b|0,d+160|0);b=x[27524];x[27524]=0;if((b|0)==1){break o}xb(d+160|0);x[27524]=0;R(644,d+192|0,l|0);b=x[27524];x[27524]=0;if((b|0)==1){break p}B=d,C=Cb(x[d+192>>2]),x[B+184>>2]=C;n=Cb(x[d+196>>2]);L:{M:{while(1){b=x[d+184>>2];if(!Mb(b,n)){b=0;if(z[d+244>>1]==65535|z[d+246>>1]==65535){break L}b=y[j|0];e=x[a+484360>>2];x[27524]=0;Y(650,Tb(e,b)|0);b=x[27524];x[27524]=0;if((b|0)!=1){x[27524]=0;R(651,k|0,h|0);e=x[27524];x[27524]=0;b=0;if((e|0)!=1){break L}}b=P()|0;break m}Eo(d+160|0,b);ci(d+8|0,x[b>>2],x[b+4>>2]);e=1;N:{g=x[d+8>>2];O:{if((g|0)!=1212960847){b=0;if((g|0)!=1312903248){break O}while(1){if(z[a+480188>>1]<=b>>>0){break O}x[27524]=0;g=W(160,x[d+160>>2],x[d+168>>2],2)|0;f=x[27524];x[27524]=0;if((f|0)!=1){if(!g){break O}x[27524]=0;R(264,d+136|0,d+160|0);g=x[27524];x[27524]=0;P:{Q:{R:{S:{if((g|0)!=1){switch(y[d+136|0]){case 4:break Q;case 2:break R;case 0:break S;default:break P}}break q}g=Lc(d+136|0);B=Jb(x[h>>2],b),C=y[g|0]^128,v[B|0]=C;g=d+144|0;Ab(g,x[d+232>>2],b);bf(g,0);break P}B=Jb(x[h>>2],b),C=128,v[B|0]=C;g=d+144|0;Ab(g,x[d+232>>2],b);bf(g,1);break P}B=Jb(x[h>>2],b),C=128,v[B|0]=C;g=d+144|0;Ab(g,x[d+232>>2],b);bf(g,0)}b=b+1|0;continue}break}break q}if(A[d+12>>2]<9){break O}b=0;x[27524]=0;Q(192,d+160|0,2)|0;e=x[27524];x[27524]=0;g=65535;if((e|0)==1){break N}while(1){T:{x[27524]=0;e=W(160,x[d+160>>2],x[d+168>>2],1)|0;f=x[27524];x[27524]=0;U:{V:{W:{X:{Y:{Z:{_:{$:{if((f|0)!=1){if(!e){break T}x[27524]=0;f=T(210,d+160|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break q}e=0;switch(f|0){case 0:break T;case 14:break V;case 13:break W;case 12:break X;case 8:break Y;case 7:break Z;case 4:break _;case 1:break $;default:break O}}break q}e=Tb(x[a+484360>>2],y[j|0]);if(z[d+244>>1]==65535){B=d,C=Gl(x[e>>2],x[e+4>>2]),w[B+244>>1]=C}e=Gl(x[e>>2],x[e+4>>2]);x[27524]=0;w[d+246>>1]=e;e=Q(652,d+160|0,d+287|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break q}aa:{ba:{switch(e-254|0){case 1:e=65535;break aa;case 0:break ba;default:break aa}}e=65534}f=y[j|0];m=x[a+484360>>2];x[27524]=0;R(526,Tb(m,f)|0,e|0);e=x[27524];x[27524]=0;if((e|0)==1){break q}g=(g&65535)==65535?b:g;break U}x[27524]=0;e=T(198,d+160|0)|0;f=x[27524];x[27524]=0;ca:{da:{if((f|0)!=1){if(e>>>0>=(g&65535)>>>0){break da}e=z[d+248>>1];break ca}break q}e=e-g|0;w[d+248>>1]=e}_e(Tb(x[a+484360>>2],y[j|0]),e&65535);break U}x[27524]=0;e=T(210,d+160|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break q}v[d+251|0]=e;break U}x[27524]=0;e=T(210,d+160|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break q}v[d+250|0]=e;break U}x[27524]=0;f=Q(623,d+160|0,d+144|0)|0;m=x[27524];x[27524]=0;if((m|0)!=1){if(y[d+144|0]|!f|(y[d+146|0]|y[d+145|0]!=255)){break O}if(y[d+147|0]|y[d+148|0]!=1){break O}if(!y[d+149|0]){break U}break O}break q}x[27524]=0;R(538,d+152|0,d+160|0);e=x[27524];x[27524]=0;ea:{fa:{ga:{ha:{if((e|0)!=1){m=Lc(d+152|0);e=x[h>>2];u=cd(e,x[d+212>>2]);f=y[d+152|0];if(u>>>0<=f>>>0){break U}switch(y[Ze(d+152|0)|0]){case 4:break fa;case 2:break ga;case 0:break ha;default:break ea}}break q}B=Jb(e,f),C=y[m|0]^128,v[B|0]=C;e=d+144|0;Ab(e,x[d+232>>2],y[d+152|0]);bf(e,0);break ea}B=Jb(e,f),C=128,v[B|0]=C;e=d+144|0;Ab(e,x[d+232>>2],y[d+152|0]);bf(e,1);break ea}B=Jb(e,f),C=128,v[B|0]=C;e=d+144|0;Ab(e,x[d+232>>2],y[d+152|0]);bf(e,0)}ia:{if(t){break ia}t=0;e=x[k+4>>2];if(!rq(x[k>>2],e)){break U}f=e-56|0;e=y[d+152|0];if(y[Jb(x[f>>2],e)|0]!=y[Jb(x[h>>2],e)|0]){break ia}Ab(d+144|0,x[f+24>>2],e);e=zb(x[x[d+144>>2]>>2],x[d+148>>2]);Ab(d+136|0,x[d+232>>2],y[d+152|0]);if((zb(x[x[d+136>>2]>>2],x[d+140>>2])|0)==(e|0)){break U}}t=1;break U}x[27524]=0;R(264,d+144|0,d+160|0);e=x[27524];x[27524]=0;if((e|0)==1){break q}e=x[d+220>>2];m=cd(e,x[d+224>>2]);f=y[d+144|0];if(m>>>0<=f>>>0){break U}m=Lc(d+144|0);B=Jb(e,f),C=(y[m|0]>>>2|0)+1|0,v[B|0]=C}b=b+1|0;continue}break}e=1}yb(d+160|0);if(!e){break M}Qm(d+184|0);continue}break}break q}b=1}Zd(d+192|0)}ku(h)}yb(l);if(!b){Uf(d+264|0);continue}break}e=0;if((b|0)!=2){break w}}e=0;Lj(i,0);b=x[k>>2];if(pc(b,x[k+4>>2])){break w}if(!(c&2)){break x}x[27524]=0;U(647,d+160|0,o|0,1347244868);b=x[27524];x[27524]=0;if((b|0)!=1){B=d,C=Cb(x[d+160>>2]),x[B+8>>2]=C;e=a+480190|0;g=d+53|0;h=d+57|0;j=Cb(x[d+164>>2]);l=y[d+287|0];while(1){b=x[d+8>>2];if(!Mb(b,j)){Sc(d+160|0);b=x[k>>2];break x}ja:{ka:{la:{if(!l){x[27524]=0;f=Q(653,b|0,d+40|0)|0;i=x[27524];x[27524]=0;if((i|0)==1){break ja}if(!f){break ka}f=z[d+92>>1];i=f+1|0;w[d+144>>1]=i;if(f>>>0>3998){break la}B=a,C=z[pe(e,d+144|0)>>1],w[B+480190>>1]=C;x[27524]=0;R(654,d+40|0,(D(i&65535,104)+a|0)+484380|0);f=x[27524];x[27524]=0;if((f|0)==1){break ja}f=d+24|0;MT(f,g);x[27524]=0;R(226,d+192|0,f|0);f=x[27524];x[27524]=0;if((f|0)==1){break y}f=d+192|0;Cc(((z[d+144>>1]<<5)+a|0)+946304|0,f);wb(f);break la}x[27524]=0;f=Q(655,b|0,d+40|0)|0;i=x[27524];x[27524]=0;if((i|0)==1){break y}if(!f){break ka}f=z[d+96>>1];i=f+1|0;w[d+144>>1]=i;if(f>>>0>3998){break la}B=a,C=z[pe(e,d+144|0)>>1],w[B+480190>>1]=C;x[27524]=0;R(656,d+40|0,(D(i&65535,104)+a|0)+484380|0);f=x[27524];x[27524]=0;if((f|0)==1){break y}f=d+24|0;MT(f,h);x[27524]=0;R(226,d+192|0,f|0);f=x[27524];x[27524]=0;if((f|0)==1){break y}f=d+192|0;Cc(((z[d+144>>1]<<5)+a|0)+946304|0,f);wb(f)}f=z[d+144>>1];if((f-1&65535)>>>0>3998){break ka}i=Zc(d+40|0,8,1,0,2);x[27524]=0;W(223,i|0,(D(f,104)+a|0)+484380|0,b|0)|0;b=x[27524];x[27524]=0;if((b|0)!=1){break ka}break y}Uf(d+8|0);continue}break}break y}b=P()|0;break j}b=P()|0;break k}b=P()|0;break c}b=P()|0;break c}b=P()|0;Sc(d+160|0);break j}b=FA(b,0);x[a+480196>>2]=y[b+43|0];x[a+480204>>2]=D(y[b+42|0],1e4);_e(Tb(x[a+484360>>2],y[a+484376|0]),z[b+40>>1]);b=0;while(1){if(z[a+480188>>1]>b>>>0){e=(b<<5)+a|0;g=e+480280|0;lf(g);h=FA(x[k>>2],0);B=e+480286|0,C=y[Jb(x[h+12>>2],b)|0],w[B>>1]=C;B=e+480284|0,C=y[Jb(x[h>>2],b)|0],w[B>>1]=C;Ab(d+40|0,x[h+24>>2],b);B=g,C=x[g>>2]&-257|(zb(x[x[d+40>>2]>>2],x[d+44>>2])?256:0),x[B>>2]=C;b=b+1|0;continue}break}x[27524]=0;b=Q(1,d+192|0,(y[d+287|0]?17108:16981)|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break r}Gb(a+1298344|0,b);xb(b);x[27524]=0;b=Q(1,d+24|0,10075)|0;e=x[27524];x[27524]=0;if((e|0)==1){break s}Gb(a+1298356|0,b);xb(b);x[a+1298404>>2]=4;e=1;if(!(c&1)|!z[a+480188>>1]){break w}x[27524]=0;U(647,d+8|0,o|0,1146045008);b=x[27524];x[27524]=0;if((b|0)==1){break t}b=x[d+12>>2];c=x[d+8>>2];x[27524]=0;l=a+484344|0;R(229,l|0,Kf(c,b)&65535);b=x[27524];x[27524]=0;if((b|0)==1){break v}B=d,C=Cb(x[d+8>>2]),x[B+144>>2]=C;s=Cb(x[d+12>>2]);while(1){j=x[d+144>>2];if(!Mb(j,s)){ma:{na:{b=x[k>>2];e=x[k+4>>2];if(rq(b,e)>>>0<2){break na}j=a+484348|0;g=0;while(1){if(rq(b,e)>>>0<=g>>>0){break na}i=x[a+484344>>2];n=x[j>>2];h=Dj(x[a+484360>>2],g&255);m=x[h>>2];c=FA(b,g);f=z[c+36>>1];if(Ce(i,n,z[bc(m,f)>>1])){x[27524]=0;e=Q(364,h|0,f|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break ma}oa:{if(!t){break oa}b=0;while(1){if(z[a+480188>>1]<=b>>>0){break oa}Ab(d+40|0,x[c+24>>2],b);f=zb(x[x[d+40>>2]>>2],x[d+44>>2]);h=Xb(x[l>>2],e);pa:{if(f){ue(h,Kh(zo(Te(Me(d+40|0,20,145),0),b&65535)));break pa}ue(h,Kh(zo(Te(Me(d+40|0,9,y[Jb(x[c>>2],b)|0]),0),b&65535)))}b=b+1|0;continue}}b=d+40|0;ue(Xb(x[l>>2],e),Kh(Te(Me(b,16,y[c+43|0]),0)));ue(Xb(x[l>>2],e),Kh(Te(Me(b,17,y[c+42|0]),0)));e=x[k+4>>2];b=x[k>>2]}g=g+1|0;continue}}Sc(d+8|0);e=1;break w}b=P()|0;break u}b=x[j>>2];x[27524]=0;b=T(164,b|0)|0;c=x[27524];x[27524]=0;qa:{ra:{sa:{ta:{ua:{va:{wa:{if((c|0)==1){break wa}x[27524]=0;c=T(161,j|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break wa}if((b|0)!=(c|0)){break qa}b=x[j>>2];x[27524]=0;b=Q(657,b|0,8)|0;c=x[27524];x[27524]=0;if((c|0)==1){break wa}if(!b){break qa}x[27524]=0;i=Q(652,j|0,d+287|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break ra}x[27524]=0;q=T(198,j|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break sa}x[27524]=0;b=W(230,l|0,i|0,q|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break sa}if(!b){break qa}f=0;while(1){if((f|0)==(q|0)){break qa}b=Xb(x[l>>2],i);c=qf(x[b>>2],x[x[b+48>>2]+12>>2],f);x[27524]=0;b=T(198,j|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break va}xa:{if(b>>>0>=3){x[27524]=0;U(194,d+160|0,j|0,b-2|0);b=x[27524];x[27524]=0;if((b|0)==1){break ta}b=d+160|0;h=hc(d+40|0,b);yb(b);while(1){b=x[h>>2];x[27524]=0;b=W(160,b|0,x[d+48>>2],3)|0;e=x[27524];x[27524]=0;if((e|0)==1){break xa}if(b){x[27524]=0;R(264,d+160|0,h|0);b=x[27524];x[27524]=0;ya:{za:{Aa:{Ba:{if((b|0)!=1){w[d+136>>1]=z[a+480188>>1]-1;B=d,C=y[Lc(d+160|0)|0],w[B+264>>1]=C;e=z[Tc(d+136|0,d+264|0)>>1];g=c+D(e,6)|0;b=v[d+160|0];if((b|0)>=0){break ya}x[27524]=0;b=T(210,h|0)|0;n=x[27524];x[27524]=0;if((n|0)==1){break ua}if(y[d+287|0]){break Aa}if((b|0)!=255){break Ba}b=254;break za}break ua}if(b>>>0>128){break za}b=(D(b>>>4|0,12)+(b&15)|0)+13|0;break za}b=b>>>0<85?b+36|0:b}v[g|0]=b;b=y[d+160|0]}if(b&64){x[27524]=0;b=T(210,h|0)|0;n=x[27524];x[27524]=0;if((n|0)==1){break ua}v[g+1|0]=b+1;b=y[d+160|0]}if(b&32){x[27524]=0;b=T(210,h|0)|0;n=x[27524];x[27524]=0;if((n|0)==1){break ua}v[d+136|0]=b;v[g+2|0]=1;v[d+264|0]=127;B=g,C=y[Ub(d+136|0,d+264|0)|0]+1>>>1|0,v[B+4|0]=C;b=y[d+160|0]}if(!(b&16)){continue}x[27524]=0;R(264,d+136|0,h|0);b=x[27524];x[27524]=0;Ca:{Da:{Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{Za:{_a:{$a:{ab:{bb:{cb:{db:{eb:{fb:{gb:{hb:{if((b|0)!=1){b=y[Lc(d+136|0)|0];v[g+5|0]=b;switch(y[d+136|0]-1|0){case 72:break Da;case 71:break Ea;case 70:break Fa;case 61:break Ga;case 60:break Ha;case 53:break Ia;case 52:break Ja;case 51:break Ka;case 50:break Ma;case 43:break Na;case 42:break Oa;case 41:break Pa;case 40:break Qa;case 31:break Ra;case 30:break Sa;case 23:break Ta;case 22:break Ua;case 21:break Va;case 20:break Wa;case 18:break Xa;case 17:break Ya;case 15:break Za;case 16:break _a;case 14:break $a;case 13:break ab;case 12:break bb;case 11:break cb;case 10:break db;case 3:break eb;case 2:break fb;case 1:break gb;case 0:break hb;default:break Ca}}break ua}v[(c+D(e,6)|0)+3|0]=11;if(y[d+287|0]){v[g+5|0]=b<<4|15;continue}v[g+5|0]=b<<3|15;continue}v[(c+D(e,6)|0)+3|0]=11;if(y[d+287|0]){v[g+5|0]=b<<4;continue}v[g+5|0]=b<<3&240;continue}v[(c+D(e,6)|0)+3|0]=11;if(y[d+287|0]){v[g+5|0]=b|240;continue}v[g+5|0]=b>>>1|240;continue}v[(c+D(e,6)|0)+3|0]=11;if(y[d+287|0]){v[g+5|0]=b&15;continue}if(b>>>0<=1){v[g+5|0]=b|240;continue}v[g+5|0]=b>>>1&15;continue}v[(c+D(e,6)|0)+3|0]=2;B=g,C=ju(b,y[d+287|0])|240,v[B+5|0]=C;continue}v[(c+D(e,6)|0)+3|0]=2;B=g,C=ju(b,y[d+287|0]),v[B+5|0]=C;continue}v[(c+D(e,6)|0)+3|0]=3;B=g,C=ju(b,y[d+287|0])|240,v[B+5|0]=C;continue}v[(c+D(e,6)|0)+3|0]=3;B=g,C=ju(b,y[d+287|0]),v[B+5|0]=C;continue}v[(c+D(e,6)|0)+3|0]=4;if(y[d+287|0]){continue}v[g+5|0]=(b&252)>>>2;continue}v[(c+D(e,6)|0)+3|0]=20;v[g+5|0]=b&1|16;continue}v[(c+D(e,6)|0)+3|0]=6;v[g+5|0]=b&240;continue}v[(c+D(e,6)|0)+3|0]=6;v[g+5|0]=(b&240)>>>4;continue}v[(c+D(e,6)|0)+3|0]=20;continue}v[(c+D(e,6)|0)+3|0]=5;continue}v[(c+D(e,6)|0)+3|0]=20;v[g+5|0]=b&15|48;continue}v[(c+D(e,6)|0)+3|0]=7;v[g+5|0]=b|240;continue}v[(c+D(e,6)|0)+3|0]=7;continue}v[(c+D(e,6)|0)+3|0]=8;continue}v[(c+D(e,6)|0)+3|0]=20;v[g+5|0]=b&15|64;continue}v[(c+D(e,6)|0)+3|0]=10;x[27524]=0;b=T(210,h|0)|0;e=x[27524];x[27524]=0;if((e|0)!=1){break La}break ua}v[(c+D(e,6)|0)+3|0]=15;continue}v[(c+D(e,6)|0)+3|0]=20;v[g+5|0]=b&15|192;continue}v[(c+D(e,6)|0)+3|0]=20;v[g+5|0]=b&15|208;continue}v[(c+D(e,6)|0)+3|0]=12;b=(b&254)>>>1|0}v[g+5|0]=b;x[27524]=0;Q(192,h|0,1)|0;b=x[27524];x[27524]=0;if((b|0)!=1){continue}break ua}v[(c+D(e,6)|0)+3|0]=14;v[g+5|0]=0;continue}v[(c+D(e,6)|0)+3|0]=20;v[g+5|0]=b&15|176;continue}v[(c+D(e,6)|0)+3|0]=20;v[g+5|0]=b&15|224;continue}v[(c+D(e,6)|0)+3|0]=16;continue}v[(c+D(e,6)|0)+3|0]=17;continue}v[(c+D(e,6)|0)+3|0]=1;continue}v[(c+D(e,6)|0)+3|0]=20;v[g+5|0]=b&15|32;continue}v[(c+D(e,6)|0)+3|0]=20;v[g+5|0]=b&15|128;continue}v[(c+D(e,6)|0)+3|0]=0;continue}break}yb(h)}f=f+1|0;continue}break}break ua}b=P()|0;break u}b=P()|0;break u}b=P()|0;yb(h);break u}b=P()|0;break u}b=P()|0;break u}b=P()|0;break u}Uf(d+144|0);continue}}Sc(d+272|0);LT(k);yb(d+304|0);break b}b=P()|0}Sc(d+8|0);break j}b=P()|0;break j}b=P()|0;break j}b=P()|0;break j}b=P()|0;yb(d+160|0);break m}b=P()|0;break l}b=P()|0;xb(d+160|0);break l}b=P()|0;break l}Zd(d+192|0)}ku(h)}yb(l)}Sc(d+272|0);break h}b=P()|0}LT(k);break f}b=P()|0}yb(d+304|0);break c}b=P()|0;break c}b=P()|0}Zd(o);yb(r);S(b|0);p()}Zd(o);yb(r)}ib=d+384|0;return e|0}function kla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0;d=ib-480|0;ib=d;yc(b);i=d+472|0;e=fv(b,i);if(!e){mV(i)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if(!e){break k}if(!nV(d+472|0)){break k}if(!c){B=1;break k}H=te(d+448|0,b);x[27524]=0;R(497,d+432|0,H|0);b=x[27524];x[27524]=0;l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{if((b|0)!=1){x[27524]=0;U(498,d+408|0,d+432|0,20041);b=x[27524];x[27524]=0;if((b|0)==1){break u}x[27524]=0;e=T(182,x[d+408>>2])|0;b=x[27524];x[27524]=0;if((b|0)==1){break m}if(!e){break l}x[27524]=0;e=Q(499,d+408|0,d+312|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break m}if(!e){break l}x[27524]=0;R(250,a|0,16384);b=x[27524];x[27524]=0;if((b|0)==1){break m}x[a+480208>>2]=8;x[27524]=0;e=W(268,a+1074312|0,9,1)|0;b=x[27524];x[27524]=0;if((b|0)==1){break m}x[27524]=0;e=W(268,e|0,114,1)|0;b=x[27524];x[27524]=0;if((b|0)==1){break m}x[27524]=0;e=Q(269,e|0,21)|0;b=x[27524];x[27524]=0;if((b|0)==1){break m}x[27524]=0;Q(269,e|0,30)|0;b=x[27524];x[27524]=0;if((b|0)==1){break m}x[27524]=0;e=Q(1,d+296|0,8228)|0;b=x[27524];x[27524]=0;if((b|0)==1){break r}Gb(a+1298344|0,e);xb(e);x[27524]=0;e=Q(1,d+280|0,10660)|0;b=x[27524];x[27524]=0;if((b|0)==1){break q}Gb(a+1298356|0,e);xb(e);x[27524]=0;g=Q(1,d+264|0,17478)|0;b=x[27524];x[27524]=0;if((b|0)==1){break p}e=15046;b=y[d+476|0];switch(b-16|0){case 1:break n;case 0:break t;default:break s}}f=P()|0;break a}f=P()|0;break b}e=15027;break n}if(!b){break o}e=21631;break n}f=P()|0;break c}f=P()|0;break c}f=P()|0;break c}e=13218}x[27524]=0;i=Q(1,d+248|0,e|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break e}x[27524]=0;U(2,d+208|0,g|0,i|0);b=x[27524];x[27524]=0;if((b|0)==1){break f}e=d+208|0;Gb(a+1298368|0,e);xb(e);xb(i);xb(g);x[a+1298404>>2]=4;b=d+96|0;Se(b,3,d+312|0);x[27524]=0;R(226,e|0,b|0);b=x[27524];x[27524]=0;if((b|0)==1){break g}b=d+208|0;Ac(a+1298308|0,b);wb(b);b=d+232|0;Hj(b,3,d+344|0);x[27524]=0;R(226,d+96|0,b|0);b=x[27524];x[27524]=0;if((b|0)==1){break h}x[27524]=0;U(11,d+208|0,4,d+96|0);b=x[27524];x[27524]=0;if((b|0)==1){break i}b=d+208|0;Gb(a+1298320|0,b);xb(b);wb(d+96|0);x[a+480200>>2]=y[d+368|0]+1;I=a,J=Bd(y[d+369|0],1,255),x[I+480196>>2]=J;I=a,J=D(Bd(y[d+370|0],4,255),1e4),x[I+480204>>2]=J;i=x[a+484360>>2];e=a+484376|0;b=y[e|0];x[27524]=0;ea(344,Tb(i,b)|0,d+408|0,z[d+364>>1],65535,65535);b=x[27524];x[27524]=0;if((b|0)==1){break m}_e(Tb(x[a+484360>>2],y[e|0]),z[d+366>>1]);w[a+480188>>1]=0;b=0;while(1){if((b|0)==32){x[27524]=0;U(498,d+208|0,d+432|0,17741);b=x[27524];x[27524]=0;if((b|0)!=1){b=d+208|0;i=fd(d+408|0,b);yb(b);b=x[i>>2];x[27524]=0;e=T(164,b|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break m}x[27524]=0;X(335,a+1298332|0,i|0,e|0,0);b=x[27524];x[27524]=0;if((b|0)==1){break m}x[27524]=0;U(498,d+208|0,d+432|0,21321);b=x[27524];x[27524]=0;if((b|0)!=1){b=d+208|0;j=fd(i,b);yb(b);b=x[j>>2];x[27524]=0;e=T(182,b|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break m}v:{w:{if(e){x[27524]=0;U(498,d+208|0,d+432|0,16723);b=x[27524];x[27524]=0;if((b|0)==1){break v}x[27524]=0;g=T(210,j|0)|0;b=x[27524];x[27524]=0;x:{if((b|0)!=1){i=c&2;G=a+480190|0;h=0;while(1){if(g>>>0<=(h&255)>>>0){break x}x[27524]=0;q=T(210,j|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break w}if(!q){break x}e=x[j+8>>2];b=x[j>>2];x[27524]=0;e=W(160,b|0,e|0,56)|0;b=x[27524];x[27524]=0;if((b|0)==1){break w}if(!e){break x}if(q>>>0>z[G>>1]){w[G>>1]=q}x[27524]=0;o=D(q,104)+a|0;k=o+484380|0;R(281,k|0,0);b=x[27524];x[27524]=0;if((b|0)==1){break w}xo(k);x[27524]=0;U(318,j|0,((q<<5)+a|0)+946304|0,32);b=x[27524];x[27524]=0;if((b|0)==1){break w}x[27524]=0;R(321,j|0,o+484423|0);b=x[27524];x[27524]=0;if((b|0)==1){break w}y:{if(y[d+476|0]<=15){x[27524]=0;f=T(198,j|0)|0;b=x[27524];x[27524]=0;if((b|0)!=1){break y}break w}x[27524]=0;f=T(161,j|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break w}}x[o+484404>>2]=f<<1;x[27524]=0;e=T(161,j|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break w}x[k>>2]=e;x[27524]=0;e=T(161,j|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break w}C=o+484384|0;x[C>>2]=e;x[27524]=0;e=T(161,j|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break w}m=o+484388|0;x[m>>2]=e;if(e){b=o+484414|0;w[b>>1]=z[b>>1]|2;x[m>>2]=e+x[C>>2]}x[27524]=0;e=T(210,j|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break w}if(y[d+476|0]<=15){w[o+484410>>1]=e}x[27524]=0;q=T(210,j|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break w}b=o+484414|0;e=z[b>>1];B=8;if(q&1){e=e|1;w[b>>1]=e;x[k>>2]=x[k>>2]>>>1;x[C>>2]=x[C>>2]>>>1;x[m>>2]=x[m>>2]>>>1;B=16}w[b>>1]=e&65531|q<<1&4;b=Zc(d+96|0,B,1,0,((q&12)!=0)<<3);z:{if(!i){break z}x[27524]=0;W(223,b|0,k|0,d+208|0)|0;b=x[27524];x[27524]=0;if((b|0)!=1){break z}break w}h=h+1|0;continue}}break w}yb(d+208|0)}x[27524]=0;U(498,d+208|0,d+432|0,18761);b=x[27524];x[27524]=0;A:{if((b|0)!=1){b=d+208|0;l=fd(j,b);yb(b);b=x[l>>2];x[27524]=0;e=T(182,b|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break m}if(!e){break A}r=Nb(d+96|0);s=Nb(d+232|0);u=Nb(d+192|0);x[27524]=0;U(498,d+168|0,d+432|0,17750);b=x[27524];x[27524]=0;B:{if((b|0)==1){break B}b=x[d+180>>2];e=d- -64|0;x[e>>2]=x[d+176>>2];x[e+4>>2]=b;x[d+72>>2]=x[d+184>>2];x[27524]=0;b=x[d+172>>2];x[d+56>>2]=x[d+168>>2];x[d+60>>2]=b;R(500,d+56|0,r|0);b=x[27524];x[27524]=0;if((b|0)==1){break B}x[27524]=0;U(498,d+144|0,d+432|0,17744);b=x[27524];x[27524]=0;if((b|0)==1){break B}b=x[d+156>>2];x[d+40>>2]=x[d+152>>2];x[d+44>>2]=b;x[d+48>>2]=x[d+160>>2];x[27524]=0;b=x[d+148>>2];x[d+32>>2]=x[d+144>>2];x[d+36>>2]=b;R(500,d+32|0,s|0);b=x[27524];x[27524]=0;if((b|0)==1){break B}x[27524]=0;U(498,d+120|0,d+432|0,17734);b=x[27524];x[27524]=0;if((b|0)==1){break B}b=x[d+132>>2];x[d+16>>2]=x[d+128>>2];x[d+20>>2]=b;x[d+24>>2]=x[d+136>>2];x[27524]=0;b=x[d+124>>2];x[d+8>>2]=x[d+120>>2];x[d+12>>2]=b;R(500,d+8|0,u|0);b=x[27524];x[27524]=0;if((b|0)==1){break B}x[27524]=0;o=T(210,l|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break B}j=d+208|1;k=a+480190|0;B=0;while(1){if(o>>>0<=(B&255)>>>0){po(u);po(s);po(r);break A}x[27524]=0;R(264,d+80|0,l|0);b=x[27524];x[27524]=0;C:{if((b|0)!=1){E=Lc(d+80|0);D:{E:{if(!y[d+80|0]){break E}i=x[l+8>>2];e=x[l>>2];b=y[E|0];x[27524]=0;e=W(160,e|0,i|0,D(b,14)+32|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break B}if(!e){break E}x[27524]=0;n=W(255,a|0,y[d+80|0],0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break B}if(n){break D}}b=y[E|0];x[27524]=0;Q(192,l|0,D(b,14)+32|0)|0;b=x[27524];x[27524]=0;if((b|0)!=1){break C}break B}x[27524]=0;U(318,l|0,n+492|0,32);b=x[27524];x[27524]=0;if((b|0)==1){break B}C=n+88|0;m=n+68|0;q=n+48|0;G=n+236|0;b=0;h=0;while(1){if(y[E|0]<=(h&255)>>>0){break C}x[27524]=0;R(501,l|0,d+208|0);e=x[27524];x[27524]=0;if((e|0)==1){break B}e=y[d+208|0];F:{if(!e|e>>>0>z[k>>1]){break F}if(y[j|0]>=129){v[j|0]=128}while(1){e=b&255;g=y[d+209|0];if(e>>>0>g>>>0){e=x[r+4>>2];b=x[r>>2];x[27524]=0;X(502,q|0,y[d+211|0],b|0,e|0);b=x[27524];x[27524]=0;if((b|0)==1){break B}e=x[s+4>>2];b=x[s>>2];x[27524]=0;X(502,m|0,y[d+213|0],b|0,e|0);b=x[27524];x[27524]=0;if((b|0)==1){break B}e=x[u+4>>2];b=x[u>>2];x[27524]=0;X(502,C|0,y[d+221|0],b|0,e|0);b=x[27524];x[27524]=0;if((b|0)==1){break B}x[n>>2]=z[d+214>>1]+1>>>1;e=y[d+208|0];G:{if(y[d+211|0]&64){w[(D(e,104)+a|0)+484410>>1]=y[d+210|0];break G}b=(D(e,104)+a|0)+484414|0;w[b>>1]=z[b>>1]|32768}w[d+118>>1]=y[d+212|0]<<1;w[d+116>>1]=254;t=D(e,104)+a|0;I=t+484408|0,J=z[Tc(d+118|0,d+116|0)>>1],w[I>>1]=J;v[t+484418|0]=y[(y[d+219|0]&3)+26676|0];e=t+484419|0;F=y[d+218|0];v[e|0]=F;i=y[d+217|0]+3>>>2|0;v[t+484420|0]=i;v[t+484421|0]=y[d+216|0];b=g+1|0;if(F){g=Nl(Ec(((i<<8|F>>>1)>>>0)/(F>>>0)|0,0))}else{g=255}v[e|0]=g;if(!(y[d+213|0]&64)){break F}e=t+484414|0;w[e>>1]=z[e>>1]|32}else{I=bc(G,e),J=y[d+208|0],w[I>>1]=J;b=b+1|0;continue}break}}h=h+1|0;continue}}break B}B=B+1|0;continue}}f=P()|0;po(u);po(s);po(r);break c}f=P()|0;break c}B=1;r=Nb(d+232|0);H:{if(!(c&1)){break H}x[27524]=0;U(498,d+208|0,d+432|0,21076);b=x[27524];x[27524]=0;I:{J:{K:{L:{M:{N:{if((b|0)!=1){g=fd(l,d+208|0);b=x[g>>2];x[27524]=0;c=T(182,b|0)|0;b=x[27524];x[27524]=0;O:{P:{Q:{if((b|0)!=1){yb(d+208|0);if(!c){break O}x[27524]=0;e=T(198,g|0)|0;c=x[27524];x[27524]=0;b=1;if((c|0)==1){break Q}x[27524]=0;i=e+1|0;R(503,r|0,i|0);c=x[27524];x[27524]=0;if((c|0)==1){break Q}while(1){if((b|0)==(i|0)){break O}x[27524]=0;e=T(198,g|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break P}x[27524]=0;U(194,d+96|0,g|0,e|0);c=x[27524];x[27524]=0;if((c|0)==1){break P}c=d+96|0;e=hc(d+208|0,c);fd(Yg(x[r>>2],b),e);yb(e);b=b+1|0;yb(c);continue}}f=P()|0;yb(d+208|0);break I}f=P()|0;break I}f=P()|0;break I}x[27524]=0;U(498,d+208|0,d+432|0,16720);b=x[27524];x[27524]=0;if((b|0)==1){break K}l=fd(g,d+208|0);b=x[l>>2];x[27524]=0;c=T(182,b|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break L}yb(d+208|0);if(!c){break N}x[27524]=0;F=T(210,l|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break J}c=0;R:{S:{T:while(1){U:{if(F>>>0<=(c&65535)>>>0){x[27524]=0;Q(159,l|0,1)|0;b=x[27524];x[27524]=0;if((b|0)!=1){break U}break J}h=32;V:{if(y[d+476|0]<16){break V}x[27524]=0;R(504,l|0,d+208|0);b=x[27524];x[27524]=0;if((b|0)==1){break R}h=y[d+208|0];if(h>>>0<=z[a+480188>>1]|h>>>0>32){break V}w[a+480188>>1]=h}b=0;while(1){g=b&65535;if(g>>>0>=h>>>0){c=c+1|0;continue T}x[27524]=0;i=T(198,l|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break S}if(!(!i|g>>>0>31|g>>>0<z[a+480188>>1])){w[a+480188>>1]=b+1}b=b+1|0;continue}}break}x[27524]=0;s=a+484344|0;R(229,s|0,F|0);b=x[27524];x[27524]=0;if((b|0)==1){break J}q=d+208|2;n=0;while(1){if((n|0)==(F|0)){break N}u=Kb(d+96|0);W:{if(y[d+476|0]<16){j=32;i=64;break W}x[27524]=0;R(504,l|0,d+208|0);b=x[27524];x[27524]=0;if((b|0)==1){break M}c=y[d+209|0];j=y[d+208|0];b=d+80|0;yf(b,q,16,3);x[27524]=0;R(226,d+192|0,b|0);b=x[27524];x[27524]=0;if((b|0)==1){break M}b=d+192|0;Ac(u,b);wb(b);i=c+1|0}x[27524]=0;c=W(230,s|0,n&65535,i|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break M}X:{if(!c){x[27524]=0;Q(192,l|0,j<<1)|0;b=x[27524];x[27524]=0;if((b|0)!=1){break X}break M}b=x[s>>2];x[27524]=0;R(285,Xb(b,n)|0,u|0);b=x[27524];x[27524]=0;if((b|0)==1){break M}G=i-1|0;o=0;while(1){t=o&65535;if(t>>>0>=j>>>0){break X}x[27524]=0;c=T(198,l|0)|0;b=x[27524];x[27524]=0;Y:{if((b|0)!=1){if(!c){break Y}b=x[r>>2];if(Kf(b,x[r+4>>2])>>>0<=c>>>0|t>>>0>=z[a+480188>>1]){break Y}A=Yg(b,c);yc(A);c=0;Z:while(1){e=c;if(i>>>0<=e>>>0){break Y}c=x[A+8>>2];b=x[A>>2];x[27524]=0;c=W(160,b|0,c|0,1)|0;b=x[27524];x[27524]=0;_:{$:{aa:{ba:{ca:{if((b|0)!=1){if(!c){break Y}b=Xb(x[s>>2],n);b=hd(x[b>>2],x[x[b+48>>2]+12>>2],e,t);x[27524]=0;g=T(210,A|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break M}k=g<<24>>24;f=(k&252)>>>2|0;switch((k&3)-1|0){case 2:break $;case 1:break aa;case 0:break ba;default:break ca}}break M}c=(e+f|0)+1|0;continue}c=0;if(!e){continue}c=Xb(x[s>>2],n);h=hd(x[c>>2],x[x[c+48>>2]+12>>2],e-1|0,t);while(1){c=y[h|0]|y[h+1|0]<<8|(y[h+2|0]<<16|y[h+3|0]<<24);v[b|0]=c;v[b+1|0]=c>>>8;v[b+2|0]=c>>>16;v[b+3|0]=c>>>24;c=y[h+4|0]|y[h+5|0]<<8;v[b+4|0]=c;v[b+5|0]=c>>>8;c=e+1|0;if((e|0)==(G|0)){continue Z}b=D(z[a+480188>>1],6)+b|0;g=f&255;e=c;f=f-1|0;if(g){continue}break}continue}if(e>>>0<=f>>>0){break _}c=Xb(x[s>>2],n);g=hd(x[c>>2],x[x[c+48>>2]+12>>2],f,t);c=y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24);v[b|0]=c;v[b+1|0]=c>>>8;v[b+2|0]=c>>>16;v[b+3|0]=c>>>24;c=y[g+4|0]|y[g+5|0]<<8;v[b+4|0]=c;v[b+5|0]=c>>>8;break _}if(f&1){x[27524]=0;g=T(210,A|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break M}v[b|0]=g>>>0>120?-1:g}if(f&2){x[27524]=0;g=T(210,A|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break M}v[b+1|0]=g}c=0;h=0;da:{if(f&4){x[27524]=0;h=T(210,A|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break da}}E=0;if(f&8){x[27524]=0;g=T(210,A|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break da}E=g>>>4|0;c=g&15}C=0;m=0;if(f&16){x[27524]=0;m=T(210,A|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break da}}if((k|0)<0){x[27524]=0;C=T(210,A|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break da}}g=h;f=ib-32|0;ib=f;h=f+24|0;jV(h,c,m);k=Lc(h);c=f+16|0;jV(c,((E-1&255)>>>0<6?E+15|0:E)&255,C);m=Lc(c);ea:{fa:{ga:{if(y[f+24|0]==10){h=y[m|0];c=y[k|0]&15;v[k|0]=c?-1:h;c=h|c<<8;h=y[f+16|0];if((h|0)!=10){break ga}h=0;v[f+16|0]=0;break ga}if(y[f+16|0]!=10){break fa}c=y[m|0]&15;v[m|0]=c?-1:0;c=c<<8;h=y[f+24|0]}if(c-256>>>0>4294967038){break fa}if(Ri(h)>>>0>=Ri(10)>>>0){break fa}v[b+5|0]=c;v[b+2|0]=15;v[b+3|0]=10;v[b+4|0]=c>>>8;break ea}if(g){v[b+2|0]=1;v[b+4|0]=g+2>>>2}mv(f+24|0,k,f+16|0,m);c=y[f+16|0];ha:{ia:{h=y[f+24|0];if(h){if((h|0)==20|(h|0)!=(c&255)){break ia}c=h}break ha}if(!(c&255)){v[b+5|0]=y[k|0];v[b+3|0]=h;break ea}if(!g){Fo(f+8|0,b,h,y[k|0],c&255,y[m|0]);break ea}if(Ri(h)>>>0>Ri(c&255)>>>0){v[b+5|0]=y[k|0];v[b+3|0]=h;break ea}}v[b+5|0]=y[m|0];v[b+3|0]=c}ib=f+32|0;break _}break M}c=e+1|0;continue}}break M}o=o+1|0;continue}}wb(u);n=n+1|0;continue}}f=P()|0;break I}f=P()|0;break I}f=P()|0;break I}x[27524]=0;U(498,d+208|0,d+432|0,20048);b=x[27524];x[27524]=0;ja:{ka:{if((b|0)!=1){i=fd(l,d+208|0);b=x[i>>2];x[27524]=0;c=T(182,b|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break ka}yb(d+208|0);if(!c){break H}e=a+484348|0;while(1){if(!Jf(x[a+484344>>2],x[e>>2])){break H}c=x[i+8>>2];b=x[i>>2];x[27524]=0;c=W(160,b|0,c|0,16)|0;b=x[27524];x[27524]=0;if((b|0)==1){break ja}if(!c){break H}x[27524]=0;R(389,i|0,d+208|0);b=x[27524];x[27524]=0;if((b|0)!=1){b=x[a+484344>>2];x[27524]=0;R(390,Xb(b,0)|0,d+208|0);b=x[27524];x[27524]=0;if((b|0)!=1){continue}}break}f=P()|0;break I}f=P()|0;break I}f=P()|0;yb(d+208|0);break I}f=P()|0;break I}f=P()|0;wb(u);break I}f=P()|0;yb(d+208|0);break I}f=P()|0;break I}f=P()|0}Sc(r);break c}Sc(r);break l}f=P()|0;yb(d+208|0);break c}f=P()|0;break c}f=P()|0;break c}f=P()|0;break c}h=(b<<5)+a|0;g=h+480280|0;lf(g);i=v[(b+d|0)+371|0];e=i<<1&254;w[h+480284>>1]=(e|0)==254?256:e;la:{if((i|0)<0){x[g>>2]=x[g>>2]|1024;break la}w[a+480188>>1]=b+1}x[27524]=0;R(505,d+408|0,h+480289|0);e=x[27524];x[27524]=0;if((e|0)==1){break j}b=b+1|0;continue}}f=P()|0;break c}yb(d+408|0);Zd(d+432|0);yb(H)}ib=d+480|0;return B|0}f=P()|0;break c}f=P()|0;wb(d+96|0);break c}f=P()|0;break c}f=P()|0;break c}f=P()|0;xb(i);break d}f=P()|0}xb(g)}yb(d+408|0)}Zd(d+432|0)}yb(H);S(f|0);p()}function mna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0;d=ib-240|0;ib=d;yc(b);e=ib-16|0;ib=e;h=d+216|0;Tu(e+8|0,h);g=x[e+12>>2];kc(e,x[b>>2],x[b+8>>2],x[e+8>>2],x[e+12>>2]);k=x[e+4>>2];if((k|0)==(g|0)){Yb(b,x[e+12>>2])}ib=e+16|0;e=(g|0)==(k|0);if(!e){SW(h)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if(!e){break n}if(!TW(d+216|0)){break n}if(!c){f=1;break n}zd(a,1024);gg(a);x[a+480208>>2]=x[a+480208>>2]|12;fg(a+1074312|0,21);e=Fb(z[d+232>>1]);if(e){x[a+480204>>2]=D(e,1e4)}e=Fb(z[d+230>>1]);if(e){x[a+480196>>2]=e}if(!y[d+226|0]){uh(a,1)}tC(b,a+1298308|0,ac(x[d+220>>2])-14|0);b=te(d+112|0,b);x[27524]=0;R(342,d+200|0,b|0);e=x[27524];x[27524]=0;o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{if((e|0)!=1){yb(b);x[27524]=0;U(343,d+112|0,d+200|0,1395544366);b=x[27524];x[27524]=0;if((b|0)==1){break s}x[27524]=0;b=T(279,x[d+112>>2])|0;e=x[27524];x[27524]=0;if((e|0)==1){break y}if(!b){break r}x[27524]=0;b=T(275,d+112|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break y}x[27524]=0;e=T(275,d+112|0)|0;f=x[27524];x[27524]=0;A:{if((f|0)==1){break A}x[27524]=0;Q(192,d+112|0,4)|0;f=x[27524];x[27524]=0;if((f|0)==1){break A}f=a+484376|0;g=y[f|0];h=x[a+484360>>2];x[27524]=0;ea(344,Tb(h,g)|0,d+112|0,b|0,65535,65535);b=x[27524];x[27524]=0;if((b|0)!=1){break z}}break y}e=P()|0;yb(b);break a}_e(Tb(x[a+484360>>2],y[f|0]),e);b=d+112|0;yb(b);x[27524]=0;U(343,b|0,d+200|0,1346458708);b=x[27524];x[27524]=0;if((b|0)==1){break x}x[27524]=0;e=T(279,x[d+112>>2])|0;b=x[27524];x[27524]=0;if((b|0)==1){break w}f=0;b=0;if(!e){break t}x[27524]=0;e=T(275,d+112|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break w}w[a+480188>>1]=e;if((e-33&65535)>>>0<65504){break t}x[27524]=0;b=T(275,d+112|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break w}x[27524]=0;R(229,a+484344|0,b|0);b=x[27524];x[27524]=0;if((b|0)==1){break w}b=0;x[27524]=0;o=T(283,d+112|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break w}switch(o-841887796|0){case 1:break t;case 0:case 2:break u;default:break v}}e=P()|0;yb(d+112|0);break b}e=P()|0;break b}e=P()|0;yb(d+112|0);break b}if(o){break t}}b=1}yb(d+112|0);if(!b){break o}x[27524]=0;U(343,d+176|0,d+200|0,1398157625);b=x[27524];x[27524]=0;if((b|0)==1){break d}x[27524]=0;b=T(279,x[d+176>>2])|0;e=x[27524];x[27524]=0;if((e|0)==1){break c}if(!b){break q}x[27524]=0;Q(192,d+176|0,2)|0;b=x[27524];x[27524]=0;if((b|0)==1){break c}x[27524]=0;b=T(283,d+176|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break c}H=a,I=Xe((+(b>>>0)*2.3283064365386963e-10+ +(A[a+480204>>2]/1e4>>>0))*1e4),x[H+480204>>2]=I;b=0;x[27524]=0;Q(345,d+176|0,d+112|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break c}f=z[a+480188>>1];while(1){if((b|0)!=32&(b|0)!=(f|0)){H=d,I=Fb(z[(d+112|0)+(b<<1)>>1]),x[H+48>>2]=I;x[d+32>>2]=180;e=x[rd(d+48|0,d+32|0)>>2]-90|0;g=e>>31;H=((b<<5)+a|0)+480284|0,I=Dc(roa(e<<7|45,g<<7|e>>>25,90,0),kb)+128|0,w[H>>1]=I;b=b+1|0;continue}else{B:{x[27524]=0;Q(192,d+176|0,16)|0;b=x[27524];x[27524]=0;if((b|0)!=1){break B}break c}}break}x[27524]=0;b=W(160,x[d+176>>2],x[d+184>>2],2)|0;e=x[27524];x[27524]=0;if((e|0)==1){break c}C:{if(b){x[27524]=0;b=T(275,d+176|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break C}w[d+48>>1]=b;w[d+32>>1]=256;H=a,I=z[Tc(d+48|0,d+32|0)>>1],x[H+480200>>2]=I}x[27524]=0;Q(192,d+176|0,128)|0;b=x[27524];x[27524]=0;if((b|0)==1){break c}x[27524]=0;b=Q(345,d+176|0,d+48|0)|0;e=x[27524];x[27524]=0;if((e|0)!=1){if(!b){break q}e=z[a+480188>>1];b=0;while(1)if((b|0)!=32&(b|0)!=(e|0)){H=d,I=Fb(z[(d+48|0)+(b<<1)>>1]),x[H+32>>2]=I;x[d+16>>2]=128;H=((b<<5)+a|0)+480286|0,I=x[rd(d+32|0,d+16|0)>>2]/2&255,w[H>>1]=I;b=b+1|0;continue}else{x[a+480228>>2]=x[a+480228>>2]<<1;break q}}break c}break c}e=P()|0;break b}yb(d+112|0);break p}yb(d+176|0);x[27524]=0;U(343,d+112|0,d+200|0,1413830740);b=x[27524];x[27524]=0;D:{E:{if((b|0)!=1){x[27524]=0;b=T(279,x[d+112>>2])|0;e=x[27524];x[27524]=0;if((e|0)==1){break e}if(!b){break D}x[27524]=0;R(346,d+112|0,d+48|0);b=x[27524];x[27524]=0;if((b|0)==1){break e}if((Fb(z[d+58>>1])|0)!=65535){break E}x[27524]=0;Q(192,d+112|0,1)|0;b=x[27524];x[27524]=0;if((b|0)!=1){break E}break e}e=P()|0;break b}x[27524]=0;b=T(206,d+112|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break e}x[27524]=0;X(335,a+1298332|0,d+112|0,b|0,2);b=x[27524];x[27524]=0;if((b|0)==1){break e}}yb(d+112|0);x[27524]=0;U(343,d+48|0,d+200|0,1229869908);b=x[27524];x[27524]=0;if((b|0)==1){break h}x[27524]=0;b=T(279,x[d+48>>2])|0;e=x[27524];x[27524]=0;if((e|0)==1){break l}F:{if(!b){break F}x[27524]=0;b=T(275,d+48|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break i}G:{H:{b=b<<16>>16;f=b&32767;if(f>>>0>3999){break H}x[27524]=0;e=W(160,x[d+48>>2],x[d+56>>2],D(f,(b>>>14&2)+50|0)|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break g}if(!e){break H}w[a+480190>>1]=f;g=a+480190|0;h=d+130|0;k=(b|0)>=0;b=1;I:{J:{K:{L:{while(1){if(f>>>0<(b&65535)>>>0){x[27524]=0;b=T(275,d+48|0)|0;e=x[27524];x[27524]=0;if((e|0)!=1){break I}break g}M:{if(k){q=b}else{x[27524]=0;e=T(275,d+48|0)|0;m=x[27524];x[27524]=0;if((m|0)==1){break M}q=e+1|0}w[d+16>>1]=q;x[27524]=0;R(347,d+48|0,d+112|0);e=x[27524];x[27524]=0;if((e|0)==1){break L}e=z[d+16>>1];if((e-4e3&65535)>>>0>=61537){H=a,I=z[pe(g,d+16|0)>>1],w[H+480190>>1]=I;m=z[d+234>>1]|z[d+236>>1]<<16;x[27524]=0;X(348,d+112|0,(D(e,104)+a|0)+484380|0,ac(m)|0,o|0);e=x[27524];x[27524]=0;if((e|0)==1){break K}e=d+32|0;Ll(e,2,h);x[27524]=0;R(226,d+176|0,e|0);e=x[27524];x[27524]=0;if((e|0)==1){break J}e=d+176|0;Cc(((z[d+16>>1]<<5)+a|0)+946304|0,e);wb(e)}b=b+1|0;continue}break}e=P()|0;break f}e=P()|0;break f}e=P()|0;break f}e=P()|0;break f}if((b|0)!=4){break F}w[d+112>>1]=z[a+480190>>1];w[d+176>>1]=255;h=a+480192|0;b=d+176|0;H=h,I=z[Tc(d+112|0,b)>>1],w[H>>1]=I;x[27524]=0;U(343,b|0,d+200|0,1229278806);b=x[27524];x[27524]=0;if((b|0)==1){break j}N:while(1){O:{x[27524]=0;b=W(160,x[d+48>>2],x[d+56>>2],15)|0;e=x[27524];x[27524]=0;if((e|0)==1){break O}if(!b){break G}x[27524]=0;R(349,d+48|0,d+32|0);b=x[27524];x[27524]=0;if((b|0)==1){break k}b=Fb(z[d+32>>1]);if(b>>>0>=z[h>>1]){continue}e=D(b,104)+a|0;v[e+484524|0]=y[d+40|0];f=y[d+39|0];v[e+484523|0]=255;v[e+484525|0]=f;x[27524]=0;b=b+1&65535;e=W(255,a|0,b|0,b|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break k}if(!e){continue}H=d,I=Fb(y[d+37|0]|y[d+38|0]<<8),w[H+112>>1]=I;w[d+16>>1]=4095;H=e,I=z[Tc(d+112|0,d+16|0)>>1],x[H>>2]=I;b=y[d+35|0];if((b|0)==255){continue}x[27524]=0;b=Q(159,d+176|0,D(b,34)+2|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break k}if(!b){continue}x[27524]=0;R(350,d+176|0,d+112|0);b=x[27524];x[27524]=0;if((b|0)==1){break k}v[e+60|0]=y[e+60|0]|1;b=z[d+112>>1];x[d+20>>2]=16;x[d+24>>2]=240;H=d,I=Fb(b),x[H+16>>2]=I;b=pC(d+16|0);x[27524]=0;R(295,e+48|0,b|0);b=x[27524];x[27524]=0;if((b|0)==1){break k}g=x[e+52>>2];f=x[e+48>>2];b=0;while(1){k=$d(f,g);if(k>>>0<=b>>>0){b=y[d+36|0];if((b|0)!=255){v[e- -64|0]=b;v[e+63|0]=b;v[e+60|0]=y[e+60|0]|4}if(pc(f,g)){continue N}b=k-1|0;v[e+62|0]=b;v[e+61|0]=b;v[e+60|0]=y[e+60|0]|2;continue N}else{v[d+16|0]=64;k=(d+112|0)+(b<<1)|0;v[d+12|0]=y[k+2|0];m=Ub(d+16|0,d+12|0);i=Bb(f,b);v[i+2|0]=y[m|0];w[i>>1]=y[k+3|0];b=b+1|0;continue}}}break}break k}yb(d+48|0);break p}yb(d+176|0)}yb(d+48|0);x[27524]=0;U(351,d+176|0,d+200|0,1145131092);b=x[27524];x[27524]=0;if((b|0)==1){break m}H=d,I=Cb(x[d+176>>2]),x[H+16>>2]=I;m=a+484344|0;B=c&1;r=d+48|4;C=Cb(x[d+180>>2]);s=(o|0)!=841887798;t=a+480188|0;E=(o|0)!=841887796;while(1){P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{g=x[d+16>>2];if(!Mb(g,C)){Sc(d+176|0);x[27524]=0;U(343,d+112|0,d+200|0,1346458702);b=x[27524];x[27524]=0;if((b|0)!=1){break aa}e=P()|0;break b}x[27524]=0;Q(192,g|0,4)|0;b=x[27524];x[27524]=0;if((b|0)!=1){x[27524]=0;i=T(275,g|0)|0;b=x[27524];x[27524]=0;ba:{if((b|0)!=1){x[27524]=0;k=T(275,g|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break R}k=s?k:(k>>>0)/A[a+480196>>2]|0;if(!B|i>>>0>255){break P}x[27524]=0;b=W(230,m|0,i|0,k|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break R}if(b){break ba}break P}e=P()|0;break Q}if(!s){h=0;x[27524]=0;Q(192,g|0,4)|0;b=x[27524];x[27524]=0;if((b|0)==1){break R}while(1){u=h&65535;if(u>>>0>=z[t>>1]){break P}x[27524]=0;b=T(275,g|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break $}x[27524]=0;U(194,d+48|0,g|0,b+(b&1)&65535);b=x[27524];x[27524]=0;if((b|0)==1){break S}b=d+48|0;f=hc(d+112|0,b);yb(b);x[d+48>>2]=0;x[d+52>>2]=0;e=0;ca:{while(1){b=x[f>>2];x[27524]=0;b=W(160,b|0,x[d+120>>2],6)|0;j=x[27524];x[27524]=0;if((j|0)==1){break ca}j=x[d+48>>2];if(b&j>>>0<k>>>0){b=Xb(x[m>>2],i);b=hd(x[b>>2],x[x[b+48>>2]+12>>2],j,u);x[27524]=0;R(352,d+32|0,f|0);j=x[27524];x[27524]=0;da:{ea:{if((j|0)!=1){j=d+32|0;l=Lc(j);F=Ze(j);G=Si(j);q=gc(j);n=v[d+32|0];if((n-1&255)>>>0>95){break ea}v[b|0]=n+13;if(!x[d+52>>2]){break da}v[b+3|0]=19;x[d+12>>2]=15;H=b,I=y[rd(r,d+12|0)|0]|208,v[H+5|0]=I;break da}break T}if((n|0)>=0){break da}if(x[d+52>>2]){v[b+3|0]=19;x[d+12>>2]=15;H=b,I=y[rd(r,d+12|0)|0]|192,v[H+5|0]=I;break da}v[b|0]=254}if(y[l|0]){v[b+2|0]=1;v[d+12|0]=64;H=b,I=y[Ub(l,d+12|0)|0],v[H+4|0]=I}l=y[F|0];if(l){v[b+1|0]=l}l=y[G|0];n=y[q|0];if(l|n){Xf(b,l,n)}j=v[j+5|0];b=j&255;l=d+48|0;if((j|0)<0){x[27524]=0;j=T(210,f|0)|0;n=x[27524];x[27524]=0;if((n|0)==1){break T}b=j|b<<8&32512}e=b+e|0;gC(l,e,x[a+480196>>2]);continue}break}yb(f);h=h+1|0;continue}break}break T}h=0;b=Xb(x[m>>2],i);b=hd(x[b>>2],x[x[b+48>>2]+12>>2],0,0);fa:while(1){f=0;if((h|0)==(k|0)){break P}while(1){if(z[t>>1]<=(f&65535)>>>0){h=h+1|0;continue fa}x[27524]=0;R(353,d+48|0,g|0);e=x[27524];x[27524]=0;if((e|0)!=1){v[d+12|0]=0;ga:{if(!E){e=x[d+48>>2];x[d+112>>2]=e;i=d+112|0;j=Lc(i);l=Ze(i);n=Si(i);if(e<<24>>24>0){v[b|0]=(D((e&240)>>>4|0,12)+(e&15)|0)+12}e=y[j|0];if(e>>>0>=4){v[b+2|0]=1;v[b+4|0]=(e>>>2|0)-1;e=y[j|0]}v[b+1|0]=e<<4&48|y[l|0]>>>4;i=y[l|0]&15;v[d+12|0]=i;e=y[n|0];v[b+5|0]=e;break ga}e=x[d+48>>2];x[d+8>>2]=e;x[d+4>>2]=e;e=d+32|0;Su(e,d+4|0,b);i=d+112|0;ZB(i,d+12|0,b+5|0);YB(i,e);H=b,I=y[b+1|0]|y[Jb(d+48|0,0)|0]&48,v[H+1|0]=I;e=y[b+5|0];i=y[d+12|0]}Xf(b,i,e&255);e=y[b+3|0];ha:{if(e>>>0>11){break ha}e=1<<e;ia:{if(!(e&2240)){if(!(e&12)){break ha}if(!y[b+5|0]){break ia}break ha}e=y[b+5|0];i=e&240;if(i){v[b+5|0]=i;break ha}if(e){break ha}}v[b+3|0]=0}b=b+6|0;f=f+1|0;continue}break}break}e=P()|0;break Q}e=P()|0;break Q}x[27524]=0;b=T(279,x[d+112>>2])|0;e=x[27524];x[27524]=0;ja:{ka:{la:{ma:{na:{if((e|0)!=1){if(b){f=Kb(d+48|0);e=a+484348|0;b=0;oa:{while(1){pa:{x[27524]=0;g=W(160,x[d+112>>2],x[d+120>>2],1)|0;h=x[27524];x[27524]=0;if((h|0)==1){break pa}if(!g){break oa}if(Jf(x[a+484344>>2],x[e>>2])>>>0<=b>>>0){break oa}x[27524]=0;U(354,d+112|0,f|0,32);g=x[27524];x[27524]=0;if((g|0)==1){break pa}g=x[m>>2];x[27524]=0;R(285,Xb(g,b)|0,f|0);g=x[27524];x[27524]=0;if((g|0)==1){break pa}b=b+1|0;continue}break}e=P()|0;wb(f);break na}wb(f)}b=d+112|0;yb(b);x[27524]=0;U(343,b|0,d+200|0,1414679374);b=x[27524];x[27524]=0;if((b|0)==1){break ma}x[27524]=0;b=T(279,x[d+112>>2])|0;e=x[27524];x[27524]=0;if((e|0)==1){break V}if(!b){break ja}f=Kb(d+48|0);e=a+480188|0;b=0;while(1){x[27524]=0;g=W(160,x[d+112>>2],x[d+120>>2],1)|0;h=x[27524];x[27524]=0;if((h|0)==1){break la}if(!(g&z[e>>1]>b>>>0)){break ka}x[27524]=0;U(354,d+112|0,f|0,32);g=x[27524];x[27524]=0;if((g|0)==1){break la}Il(((b<<5)+a|0)+480289|0,f);b=b+1|0;continue}}e=P()|0}yb(d+112|0);break b}e=P()|0;break b}e=P()|0;wb(f);break U}wb(f)}b=d+112|0;yb(b);x[27524]=0;U(351,b|0,d+200|0,1145129300);b=x[27524];x[27524]=0;if((b|0)==1){break W}H=d,I=Cb(x[d+112>>2]),x[H+48>>2]=I;e=c&2;f=Cb(x[d+116>>2]);g=a+480190|0;qa:{ra:{sa:{ta:{ua:{va:{while(1){b=x[d+48>>2];if(!Mb(b,f)){Sc(d+112|0);b=Kb(d+48|0);if((o|0)!=841887798){break ua}x[27524]=0;c=Q(1,d+112|0,9438)|0;e=x[27524];x[27524]=0;if((e|0)==1){break va}Gb(b,c);xb(c);break ta}x[27524]=0;c=T(275,b|0)|0;h=x[27524];x[27524]=0;if((h|0)==1){break X}wa:{if(!(!e|c>>>0>=z[g>>1])){c=D(c,104)+a|0;h=z[c+484518>>1];h=Zc(d+176|0,h&1?16:8,h&64?2:1,1,0);x[27524]=0;W(223,h|0,c+484484|0,b|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break wa}}Uf(d+48|0);continue}break}break X}e=P()|0;break Y}x[27524]=0;U(343,d+112|0,d+200|0,1447383635);c=x[27524];x[27524]=0;xa:{ya:{za:{Aa:{Ba:{if((c|0)!=1){x[27524]=0;c=T(279,x[d+112>>2])|0;e=x[27524];x[27524]=0;if((e|0)==1){break sa}if(!c){break ya}x[27524]=0;c=T(283,d+112|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break Ba}x[27524]=0;R(270,d+32|0,4295);e=x[27524];x[27524]=0;if((e|0)==1){break Aa}x[d+16>>2]=c>>>4;x[27524]=0;x[d+12>>2]=c&15;X(355,d+176|0,d+32|0,d+16|0,d+12|0);c=x[27524];x[27524]=0;if((c|0)==1){break za}c=d+176|0;Gb(b,c);xb(c);$b(d+32|0);break xa}e=P()|0;break Y}e=P()|0;break Z}e=P()|0;break Z}e=P()|0;$b(d+32|0);break Z}x[27524]=0;c=Q(1,d+176|0,8457)|0;e=x[27524];x[27524]=0;if((e|0)==1){break _}Gb(b,c);xb(c)}yb(d+112|0)}x[27524]=0;c=Q(1,d+32|0,8457)|0;e=x[27524];x[27524]=0;if((e|0)==1){break ra}Gb(a+1298344|0,c);xb(c);x[27524]=0;c=Q(1,d+16|0,10071)|0;e=x[27524];x[27524]=0;if((e|0)==1){break qa}Gb(a+1298356|0,c);xb(c);Gb(a+1298368|0,b);x[a+1298404>>2]=28;xb(b);f=1;break o}e=P()|0;break Z}e=P()|0;break Y}e=P()|0;break Y}e=P()|0;break Q}e=P()|0}yb(d+112|0)}xb(b);break b}e=P()|0;Sc(d+112|0);break b}e=P()|0;break b}e=P()|0}yb(d+112|0);break b}e=P()|0;yb(f);break Q}e=P()|0;break Q}e=P()|0}Sc(d+176|0);break b}Uf(d+16|0);continue}}f=0}Zd(d+200|0)}ib=d+240|0;return f|0}e=P()|0;break b}e=P()|0;break f}e=P()|0;yb(d+176|0);break f}e=P()|0;break f}e=P()|0;break f}e=P()|0;break b}e=P()|0}yb(d+48|0);break b}e=P()|0;yb(d+112|0);break b}e=P()|0;break b}e=P()|0;yb(d+176|0)}Zd(d+200|0)}S(e|0);p()}function joa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0;d=ib-464|0;ib=d;yc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{if(!ii(b,d+456|0)){break F}if(!ZX(d+456|0)){break F}if(!c){q=1;break F}r=te(d+432|0,b);x[27524]=0;R(265,d+416|0,r|0);b=x[27524];x[27524]=0;G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{if((b|0)!=1){x[27524]=0;U(266,d+240|0,d+416|0,1229866575);b=x[27524];x[27524]=0;if((b|0)==1){break da}x[27524]=0;q=Q(267,d+240|0,d+400|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break fa}yb(d+240|0);if(!q){break G}x[27524]=0;R(250,a|0,524288);b=x[27524];x[27524]=0;ga:{if((b|0)==1){break ga}gg(a);x[a+480208>>2]=12;I=a+480188|0,J=Bd(Fb(z[d+408>>1]),1,127),w[I>>1]=J;I=d,J=Fb(z[d+400>>1]),w[I+240>>1]=J;w[d+344>>1]=255;I=a+480192|0,J=z[Tc(d+240|0,d+344|0)>>1],w[I>>1]=J;I=d,J=Fb(z[d+402>>1]),w[I+240>>1]=J;w[d+344>>1]=3999;I=a+480190|0,J=z[Tc(d+240|0,d+344|0)>>1],w[I>>1]=J;x[27524]=0;b=W(268,a+1074312|0,6,1)|0;e=x[27524];x[27524]=0;if((e|0)==1){break ga}x[27524]=0;b=Q(269,b|0,21)|0;e=x[27524];x[27524]=0;if((e|0)==1){break ga}x[27524]=0;Q(269,b|0,13)|0;b=x[27524];x[27524]=0;if((b|0)!=1){break ea}}b=P()|0;break b}b=P()|0;break a}b=P()|0;yb(d+240|0);break b}x[27524]=0;b=Q(1,d+384|0,9230)|0;e=x[27524];x[27524]=0;if((e|0)==1){break c}Gb(a+1298344|0,b);xb(b);x[27524]=0;b=Q(1,d+368|0,10255)|0;e=x[27524];x[27524]=0;if((e|0)==1){break d}Gb(a+1298356|0,b);xb(b);x[27524]=0;R(270,d+344|0,4339);b=x[27524];x[27524]=0;if((b|0)==1){break e}x[27524]=0;R(271,d+320|0,d+456|4);b=x[27524];x[27524]=0;if((b|0)==1){break g}x[27524]=0;R(271,d+296|0,d+456|5);b=x[27524];x[27524]=0;if((b|0)==1){break i}x[27524]=0;X(115,d+240|0,d+344|0,d+320|0,d+296|0);b=x[27524];x[27524]=0;if((b|0)==1){break j}b=d+240|0;Gb(a+1298368|0,b);xb(b);xb(d+296|0);xb(d+320|0);b=d+344|0;$b(b);x[a+1298404>>2]=28;x[27524]=0;U(266,b|0,d+416|0,1312902469);b=x[27524];x[27524]=0;if((b|0)==1){break k}x[27524]=0;b=T(164,x[d+344>>2])|0;e=x[27524];x[27524]=0;if((e|0)==1){break m}x[27524]=0;g=a+1298308|0;U(272,d+344|0,g|0,b|0);b=x[27524];x[27524]=0;if((b|0)==1){break m}x[27524]=0;U(266,d+320|0,d+416|0,1397706311);b=x[27524];x[27524]=0;if((b|0)==1){break n}h=a+484360|0;e=a+484376|0;Ic(Tb(x[h>>2],y[e|0]));k=Fb(z[d+404>>1]);ha:{ia:{while(1){if(k>>>0<=(f&65535)>>>0){break ha}x[27524]=0;b=W(160,x[d+320>>2],x[d+328>>2],46)|0;j=x[27524];x[27524]=0;ja:{if((j|0)!=1){if(!b){break ha}x[27524]=0;R(273,d+320|0,d+240|0);b=x[27524];x[27524]=0;if((b|0)!=1){if(!Qe(g)){break ja}x[27524]=0;R(274,g|0,d+240|0);b=x[27524];x[27524]=0;if((b|0)!=1){break ja}}b=P()|0;break o}b=P()|0;break o}x[27524]=0;j=T(275,d+320|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break ca}b=Tb(x[a+484360>>2],y[e|0]);if(!pc(x[b>>2],x[b+4>>2])){x[27524]=0;b=T(276,h|0)|0;i=x[27524];x[27524]=0;if((i|0)==1){break ca}if((b|0)==255){break ha}b=Tb(x[a+484360>>2],y[e|0])}x[27524]=0;U(5,d+296|0,28,d+240|0);i=x[27524];x[27524]=0;if((i|0)!=1){x[27524]=0;R(277,b|0,d+296|0);b=x[27524];x[27524]=0;if((b|0)==1){break ia}xb(d+296|0);b=y[e|0];i=x[a+484360>>2];x[27524]=0;U(278,Tb(i,b)|0,d+320|0,j|0);b=x[27524];x[27524]=0;if((b|0)==1){break ca}f=f+1|0;continue}break}b=P()|0;break o}b=P()|0;xb(d+296|0);break o}Lj(h,0);x[27524]=0;U(266,d+296|0,d+416|0,1229869908);b=x[27524];x[27524]=0;if((b|0)==1){break ba}x[27524]=0;b=T(279,x[d+296>>2])|0;f=x[27524];x[27524]=0;if((f|0)==1){break p}ka:{if(!b){break ka}h=a+480192|0;f=1;la:{while(1){b=f&65535;if(b>>>0>z[h>>1]){x[27524]=0;U(266,d+216|0,d+416|0,1447382614);b=x[27524];x[27524]=0;if((b|0)!=1){break la}break p}x[27524]=0;R(280,d+296|0,d+240|0);e=x[27524];x[27524]=0;if((e|0)==1){break p}e=z[d+270>>1];x[27524]=0;b=W(255,a|0,b|0,Fb(e)|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break p}ma:{na:{if(!b){break na}if(Fb(z[d+270>>1])>>>0>3999){break na}e=d+128|0;rC(e,2,d+240|0);x[27524]=0;R(226,d+152|0,e|0);e=x[27524];x[27524]=0;if((e|0)==1){break ma}e=d+152|0;Cc(b+492|0,e);wb(e);g=d+128|0;rC(g,2,d+240|0);x[27524]=0;R(226,e|0,g|0);e=x[27524];x[27524]=0;if((e|0)==1){break p}e=d+152|0;Cc(((Fb(z[d+270>>1])<<5)+a|0)+946304|0,e);wb(e);x[b>>2]=0;I=b,J=se(w[d+286>>1])+128&65535,x[I+8>>2]=J;wc(b+8|0,256);v[b+15|0]=y[b+15|0]|1;b=z[d+270>>1];x[27524]=0;b=D(Fb(b),104)+a|0;R(281,b+484380|0,0);e=x[27524];x[27524]=0;if((e|0)==1){break p}I=d,J=Fb(z[d+272>>1]),w[I+152>>1]=J;w[d+128>>1]=64;I=b+484410|0,J=z[Tc(d+152|0,d+128|0)>>1]<<2,w[I>>1]=J;e=ac(z[d+274>>1]|z[d+276>>1]<<16);g=qoa(e,e>>31,8303,0)+4181|0;e=kb;I=b+484404|0,J=Dc(roa(g,g>>>0<4181?e+1|0:e,8363,0),kb),x[I>>2]=J;e=ac(z[d+282>>1]|z[d+284>>1]<<16);if(!e){break na}g=Fb(z[d+288>>1]);if(!(g&3)){break na}k=e;e=ac(z[d+278>>1]|z[d+280>>1]<<16);x[b+484388>>2]=k+e;x[b+484384>>2]=e;b=b+484414|0;e=z[b>>1];w[b>>1]=e|2;if(!(g&2)){break na}w[b>>1]=e|6}f=f+1|0;continue}break}break p}b=x[d+228>>2];x[d+32>>2]=x[d+224>>2];x[d+36>>2]=b;x[d+40>>2]=x[d+232>>2];x[27524]=0;b=x[d+220>>2];x[d+24>>2]=x[d+216>>2];x[d+28>>2]=b;X(282,d+24|0,0,a|0,0);b=x[27524];x[27524]=0;if((b|0)==1){break p}x[27524]=0;U(266,d+192|0,d+416|0,1346719318);b=x[27524];x[27524]=0;if((b|0)==1){break p}b=x[d+204>>2];x[d+8>>2]=x[d+200>>2];x[d+12>>2]=b;x[d+16>>2]=x[d+208>>2];x[27524]=0;b=x[d+196>>2];x[d>>2]=x[d+192>>2];x[d+4>>2]=b;X(282,d|0,1,a|0,y[d+460|0]>2|0);b=x[27524];x[27524]=0;if((b|0)==1){break p}e=z[a+480192>>1]+1&65535;b=1;while(1){if((b|0)==(e|0)){break ka}f=x[((b<<2)+a|0)+900380>>2];if(!(!f|v[f+60|0]&1)){x[f>>2]=32767}b=b+1|0;continue}}yb(d+296|0);x[27524]=0;U(266,d+240|0,d+416|0,1346458708);b=x[27524];x[27524]=0;if((b|0)==1){break q}x[27524]=0;b=T(182,x[d+240>>2])|0;f=x[27524];x[27524]=0;if((f|0)==1){break s}if(!(!(c&1)|b^1)){x[27524]=0;U(266,d+296|0,d+416|0,1347305805);b=x[27524];x[27524]=0;if((b|0)==1){break t}x[27524]=0;Q(192,d+296|0,1)|0;b=x[27524];x[27524]=0;if((b|0)==1){break v}b=z[d+406>>1];x[27524]=0;m=a+484344|0;R(229,m|0,Fb(b)|0);b=x[27524];x[27524]=0;if((b|0)==1){break v}b=d+128|0;B=b|3;C=b|1;i=Nb(d+176|0);E=a+480188|0;h=0;while(1){if(Fb(z[d+406>>1])>>>0<=l>>>0){jd(i);e=h;yb(d+296|0);if(!(c&4)){break $}f=0;if(!F){break aa}g=z[a+480188>>1];b=0;f=1;while(1){if((b|0)==(g|0)){break aa}h=(b<<5)+a|0;v[h+480288|0]=1;h=h+480280|0;x[h>>2]=x[h>>2]|67108864;b=b+1|0;continue}}x[27524]=0;b=T(275,d+240|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break x}x[27524]=0;f=T(283,d+240|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break y}x[27524]=0;U(194,d+128|0,d+240|0,f|0);f=x[27524];x[27524]=0;if((f|0)==1){break z}f=d+128|0;j=hc(d+152|0,f);yb(f);x[27524]=0;f=W(230,m|0,l&65535,b|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break B}oa:{if(f){o=Kb(d+112|0);x[27524]=0;R(284,d+296|0,o|0);f=x[27524];x[27524]=0;if((f|0)==1){break oa}f=x[m>>2];x[27524]=0;R(285,Xb(f,l)|0,o|0);f=x[27524];x[27524]=0;if((f|0)==1){break oa}n=0;f=Xb(x[m>>2],l);u=qf(x[f>>2],x[x[f+48>>2]+12>>2],0);Ic(i);G=(b>>>0<=1?1:b)-1|0;pa:while(1){b=x[j>>2];x[27524]=0;b=W(160,b|0,x[d+160>>2],1)|0;f=x[27524];x[27524]=0;if((f|0)==1){break C}qa:{if(!b){break qa}x[27524]=0;f=T(210,j|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break C}if(!f){I=d,J=Cb(x[i>>2]),x[I+104>>2]=J;f=Cb(x[i+4>>2]);while(1){b=x[d+104>>2];if(Mb(b,f)){ue(Xb(x[m>>2],l),Te(Me(d+128|0,y[b|0],y[b+1|0]),n));Ye(d+104|0);continue}else{Ic(i);if((n|0)==(G|0)){break qa}b=Xb(x[m>>2],l);n=n+1|0;u=qf(x[b>>2],x[x[b+48>>2]+12>>2],n);continue pa}}}Jj(d+128|0);e=z[E>>1];x[27524]=0;b=T(210,j|0)|0;g=x[27524];x[27524]=0;ra:{sa:{if((g|0)!=1){s=D(f-1|0,6)+u|0;t=e>>>0<f>>>0;k=t?d+128|0:s;ta:{if(!(b&1)){break ta}x[27524]=0;f=T(210,j|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break C}if((f|0)!=31){if((f-1&255)>>>0>252){break ta}e=(D(f>>>4|0,12)+(f&15)|0)+13|0}else{e=255}v[k|0]=e}if(!(b&2)){break ra}x[27524]=0;f=T(210,j|0)|0;e=x[27524];x[27524]=0;if((e|0)!=1){break sa}}break C}v[(t?C:s+1|0)|0]=f}if(!(b&60)){continue}f=0;e=0;if(b&4){x[27524]=0;e=T(210,j|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break C}}if(b&8){x[27524]=0;f=T(210,j|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break C}}g=0;A=0;if(b&16){x[27524]=0;A=T(210,j|0)|0;H=x[27524];x[27524]=0;if((H|0)==1){break C}}if(b&32){x[27524]=0;g=T(210,j|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break C}}b=d+104|0;WX(b,A,g);g=Lc(b);b=d+96|0;WX(b,e,f);f=Lc(b);b=y[d+96|0];ua:{if((b|0)!=13){if(b){break ua}b=0;if(y[d+104|0]==13){break ua}}Qi(d+104|0,d+96|0);Qi(g,f);b=y[d+96|0]}Fo(d+88|0,k,y[d+104|0],y[g|0],b&255,y[f|0]);if(VX(y[d+88|0],y[d+89|0])){b=x[Wb(d+80|0,Cb(x[i>>2]))>>2];x[27524]=0;U(286,i|0,b|0,d+88|0);b=x[27524];x[27524]=0;if((b|0)==1){break C}}b=y[(t?B:s+3|0)|0];if((b|0)==43){F=1;continue}if((b|0)!=31){continue}h=1;continue}break}wb(o)}yb(j);l=l+1|0;continue}break}break C}e=0;f=0;if(c&4){break aa}break H}b=P()|0;break b}b=P()|0;break o}b=P()|0;break o}x[d+176>>2]=-1778364416;x[d+180>>2]=-16756736;x[27524]=0;U(266,d+296|0,d+416|0,1146310725);b=x[27524];x[27524]=0;if((b|0)==1){break E}x[27524]=0;b=T(279,x[d+296>>2])|0;g=x[27524];x[27524]=0;if((g|0)==1){break D}if(b){x[27524]=0;k=T(275,d+296|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break D}j=a+480188|0;b=0;g=f;while(1){va:{if((b|0)==(k|0)){x[27524]=0;R(287,d+296|0,d+176|0);b=x[27524];x[27524]=0;if((b|0)!=1){break va}break D}x[27524]=0;h=T(210,d+296|0)|0;i=x[27524];x[27524]=0;wa:{xa:{if((i|0)!=1){if(z[j>>1]<=b>>>0){break wa}if(!f){break xa}i=((b<<5)+a|0)+480280|0;x[i>>2]=x[i>>2]&-67108865|((h|0)!=0)<<26;break wa}break D}if(h){break wa}g=1;v[((b<<5)+a|0)+480288|0]=1}b=b+1|0;continue}break}f=g&1}yb(d+296|0);if(!f){break $}x[27524]=0;b=Nd(a+906300|0,0);Y(288,b|0);f=x[27524];x[27524]=0;if((f|0)==1){break _}x[b+16>>2]=810369604;x[b+20>>2]=1869112133;x[b+24>>2]=655376;x[b+28>>2]=0;x[d+296>>2]=0;g=b+48|0;SX(b+32|0,g,d+296|0);x[27524]=0;f=Q(55,d+152|0,9504)|0;h=x[27524];x[27524]=0;if((h|0)==1){break Z}qC(g,f);wb(f);x[27524]=0;f=Q(55,d+128|0,9468)|0;g=x[27524];x[27524]=0;if((g|0)==1){break Y}cv(b+80|0,f);wb(f);x[27524]=0;R(289,b+4|0,8);f=x[27524];x[27524]=0;if((f|0)==1){break _}RX(d+296|0,y[d+177|0],y[d+179|0],y[d+181|0],y[d+183|0]);f=x[d+300>>2];b=x[b+4>>2];g=x[d+296>>2];v[b|0]=g;v[b+1|0]=g>>>8;v[b+2|0]=g>>>16;v[b+3|0]=g>>>24;v[b+4|0]=f;v[b+5|0]=f>>>8;v[b+6|0]=f>>>16;v[b+7|0]=f>>>24}if(!e){break H}f=a+902204|0;b=0;while(1){if((b|0)==32){break H}x[d+104>>2]=D(b,127)>>>5;x[27524]=0;R(290,d+176|0,4096);e=x[27524];x[27524]=0;if((e|0)==1){break X}x[27524]=0;R(291,d+112|0,d+104|0);e=x[27524];x[27524]=0;if((e|0)==1){break W}x[27524]=0;U(292,d+296|0,d+176|0,d+112|0);e=x[27524];x[27524]=0;if((e|0)==1){break V}e=d+296|0;ye(d+72|0,e);pf(De(f,b),x[d+72>>2],x[d+76>>2]);wb(e);wb(d+112|0);e=d+176|0;Zb(e);x[27524]=0;R(290,e|0,4078);e=x[27524];x[27524]=0;if((e|0)==1){break T}x[27524]=0;R(291,d+112|0,d+104|0);e=x[27524];x[27524]=0;if((e|0)==1){break S}x[27524]=0;U(292,d+296|0,d+176|0,d+112|0);e=x[27524];x[27524]=0;if((e|0)==1){break R}e=d+296|0;ye(d- -64|0,e);pf(De(f,b+32|0),x[d+64>>2],x[d+68>>2]);wb(e);wb(d+112|0);e=d+176|0;Zb(e);x[27524]=0;R(290,e|0,4069);e=x[27524];x[27524]=0;if((e|0)==1){break P}x[27524]=0;R(291,d+112|0,d+104|0);e=x[27524];x[27524]=0;if((e|0)==1){break O}x[27524]=0;U(292,d+296|0,d+176|0,d+112|0);e=x[27524];x[27524]=0;if((e|0)==1){break N}e=d+296|0;ye(d+56|0,e);pf(De(f,b- -64|0),x[d+56>>2],x[d+60>>2]);wb(e);wb(d+112|0);e=d+176|0;Zb(e);x[27524]=0;R(290,e|0,4042);e=x[27524];x[27524]=0;if((e|0)==1){break L}x[27524]=0;R(291,d+112|0,d+104|0);e=x[27524];x[27524]=0;if((e|0)==1){break K}x[27524]=0;U(292,d+296|0,d+176|0,d+112|0);e=x[27524];x[27524]=0;if((e|0)==1){break J}e=d+296|0;ye(d+48|0,e);pf(De(f,b+96|0),x[d+48>>2],x[d+52>>2]);b=b+1|0;wb(e);wb(d+112|0);Zb(d+176|0);continue}}b=P()|0;break r}b=P()|0;break r}b=P()|0;break r}b=P()|0;break r}b=P()|0;break U}b=P()|0;wb(d+112|0)}Zb(d+176|0);break r}b=P()|0;break r}b=P()|0;break Q}b=P()|0;wb(d+112|0)}Zb(d+176|0);break r}b=P()|0;break r}b=P()|0;break M}b=P()|0;wb(d+112|0)}Zb(d+176|0);break r}b=P()|0;break r}b=P()|0;break I}b=P()|0;wb(d+112|0)}Zb(d+176|0);break r}x[27524]=0;U(266,d+296|0,d+416|0,1397575756);b=x[27524];x[27524]=0;ya:{if((b|0)!=1){x[27524]=0;b=T(182,x[d+296>>2])|0;f=x[27524];x[27524]=0;if((f|0)!=1){za:{f=1;if(!(c&2)|b^1){break ya}c=a+480190|0;while(1){e=f&65535;if(e>>>0>z[c>>1]){break ya}x[27524]=0;b=T(283,d+296|0)|0;g=x[27524];x[27524]=0;Aa:{if((g|0)!=1){x[27524]=0;g=T(283,d+296|0)|0;h=x[27524];x[27524]=0;if((h|0)==1){break za}if(!(b&7)){break Aa}e=(D(e,104)+a|0)+484380|0;x[e>>2]=g;b=Zc(d+176|0,b&4?32:b&2?16:8,1,1,0);x[27524]=0;W(223,b|0,e|0,d+296|0)|0;b=x[27524];x[27524]=0;if((b|0)!=1){break Aa}break za}break za}f=f+1|0;continue}}}b=P()|0;yb(d+296|0);break r}b=P()|0;break r}yb(d+296|0);yb(d+240|0);yb(d+320|0);yb(d+344|0)}Zd(d+416|0);yb(r)}ib=d+464|0;return q|0}b=P()|0;break r}b=P()|0;yb(d+296|0);break r}b=P()|0;wb(o);break A}b=P()|0}yb(j);break w}b=P()|0;break w}b=P()|0;break w}b=P()|0}jd(i);break u}b=P()|0}yb(d+296|0);break r}b=P()|0;break r}b=P()|0}yb(d+240|0);break o}b=P()|0;break o}b=P()|0;yb(d+296|0)}yb(d+320|0);break l}b=P()|0;break l}b=P()|0}yb(d+344|0);break b}b=P()|0;break b}b=P()|0;xb(d+296|0);break h}b=P()|0}xb(d+320|0);break f}b=P()|0}$b(d+344|0);break b}b=P()|0;break b}b=P()|0;break b}b=P()|0}Zd(d+416|0)}yb(r);S(b|0);p()}function Iia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,V=0;f=ib-496|0;ib=f;yc(b);i=ib-16|0;ib=i;g=f+288|0;bT(i+8|0,g);e=x[i+12>>2];n=b;kc(i,x[b>>2],x[b+8>>2],x[i+8>>2],x[i+12>>2]);b=x[i+4>>2];if((b|0)==(e|0)){Yb(n,x[i+12>>2])}ib=i+16|0;b=(b|0)==(e|0);if(!b){aT(g)}a:{if(!b){break a}if(!cT(f+288|0)){break a}if(!c){d=1;break a}zd(a,134217728);b=f+8|0;_f(b,3956);x[27524]=0;U(680,f+120|0,b|0,z[f+292>>1]);b=x[27524];x[27524]=0;b:{c:{d:{e:{f:{g:{if((b|0)!=1){b=f+120|0;Gb(a+1298344|0,b);xb(b);$b(f+8|0);b=xc(b,8922);Gb(a+1298356|0,b);xb(b);x[a+480188>>2]=4;x[a+1298404>>2]=28;O=a,V=Fb(z[f+424>>1]),x[O+480196>>2]=V;b=z[f+428>>1];x[a+480260>>2]=56;x[a+480264>>2]=13696;O=a,V=$S(Fb(b)),x[O+480204>>2]=V;Uq(Tb(x[a+484360>>2],y[a+484376|0]),f+296|0,y[f+294|0]);q=a+480190|0;m=a+480188|0;o=Nb(f+272|0);u=Nb(f+256|0);h:{i:{j:{k:{l:{while(1){if(Fb(z[f+488>>1])>>>0<=(l&65535)>>>0){break k}x[27524]=0;b=T(275,n|0)|0;i=x[27524];x[27524]=0;if((i|0)==1){break g}w[f+232>>1]=b;if((b-4e3&65535)>>>0<=61536){break c}d=Fb(z[f+490>>1]);if((Fb(z[f+292>>1])|0)==2){x[27524]=0;b=T(283,n|0)|0;i=x[27524];x[27524]=0;if((i|0)==1){break h}d=b-2|0}x[27524]=0;U(194,f+8|0,n|0,d|0);b=x[27524];x[27524]=0;if((b|0)==1){break i}b=f+8|0;h=hc(f+120|0,b);yb(b);C=z[pe(q,f+232|0)>>1];w[q>>1]=C;x[27524]=0;j=D(z[f+232>>1],104)+a|0;e=j+484380|0;R(281,e|0,1);b=x[27524];x[27524]=0;m:{n:{o:{if((b|0)==1){break o}if(Fb(z[f+292>>1])>>>0>1){break n}x[27524]=0;R(681,h|0,j+484423|0);b=x[27524];x[27524]=0;if((b|0)==1){break o}x[27524]=0;Q(192,h|0,1)|0;b=x[27524];x[27524]=0;if((b|0)==1){break o}x[27524]=0;U(329,h|0,((z[f+232>>1]<<5)+a|0)+946304|0,30);b=x[27524];x[27524]=0;if((b|0)!=1){break m}}e=P()|0;break f}b=Kb(f+8|0);x[27524]=0;U(354,h|0,b|0,257);i=x[27524];x[27524]=0;p:{q:{if((i|0)==1){break q}Fe(j+484423|0,b);x[27524]=0;Q(192,h|0,1)|0;i=x[27524];x[27524]=0;if((i|0)==1){break q}x[27524]=0;U(354,h|0,b|0,31);i=x[27524];x[27524]=0;if((i|0)==1){break q}Cc(((z[f+232>>1]<<5)+a|0)+946304|0,b);if(!(v[f+128|0]&1)){break p}x[27524]=0;Q(192,h|0,1)|0;i=x[27524];x[27524]=0;if((i|0)!=1){break p}}e=P()|0;wb(b);break f}wb(b)}x[27524]=0;R(682,h|0,f+8|0);b=x[27524];x[27524]=0;if((b|0)==1){break l}d=ib-16|0;ib=d;i=ac(y[f+8|0]|y[f+9|0]<<8|(y[f+10|0]<<16|y[f+11|0]<<24));x[e>>2]=i;v[d+15|0]=y[f+12|0];v[d+14|0]=64;O=e,V=y[Ub(d+15|0,d+14|0)|0]<<2,w[O+30>>1]=V;g=ac(y[f+14|0]|y[f+15|0]<<8|(y[f+16|0]<<16|y[f+17|0]<<24));x[e+4>>2]=g;b=ac(y[f+14|0]|y[f+15|0]<<8|(y[f+16|0]<<16|y[f+17|0]<<24))+ac(y[f+18|0]|y[f+19|0]<<8|(y[f+20|0]<<16|y[f+21|0]<<24))|0;x[e+8>>2]=b;if(g>>>0>=i>>>0){g=i-1|0;x[e+4>>2]=g}if(b>>>0>i>>>0){x[e+8>>2]=i;b=i}r:{if(b>>>0<g>>>0){x[e+4>>2]=0;x[e+8>>2]=0;break r}if(b>>>0<=g>>>0){break r}w[e+34>>1]=z[e+34>>1]|2;O=Bb(e+68|0,0),V=g,x[O>>2]=V}ib=d+16|0;s:{t:{u:{switch(Fb(z[f+292>>1])|0){case 2:v[j+484417|0]=y[f+26|0]<<3;break;case 0:break t;default:break u}}x[27524]=0;R(218,u|0,C|0);b=x[27524];x[27524]=0;if((b|0)==1){break l}x[27524]=0;R(683,o|0,C|0);b=x[27524];x[27524]=0;if((b|0)==1){break l}i=Cd(x[o>>2],z[f+232>>1]-1|0);Ic(i);x[27524]=0;b=T(275,n|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break j}e=x[n+8>>2];d=x[n>>2];x[27524]=0;e=W(160,d|0,e|0,b<<3)|0;d=x[27524];x[27524]=0;if((d|0)==1){break j}if(!e){break s}x[27524]=0;R(684,i|0,b|0);e=x[27524];x[27524]=0;if((e|0)==1){break j}d=0;x[f+248>>2]=0;if(!(!(y[j+484414|0]&2)|b)){b=x[j+484384>>2];x[f+240>>2]=b;e=x[j+484388>>2];x[27524]=0;x[f+244>>2]=e-b;R(685,i|0,f+240|0);b=x[27524];x[27524]=0;if((b|0)!=1){break t}e=P()|0;break f}while(1){if(b>>>0<=(d&65535)>>>0){break t}x[27524]=0;e=T(283,n|0)|0;g=x[27524];x[27524]=0;v:{if((g|0)==1){break v}x[27524]=0;x[f+240>>2]=e;e=T(283,n|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break v}x[27524]=0;x[f+244>>2]=e;R(685,i|0,f+240|0);e=x[27524];x[27524]=0;if((e|0)==1){break v}d=d+1|0;continue}break}e=P()|0;break f}yb(h);l=l+1|0;continue}break}yb(h);break c}e=P()|0;break f}w:{x:{y:{z:{if(Fb(z[f+292>>1])){B=y[f+295|0];w[f+238>>1]=4;E=128;break z}x[27524]=0;E=T(275,n|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){e=P()|0;break e}b=z[f+292>>1];B=y[f+295|0];w[f+238>>1]=4;if(!Fb(b)){break y}}i=x[n+8>>2];e=0;while(1){A:{if((e&65535)>>>0>=E>>>0){break A}x[27524]=0;b=T(275,n|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break x}if((b|0)==65535){break A}x[27524]=0;B=T(275,n|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break x}x[27524]=0;b=T(275,n|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break x}w[f+238>>1]=b;if(b>>>0>127){break c}O=m,V=z[pe(m,f+238|0)>>1],w[O>>1]=V;x[27524]=0;Q(192,n|0,D(b,B)<<2)|0;b=x[27524];x[27524]=0;if((b|0)==1){break x}e=e+1|0;continue}break}x[27524]=0;Q(159,n|0,i|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break w}}b=z[m>>1];x[27524]=0;F=Q(686,f+240|0,b|0)|0;b=x[27524];x[27524]=0;if((b|0)!=1){K=a+484344|0;N=c&1;G=Fb(z[f+426>>1]);b=0;i=0;while(1){B:{C:{D:{E:{if((b&65535)>>>0>=E>>>0){break E}F:{if(!Fb(z[f+292>>1])){d=z[f+238>>1];e=b;break F}x[27524]=0;e=T(275,n|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break B}if((e|0)==65535){break E}x[27524]=0;B=T(275,n|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break B}x[27524]=0;d=T(275,n|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break B}w[f+238>>1]=d}g=x[n+8>>2];h=x[n>>2];x[27524]=0;s=g;H=B&65535;g=H<<2;d=W(160,h|0,s|0,D(g,d&65535)|0)|0;h=x[27524];x[27524]=0;if((h|0)==1){break B}if(!d){break E}if(!N){break D}x[27524]=0;L=e&65535;e=W(230,K|0,L|0,H|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break B}if(!e){break D}t=0;G:while(1){if((t|0)==(H|0)){break C}e=0;d=Xb(x[K>>2],L);j=qf(x[d>>2],x[x[d+48>>2]+12>>2],t);I=0;s=0;H:{I:{J:{switch((G&3)-1|0){case 0:s=!(t&3);break I;case 1:s=!(t&1);break I;case 2:break J;default:break H}}s=(t&3)!=3}}while(1){if(z[f+238>>1]<=e>>>0){t=t+1|0;continue G}d=x[F>>2];x[27524]=0;R(353,f+232|0,n|0);g=x[27524];x[27524]=0;if((g|0)==1){break B}h=D(e,9)+d|0;d=f+232|0;g=Lc(d);r=Ze(d);m=j+D(e,6)|0;v[m+1|0]=y[f+232|0];k=y[g|0];v[m|0]=k;g=y[Si(d)|0];v[m+5|0]=g;l=m+5|0;if(k){v[m|0]=k+25;v[h+8|0]=0;v[h|0]=0;v[h+1|0]=0;v[h+2|0]=0;v[h+3|0]=0;v[h+4|0]=0;v[h+5|0]=0;v[h+6|0]=0;v[h+7|0]=0;g=y[l|0]}k=g&255;r=y[r|0];K:{if(r>>>0>=240){d=k|(r&15)<<8;if(d){O=l,V=Ak(+($S(d)>>>0)/1e4),v[O|0]=V;v[m+3|0]=17;break K}v[m+3|0]=0;break K}J=k>>>4|0;M=k<<4;d=J|M;L:{switch(r|0){case 0:d=j+D(e,6)|0;if(g&255){v[d+3|0]=1;break K}v[d+3|0]=0;break K;case 1:v[(j+D(e,6)|0)+3|0]=2;break K;case 2:v[(j+D(e,6)|0)+3|0]=3;break K;case 3:v[f+228|0]=15;O=h,V=y[Ub(l,f+228|0)|0]|16,v[O|0]=V;v[h+7|0]=0;v[h+1|0]=0;v[h+2|0]=0;v[(j+D(e,6)|0)+3|0]=0;break K;case 4:v[f+228|0]=15;O=h,V=y[Ub(l,f+228|0)|0]|32,v[O|0]=V;v[h+7|0]=0;v[h+1|0]=0;v[h+2|0]=0;v[(j+D(e,6)|0)+3|0]=0;break K;case 5:v[h+7|0]=0;v[h+2|0]=0;v[h+1|0]=g;v[h|0]=0;v[(j+D(e,6)|0)+3|0]=0;break K;case 6:v[h+7|0]=0;v[h+2|0]=g;v[h|0]=0;v[h+1|0]=0;v[(j+D(e,6)|0)+3|0]=0;break K;case 7:v[(j+D(e,6)|0)+3|0]=23;i=0;break K;case 8:v[(j+D(e,6)|0)+3|0]=0;i=d;break K;case 9:v[(j+D(e,6)|0)+3|0]=19;v[f+228|0]=15;O=l,V=y[Ub(l,f+228|0)|0]|16,v[O|0]=V;break K;case 10:v[(j+D(e,6)|0)+3|0]=19;v[f+228|0]=15;O=l,V=y[Ub(l,f+228|0)|0]|32,v[O|0]=V;break K;case 11:v[h+3|0]=d;v[(j+D(e,6)|0)+3|0]=0;break K;case 12:d=j+D(e,6)|0;v[d+4|0]=g;v[d+2|0]=1;v[h+3|0]=0;v[d+3|0]=0;break K;case 13:M:{N:{if((g&255)>>>0>=16){v[(j+D(e,6)|0)+2|0]=4;g=(g&240)>>>4|0;break N}if(!(k&15)){break M}v[(j+D(e,6)|0)+2|0]=3}v[(j+D(e,6)|0)+4|0]=g}v[h+3|0]=0;v[(j+D(e,6)|0)+3|0]=0;break K;case 14:v[(j+D(e,6)|0)+3|0]=19;v[l|0]=!(g&255);break K;case 15:v[(j+D(e,6)|0)+3|0]=16;v[l|0]=(g&240)>>>4;G=g&15;break K;case 16:v[h+5|0]=0;v[h+4|0]=g;v[(j+D(e,6)|0)+3|0]=0;break K;case 17:v[h+6|0]=k&15?g:0;v[(j+D(e,6)|0)+3|0]=0;break K;case 18:v[(j+D(e,6)|0)+3|0]=14;break K;case 19:v[h+8|0]=0;v[h+7|0]=g;v[h+2|0]=0;v[h|0]=0;v[h+1|0]=0;v[(j+D(e,6)|0)+3|0]=0;break K;case 20:v[(j+D(e,6)|0)+3|0]=12;break K;case 22:d=y[m+1|0];O:{if(!d){break O}k=x[o>>2];if(wd(k,x[o+4>>2])>>>0<d>>>0){break O}g=g-1|0;v[l|0]=g;x[27524]=0;T(687,f+120|0)|0;r=x[27524];x[27524]=0;if((r|0)==1){break B}x[f+228>>2]=9;d=Cd(k,d-1|0);O=f,V=wd(x[d>>2],x[d+4>>2]),x[O+116>>2]=V;if(A[Hb(f+228|0,f+116|0)>>2]<=(g&255)>>>0){break O}d=j+D(e,6)|0;v[d+2|0]=15;v[d+4|0]=y[l|0]}v[(j+D(e,6)|0)+3|0]=0;break K;case 23:d=y[m+1|0];P:{if(!d){break P}k=x[o>>2];if(wd(k,x[o+4>>2])>>>0<d>>>0){break P}g=g-1|0;v[l|0]=g;d=Cd(k,d-1|0);k=x[d>>2];r=wd(k,x[d+4>>2]);d=g&255;if(r>>>0<=d>>>0){break P}d=Cd(k,d);g=z[d+8>>1];Q:{if(g){break Q}g=0;k=z[q>>1];if(!bi(k)){break Q}g=k+1|0;w[q>>1]=g;w[d+8>>1]=g}v[m+1|0]=g}v[(j+D(e,6)|0)+3|0]=0;break K;case 24:d=y[m+1|0];R:{if(!d){break R}k=x[o>>2];if(wd(k,x[o+4>>2])>>>0<d>>>0){break R}g=g-1|0;v[l|0]=g;x[27524]=0;T(687,f+8|0)|0;r=x[27524];x[27524]=0;if((r|0)==1){break B}x[f+228>>2]=9;d=Cd(k,d-1|0);O=f,V=wd(x[d>>2],x[d+4>>2]),x[O+116>>2]=V;if(A[Hb(f+228|0,f+116|0)>>2]>(g&255)>>>0){d=j+D(e,6)|0;v[d+2|0]=15;v[d+4|0]=y[l|0]}d=bc(x[u>>2],y[m+1|0]-1|0);g=z[d>>1];S:{if(g){break S}g=0;k=z[q>>1];if(!bi(k)){break S}g=k+1|0;w[q>>1]=g;w[d>>1]=g}v[m+1|0]=g}v[(j+D(e,6)|0)+3|0]=0;break K;case 25:d=y[m+1|0];T:{if(!d){break T}k=x[o>>2];if(wd(k,x[o+4>>2])>>>0<d>>>0){break T}g=g-1|0;v[l|0]=g;d=Cd(k,d-1|0);k=x[d>>2];r=wd(k,x[d+4>>2]);d=g&255;if(r>>>0<=d>>>0){break T}d=Cd(k,d);g=z[d+10>>1];U:{if(g){break U}g=0;k=z[q>>1];if(!bi(k)){break U}g=k+1|0;w[q>>1]=g;w[d+10>>1]=g}v[m+1|0]=g}v[(j+D(e,6)|0)+3|0]=0;break K;case 29:v[(j+D(e,6)|0)+3|0]=11;v[l|0]=d;if(k&15){v[l|0]=M|15;break K}if((g&255)>>>0<16){break K}v[l|0]=J|240;break K;case 32:if((g&255)>>>0>=16){v[h+3|0]=J;v[(j+D(e,6)|0)+3|0]=0;break K}v[(j+D(e,6)|0)+3|0]=19;v[l|0]=g|192;break K;case 33:v[(j+D(e,6)|0)+3|0]=19;v[f+228|0]=15;O=l,V=y[Ub(l,f+228|0)|0]|208,v[O|0]=V;break K;case 34:v[(j+D(e,6)|0)+3|0]=19;v[f+228|0]=15;O=l,V=y[Ub(l,f+228|0)|0]|144,v[O|0]=V;break K;case 73:v[(j+D(e,6)|0)+3|0]=10;break K;case 78:if((g&112|128)==224){v[(j+D(e,6)|0)+3|0]=19;break K}v[(j+D(e,6)|0)+3|0]=0;break K;case 79:d=j+D(e,6)|0;if((g&255)>>>0<=31){v[d+3|0]=16;G=0;break K}v[d+3|0]=17;break K;default:break L}}v[(j+D(e,6)|0)+3|0]=0}k=0;g=y[h+3|0];if(!(y[m+2|0]|!g)){V:{if(g>>>0>=16){v[m+2|0]=5;g=g>>>4|0;break V}v[m+2|0]=6}v[m+4|0]=g;k=1}W:{if(y[m+3|0]){break W}d=y[h+1|0];X:{if(d){v[m+3|0]=2;break X}d=y[h+2|0];if(d){v[m+3|0]=3;break X}d=y[h|0];if(d){v[m+3|0]=19;break X}d=y[h+7|0];if(d){v[m+3|0]=4;v[h+8|0]=d;break X}d=y[h+4|0];if(d){v[m+3|0]=5;v[h+5|0]=d;break X}d=y[h+3|0];if(!(!d|k)){v[m+3|0]=11;v[l|0]=d;if(d&15){d=d|-16;break X}if(d>>>0<16){break W}d=d|15;break X}d=y[h+6|0];if(d){v[m+3|0]=8;break X}if(s){v[m+3|0]=20;s=0;d=97;break X}s=0;if(I){break W}d=i&255;if(!d){break W}v[m+3|0]=24;v[l|0]=i;if(i&15){d=i|-16}else{I=1;if(d>>>0<16){break W}d=i|15}I=1}v[l|0]=d}e=e+1|0;continue}}}x[a+480228>>2]=256/z[a+480188>>1];k=1;uh(a,1);if(Fb(z[f+292>>1])){Y:{while(1){b=x[n+8>>2];i=x[n>>2];x[27524]=0;b=W(160,i|0,b|0,2)|0;i=x[27524];x[27524]=0;if((i|0)==1){break B}if(!b){break Y}x[27524]=0;b=T(275,n|0)|0;i=x[27524];x[27524]=0;if((i|0)==1){break B}if((b|0)==65535){break Y}x[27524]=0;Q(192,n|0,2)|0;b=x[27524];x[27524]=0;if((b|0)==1){break B}x[27524]=0;b=T(283,n|0)|0;i=x[27524];x[27524]=0;if((i|0)!=1){x[27524]=0;Q(192,n|0,b|0)|0;b=x[27524];x[27524]=0;if((b|0)!=1){continue}}break}break B}x[27524]=0;Q(192,n|0,34)|0;b=x[27524];x[27524]=0;if((b|0)==1){break B}}Z:{if(!(c&2)){break Z}while(1){b=k&65535;if(b>>>0>C>>>0){break Z}_:{e=(D(b,104)+a|0)+484380|0;if(!x[e>>2]){break _}c=Zc(f+232|0,8,1,0,0);x[27524]=0;W(223,c|0,e|0,n|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break B}c=x[o>>2];if(wd(c,x[o+4>>2])>>>0<b>>>0){break _}j=b-1|0;g=Cd(c,j);c=0;b=0;m=ib-112|0;ib=m;$:{h=x[e>>2];if(!_d(h,x[e+20>>2])){break $}q=x[g>>2];i=wd(q,x[g+4>>2]);if(i>>>0<2){break $}d=no(m+8|0,e);x[d+20>>2]=0;x[d>>2]=0;aa:{while(1){if((c|0)==(i|0)){break aa}ba:{l=Cd(q,c);t=x[l>>2];if(t>>>0>=h>>>0){break ba}l=x[l+4>>2];if(l>>>0>h-t>>>0|268435456-l>>>0<b>>>0){break ba}b=b+l|0;x[d>>2]=b;c=c+1|0;continue}break}i=c}if(!Xg(d)){break $}l=d+68|0;b=0;c=0;while(1){if((c|0)==(i|0)){Jm(e);b=no(e,d);x[b+4>>2]=0;x[b+8>>2]=x[b>>2];w[b+34>>1]=z[b+34>>1]|2;break $}s=x[d+20>>2]+b|0;q=x[e+20>>2];h=Cd(x[g>>2],c);rc(s,q+x[h>>2]|0,x[h+4>>2]);x[h>>2]=b;if(c-10>>>0>=4294967287){O=Bb(l,c-1|0),V=b,x[O>>2]=V}c=c+1|0;b=x[h+4>>2]+b|0;continue}}ib=m+112|0;b=z[bc(x[u>>2],j)>>1];if(b){BA(e,(D(b,104)+a|0)+484380|0,0,x[e>>2],0)}b=Cd(x[o>>2],j);O=f,V=Cb(x[b>>2]),x[O+232>>2]=V;c=Cb(x[b+4>>2]);while(1){b=x[f+232>>2];if(!Mb(b,c)){break _}i=z[b+8>>1];if(i){BA(e,(D(i,104)+a|0)+484380|0,x[b>>2],x[b+4>>2],1)}i=z[b+10>>1];if(i){BA(e,(D(i,104)+a|0)+484380|0,x[b>>2],x[b+4>>2],0)}yq(f+232|0);continue}}k=k+1|0;continue}}iu(F);d=1;break b}x[27524]=0;Q(192,n|0,D(g,z[f+238>>1])|0)|0;e=x[27524];x[27524]=0;if((e|0)!=1){break C}break B}b=b+1|0;continue}break}e=P()|0;iu(F);break e}e=P()|0;break e}e=P()|0;break e}e=P()|0;break e}e=P()|0;break f}e=P()|0;break e}e=P()|0;break e}e=P()|0;$b(f+8|0);break d}e=P()|0;break e}yb(h)}jd(u);ZS(o)}S(e|0);p()}d=0}jd(u);ZS(o)}ib=f+496|0;return d|0}function Tia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0;e=ib-336|0;ib=e;yc(b);a:{b:{c:{if(!mu(b,e+240|0)){break c}if(!xT(e+240|0)){break c}if(!Ob(x[b>>2],x[b+8>>2],Ec(wT(e+240|0),kb))){break c}if(!c){t=1;break c}zd(a,2);x[a+480260>>2]=64;x[a+480264>>2]=32767;i=Kb(e+224|0);d=z[e+280>>1];j=(d|0)==20479?z[e+294>>1]:d-16464|0;d:{e:{f:{g:{h:{i:{switch(d>>>12|0){case 0:if((d|0)!=520){break d}x[27524]=0;d=Q(1,e+208|0,12273)|0;h=x[27524];x[27524]=0;if((h|0)!=1){Gb(i,d);break e}b=P()|0;break a;case 1:j:{if((d|0)!=4896){break j}d=z[e+302>>1];if(d){break j}if(!(z[e+278>>1]&65455|(y[e+292|0]|y[e+272|0]&15))){k:{if(v[e+291|0]<0){x[a+1074308>>2]=18219008;x[27524]=0;d=Q(1,e+208|0,14764)|0;f=x[27524];x[27524]=0;if((f|0)!=1){break k}b=P()|0;break a}x[a+1074308>>2]=16777216;x[27524]=0;d=Q(1,e+208|0,13314)|0;f=x[27524];x[27524]=0;if((f|0)==1){break h}}Gb(i,d);xb(d);x[27524]=0;f=1;W(268,a+1074312|0,81,1)|0;d=x[27524];x[27524]=0;g=1;if((d|0)!=1){break d}break b}if(y[e+292|0]|d|(z[e+278>>1]|y[e+293|0])){break j}x[27524]=0;d=Q(1,e+208|0,9424)|0;h=x[27524];x[27524]=0;if((h|0)!=1){Gb(i,d);break e}b=P()|0;break a}x[27524]=0;d=Q(1,e+208|0,8442)|0;f=x[27524];x[27524]=0;k=1;if((f|0)!=1){Gb(i,d);xb(d);break f}b=P()|0;break a;case 2:x[27524]=0;d=Q(1,e+208|0,6776)|0;f=x[27524];x[27524]=0;g=1;if((f|0)!=1){Gb(i,d);xb(d);break f}b=P()|0;break a;case 3:l:{m:{n:{o:{if(d>>>0<=12820){x[27524]=0;f=Q(1,e+208|0,8505)|0;h=x[27524];x[27524]=0;if((h|0)!=1){Gb(i,f);xb(f);break o}b=P()|0;break a}x[27524]=0;R(435,e+208|0,4018);f=x[27524];x[27524]=0;if((f|0)==1){break n}x[27524]=0;x[e+192>>2]=z[e+280>>1]-12820;U(436,e+48|0,e+208|0,e+192|0);f=x[27524];x[27524]=0;if((f|0)==1){break m}f=e+48|0;Gb(i,f);xb(f);$b(e+208|0)}f=z[e+280>>1];if(f>>>0<12807){break g}h=x[e+296>>2];if(h){break l}break g}b=P()|0;break a}b=P()|0;$b(e+208|0);break a}f=AD(f,h);h=Bo(e+48|0);x[h+32>>2]=f;x[27524]=0;R(438,a+1298412|0,h|0);f=x[27524];x[27524]=0;if((f|0)!=1){break g}b=P()|0;break a;case 4:p:{if((d|0)==16640){x[27524]=0;f=Q(1,e+208|0,8288)|0;h=x[27524];x[27524]=0;if((h|0)!=1){Gb(i,f);xb(f);x[27524]=0;W(268,a+1074312|0,81,1)|0;break p}b=P()|0;break a}x[27524]=0;U(439,e+48|0,d|0,z[e+294>>1]);f=x[27524];x[27524]=0;q:{r:{s:{if((f|0)!=1){f=e+48|0;Gb(i,f);xb(f);x[a+480260>>2]=1;if((j|0)<4201){break s}x[27524]=0;W(268,a+1074312|0,7,1)|0;f=x[27524];x[27524]=0;if((f|0)==1){break b}break r}b=P()|0;break a}if((j|0)<2386){break q}}x[27524]=0;W(268,a+1074312|0,38,1)|0;f=x[27524];x[27524]=0;if((f|0)==1){break b}}x[27524]=0;Q(269,a+1074312|0,118)|0}f=x[27524];x[27524]=0;if((f|0)==1){break b}h=(d|0)!=16640;g=1;f=0;break d;case 5:d=d&4095;x[a+1074308>>2]=d<<16|(d>>>0>296?z[e+294>>1]:0)&65535;x[27524]=0;d=Q(1,e+208|0,17591)|0;f=x[27524];x[27524]=0;t:{u:{v:{if((f|0)!=1){f=x[a+1074308>>2];x[27524]=0;R(144,e+192|0,f|0);f=x[27524];x[27524]=0;if((f|0)==1){break v}f=0;x[27524]=0;U(2,e+48|0,d|0,e+192|0);h=x[27524];x[27524]=0;if((h|0)==1){break u}h=e+48|0;Gb(i,h);xb(h);xb(e+192|0);break e}b=P()|0;break a}b=P()|0;break t}b=P()|0;xb(e+192|0)}xb(d);break a;case 6:x[27524]=0;d=Q(1,e+208|0,8288)|0;h=x[27524];x[27524]=0;if((h|0)!=1){Gb(i,d);xb(d);x[27524]=0;W(268,a+1074312|0,81,1)|0;d=x[27524];x[27524]=0;h=0;if((d|0)==1){break b}break d}b=P()|0;break a;case 7:x[27524]=0;d=Q(1,e+208|0,8300)|0;h=x[27524];x[27524]=0;if((h|0)!=1){Gb(i,d);break e}b=P()|0;break a;default:break i}}if((d|0)!=51712){break d}x[27524]=0;d=Q(1,e+208|0,9223)|0;h=x[27524];x[27524]=0;if((h|0)!=1){Gb(i,d);break e}b=P()|0;break a}b=P()|0;break a}x[27524]=0;f=W(268,a+1074312|0,7,1)|0;h=x[27524];x[27524]=0;if((h|0)==1){break b}x[27524]=0;f=W(268,f|0,23,1)|0;h=x[27524];x[27524]=0;if((h|0)==1){break b}x[27524]=0;f=W(268,f|0,38,1)|0;h=x[27524];x[27524]=0;if((h|0)==1){break b}x[27524]=0;W(268,f|0,107,1)|0;f=x[27524];x[27524]=0;if((f|0)==1){break b}g=1;x[a+480260>>2]=1;f=0;h=0;if(d>>>0>12820){break d}}x[27524]=0;Y(672,e+192|0);d=x[27524];x[27524]=0;w:{x:{y:{if((d|0)!=1){d=z[e+280>>1];x[e+160>>2]=d>>>8&15;x[27524]=0;x[e+136>>2]=d&255;R(437,e+176|0,e+136|0);d=x[27524];x[27524]=0;if((d|0)==1){break y}f=0;x[27524]=0;ea(673,e+48|0,e+192|0,i|0,e+160|0,e+176|0);d=x[27524];x[27524]=0;if((d|0)==1){break x}d=e+48|0;Gb(i,d);xb(d);xb(e+176|0);$b(e+192|0);break d}b=P()|0;break a}b=P()|0;break w}b=P()|0;xb(e+176|0)}$b(e+192|0);break a}xb(d);h=0}x[27524]=0;d=Q(1,e+192|0,15031)|0;n=x[27524];x[27524]=0;z:{A:{B:{C:{D:{E:{F:{G:{if((n|0)!=1){Gb(a+1298344|0,d);xb(d);x[27524]=0;d=Q(1,e+176|0,10412)|0;n=x[27524];x[27524]=0;if((n|0)==1){break G}Gb(a+1298356|0,d);xb(d);r=Gb(a+1298368|0,i);x[a+1298404>>2]=x[a+1074308>>2]?22:4;if(g){x[27524]=0;d=Q(269,a+1074312|0,77)|0;g=x[27524];x[27524]=0;if((g|0)==1){break b}x[27524]=0;d=Q(269,d|0,78)|0;g=x[27524];x[27524]=0;if((g|0)==1){break b}x[27524]=0;d=Q(269,d|0,79)|0;g=x[27524];x[27524]=0;if((g|0)==1){break b}x[27524]=0;d=Q(269,d|0,80)|0;g=x[27524];x[27524]=0;if((g|0)==1){break b}x[27524]=0;d=Q(269,d|0,82)|0;g=x[27524];x[27524]=0;if((g|0)==1){break b}x[27524]=0;d=Q(269,d|0,96)|0;g=x[27524];x[27524]=0;if((g|0)==1){break b}x[27524]=0;Q(269,d|0,113)|0;d=x[27524];x[27524]=0;if((d|0)==1){break b}}d=z[e+280>>1];if(d>>>0<=4865){x[27524]=0;Q(269,a+1074312|0,118)|0;d=x[27524];x[27524]=0;if((d|0)==1){break b}d=z[e+280>>1]}g=d&61440;if(g>>>0>=4097){f=(g|0)!=12288|(d&65535)>>>0>12819|f}x[27524]=0;d=a+901404|0;Y(674,d|0);g=x[27524];x[27524]=0;if((g|0)==1){break b}if(!f){Dq(d)}d=e+160|0;Pi(d,1,e+240|0);x[27524]=0;R(226,e+48|0,d|0);d=x[27524];x[27524]=0;if((d|0)==1){break D}d=e+48|0;Ac(a+1298308|0,d);wb(d);d=z[e+278>>1];if(d&16){x[a+480208>>2]=x[a+480208>>2]|65536}if(d&1){x[a+480208>>2]=x[a+480208>>2]|131072}f=z[e+280>>1];if(!(!(d&64)&(f|0)!=4864)){x[a+480208>>2]=x[a+480208>>2]|2}d=y[e+289|0];x[a+480196>>2]=d;if(!(!k|(d|0)!=255?d:0)){x[a+480196>>2]=6}d=y[e+290|0];x[a+480204>>2]=d>>>0<33?k?125e4:32e4:D(d,1e4);v[e+48|0]=y[e+288|0];v[e+160|0]=64;d=y[Ub(e+48|0,e+160|0)|0];x[a+480200>>2]=d<<2;if(!(d|f>>>0>4895)){x[a+480200>>2]=256}g=y[e+291|0];if(z[e+282>>1]!=1|g>>>0>7){break F}x[e+48>>2]=(g<<4)+16;x[e+160>>2]=127;f=x[rd(e+48|0,e+160|0)>>2];break E}b=P()|0;break a}b=P()|0;break a}f=32;if((g|16)==18){break E}d=g&127;f=48;if(!d){break E}x[e+48>>2]=d;x[e+160>>2]=16;f=x[Ve(e+48|0,e+160|0)>>2]}x[a+480228>>2]=f;d=0;n=x[a+1074308>>2]!=0|g<<24>>24<0;if(!n){I=a,J=Ec(soa(f<<3|5,f>>>29|0,11,0),kb),x[I+480228>>2]=J}s=a+480188|0;w[s>>1]=4;x[a+480232>>2]=h?(j|0)<3299?64:36:36;f=sc(e+152|0);while(1){if((d|0)==32){d=a+480188|0;if(!z[d>>1]){w[d>>1]=1}d=y[a+484376|0];h=x[a+484360>>2];x[27524]=0;ea(344,Tb(h,d)|0,b|0,z[e+272>>1],255,254);d=x[27524];x[27524]=0;if((d|0)!=1){n=Nb(e+160|0);x[27524]=0;W(221,b|0,n|0,z[e+274>>1])|0;d=x[27524];x[27524]=0;if((d|0)!=1){s=Nb(e+136|0);x[27524]=0;W(221,b|0,s|0,z[e+276>>1])|0;d=x[27524];x[27524]=0;H:{if((d|0)!=1){if(y[e+293|0]!=252){break C}d=0;x[27524]=0;R(675,b|0,e+48|0);h=x[27524];x[27524]=0;if((h|0)==1){break H}while(1){if((d|0)==32){break C}h=y[(e+48|0)+d|0];I:{if(!(h&32)){break I}if(k){Pc(e+32|0,f,d);if(zb(x[x[e+32>>2]>>2],x[e+36>>2])){break I}}w[((d<<5)+a|0)+480284>>1]=(((h&15)<<8|8)>>>0)/15}d=d+1|0;continue}}break B}break B}b=P()|0;break A}b=P()|0;break a}h=(d<<5)+a|0;j=h+480280|0;lf(j);g=y[(d+e|0)+304|0];o=g&126;J:{if((g|0)!=255){g=g<<24>>24;w[s>>1]=d+1;if(n){w[h+480284>>1]=g&8?204:51}if((g|0)>=0){break J}}x[j>>2]=1024}if((o-16&255)>>>0<=13){w[h+480284>>1]=128;h=e+48|0;Pc(h,f,d);uo(h)}d=d+1|0;continue}}b=P()|0;break a}w[e+48>>1]=z[e+274>>1];w[e+32>>1]=3999;f=z[Tc(e+48|0,e+32|0)>>1];w[a+480190>>1]=f;j=c&2;o=e+96|0;d=0;g=0;h=0;K:{L:{M:{while(1){if((f&65535)>>>0<=d>>>0){if(!k){break L}if(!(!(g&1)|h&65535)&z[e+280>>1]!=4864){break M}x[27524]=0;d=h&65535;f=W(268,a+1074312|0,79,d>>>0>1|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break B}x[27524]=0;d=d>>>0<2;f=W(268,f|0,107,d|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break B}x[27524]=0;W(268,f|0,38,d|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break B}x[27524]=0;d=h&65535;Q(137,r|0,(d>>>0>1?17152:17159)|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break B}if(d>>>0<2){break L}x[a+480228>>2]=48;break L}f=bc(x[n>>2],d);f=y[f|0]|y[f+1|0]<<8;x[27524]=0;f=Q(159,b|0,f<<4)|0;l=x[27524];x[27524]=0;if((l|0)==1){break K}N:{O:{if(!f){break O}x[27524]=0;f=Q(676,b|0,e+48|0)|0;l=x[27524];x[27524]=0;if((l|0)==1){break K}if(!f){break O}x[27524]=0;f=d+1|0;l=(D(f,104)+a|0)+484380|0;U(677,e+48|0,l|0,k|0);m=x[27524];x[27524]=0;if((m|0)==1){break K}m=e+16|0;Pi(m,1,o);x[27524]=0;R(226,e+32|0,m|0);m=x[27524];x[27524]=0;if((m|0)==1){break N}m=((f<<5)+a|0)+946304|0;f=e+32|0;Cc(m,f);wb(f);if(y[e+48|0]>1){break O}P:{if(!j|!x[e+64>>2]){break P}f=uT(e+48|0);x[27524]=0;f=Q(159,b|0,f|0)|0;m=x[27524];x[27524]=0;if((m|0)==1){break B}if(!f){break P}f=e+32|0;sT(f,y[e+78|0],y[e+79|0],z[e+282>>1]==1);x[27524]=0;W(223,f|0,l|0,b|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break B}g=1}h=z[e+88>>1]|h}d=d+1|0;f=z[a+480190>>1];continue}break}break B}x[27524]=0;d=Q(1,e+48|0,9688)|0;f=x[27524];x[27524]=0;if((f|0)==1){break B}Gb(r,d);xb(d)}t=1;if(!(c&1)){break z}c=z[e+280>>1];w[e+32>>1]=z[e+276>>1];w[e+16>>1]=255;u=z[Tc(e+32|0,e+16|0)>>1];x[27524]=0;k=a+484344|0;R(229,k|0,u|0);d=x[27524];x[27524]=0;if((d|0)==1){break K}A=c>>>0<4896;c=e+32|0;m=c|5;E=c|3;B=c|4;F=c|2;G=c|1;H=a+480188|0;h=0;r=0;o=0;while(1){if((h|0)==(u|0)){if(!A){break z}a=z[a+480188>>1];if((a|0)>(o+r|0)|(a|0)<=(r-o|0)){break z}d=Jf(x[k>>2],x[k+4>>2])-1&65535;b=0;Q:{if(Jf(x[k>>2],x[k+4>>2])>>>0<=d>>>0){break Q}while(1){c=b&65535;if(c>>>0>d>>>0){break Q}a=hg(x[k>>2],c);f=x[a>>2];if(Mb(f,x[a+4>>2])){a=Cb(f);f=Cb(x[hg(x[k>>2],c)+4>>2]);c=ib-16|0;ib=c;x[c+8>>2]=a;while(1){if(Mb(a,f)){if(y[a+3|0]==31){v[a+3|0]=20;v[a+5|0]=y[a+5|0]|128}a=x[Hk(c+8|0)>>2];continue}break}ib=c+16|0}b=b+1|0;continue}}break z}x[27524]=0;c=W(230,k|0,h&65535,64)|0;d=x[27524];x[27524]=0;if((d|0)==1){break K}R:{if(!c){break R}c=bc(x[s>>2],h);c=y[c|0]|y[c+1|0]<<8;if(!c){break R}x[27524]=0;c=Q(159,b|0,c<<4)|0;d=x[27524];x[27524]=0;if((d|0)==1){break K}if(!c){break R}x[27524]=0;Q(192,b|0,2)|0;c=x[27524];x[27524]=0;if((c|0)==1){break K}d=0;c=Xb(x[k>>2],h);c=qf(x[c>>2],x[x[c+48>>2]+12>>2],0);while(1){if(d>>>0>63){break R}f=d;x[27524]=0;d=T(210,b|0)|0;g=x[27524];x[27524]=0;S:{if((g|0)!=1){l=d<<24>>24;if(l){break S}d=64;if(f>>>0>62){continue}c=Xb(x[k>>2],h);d=f+1|0;c=qf(x[c>>2],x[x[c+48>>2]+12>>2],d);continue}break B}g=l&31;d=D(g,6)+c|0;q=Bg(e+32|0);j=g>>>0<z[H>>1];C=j?d:q;if(l&32){x[27524]=0;R(264,e+16|0,b|0);g=x[27524];x[27524]=0;T:{U:{V:{if((g|0)!=1){q=Lc(e+16|0);g=y[e+16|0];if(g>>>0>239){break V}g=rT((D(g>>>4|0,12)+(g&15)|0)+13|0);break U}break B}W:{switch(g-254|0){case 0:break U;case 1:break W;default:break T}}g=0}v[C|0]=g}v[(j?d+1|0:G)|0]=y[q|0]}X:{if(!(l&64)){break X}x[27524]=0;q=T(210,b|0)|0;g=x[27524];x[27524]=0;Y:{if((g|0)!=1){g=j?d+2|0:F;q=q<<24>>24;v[e+16|0]=q;if((q|0)>-64){break Y}v[g|0]=2;v[(j?d+4|0:B)|0]=y[e+16|0]^128;break X}break B}v[g|0]=1;v[e+15|0]=64;I=j?d+4|0:B,J=y[Ub(e+16|0,e+15|0)|0],v[I|0]=J}Z:{if((l|0)>=0){break Z}x[27524]=0;R(264,e+16|0,b|0);g=x[27524];x[27524]=0;_:{$:{if((g|0)!=1){zB(C,y[e+16|0],y[Lc(e+16|0)|0],0);l=j?d+3|0:E;g=y[l|0];if((g|0)==10){break _}if((g|0)==31){break $}if((g|0)!=20){break Z}d=j?d+5|0:m;g=y[d|0];if((g&240)!=160|z[e+280>>1]>4895){break Z}v[d|0]=g&15^136;break Z}break B}d=y[(j?d+5|0:m)|0];if(d>>>0>15){A=0;break Z}if(d>>>0<=7){o=o+1|0;break Z}r=((d|0)!=8)+r|0;break Z}if(y[(j?d+5|0:m)|0]|z[e+280>>1]>4865){break Z}v[l|0]=37}d=f;continue}}h=h+1|0;continue}}}b=P()|0;jd(s)}jd(n);break a}jd(s);jd(n);xb(i)}ib=e+336|0;return t|0}b=P()|0}xb(i);S(b|0);p()}function Uha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0;d=ib-592|0;ib=d;yc(b);a:{if(!AB(b,d+512|0)){break a}if(!iS(d+512|0)){break a}if(!Ob(x[b>>2],x[b+8>>2],Ec(hS(d+512|0),kb))){break a}b:{if(!c){break b}zd(a,4);gg(a);v[a+1074368|0]=4;k=Kb(d+496|0);c:{d:{e:{f:{l=d+550|0;g:{if(!(Qb(l,17774,20)|x[d+572>>2]!=276)){if(z[d+570>>1]<260){break g}e=CB(d+529|0,0,20)?1154:34;break e}if(!Qb(l,17753,20)){e=1;break e}g=d- -64|0;Hj(g,3,l);x[27524]=0;R(226,d+104|0,g|0);g=x[27524];x[27524]=0;h:{i:{if((g|0)!=1){x[27524]=0;U(11,d+208|0,4,d+104|0);g=x[27524];x[27524]=0;if((g|0)==1){break i}g=d+208|0;Gb(k,g);xb(g);wb(d+104|0);if(Qb(l,17591,8)){break h}e=1048;break e}f=P()|0;break c}f=P()|0;wb(d+104|0);break c}if(!Qb(l,17491,12)){e=16;if(!Qb(d+562|0,17795,8)){break e}v[a+1074368|0]=5;break e}if(Qb(l,11553,20)){break f}}e=48;break e}if(!Qb(l,27104,15)){x[27524]=0;g=Q(269,a+1074312|0,54)|0;e=x[27524];x[27524]=0;C=1;if((e|0)==1){break d}x[27524]=0;Q(269,g|0,51)|0;g=x[27524];x[27524]=0;e=16;if((g|0)==1){break d}break e}j:{if(Qb(l,27120,14)){if(Qb(l,27135,14)){break j}}x[27524]=0;g=Q(269,a+1074312|0,57)|0;e=x[27524];x[27524]=0;if((e|0)==1){break d}x[27524]=0;Q(269,g|0,51)|0;g=x[27524];x[27524]=0;e=16;if((g|0)!=1){break e}break d}e=Qb(l,17579,11)?16:256}g=d+104|0;t=d+529|0;Hj(g,3,t);x[27524]=0;R(226,d+208|0,g|0);g=x[27524];x[27524]=0;k:{l:{m:{n:{o:{p:{q:{if((g|0)!=1){g=d+208|0;Ac(a+1298308|0,g);wb(g);x[a+480260>>2]=1;x[a+480264>>2]=31999;_e(Tb(x[a+484360>>2],y[a+484376|0]),z[d+578>>1]);w[a+480188>>1]=z[d+580>>1];w[d+208>>1]=z[d+584>>1];w[d+104>>1]=255;G=a+480192|0,H=z[Tc(g,d+104|0)>>1],w[G>>1]=H;g=z[d+588>>1];if(g){x[a+480196>>2]=g}g=z[d+590>>1];if(g){g=D(g,1e4);g=g>>>0>=1e7?1e7:g;x[a+480204>>2]=g>>>0<=32e4?32e4:g}g=z[d+586>>1];x[a+480208>>2]=g<<4&16|g<<3&32768;f=y[a+484376|0];n=x[a+484360>>2];x[27524]=0;ea(344,Tb(n,f)|0,b|0,z[d+576>>1],65535,65535);f=x[27524];x[27524]=0;if((f|0)==1){break d}f=g>>>12&1?(e|0)==34?146:e:e;if(!(z[d+576>>1]|f>>>0>1023)){g=y[a+484376|0];e=x[a+484360>>2];x[27524]=0;Y(737,Tb(e,g)|0);g=x[27524];x[27524]=0;if((g|0)==1){break d}}x[27524]=0;Q(159,b|0,x[d+572>>2]+60|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break d}if(z[d+570>>1]>=260){x[27524]=0;U(738,b|0,d+512|0,a|0);g=x[27524];x[27524]=0;if((g|0)==1){break d}}v[d+495|0]=0;u=c&2;E=d+122|0;o=d+241|0;n=Nb(d+480|0);F=a+480192|0;g=-1;q=1;while(1){e=q&65535;if(e>>>0>z[F>>1]){if(!(!(f&2)|r&255)){f=CB(t,0,20)?f|16:f}if(z[d+570>>1]>259){break o}if(c&3){x[27524]=0;U(738,b|0,d+512|0,a|0);c=x[27524];x[27524]=0;if((c|0)==1){break n}}if(!u){break o}o=a+480190|0;e=1;while(1){c=e&65535;if(c>>>0>z[o>>1]){break o}i=x[n>>2];x[27524]=0;W(223,Bb(i,c-1|0)|0,(D(c,104)+a|0)+484380|0,b|0)|0;c=x[27524];x[27524]=0;if((c|0)!=1){e=e+1|0;continue}break}f=P()|0;break k}x[27524]=0;i=T(161,b|0)|0;h=x[27524];x[27524]=0;r:{s:{if((h|0)!=1){Gg(b,4);x[27524]=0;U(739,b|0,d+208|0,(i?i:263)|0);i=x[27524];x[27524]=0;if((i|0)==1){break p}t:{if((f|0)==1){i=x[d+208>>2];if((i|0)!=263){f=16;if((i|0)!=245){break t}x[a+1074308>>2]=16777381;x[27524]=0;f=Q(1,d+192|0,13314)|0;i=x[27524];x[27524]=0;if((i|0)!=1){Gb(k,f);xb(f);f=17;break t}f=P()|0;break k}x[a+1074308>>2]=16777395;x[27524]=0;f=Q(1,d+176|0,13229)|0;i=x[27524];x[27524]=0;if((i|0)!=1){Gb(k,f);xb(f);f=17;break t}f=P()|0;break k}if(y[d+235|0]|y[d+236|0]<<8){break t}i=x[d+208>>2];if(!(!(f&2)|(y[d+237|0]|y[d+238|0]<<8|(y[d+239|0]<<16|y[d+240|0]<<24))|(i|0)!=263)){f=f|16;break t}if(!(!(f&256)|(i|0)==29)){f=f&-257;break t}if(!(f&160)){break t}f=(i|0)==33?f:0}x[27524]=0;i=W(255,a|0,e|0,0)|0;h=x[27524];x[27524]=0;if((h|0)==1){break p}if(!i){break r}i=((e<<2)+a|0)+900380|0;e=x[i>>2];x[27524]=0;R(740,d+208|0,e|0);e=x[27524];x[27524]=0;if((e|0)==1){break p}e=y[d+234|0];u:{if((g|0)==-1){g=e;break u}if(!(f&32)|(e|0)==(g|0)){break u}f=f&-161|128}e=y[d+235|0]|y[d+236|0]<<8;if(!e){break r}x[27524]=0;h=y[d+455|0];j=y[d+451|0]|y[d+452|0]<<8;m=y[d+450|0];s=y[d+449|0];U(741,d+160|0,a|0,e|0);e=x[27524];x[27524]=0;if((e|0)==1){break q}f=h|(j|(m|s))?f&-4:f;i=x[i>>2]+236|0;e=12;h=x[d+160>>2];j=Oc(h,x[d+164>>2]);v:{while(1){w:{if((e|0)==108){if(z[d+570>>1]>259){Ic(n)}e=0;x[27524]=0;i=Q(742,d+144|0,y[d+235|0]|y[d+236|0]<<8)|0;h=x[27524];x[27524]=0;if((h|0)!=1){break w}f=P()|0;break v}m=bc(i,e);if(j>>>0>z[m>>1]){G=m,H=z[bc(h,z[bc(i,e)>>1])>>1],w[G>>1]=H}e=e+1|0;continue}break}x:{y:{z:{A:{while(1){h=y[d+235|0]|y[d+236|0]<<8;if(e>>>0>=h>>>0){e=0;if(z[d+570>>1]<=259){break s}B:{while(1){if(e>>>0>=h>>>0){break s}j=y[Bb(x[n>>2],e)+3|0];h=x[Bb(x[i>>2],e)>>2];x[27524]=0;U(194,d- -64|0,b|0,((j|0)==10?(h+1>>>1|0)+16|0:h)|0);h=x[27524];x[27524]=0;if((h|0)!=1){j=d- -64|0;h=hc(d+104|0,j);yb(j);j=x[d+160>>2];if(!(!u|Oc(j,x[d+164>>2])>>>0<=e>>>0)){m=z[bc(j,e)>>1];j=Bb(x[n>>2],e);j=y[j|0]|y[j+1|0]<<8|(y[j+2|0]<<16|y[j+3|0]<<24);x[27524]=0;x[d+56>>2]=j;x[d>>2]=j;j=fa(743,(D(m,104)+a|0)+484380|0,d|0,h|0,d+495|0)|0;m=x[27524];x[27524]=0;if((m|0)==1){break B}B=j^1|B}yb(h);e=e+1|0;h=y[d+235|0]|y[d+236|0]<<8;continue}break}f=P()|0;break x}f=P()|0;yb(h);break x}x[27524]=0;R(744,b|0,d+104|0);h=x[27524];x[27524]=0;if((h|0)==1){break y}h=d- -64|0;j=y[d+118|0];C:{if(!(j&48|y[d+121|0]!=173)){Zc(h,8,1,0,10);break C}Zc(h,j&16?16:8,j&32?3:1,0,2)}x[27524]=0;R(745,n|0,h|0);h=x[27524];x[27524]=0;if((h|0)!=1){G=Bb(x[i>>2],e),H=x[d+104>>2],x[G>>2]=H;m=y[d+121|0];h=x[d+160>>2];if(Oc(h,x[d+164>>2])>>>0>e>>>0){j=z[bc(h,e)>>1];x[27524]=0;h=(D(j,104)+a|0)+484380|0;R(746,d+104|0,h|0);s=x[27524];x[27524]=0;if((s|0)==1){break A}v[h+38|0]=y[o+202|0];v[h+39|0]=y[o+203|0];v[h+40|0]=y[o+204|0];v[h+41|0]=y[o+205|0];h=d+88|0;Ll(h,3,E);x[27524]=0;R(226,d- -64|0,h|0);h=x[27524];x[27524]=0;if((h|0)==1){break z}h=d- -64|0;Cc(((j<<5)+a|0)+946304|0,h);wb(h);f=(y[d+118|0]&3)==3?(f&2)>>>1|0?f|4:f:f}r=m|r;e=e+1|0;continue}break}f=P()|0;break x}f=P()|0;break x}f=P()|0;break x}f=P()|0}uc(i)}jd(d+160|0);break k}f=P()|0;break k}uc(i);jd(d+160|0)}q=q+1|0;continue}}f=P()|0;break c}f=P()|0;break k}f=P()|0;break k}D:{if(!(B&1)){break D}x[27524]=0;c=Q(1,d+104|0,16606)|0;e=x[27524];x[27524]=0;E:{if((e|0)!=1){e=x[a+1298472>>2];x[27524]=0;U(380,e|0,2,c|0);e=x[27524];x[27524]=0;if((e|0)==1){break E}xb(c);break D}f=P()|0;break k}f=P()|0;xb(c);break k}x[27524]=0;c=Q(406,b|0,5561)|0;e=x[27524];x[27524]=0;if((e|0)==1){break n}if(c){x[27524]=0;c=T(161,b|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break n}x[27524]=0;X(335,a+1298332|0,b|0,c|0,0);c=x[27524];x[27524]=0;if((c|0)==1){break n}f=f|16}x[27524]=0;o=Q(406,b|0,14087)|0;c=x[27524];x[27524]=0;if((c|0)==1){break l}if(o){x[27524]=0;c=T(161,b|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break l}x[27524]=0;e=a+901404|0;U(747,b|0,e|0,c|0);c=x[27524];x[27524]=0;if((c|0)==1){break l}BB(e);f=f|16}x[27524]=0;c=Q(406,b|0,13849)|0;e=x[27524];x[27524]=0;if((e|0)==1){break l}if(!c){break m}x[27524]=0;c=T(161,b|0)|0;e=x[27524];x[27524]=0;if((e|0)!=1){w[d+208>>1]=c>>>5;G=d,H=Jf(x[a+484344>>2],x[a+484348>>2]),w[G+64>>1]=H;c=z[Tc(d+208|0,d- -64|0)>>1];e=0;while(1){if((c|0)==(e|0)){f=f|16;break m}x[27524]=0;R(569,b|0,d+208|0);i=x[27524];x[27524]=0;F:{if((i|0)==1){break F}i=x[a+484344>>2];x[27524]=0;R(570,Xb(i,e)|0,d+208|0);i=x[27524];x[27524]=0;if((i|0)==1){break F}e=e+1|0;continue}break}f=P()|0;break k}f=P()|0;break k}f=P()|0;break k}x[27524]=0;c=Q(406,b|0,13854)|0;e=x[27524];x[27524]=0;if((e|0)==1){break l}G:{if(!c){break G}x[27524]=0;c=T(161,b|0)|0;e=x[27524];x[27524]=0;if((e|0)!=1){w[d+208>>1]=(c>>>0)/20;w[d+64>>1]=z[a+480188>>1];c=z[Tc(d+208|0,d- -64|0)>>1];e=0;while(1){if((c|0)==(e|0)){f=f|16;break G}x[27524]=0;U(417,b|0,((e<<5)+a|0)+480289|0,20);i=x[27524];x[27524]=0;if((i|0)!=1){e=e+1|0;continue}break}f=P()|0;break k}f=P()|0;break k}c=x[b+8>>2];e=x[b>>2];x[27524]=0;c=W(160,e|0,c|0,8)|0;e=x[27524];x[27524]=0;if((e|0)==1){break l}H:{I:{J:{K:{if(c){c=x[b+8>>2];x[27524]=0;Q(418,a|0,b|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break K}f=(c|0)==x[b+8>>2]?f:f|16}L:{if(!(f&16)){break L}if(f&4){x[a+1074308>>2]=17367040;x[27524]=0;c=Q(1,d+208|0,14694)|0;e=x[27524];x[27524]=0;if((e|0)!=1){Gb(k,c);xb(c);break L}f=P()|0;break k}if(!(f&2)){break L}x[a+1074308>>2]=18219008;x[27524]=0;c=Q(1,d+208|0,14851)|0;e=x[27524];x[27524]=0;if((e|0)==1){break J}Gb(k,c);xb(c)}M:{N:{O:{P:{Q:{R:{S:{if(!Qb(l,17591,8)){x[27524]=0;c=W(387,d- -64|0,d+558|0,12)|0;e=x[27524];x[27524]=0;if((e|0)==1){break S}x[27524]=0;U(11,d+160|0,1,c|0);e=x[27524];x[27524]=0;if((e|0)==1){break R}x[27524]=0;e=T(748,d+160|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break Q}x[a+1074308>>2]=e;xb(d+160|0);v[a+1074368|0]=A[a+1074308>>2]<19007257?4:5;wb(c);f=24}if(!(!x[a+1074308>>2]|f&8)){v[a+1074368|0]=0;Iu(a+1074312|0)}c=f&32;T:{if(!c){break T}v[a+1074368|0]=5;if(!o){Dq(a+901404|0)}if(z[d+570>>1]<260){break T}x[27524]=0;W(268,a+1074312|0,4,1)|0;e=x[27524];x[27524]=0;if((e|0)==1){break l}}if(!yh(x[k+4>>2],y[k+11|0])){break M}if(!(f&256)|r&255|g+1>>>0>1){break N}x[27524]=0;c=Q(1,d+160|0,8240)|0;g=x[27524];x[27524]=0;if((g|0)==1){break O}Gb(k,c);xb(c);break M}f=P()|0;break k}f=P()|0;break P}f=P()|0;xb(d+160|0)}wb(c);break k}f=P()|0;break k}if(c){x[27524]=0;c=Q(1,d+160|0,11965)|0;g=x[27524];x[27524]=0;if((g|0)!=1){Gb(k,c);xb(c);break M}f=P()|0;break k}x[27524]=0;c=Q(1,d+160|0,9688)|0;g=x[27524];x[27524]=0;if((g|0)==1){break I}Gb(k,c);xb(c)}v[d+55|0]=0;U:{if(z[a+480192>>1]){x[27524]=0;c=Q(426,a|0,b|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break U}v[d+55|0]=c}x[27524]=0;X(427,a|0,b|0,1,d+55|0);b=x[27524];x[27524]=0;if((b|0)==1){break U}e=x[a+1074308>>2];V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{if(y[d+55|0]){if(e>>>0>18284543){break ha}x[a+1074308>>2]=18284544;break ha}if(e>>>0<18284544){break ga}}x[27524]=0;b=Q(1,d+40|0,17591)|0;c=x[27524];x[27524]=0;if((c|0)==1){break fa}c=x[a+1074308>>2];x[27524]=0;R(749,d+24|0,c|0);c=x[27524];x[27524]=0;if((c|0)==1){break ea}x[27524]=0;U(2,d+88|0,b|0,d+24|0);c=x[27524];x[27524]=0;if((c|0)==1){break da}c=d+88|0;Gb(k,c);xb(c);xb(d+24|0);xb(b);e=x[a+1074308>>2]}ia:{if(e-1>>>0>19005952){break ia}b=x[a+484344>>2];f=x[a+484348>>2];if(!Ce(b,f,254)){b=y[a+484376|0];c=x[a+484360>>2];x[27524]=0;Y(750,Tb(c,b)|0);b=x[27524];x[27524]=0;if((b|0)==1){break U}f=x[a+484348>>2];b=x[a+484344>>2]}if(Ce(b,f,255)){break ia}SA(Tb(x[a+484360>>2],y[a+484376|0]),255,65535)}x[27524]=0;R(751,d+24|0,4105);b=x[27524];x[27524]=0;if((b|0)==1){break ba}b=z[d+570>>1];x[d+20>>2]=b>>>8;x[27524]=0;x[d+4>>2]=b&255;R(437,d+8|0,d+4|0);b=x[27524];x[27524]=0;if((b|0)==1){break aa}x[27524]=0;X(423,d+88|0,d+24|0,d+20|0,d+8|0);b=x[27524];x[27524]=0;if((b|0)==1){break $}c=d+88|0;b=Gb(a+1298344|0,c);xb(c);xb(d+8|0);$b(d+24|0);Gb(a+1298368|0,k);x[a+1298404>>2]=C?22:x[a+1074308>>2]?22:4;if(!y[d+495|0]){break W}Gb(a+1298380|0,b);x[27524]=0;c=Q(1,d+88|0,15269)|0;g=x[27524];x[27524]=0;if((g|0)==1){break Z}Gb(b,c);xb(c);x[27524]=0;b=Q(1,d+24|0,10039)|0;c=x[27524];x[27524]=0;if((c|0)==1){break Y}Gb(a+1298356|0,b);xb(b);x[27524]=0;b=Q(1,d+8|0,10040)|0;c=x[27524];x[27524]=0;if((c|0)==1){break X}Gb(a+1298392|0,b);break V}f=P()|0;break k}f=P()|0;break ca}f=P()|0;xb(d+24|0)}xb(b);break k}f=P()|0;break k}f=P()|0;break _}f=P()|0;xb(d+8|0)}$b(d+24|0);break k}f=P()|0;break k}f=P()|0;break k}f=P()|0;break k}x[27524]=0;b=Q(1,d+88|0,10040)|0;c=x[27524];x[27524]=0;if((c|0)==1){break H}Gb(a+1298356|0,b)}xb(b);uc(n);xb(k);break b}f=P()|0;break k}f=P()|0;break k}f=P()|0;break k}f=P()|0;break k}f=P()|0;break k}f=P()|0}uc(n);break c}f=P()|0}xb(k);S(f|0);p()}e=1}ib=d+592|0;return e|0}function xea(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,n=0,o=0,s=0,t=0,u=0,B=0,C=0,F=0,G=0,H=0,I=0,J=0,K=0,L=E(0),M=E(0),N=0,O=0;g=ib-48|0;ib=g;b=x[a+1074308>>2];if(!(b>>>0>18285125|(b|0)==18284544)){fg(a+1074312|0,0)}i=a+1074308|0;b=g+32|0;h=a+1074312|0;Ab(b,h,0);d=zb(x[x[g+32>>2]>>2],x[g+36>>2]);e=a+480180|0;c=x[e>>2];Ab(b,h,0);t=d&(c&16777248)!=0;I=zb(x[x[g+32>>2]>>2],x[g+36>>2]);J=x[e>>2];a:{d=x[a+1074308>>2];if(d>>>0>18874367){break a}d=!t;f=a+480192|0;c=1;while(1){b:{b=c&65535;if(b>>>0<=z[f>>1]){b=x[((b<<2)+a|0)+900380>>2];if(!b){break b}x[g+32>>2]=D(y[b+20|0],100)>>>6;x[g+16>>2]=100;N=b,O=x[Hb(g+32|0,g+16|0)>>2],v[N+20|0]=O;if(!(d|A[i>>2]<18350080)){break b}k=v[b+26|0];v[b+26|0]=((k>>31|1)+k|0)/2;if(!(d|A[i>>2]<18285314)){break b}EB(Mh(b,2),x[e>>2]);k=x[a+1074308>>2];c:{if(k>>>0<18284544){break c}if(k>>>0>18285135){break b}if(!y[b+34|0]){break c}if(!zj(y[b+31|0])){break c}Lb(h,2,1);if(A[i>>2]>18285135){break b}}if(!(y[b+24|0]|(y[b+23|0]|(y[b+19|0]|y[b+20|0])))){break b}Lb(h,1,1)}d:{if(!(x[a+480180>>2]&16777248)|A[i>>2]>18285313&t){break d}c=z[a+480190>>1]+1&65535;b=1;while(1){if((b|0)==(c|0)){break d}d=D(b,104)+a|0;e=d+484419|0;if(!(y[e|0]|!(y[d+484421|0]|y[d+484420|0]))){v[e|0]=255}b=b+1|0;continue}}d=a+901404|0;f=oA(d);while(1){if((d|0)!=(f|0)){b=d;k=jo(b);while(1){if((b|0)!=(k|0)){c=y[b|0];e:{f:{if((c-97&255)>>>0<=5){m=c-32|0;break f}if(!(c-88>>>0<2|c-120>>>0<2)){m=99;if((c|0)==75|(c|0)==107){break f}break e}m=122}v[b|0]=m}b=b+1|0;continue}break}d=d+32|0;continue}break}d=x[a+1074308>>2];break a}c=c+1|0;continue}}g:{if(!(x[a+480180>>2]&16777252)|((d|0)==18874368|d>>>0>18874895)){break g}f=z[a+480192>>1]+1&65535;c=0;b=1;while(1){if((b|0)==(f|0)){if(!(c&1)){break g}Lb(h,3,1);d=x[i>>2]}else{e=x[((b<<2)+a|0)+900380>>2];if(!(!e|!y[e+31|0])){v[e+33|0]=13;c=1}b=b+1|0;continue}break}}h:{if(!(x[a+480180>>2]&16777248)|((d|0)==19005440|d>>>0>19006225)){break h}Ab(g+32|0,h,0);if(!zb(x[x[g+32>>2]>>2],x[g+36>>2])){Ab(g+16|0,h,1);if(!zb(x[x[g+16>>2]>>2],x[g+20>>2])){break h}}c=z[a+480192>>1]+1&65535;b=1;while(1){if((b|0)==(c|0)){break h}d=x[((b<<2)+a|0)+900380>>2];if(!(!d|!y[d+19|0]|!(v[d+80|0]&1))){v[d+19|0]=0}b=b+1|0;continue}}i:{if(A[i>>2]>19007232){break i}b=a+906300|0;d=rj(b);while(1){if((b|0)==(d|0)){break i}c=g+16|0;e=b+80|0;OO(c,e);x[27524]=0;X(239,g+32|0,0,22,c|0);c=x[27524];x[27524]=0;if((c|0)!=1){wb(g+16|0);c=g+32|0;cv(e,c);b=b+160|0;wb(c);continue}break}a=P()|0;wb(g+16|0);S(a|0);p()}j:{k:{l:{m:{n:{o:{if(x[a+480180>>2]!=4){break o}c=x[i>>2];if(c>>>0<19007257){break m}if(c>>>0>19071235){break n}if(y[a+1074368|0]!=4){break o}bz(a,5)}c=x[i>>2]}if(c>>>0>19202054){break l}d=19202048;if((c|0)==19202048){break k}}f=z[a+480192>>1]+1&65535;d=1;while(1){if((d|0)==(f|0)){break l}e=x[((d<<2)+a|0)+900380>>2];p:{if(!e|!y[e+20|0]|!y[e+31|0]){break p}b=e+236|0;k=Kq(b);while(1){if((b|0)!=(k|0)){n=z[b>>1];b=b+2|0;if(!n){continue}break p}break}v[e+20|0]=0}d=d+1|0;continue}}d=c;if(c>>>0>19267583){break j}}e=!t;f=z[a+480192>>1]+1&65535;b=1;while(1){if((b|0)==(f|0)){break j}c=x[((b<<2)+a|0)+900380>>2];q:{if(!c){break q}d=v[c+26|0];v[c+26|0]=((d>>31|1)+d|0)/2;d=x[i>>2];if(!(e|d>>>0<18350080)){break q}v[c+19|0]=y[c+19|0]+3>>>2}b=b+1|0;continue}}r:{if(d>>>0>19398673){break r}c=z[a+480192>>1];b=1;while(1){e=b&65535;if(e>>>0>c>>>0){break r}e=x[((e<<2)+a|0)+900380>>2];if(!e|y[e+65|0]==255){b=b+1|0;continue}else{Lb(h,94,1);d=x[i>>2]}break}}s:{if(d>>>0>19399427){break s}c=z[a+480192>>1];b=1;while(1){e=b&65535;if(e>>>0>c>>>0){break s}e=x[((e<<2)+a|0)+900380>>2];if(!e|y[e+36|0]>1){b=b+1|0;continue}else{Lb(h,101,1);d=x[i>>2]}break}}t:{if(d>>>0>19923027){break t}c=z[a+480190>>1];b=1;while(1){d=b&65535;if(d>>>0>c>>>0){break t}d=D(d,104)+a|0;if(!_d(x[d+484380>>2],x[d+484400>>2])|!(y[d+484414|0]&20)){b=b+1|0;continue}else{Lb(h,116,1)}break}}b=ib-16|0;ib=b;w[g+12>>1]=0;x[g+8>>2]=a;Ab(b+8|0,a+1074312|0,0);N=g,O=zb(x[x[b+8>>2]>>2],x[b+12>>2]),v[N+14|0]=O;ib=b+16|0;B=x[g+8>>2];C=x[g+12>>2];b=a+484344|0;m=b;G=Jf(x[b>>2],x[b+4>>2])-1&65535;d=ib-32|0;ib=d;u:{if(Jf(x[b>>2],x[b+4>>2])>>>0<=G>>>0){break u}while(1){b=H&65535;if(b>>>0>G>>>0){break u}c=hg(x[m>>2],b);e=x[c>>2];if(Mb(e,x[c+4>>2])){c=Cb(e);K=Cb(x[hg(x[m>>2],b)+4>>2]);x[d+24>>2]=B;x[d+28>>2]=C;x[d+8>>2]=B;x[d+12>>2]=C;k=d+8|0;u=ib-16|0;ib=u;x[u+8>>2]=c;while(1){if(Mb(c,K)){n=ib-16|0;ib=n;F=z[k+4>>1];b=F+1|0;w[k+4>>1]=b;f=x[k>>2];w[k+4>>1]=z[f+480188>>1]>(b&65535)>>>0?b:0;v:{if(oh(y[c|0])){break v}e=x[f+1074308>>2];w:{s=x[f+480180>>2];x:{y:{if((s|0)==2){if(e>>>0>18415615){break y}if(y[c+3|0]!=23){break x}Ff(c+5|0,64);break x}if(s&16777248){z:{A:{if(e>>>0>=18285314){if(y[k+6|0]){break A}f=0;b=0;if(e>>>0>18874367){break z}}B:{switch(y[c+3|0]-20|0){case 3:Ff(c+5|0,128);break A;case 0:break B;default:break A}}b=y[c+5|0];if((b|0)!=208){if((b|0)!=192){break A}v[c|0]=254;v[c+3|0]=0;break A}v[c+3|0]=0}C:{D:{E:{if(e>>>0>=18350080){if(y[k+6|0]){break E}f=0;b=0;if(e>>>0>18874367){break z}}b=y[c+3|0];if(b>>>0>29){break D}f=1;if(!(1<<b&536873152)){break D}break C}f=0;b=0;if(e>>>0>18874367){break z}b=y[c+3|0]}f=0}b=(b|0)==24|(b|0)==22}F:{if(!(b|f)){break F}f=y[c+5|0];b=f&15;if(!b|(b|0)==15){break F}f=f&240;if(!f|(f|0)==240){break F}v[c+5|0]=y[c+3|0]==24?f:b}G:{if((e|0)==19005440|e>>>0>19005699){break G}b=z[x[k>>2]+480192>>1];if(y[k+6|0]|(!b|b>>>0>=y[c+1|0])){break G}v[c+4|0]=0;v[c+2|0]=1}if(y[c+5|0]!=17|e>>>0>19468801|y[c+3|0]!=18){break y}Ab(n+8|0,x[k>>2]+1074312|0,22);if(!zb(x[x[n+8>>2]>>2],x[n+12>>2])|x[x[k>>2]+480208>>2]&4){break y}v[c+5|0]=0;break y}if((s|0)!=4){break y}b=!y[k+6|0];H:{if((b|e>>>0<18285314)&e>>>0<18874368){break H}if(e>>>0>19137025){break w}if(y[c+3|0]!=23|y[c+5|0]<65){break H}v[c+3|0]=0}I:{J:{K:{if(!(!(b&e>>>0<18874368)&e>>>0>=18415616)){f=y[c+3|0];b=y[c+2|0];if((f|0)!=10|(b|0)!=11){break K}f=0;v[c+3|0]=0;break I}if(e>>>0>18874639){break J}f=y[c+3|0];b=y[c+2|0]}if((b|0)!=11|(f|0)!=4){break I}b=y[c+4|0];if(!(b|y[k+6|0])){f=4;break I}f=4;o=y[c+5|0];if(!o){break I}v[c+2|0]=0;N=c,O=Uu(o+(b<<4)|0),v[N+5|0]=O;break I}if(e>>>0>19007240){break w}f=y[c+3|0]}if(y[c+5|0]|(f|0)!=16){break y}v[c+3|0]=0}if(e>>>0>18874367){break w}}f=y[c+3|0];o=y[c+5|0]&240;L:{M:{if((f|0)!=28|(o|0)!=96){b=0}else{if(!y[k+6|0]|(s|0)!=4){break M}b=e>>>0<18350080}if(!(b|(f|0)==20&(o|0)==96)){break L}}b=D(F,-6)+c|0;while(1){if(b>>>0<c>>>0){if(!((y[b+3|0]|8)!=28|(y[b+5|0]&240)!=96)){v[b+3|0]=0}b=b+6|0;continue}break}f=y[c+3|0]}if((f|0)!=20|(o|0)!=224){break w}b=D(F,-6)+c|0;while(1){if(b>>>0>=c>>>0){break w}if(!(y[b+3|0]!=20|(y[b+5|0]&240)!=224)){v[b+3|0]=0}b=b+6|0;continue}}b=y[c+2|0];if(!((b|0)!=8|e>>>0>19333174|(e|0)==19333120)){e=y[c+4|0];b=y[c+3|0];if(!(!e|(b|0)!=7)){v[c+3|0]=11;break v}N:{O:{switch(b-5|0){default:if((b|0)!=26){break v}break;case 1:break v;case 2:break N;case 0:break O}}f=y[c+5|0];if(!(f&15)){v[c+2|0]=0;v[c+3|0]=5;v[c+5|0]=f|e&15;break v}P:{switch(b-5|0){case 1:break v;case 0:case 2:break N;default:break P}}if((b|0)!=26){break v}}v[c+2|0]=0;break v}Q:{if(!((s|0)==16777216|(b|0)!=15)){b=y[c+3|0];if(b){break Q}v[c+2|0]=0;v[c+3|0]=10;v[c+5|0]=y[c+4|0]<<3;break v}if((b|0)!=15){break v}b=y[c+3|0]}if((b&255)!=10|e>>>0>19922963){break v}if(y[c+4|0]?y[c+5|0]:1){v[c+2|0]=0;break v}v[c+3|0]=0}ib=n+16|0;c=x[Hk(u+8|0)>>2];continue}break}b=x[k+4>>2];x[d+16>>2]=x[k>>2];x[d+20>>2]=b;ib=u+16|0}H=H+1|0;continue}}x[g+32>>2]=B;x[g+36>>2]=C;ib=d+32|0;R:{b=A[a+1074308>>2]<19267584;if(b&t){b=41888;while(1){if((b|0)==42232){break R}d=x[i>>2];c=x[b+4>>2];Lb(h,x[b>>2],d>>>0>=c>>>0|(d|0)==(c&-65536));b=b+8|0;continue}}if(!(b&((J|0)==4&I))){break R}b=42240;while(1){if((b|0)==42480){break R}Lb(h,x[b>>2],A[i>>2]>=A[b+4>>2]);b=b+8|0;continue}}S:{T:{d=x[a+480180>>2];if(d&16777248){b=42480;while(1){if((b|0)==42536){break T}d=x[i>>2];c=x[b+4>>2];e=c&-65536;if(!(d>>>0>=e>>>0&(c>>>0<=d>>>0|d>>>0<=e>>>0))){fg(h,x[b>>2])}b=b+8|0;continue}}b=42608;c=42544;U:{switch(d-2|0){case 2:while(1){if((c|0)==42608){break T}if(A[i>>2]<A[c+4>>2]){fg(h,x[c>>2])}c=c+8|0;continue};case 0:break U;default:break S}}while(1){if((b|0)==42704){break T}if(A[i>>2]<A[b+4>>2]){fg(h,x[b>>2])}b=b+8|0;continue}}d=x[a+480180>>2]}V:{if((d|0)==4){b=x[i>>2];if(b>>>0>18415615){break V}Lb(h,98,1)}b=x[i>>2]}c=8;if(b-19333159>>>0<=33){b=0;while(1){if((b|0)!=5){d=b+77|0;Ab(g+32|0,h,d);fg(Lb(h,b+86|0,zb(x[x[g+32>>2]>>2],x[g+36>>2])),d);b=b+1|0;continue}break}b=x[i>>2]}W:{if(b>>>0>=18284544){if(b>>>0>18874627){break W}c=6;if((b|0)==18874368){break W}}Lb(h,c,1)}b=x[a+1074308>>2];X:{if(y[a+480208|0]&16){if(b>>>0<=19136511){fg(h,7);break X}if(!(x[a+480180>>2]&16777248)|b>>>0>19267583){break X}Lb(h,7,1);break X}if((b|0)==19922944|b>>>0>19922997){break X}fg(h,7)}Ab(g+32|0,h,31);Y:{if(!zb(x[x[g+32>>2]>>2],x[g+36>>2])){break Y}b=x[i>>2];if(b>>>0<19071234|b>>>0>19398722){break Y}c=z[a+480192>>1];b=1;while(1){d=b&65535;if(d>>>0>c>>>0){break Y}Z:{d=x[((d<<2)+a|0)+900380>>2];if(!d){break Z}e=y[d+65|0];if(!(y[d+60|0]&4)|(e|0)==255|e>>>0<=y[d- -64|0]){break Z}Lb(h,97,1);break Y}b=b+1|0;continue}}d=x[a+480180>>2];_:{if(!(d&16777218)){break _}c=z[a+480190>>1];b=1;while(1){e=b&65535;if(e>>>0>c>>>0){break _}b=b+1|0;if(!(y[(D(e,104)+a|0)+484415|0]&2)){continue}break}$:{aa:{ba:{if(!(!z[a+480192>>1]|(d|0)!=16777216)){b=x[i>>2];if(b>>>0<19398688){break aa}if(b>>>0>19464277){break ba}Lb(h,109,1)}b=x[i>>2]}if((b|0)==19922944|b>>>0>19922996){break $}}fg(h,111);b=x[i>>2]}d=x[a+480180>>2];if(!((d|0)!=2|b>>>0>19464191)){Lb(h,108,1);break _}if((d|0)==2){break _}fg(h,108)}c=x[i>>2];ca:{da:{if(c>>>0<19333186){break da}if(c>>>0<=19923013){if(!(x[a+480180>>2]&16777252)){break da}b=a+906300|0;d=rj(b);while(1){if((b|0)!=(d|0)){ea:{if((y[b+16|0]|y[b+17|0]<<8|(y[b+18|0]<<16|y[b+19|0]<<24))!=1146637647|(y[b+20|0]|y[b+21|0]<<8|(y[b+22|0]<<16|y[b+23|0]<<24))!=-271958638){break ea}if((cd(x[b+4>>2],x[b+8>>2])|0)!=32){break ea}c=Kc(g+32|0,16829);cv(b+80|0,c);wb(c)}b=b+160|0;continue}break}c=x[i>>2]}if(c>>>0>19988488){break ca}}if(!(x[a+480180>>2]&16777252)){break ca}b=a+906300|0;e=rj(b);while(1){if((b|0)==(e|0)){break ca}d=b;b=b+160|0;if(!Gi(x[d+16>>2],x[d+20>>2])){continue}break}Lb(h,117,1);c=x[i>>2]}fa:{if(!(x[a+480180>>2]&16777252)|c-19333120>>>0>591359){break fa}b=a+906300|0;c=rj(b);while(1){if((b|0)==(c|0)){break fa}ga:{if((y[b+16|0]|y[b+17|0]<<8|(y[b+18|0]<<16|y[b+19|0]<<24))!=1146637647|(y[b+20|0]|y[b+21|0]<<8|(y[b+22|0]<<16|y[b+23|0]<<24))!=-281111764){break ga}a=x[b+4>>2];if((cd(a,x[b+8>>2])|0)!=24){break ga}L=Ld(E(E(E((l(2,y[a+12|0]|y[a+13|0]<<8|(y[a+14|0]<<16|y[a+15|0]<<24)),r())*E(2e3))+E(-1))/E(1999)),E(0));M=Ld(E(E(E((l(2,y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24)),r())*E(2e3))+E(-1))/E(1999)),E(0));d=(q(L),j(2));v[a+12|0]=d;v[a+13|0]=d>>>8;v[a+14|0]=d>>>16;v[a+15|0]=d>>>24;a=x[b+4>>2];d=(q(M),j(2));v[a+16|0]=d;v[a+17|0]=d>>>8;v[a+18|0]=d>>>16;v[a+19|0]=d>>>24}b=b+160|0;continue}}ib=g+48|0}function Gd(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;l=ib-16|0;ib=l;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if(a>>>0<=244){e=x[27400];h=a>>>0<11?16:a+11&-8;c=h>>>3|0;b=e>>>c|0;if(b&3){c=c+((b^-1)&1)|0;a=c<<3;b=a+109640|0;d=x[a+109648>>2];a=x[d+8>>2];l:{if((b|0)==(a|0)){m=109600,n=toa(-2,c)&e,x[m>>2]=n;break l}x[a+12>>2]=b;x[b+8>>2]=a}a=d+8|0;b=c<<3;x[d+4>>2]=b|3;b=b+d|0;x[b+4>>2]=x[b+4>>2]|1;break a}k=x[27402];if(k>>>0>=h>>>0){break k}if(b){a=2<<c;a=(0-a|a)&b<<c;b=a-1&(a^-1);a=b>>>12&16;c=a;b=b>>>a|0;a=b>>>5&8;c=c|a;b=b>>>a|0;a=b>>>2&4;c=c|a;b=b>>>a|0;a=b>>>1&2;c=c|a;b=b>>>a|0;a=b>>>1&1;d=(c|a)+(b>>>a|0)|0;a=d<<3;b=a+109640|0;g=x[a+109648>>2];a=x[g+8>>2];m:{if((b|0)==(a|0)){e=toa(-2,d)&e;x[27400]=e;break m}x[a+12>>2]=b;x[b+8>>2]=a}x[g+4>>2]=h|3;c=g+h|0;a=d<<3;d=a-h|0;x[c+4>>2]=d|1;x[a+g>>2]=d;if(k){b=(k&-8)+109640|0;f=x[27405];a=1<<(k>>>3);n:{if(!(a&e)){x[27400]=a|e;a=b;break n}a=x[b+8>>2]}x[b+8>>2]=f;x[a+12>>2]=f;x[f+12>>2]=b;x[f+8>>2]=a}a=g+8|0;x[27405]=c;x[27402]=d;break a}j=x[27401];if(!j){break k}b=j-1&(j^-1);a=b>>>12&16;c=a;b=b>>>a|0;a=b>>>5&8;c=c|a;b=b>>>a|0;a=b>>>2&4;c=c|a;b=b>>>a|0;a=b>>>1&2;c=c|a;b=b>>>a|0;a=b>>>1&1;c=x[((c|a)+(b>>>a|0)<<2)+109904>>2];f=(x[c+4>>2]&-8)-h|0;b=c;while(1){o:{a=x[b+16>>2];if(!a){a=x[b+20>>2];if(!a){break o}}b=(x[a+4>>2]&-8)-h|0;d=b>>>0<f>>>0;f=d?b:f;c=d?a:c;b=a;continue}break}i=x[c+24>>2];d=x[c+12>>2];if((d|0)!=(c|0)){a=x[c+8>>2];x[a+12>>2]=d;x[d+8>>2]=a;break b}b=c+20|0;a=x[b>>2];if(!a){a=x[c+16>>2];if(!a){break j}b=c+16|0}while(1){g=b;d=a;b=a+20|0;a=x[b>>2];if(a){continue}b=d+16|0;a=x[d+16>>2];if(a){continue}break}x[g>>2]=0;break b}h=-1;if(a>>>0>4294967231){break k}a=a+11|0;h=a&-8;j=x[27401];if(!j){break k}f=0-h|0;e=0;p:{if(h>>>0<256){break p}e=31;if(h>>>0>16777215){break p}a=a>>>8|0;g=a+1048320>>>16&8;a=a<<g;c=a+520192>>>16&4;a=a<<c;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(c|g))|0;e=(a<<1|h>>>a+21&1)+28|0}b=x[(e<<2)+109904>>2];q:{r:{s:{if(!b){a=0;break s}a=0;c=h<<((e|0)!=31?25-(e>>>1|0)|0:0);while(1){t:{g=(x[b+4>>2]&-8)-h|0;if(g>>>0>=f>>>0){break t}d=b;f=g;if(f){break t}f=0;a=b;break r}g=x[b+20>>2];b=x[((c>>>29&4)+b|0)+16>>2];a=g?(g|0)==(b|0)?a:g:a;c=c<<1;if(b){continue}break}}if(!(a|d)){d=0;a=2<<e;a=(0-a|a)&j;if(!a){break k}b=a-1&(a^-1);a=b>>>12&16;c=a;b=b>>>a|0;a=b>>>5&8;c=c|a;b=b>>>a|0;a=b>>>2&4;c=c|a;b=b>>>a|0;a=b>>>1&2;c=c|a;b=b>>>a|0;a=b>>>1&1;a=x[((c|a)+(b>>>a|0)<<2)+109904>>2]}if(!a){break q}}while(1){b=(x[a+4>>2]&-8)-h|0;c=b>>>0<f>>>0;f=c?b:f;d=c?a:d;b=x[a+16>>2];if(b){a=b}else{a=x[a+20>>2]}if(a){continue}break}}if(!d|x[27402]-h>>>0<=f>>>0){break k}e=x[d+24>>2];c=x[d+12>>2];if((d|0)!=(c|0)){a=x[d+8>>2];x[a+12>>2]=c;x[c+8>>2]=a;break c}b=d+20|0;a=x[b>>2];if(!a){a=x[d+16>>2];if(!a){break i}b=d+16|0}while(1){g=b;c=a;b=a+20|0;a=x[b>>2];if(a){continue}b=c+16|0;a=x[c+16>>2];if(a){continue}break}x[g>>2]=0;break c}c=x[27402];if(c>>>0>=h>>>0){d=x[27405];b=c-h|0;u:{if(b>>>0>=16){x[27402]=b;a=d+h|0;x[27405]=a;x[a+4>>2]=b|1;x[c+d>>2]=b;x[d+4>>2]=h|3;break u}x[27405]=0;x[27402]=0;x[d+4>>2]=c|3;a=c+d|0;x[a+4>>2]=x[a+4>>2]|1}a=d+8|0;break a}i=x[27403];if(i>>>0>h>>>0){b=i-h|0;x[27403]=b;c=x[27406];a=c+h|0;x[27406]=a;x[a+4>>2]=b|1;x[c+4>>2]=h|3;a=c+8|0;break a}a=0;j=h+47|0;if(x[27518]){c=x[27520]}else{x[27521]=-1;x[27522]=-1;x[27519]=4096;x[27520]=4096;x[27518]=l+12&-16^1431655768;x[27523]=0;x[27511]=0;c=4096}g=j+c|0;f=0-c|0;b=g&f;if(b>>>0<=h>>>0){break a}d=x[27510];if(d){c=x[27508];e=c+b|0;if(d>>>0<e>>>0|c>>>0>=e>>>0){break a}}if(y[110044]&4){break f}v:{w:{d=x[27406];if(d){a=110048;while(1){c=x[a>>2];if(c>>>0<=d>>>0&d>>>0<c+x[a+4>>2]>>>0){break w}a=x[a+8>>2];if(a){continue}break}}c=Hm(0);if((c|0)==-1){break g}e=b;d=x[27519];a=d-1|0;if(a&c){e=(b-c|0)+(a+c&0-d)|0}if(e>>>0<=h>>>0|e>>>0>2147483646){break g}d=x[27510];if(d){a=x[27508];f=a+e|0;if(d>>>0<f>>>0|a>>>0>=f>>>0){break g}}a=Hm(e);if((c|0)!=(a|0)){break v}break e}e=f&g-i;if(e>>>0>2147483646){break g}c=Hm(e);if((c|0)==(x[a>>2]+x[a+4>>2]|0)){break h}a=c}if(!((a|0)==-1|h+48>>>0<=e>>>0)){c=x[27520];c=c+(j-e|0)&0-c;if(c>>>0>2147483646){c=a;break e}if((Hm(c)|0)!=-1){e=c+e|0;c=a;break e}Hm(0-e|0);break g}c=a;if((a|0)!=-1){break e}break g}d=0;break b}c=0;break c}if((c|0)!=-1){break e}}x[27511]=x[27511]|4}if(b>>>0>2147483646){break d}c=Hm(b);a=Hm(0);if((c|0)==-1|(a|0)==-1|a>>>0<=c>>>0){break d}e=a-c|0;if(e>>>0<=h+40>>>0){break d}}a=x[27508]+e|0;x[27508]=a;if(a>>>0>A[27509]){x[27509]=a}x:{y:{z:{g=x[27406];if(g){a=110048;while(1){d=x[a>>2];b=x[a+4>>2];if((d+b|0)==(c|0)){break z}a=x[a+8>>2];if(a){continue}break}break y}a=x[27404];if(!(a>>>0<=c>>>0?a:0)){x[27404]=c}a=0;x[27513]=e;x[27512]=c;x[27408]=-1;x[27409]=x[27518];x[27515]=0;while(1){d=a<<3;b=d+109640|0;x[d+109648>>2]=b;x[d+109652>>2]=b;a=a+1|0;if((a|0)!=32){continue}break}d=e-40|0;a=c+8&7?-8-c&7:0;b=d-a|0;x[27403]=b;a=a+c|0;x[27406]=a;x[a+4>>2]=b|1;x[(c+d|0)+4>>2]=40;x[27407]=x[27522];break x}if(y[a+12|0]&8|d>>>0>g>>>0|c>>>0<=g>>>0){break y}x[a+4>>2]=b+e;a=g+8&7?-8-g&7:0;c=a+g|0;x[27406]=c;b=x[27403]+e|0;a=b-a|0;x[27403]=a;x[c+4>>2]=a|1;x[(b+g|0)+4>>2]=40;x[27407]=x[27522];break x}if(A[27404]>c>>>0){x[27404]=c}b=c+e|0;a=110048;A:{B:{C:{D:{E:{F:{while(1){if((b|0)!=x[a>>2]){a=x[a+8>>2];if(a){continue}break F}break}if(!(y[a+12|0]&8)){break E}}a=110048;while(1){b=x[a>>2];if(b>>>0<=g>>>0){f=b+x[a+4>>2]|0;if(f>>>0>g>>>0){break D}}a=x[a+8>>2];continue}}x[a>>2]=c;x[a+4>>2]=x[a+4>>2]+e;j=(c+8&7?-8-c&7:0)+c|0;x[j+4>>2]=h|3;e=b+(b+8&7?-8-b&7:0)|0;i=h+j|0;a=e-i|0;if((e|0)==(g|0)){x[27406]=i;a=x[27403]+a|0;x[27403]=a;x[i+4>>2]=a|1;break B}if(x[27405]==(e|0)){x[27405]=i;a=x[27402]+a|0;x[27402]=a;x[i+4>>2]=a|1;x[a+i>>2]=a;break B}f=x[e+4>>2];if((f&3)==1){g=f&-8;G:{if(f>>>0<=255){d=x[e+8>>2];b=f>>>3|0;c=x[e+12>>2];if((c|0)==(d|0)){m=109600,n=x[27400]&toa(-2,b),x[m>>2]=n;break G}x[d+12>>2]=c;x[c+8>>2]=d;break G}h=x[e+24>>2];c=x[e+12>>2];H:{if((e|0)!=(c|0)){b=x[e+8>>2];x[b+12>>2]=c;x[c+8>>2]=b;break H}I:{f=e+20|0;b=x[f>>2];if(b){break I}f=e+16|0;b=x[f>>2];if(b){break I}c=0;break H}while(1){d=f;c=b;f=b+20|0;b=x[f>>2];if(b){continue}f=c+16|0;b=x[c+16>>2];if(b){continue}break}x[d>>2]=0}if(!h){break G}d=x[e+28>>2];b=(d<<2)+109904|0;J:{if(x[b>>2]==(e|0)){x[b>>2]=c;if(c){break J}m=109604,n=x[27401]&toa(-2,d),x[m>>2]=n;break G}x[h+(x[h+16>>2]==(e|0)?16:20)>>2]=c;if(!c){break G}}x[c+24>>2]=h;b=x[e+16>>2];if(b){x[c+16>>2]=b;x[b+24>>2]=c}b=x[e+20>>2];if(!b){break G}x[c+20>>2]=b;x[b+24>>2]=c}e=e+g|0;f=x[e+4>>2];a=a+g|0}x[e+4>>2]=f&-2;x[i+4>>2]=a|1;x[a+i>>2]=a;if(a>>>0<=255){b=(a&-8)+109640|0;c=x[27400];a=1<<(a>>>3);K:{if(!(c&a)){x[27400]=a|c;a=b;break K}a=x[b+8>>2]}x[b+8>>2]=i;x[a+12>>2]=i;x[i+12>>2]=b;x[i+8>>2]=a;break B}f=31;if(a>>>0<=16777215){b=a>>>8|0;f=b+1048320>>>16&8;b=b<<f;d=b+520192>>>16&4;b=b<<d;c=b+245760>>>16&2;b=(b<<c>>>15|0)-(c|(d|f))|0;f=(b<<1|a>>>b+21&1)+28|0}x[i+28>>2]=f;x[i+16>>2]=0;x[i+20>>2]=0;b=(f<<2)+109904|0;d=x[27401];c=1<<f;L:{if(!(d&c)){x[27401]=c|d;x[b>>2]=i;break L}f=a<<((f|0)!=31?25-(f>>>1|0)|0:0);c=x[b>>2];while(1){b=c;if((x[b+4>>2]&-8)==(a|0)){break C}c=f>>>29|0;f=f<<1;d=(c&4)+b|0;c=x[d+16>>2];if(c){continue}break}x[d+16>>2]=i}x[i+24>>2]=b;x[i+12>>2]=i;x[i+8>>2]=i;break B}d=e-40|0;a=c+8&7?-8-c&7:0;b=d-a|0;x[27403]=b;a=a+c|0;x[27406]=a;x[a+4>>2]=b|1;x[(c+d|0)+4>>2]=40;x[27407]=x[27522];a=(f+(f-39&7?39-f&7:0)|0)-47|0;d=a>>>0<g+16>>>0?g:a;x[d+4>>2]=27;a=x[27515];x[d+16>>2]=x[27514];x[d+20>>2]=a;a=x[27513];x[d+8>>2]=x[27512];x[d+12>>2]=a;x[27514]=d+8;x[27513]=e;x[27512]=c;x[27515]=0;a=d+24|0;while(1){x[a+4>>2]=7;b=a+8|0;a=a+4|0;if(b>>>0<f>>>0){continue}break}if((d|0)==(g|0)){break x}x[d+4>>2]=x[d+4>>2]&-2;f=d-g|0;x[g+4>>2]=f|1;x[d>>2]=f;if(f>>>0<=255){b=(f&-8)+109640|0;c=x[27400];a=1<<(f>>>3);M:{if(!(c&a)){x[27400]=a|c;a=b;break M}a=x[b+8>>2]}x[b+8>>2]=g;x[a+12>>2]=g;x[g+12>>2]=b;x[g+8>>2]=a;break x}a=31;if(f>>>0<=16777215){a=f>>>8|0;d=a+1048320>>>16&8;a=a<<d;c=a+520192>>>16&4;a=a<<c;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(c|d))|0;a=(a<<1|f>>>a+21&1)+28|0}x[g+28>>2]=a;x[g+16>>2]=0;x[g+20>>2]=0;b=(a<<2)+109904|0;d=x[27401];c=1<<a;N:{if(!(d&c)){x[27401]=c|d;x[b>>2]=g;break N}a=f<<((a|0)!=31?25-(a>>>1|0)|0:0);d=x[b>>2];while(1){b=d;if((f|0)==(x[b+4>>2]&-8)){break A}c=a>>>29|0;a=a<<1;c=(c&4)+b|0;d=x[c+16>>2];if(d){continue}break}x[c+16>>2]=g}x[g+24>>2]=b;x[g+12>>2]=g;x[g+8>>2]=g;break x}a=x[b+8>>2];x[a+12>>2]=i;x[b+8>>2]=i;x[i+24>>2]=0;x[i+12>>2]=b;x[i+8>>2]=a}a=j+8|0;break a}a=x[b+8>>2];x[a+12>>2]=g;x[b+8>>2]=g;x[g+24>>2]=0;x[g+12>>2]=b;x[g+8>>2]=a}a=x[27403];if(a>>>0<=h>>>0){break d}b=a-h|0;x[27403]=b;c=x[27406];a=c+h|0;x[27406]=a;x[a+4>>2]=b|1;x[c+4>>2]=h|3;a=c+8|0;break a}x[12e4]=48;a=0;break a}O:{if(!e){break O}b=x[d+28>>2];a=(b<<2)+109904|0;P:{if(x[a>>2]==(d|0)){x[a>>2]=c;if(c){break P}j=toa(-2,b)&j;x[27401]=j;break O}x[e+(x[e+16>>2]==(d|0)?16:20)>>2]=c;if(!c){break O}}x[c+24>>2]=e;a=x[d+16>>2];if(a){x[c+16>>2]=a;x[a+24>>2]=c}a=x[d+20>>2];if(!a){break O}x[c+20>>2]=a;x[a+24>>2]=c}Q:{if(f>>>0<=15){a=f+h|0;x[d+4>>2]=a|3;a=a+d|0;x[a+4>>2]=x[a+4>>2]|1;break Q}x[d+4>>2]=h|3;e=d+h|0;x[e+4>>2]=f|1;x[e+f>>2]=f;if(f>>>0<=255){b=(f&-8)+109640|0;c=x[27400];a=1<<(f>>>3);R:{if(!(c&a)){x[27400]=a|c;a=b;break R}a=x[b+8>>2]}x[b+8>>2]=e;x[a+12>>2]=e;x[e+12>>2]=b;x[e+8>>2]=a;break Q}a=31;if(f>>>0<=16777215){a=f>>>8|0;g=a+1048320>>>16&8;a=a<<g;c=a+520192>>>16&4;a=a<<c;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(c|g))|0;a=(a<<1|f>>>a+21&1)+28|0}x[e+28>>2]=a;x[e+16>>2]=0;x[e+20>>2]=0;b=(a<<2)+109904|0;S:{c=1<<a;T:{if(!(c&j)){x[27401]=c|j;x[b>>2]=e;break T}a=f<<((a|0)!=31?25-(a>>>1|0)|0:0);h=x[b>>2];while(1){b=h;if((x[b+4>>2]&-8)==(f|0)){break S}c=a>>>29|0;a=a<<1;c=(c&4)+b|0;h=x[c+16>>2];if(h){continue}break}x[c+16>>2]=e}x[e+24>>2]=b;x[e+12>>2]=e;x[e+8>>2]=e;break Q}a=x[b+8>>2];x[a+12>>2]=e;x[b+8>>2]=e;x[e+24>>2]=0;x[e+12>>2]=b;x[e+8>>2]=a}a=d+8|0;break a}U:{if(!i){break U}b=x[c+28>>2];a=(b<<2)+109904|0;V:{if(x[a>>2]==(c|0)){x[a>>2]=d;if(d){break V}m=109604,n=toa(-2,b)&j,x[m>>2]=n;break U}x[i+(x[i+16>>2]==(c|0)?16:20)>>2]=d;if(!d){break U}}x[d+24>>2]=i;a=x[c+16>>2];if(a){x[d+16>>2]=a;x[a+24>>2]=d}a=x[c+20>>2];if(!a){break U}x[d+20>>2]=a;x[a+24>>2]=d}W:{if(f>>>0<=15){a=f+h|0;x[c+4>>2]=a|3;a=a+c|0;x[a+4>>2]=x[a+4>>2]|1;break W}x[c+4>>2]=h|3;d=c+h|0;x[d+4>>2]=f|1;x[d+f>>2]=f;if(k){b=(k&-8)+109640|0;g=x[27405];a=1<<(k>>>3);X:{if(!(a&e)){x[27400]=a|e;a=b;break X}a=x[b+8>>2]}x[b+8>>2]=g;x[a+12>>2]=g;x[g+12>>2]=b;x[g+8>>2]=a}x[27405]=d;x[27402]=f}a=c+8|0}ib=l+16|0;return a|0}function xM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;g=ib-32|0;ib=g;a:{b:{c:{d:{e:{f:{if(de(b,21631)){Kb(a);break f}if(de(b,9831)){b=ib-128|0;ib=b;f=Kb(a);x[27524]=0;Y(138,b+96|0);a=x[27524];x[27524]=0;g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{if((a|0)!=1){x[27524]=0;x[b+64>>2]=0;R(1078,b+80|0,b- -64|0);a=x[27524];x[27524]=0;if((a|0)==1){break q}x[27524]=0;a=Q(806,f|0,b+80|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break p}wb(b+80|0);x[27524]=0;a=Q(947,a|0,16748)|0;c=x[27524];x[27524]=0;r:{if((c|0)==1){break r}x[27524]=0;x[b+64>>2]=7;R(1078,b+80|0,b- -64|0);c=x[27524];x[27524]=0;if((c|0)==1){break o}x[27524]=0;a=Q(806,a|0,b+80|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break n}wb(b+80|0);x[27524]=0;a=Q(947,a|0,16748)|0;c=x[27524];x[27524]=0;if((c|0)==1){break r}x[27524]=0;x[b+64>>2]=0;R(1078,b+80|0,b- -64|0);c=x[27524];x[27524]=0;if((c|0)==1){break m}x[27524]=0;a=Q(806,a|0,b+80|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break l}c=b+80|0;wb(c);x[27524]=0;c=Q(55,c|0,15232)|0;d=x[27524];x[27524]=0;if((d|0)==1){break k}d=Eb(c);wb(c);if(!d){break j}x[27524]=0;Q(947,a|0,15232)|0;c=x[27524];x[27524]=0;if((c|0)!=1){break j}}a=P()|0;break i}a=P()|0;break h}a=P()|0;break i}a=P()|0;wb(b+80|0);break i}a=P()|0;break i}a=P()|0;wb(b+80|0);break i}a=P()|0;break i}a=P()|0;wb(b+80|0);break i}a=P()|0;break i}c=Nb(b- -64|0);s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{d=x[b+108>>2];if(d){x[27524]=0;x[b+16>>2]=d;R(1078,b+32|0,b+16|0);d=x[27524];x[27524]=0;if((d|0)==1){break E}x[27524]=0;U(973,b+48|0,8912,b+32|0);d=x[27524];x[27524]=0;if((d|0)==1){break D}x[27524]=0;R(187,c|0,b+48|0);d=x[27524];x[27524]=0;if((d|0)==1){break C}wb(b+48|0);wb(b+32|0)}if(!Qd(y[b+112|0])){break y}x[27524]=0;d=Q(55,b+48|0,12734)|0;e=x[27524];x[27524]=0;if((e|0)==1){break A}x[27524]=0;R(187,c|0,d|0);e=x[27524];x[27524]=0;if((e|0)==1){break z}wb(d);break x}a=P()|0;break s}a=P()|0;break B}a=P()|0;wb(b+48|0)}wb(b+32|0);break s}a=P()|0;break s}a=P()|0;wb(d);break s}if(!Qd(y[b+113|0])){break x}x[27524]=0;d=Q(55,b+48|0,12505)|0;e=x[27524];x[27524]=0;if((e|0)==1){break w}x[27524]=0;R(187,c|0,d|0);e=x[27524];x[27524]=0;if((e|0)==1){break v}wb(d)}if(Qd(y[b+114|0])){break u}break t}a=P()|0;break s}a=P()|0;wb(d);break s}x[27524]=0;d=Q(55,b+32|0,11042)|0;e=x[27524];x[27524]=0;F:{if((e|0)!=1){x[27524]=0;R(187,c|0,d|0);e=x[27524];x[27524]=0;if((e|0)==1){break F}wb(d);break t}a=P()|0;break s}a=P()|0;wb(d);break s}if(pc(x[c>>2],x[c+4>>2])){break g}x[27524]=0;a=Q(947,a|0,16778)|0;d=x[27524];x[27524]=0;if((d|0)!=1){x[27524]=0;d=Q(55,b|0,16748)|0;e=x[27524];x[27524]=0;G:{H:{I:{if((e|0)!=1){x[27524]=0;U(1079,b+16|0,c|0,d|0);e=x[27524];x[27524]=0;if((e|0)==1){break I}x[27524]=0;Q(806,a|0,b+16|0)|0;a=x[27524];x[27524]=0;if((a|0)==1){break H}wb(b+16|0);wb(d);break g}a=P()|0;break s}a=P()|0;break G}a=P()|0;wb(b+16|0)}wb(d);break s}a=P()|0}ve(c)}Lf(b+96|0)}wb(f);break b}ve(c);Lf(b+96|0);ib=b+128|0;break f}if(de(b,8080)){x[g>>2]=0;Lp(a,g);break f}if(de(b,8058)){x[g>>2]=7;Lp(a,g);break f}if(de(b,10762)){x[g>>2]=0;Lp(a,g);break f}if(de(b,10534)){Kc(a,15232);break f}if(de(b,11299)){b=Kc(g,15232);c=Eb(b);x[27524]=0;Q(55,a|0,(c?15783:15460)|0)|0;a=x[27524];x[27524]=0;if((a|0)==1){break e}wb(b);break f}if(de(b,7360)){b=ib-48|0;ib=b;HE(b+16|0);x[27524]=0;Y(155,b|0);c=x[27524];x[27524]=0;J:{K:{L:{M:{if((c|0)!=1){x[27524]=0;U(156,b+32|0,b+16|0,b|0);c=x[27524];x[27524]=0;if((c|0)==1){break M}x[27524]=0;R(1021,a|0,b+32|0);a=x[27524];x[27524]=0;if((a|0)==1){break L}xb(b+32|0);xb(b);xb(b+16|0);ib=b+48|0;break f}a=P()|0;break J}a=P()|0;break K}a=P()|0;xb(b+32|0)}xb(b)}xb(b+16|0);break b}if(de(b,9847)){b=ib-16|0;ib=b;e=ib-16|0;ib=e;x[e+8>>2]=101;c=ib-112|0;ib=c;f=Nb(c+96|0);N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{d=x[e+8>>2];if(d&1){x[27524]=0;R(144,c- -64|0,19988503);d=x[27524];x[27524]=0;if((d|0)==1){break aa}x[27524]=0;R(128,f|0,c- -64|0);d=x[27524];x[27524]=0;if((d|0)==1){break $}xb(c- -64|0);d=x[e+8>>2]}if(!(d&4)){break Z}x[27524]=0;d=ga(145)|0;h=x[27524];x[27524]=0;if((h|0)==1){break Y}if(!d){break _}break Z}d=P()|0;break O}d=P()|0;xb(c- -64|0);break O}x[27524]=0;Y(146,c- -64|0);d=x[27524];x[27524]=0;ba:{if((d|0)!=1){x[27524]=0;R(128,f|0,c- -64|0);d=x[27524];x[27524]=0;if((d|0)==1){break ba}xb(c- -64|0);break Z}d=P()|0;break O}d=P()|0;xb(c- -64|0);break O}ca:{d=x[e+8>>2];if(!(d&32)){break ca}x[27524]=0;Y(138,c- -64|0);d=x[27524];x[27524]=0;da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{if((d|0)!=1){x[27524]=0;R(147,c+48|0,c- -64|0);d=x[27524];x[27524]=0;if((d|0)==1){break ea}d=yh(x[c+52>>2],y[c+59|0]);xb(c+48|0);if(!d){x[27524]=0;Y(148,c+32|0);d=x[27524];x[27524]=0;if((d|0)==1){break va}x[27524]=0;R(147,c+16|0,c- -64|0);d=x[27524];x[27524]=0;if((d|0)==1){break ua}x[27524]=0;U(149,c+48|0,c+32|0,c+16|0);d=x[27524];x[27524]=0;if((d|0)==1){break ta}x[27524]=0;R(128,f|0,c+48|0);d=x[27524];x[27524]=0;if((d|0)==1){break sa}xb(c+48|0);xb(c+16|0);$b(c+32|0)}d=bp(c- -64|0);if(!yh(x[d+4>>2],y[d+11|0])){x[27524]=0;Y(150,c+32|0);h=x[27524];x[27524]=0;if((h|0)==1){break pa}x[27524]=0;U(151,c+48|0,c+32|0,d|0);d=x[27524];x[27524]=0;if((d|0)==1){break oa}x[27524]=0;R(128,f|0,c+48|0);d=x[27524];x[27524]=0;if((d|0)==1){break na}xb(c+48|0);$b(c+32|0)}x[27524]=0;R(152,c+48|0,c- -64|0);d=x[27524];x[27524]=0;if((d|0)==1){break la}d=yh(x[c+52>>2],y[c+59|0]);xb(c+48|0);if(!d){x[27524]=0;Y(148,c+32|0);d=x[27524];x[27524]=0;if((d|0)==1){break ka}x[27524]=0;R(152,c+16|0,c- -64|0);d=x[27524];x[27524]=0;if((d|0)==1){break ja}x[27524]=0;U(149,c+48|0,c+32|0,c+16|0);d=x[27524];x[27524]=0;if((d|0)==1){break ia}x[27524]=0;R(128,f|0,c+48|0);d=x[27524];x[27524]=0;if((d|0)==1){break ha}xb(c+48|0);xb(c+16|0);$b(c+32|0)}Lf(c- -64|0);d=x[e+8>>2];break ca}d=P()|0;break O}d=P()|0;break da}d=P()|0;break qa}d=P()|0;break ra}d=P()|0;xb(c+48|0)}xb(c+16|0)}$b(c+32|0);break da}d=P()|0;break da}d=P()|0;break ma}d=P()|0;xb(c+48|0)}$b(c+32|0);break da}d=P()|0;break da}d=P()|0;break da}d=P()|0;break fa}d=P()|0;break ga}d=P()|0;xb(c+48|0)}xb(c+16|0)}$b(c+32|0);break da}d=P()|0}Lf(c- -64|0);break O}wa:{if(!(d&64)){break wa}x[27524]=0;d=ga(145)|0;h=x[27524];x[27524]=0;if((h|0)==1){break Y}if(d){break wa}d=c- -64|0;Kb(d);x[27524]=0;R(128,f|0,d|0);d=x[27524];x[27524]=0;if((d|0)==1){break P}xb(c- -64|0)}if(y[e+8|0]&128){x[27524]=0;Y(153,c- -64|0);d=x[27524];x[27524]=0;if((d|0)==1){break X}x[27524]=0;R(128,f|0,c- -64|0);d=x[27524];x[27524]=0;if((d|0)==1){break W}xb(c- -64|0)}x[27524]=0;h=Q(1,c- -64|0,21631)|0;d=x[27524];x[27524]=0;if((d|0)==1){break V}x[27524]=0;U(154,c|0,f|0,h|0);d=x[27524];x[27524]=0;if((d|0)==1){break U}x[27524]=0;Y(155,c+48|0);d=x[27524];x[27524]=0;if((d|0)==1){break T}x[27524]=0;U(156,b|0,c|0,c+48|0);d=x[27524];x[27524]=0;if((d|0)==1){break S}xb(c+48|0);xb(c);xb(h);Wl(f);ib=c+112|0;break N}d=P()|0;break O}d=P()|0;break O}d=P()|0;xb(c- -64|0);break O}d=P()|0;break O}d=P()|0;break Q}d=P()|0;break R}d=P()|0;xb(c+48|0)}xb(c)}xb(h);break O}d=P()|0;xb(c- -64|0)}Wl(f);S(d|0);p()}ib=e+16|0;x[27524]=0;R(1021,a|0,b|0);a=x[27524];x[27524]=0;if((a|0)!=1){xb(b);ib=b+16|0;break f}break c}if(de(b,10463)){b=ib-48|0;ib=b;Gr(b);x[27524]=0;R(147,b+32|0,b|0);c=x[27524];x[27524]=0;xa:{ya:{if((c|0)!=1){x[27524]=0;R(1021,a|0,b+32|0);a=x[27524];x[27524]=0;if((a|0)==1){break ya}xb(b+32|0);Lf(b);ib=b+48|0;break f}a=P()|0;break xa}a=P()|0;xb(b+32|0)}Lf(b);break b}if(de(b,11262)){b=ib-32|0;ib=b;Gr(b);x[27524]=0;R(1021,a|0,bp(b)|0);a=x[27524];x[27524]=0;if((a|0)!=1){Lf(b);ib=b+32|0;break f}a=P()|0;Lf(b);break b}if(de(b,9860)){b=ib-48|0;ib=b;Gr(b+16|0);c=x[b+28>>2];za:{if(c){x[27524]=0;x[b+12>>2]=c;R(1078,a|0,b+12|0);a=x[27524];x[27524]=0;if((a|0)!=1){break za}a=P()|0;Lf(b+16|0);break b}Kb(a)}Lf(b+16|0);ib=b+48|0;break f}if(de(b,12724)){Gr(g);b=y[g+16|0];x[27524]=0;Q(55,a|0,(Qd(b)?15460:15783)|0)|0;a=x[27524];x[27524]=0;if((a|0)!=1){Lf(g);break f}a=P()|0;Lf(g);break b}if(de(b,9876)){Gr(g);b=y[g+17|0];x[27524]=0;Q(55,a|0,(Qd(b)?15460:15783)|0)|0;a=x[27524];x[27524]=0;if((a|0)!=1){Lf(g);break f}a=P()|0;Lf(g);break b}if(de(b,12177)){Gr(g);b=y[g+18|0];x[27524]=0;Q(55,a|0,(Qd(b)?15460:15783)|0)|0;a=x[27524];x[27524]=0;if((a|0)!=1){Lf(g);break f}a=P()|0;Lf(g);break b}if(de(b,12479)){b=ib-16|0;ib=b;c=ib-32|0;ib=c;d=Kb(b);x[27524]=0;Y(138,c|0);f=x[27524];x[27524]=0;Aa:{Ba:{if((f|0)!=1){x[27524]=0;R(139,d|0,bp(c)|0);f=x[27524];x[27524]=0;if((f|0)==1){break Ba}Lf(c);ib=c+32|0;break Aa}a=P()|0;break a}a=P()|0;Lf(c);break a}x[27524]=0;R(1021,a|0,b|0);a=x[27524];x[27524]=0;if((a|0)!=1){xb(b);ib=b+16|0;break f}break c}if(de(b,8201)){b=ib-16|0;ib=b;c=ib-48|0;ib=c;d=Kb(b);x[27524]=0;R(141,c+16|0,4138);f=x[27524];x[27524]=0;Ca:{Da:{Ea:{Fa:{if((f|0)!=1){x[c+12>>2]=16;x[c+8>>2]=0;x[27524]=0;x[c+4>>2]=0;ea(142,c+32|0,c+16|0,c+12|0,c+8|0,c+4|0);f=x[27524];x[27524]=0;if((f|0)==1){break Fa}x[27524]=0;Q(99,d|0,c+32|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break Ea}xb(c+32|0);$b(c+16|0);ib=c+48|0;break Ca}a=P()|0;break a}a=P()|0;break Da}a=P()|0;xb(c+32|0)}$b(c+16|0);break a}x[27524]=0;R(1021,a|0,b|0);a=x[27524];x[27524]=0;if((a|0)!=1){xb(b);ib=b+16|0;break f}break c}if(de(b,6825)){b=ib-16|0;ib=b;en(b,0,19577);x[27524]=0;R(1021,a|0,b|0);a=x[27524];x[27524]=0;if((a|0)!=1){xb(b);ib=b+16|0;break f}break c}if(de(b,6458)){b=ib-48|0;ib=b;c=xc(b+16|0,17638);x[27524]=0;R(1080,b|0,2);d=x[27524];x[27524]=0;Ga:{Ha:{Ia:{Ja:{if((d|0)!=1){x[27524]=0;U(2,b+32|0,c|0,b|0);d=x[27524];x[27524]=0;if((d|0)==1){break Ja}x[27524]=0;R(1021,a|0,b+32|0);a=x[27524];x[27524]=0;if((a|0)==1){break Ia}xb(b+32|0);xb(b);xb(c);ib=b+48|0;break f}a=P()|0;break Ga}a=P()|0;break Ha}a=P()|0;xb(b+32|0)}xb(b)}xb(c);break b}if(de(b,11285)){b=ib-16|0;ib=b;en(b,0,17977);x[27524]=0;R(1021,a|0,b|0);a=x[27524];x[27524]=0;if((a|0)!=1){xb(b);ib=b+16|0;break f}break c}if(de(b,10470)){b=ib-16|0;ib=b;Dr(b,0);x[27524]=0;R(1021,a|0,b|0);a=x[27524];x[27524]=0;if((a|0)!=1){xb(b);ib=b+16|0;break f}break c}if(de(b,10445)){b=ib-16|0;ib=b;Dr(b,2);x[27524]=0;R(1021,a|0,b|0);a=x[27524];x[27524]=0;if((a|0)!=1){xb(b);ib=b+16|0;break f}break c}if(de(b,10430)){b=ib-16|0;ib=b;Dr(b,3);x[27524]=0;R(1021,a|0,b|0);a=x[27524];x[27524]=0;if((a|0)!=1){xb(b);ib=b+16|0;break f}break c}Kb(a)}ib=g+32|0;break d}a=P()|0;wb(b);break b}return}a=P()|0;xb(b)}S(a|0);p()}xb(d);S(a|0);p()}function SY(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;a:{n=Lh(b,13823);if(!n){break a}o=a+480192|0;b:while(1){if(!Ob(x[b>>2],x[b+8>>2],6)){break a}c:{f=Jg(b);d:{if((f|0)==(Vm(13642)|0)){break d}c=y[21607]|y[21608]<<8|(y[21609]<<16|y[21610]<<24);if(!(f&1616928864)|f&-2139062144){break d}if((c|0)!=(f|0)){break c}}Gg(b,4);break a}l=1;c=_g(b);while(1){d=l&65535;if(d>>>0>z[o>>1]){continue b}d=x[((d<<2)+a|0)+900380>>2];if(d){e:{g=0;if((Vm(16732)|0)==(f|0)){Yb(b,c);break e}e=ib-48|0;ib=e;f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{switch(f-1349079874|0){default:if((f|0)==1095062094){break v}if((f|0)==1095126087){break s}if((f|0)==1129524782){break B}if((f|0)==1145263150){break Y}if((f|0)==1145979182){break X}if((f|0)==1179463214){break z}if((f|0)==1851469358){break F}if((f|0)==1179931728){break n}$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{if((f|0)!=1196830254){if((f|0)==1229341486){break U}if((f|0)==1229345326){break T}if((f|0)==1264266798){break G}if((f|0)==1296182830){break S}if((f|0)==1296248366){break Q}if((f|0)==1297100334){break R}if((f|0)==1297110852){break q}if((f|0)==1298747438){break D}if((f|0)==1313692462){break H}if((f|0)==1313751342){break Z}if((f|0)==1345203758){break ja}if((f|0)==1346711086){break l}if((f|0)==1346720334){break w}if((f|0)==1346722606){break J}if((f|0)==1346784327){break t}if((f|0)==1347175726){break da}if((f|0)==1347179310){break ea}if((f|0)==1347437358){break O}if((f|0)==1347441454){break P}if((f|0)==1347443502){break M}if((f|0)==1347628590){break W}if((f|0)==1347633710){break ca}if((f|0)==1347634478){break ba}if((f|0)==1347703884){break o}if((f|0)==1347831112){break y}if((f|0)==1347833672){break x}if((f|0)==1349076270){break k}if((f|0)==1349076315){break I}if((f|0)==1349078085){break $}if((f|0)==1349078099){break aa}if((f|0)==1349079131){break L}if((f|0)==1378758190){break p}if((f|0)==1381183022){break A}if((f|0)==1447374382){break m}if((f|0)==1447383630){break u}if((f|0)==1447385902){break K}if((f|0)==1447447623){break r}if((f|0)==1447839022){break ha}if((f|0)==1447842606){break ia}if((f|0)==1448106798){break N}if((f|0)==1448226350){break C}if((f|0)==1448291886){break V}if((f|0)==1448297006){break ga}if((f|0)==1448297774){break fa}if((f|0)!=1682320942){if((f|0)==1718508334){break E}if((f|0)!=1179594286|c>>>0>4){break f}if(!Ob(x[b>>2],x[b+8>>2],c)){break f}q=d,r=Fv(b,c),x[q>>2]=r;break g}if(c>>>0>1){break f}if(!Ob(x[b>>2],x[b+8>>2],c)){break f}q=d,r=Ad(b,c),v[q+15|0]=r;break g}if(c>>>0>4){break f}if(!Ob(x[b>>2],x[b+8>>2],c)){break f}q=d,r=Fv(b,c),x[q+4>>2]=r;break g}if(c>>>0>4){break f}if(!Ob(x[b>>2],x[b+8>>2],c)){break f}q=d,r=Fv(b,c),x[q+8>>2]=r;break g}if(c>>>0>1){break f}if(!Ob(x[b>>2],x[b+8>>2],c)){break f}q=d,r=Ad(b,c),v[q+61|0]=r;break g}if(c>>>0>1){break f}if(!Ob(x[b>>2],x[b+8>>2],c)){break f}q=d,r=Ad(b,c),v[q+62|0]=r;break g}if(c>>>0>1){break f}if(!Ob(x[b>>2],x[b+8>>2],c)){break f}q=d,r=Ad(b,c),v[q+63|0]=r;break g}if(c>>>0>1){break f}if(!Ob(x[b>>2],x[b+8>>2],c)){break f}q=d- -64|0,r=Ad(b,c),v[q|0]=r;break g}if(c>>>0>1){break f}if(!Ob(x[b>>2],x[b+8>>2],c)){break f}q=d,r=Ad(b,c),v[q+81|0]=r;break g}if(c>>>0>1){break f}if(!Ob(x[b>>2],x[b+8>>2],c)){break f}q=d,r=Ad(b,c),v[q+82|0]=r;break g}if(c>>>0>1){break f}if(!Ob(x[b>>2],x[b+8>>2],c)){break f}q=d,r=Ad(b,c),v[q+83|0]=r;break g}if(c>>>0>1){break f}if(!Ob(x[b>>2],x[b+8>>2],c)){break f}q=d,r=Ad(b,c),v[q+84|0]=r;break g}if(c>>>0>1){break f}if(!Ob(x[b>>2],x[b+8>>2],c)){break f}q=d,r=Ad(b,c),v[q+101|0]=r;break g}if(c>>>0>1){break f}if(!Ob(x[b>>2],x[b+8>>2],c)){break f}q=d,r=Ad(b,c),v[q+102|0]=r;break g;case 0:if(c>>>0>1){break f}if(!Ob(x[b>>2],x[b+8>>2],c)){break f}q=d,r=Ad(b,c),v[q+103|0]=r;break g;case 3:break _;case 1:case 2:break f}}if(c>>>0>1){break f}if(!Ob(x[b>>2],x[b+8>>2],c)){break f}q=d,r=Ad(b,c),v[q+104|0]=r;break g}if(c>>>0>1){break f}if(!Ob(x[b>>2],x[b+8>>2],c)){break f}q=d,r=Ad(b,c),v[q+16|0]=r;break g}if(c>>>0>1){break f}if(!Ob(x[b>>2],x[b+8>>2],c)){break f}q=d,r=Ad(b,c),v[q+17|0]=r;break g}if(c>>>0>1){break f}if(!Ob(x[b>>2],x[b+8>>2],c)){break f}q=d,r=Ad(b,c),v[q+18|0]=r;break g}if(c>>>0>1){break f}if(!Ob(x[b>>2],x[b+8>>2],c)){break f}q=d,r=Ad(b,c),v[q+19|0]=r;break g}if(c>>>0>1){break f}if(!Ob(x[b>>2],x[b+8>>2],c)){break f}q=d,r=Ad(b,c),v[q+20|0]=r;break g}if(c>>>0>1){break f}if(!Ob(x[b>>2],x[b+8>>2],c)){break f}q=d,r=Ad(b,c),v[q+21|0]=r;break g}if(c>>>0>1){break f}if(!Ob(x[b>>2],x[b+8>>2],c)){break f}q=d,r=Ad(b,c),v[q+22|0]=r;break g}if(c>>>0>2){break f}if(!Ob(x[b>>2],x[b+8>>2],c)){break f}q=d,r=yD(b,c),w[q+28>>1]=r;break g}if(c>>>0>1){break f}if(!Ob(x[b>>2],x[b+8>>2],c)){break f}q=d,r=Ad(b,c),v[q+30|0]=r;break g}if(c>>>0>1){break f}if(!Ob(x[b>>2],x[b+8>>2],c)){break f}q=d,r=Ad(b,c),v[q+31|0]=r;break g}if(c>>>0>1){break f}if(!Ob(x[b>>2],x[b+8>>2],c)){break f}q=d,r=xD(b,c),v[q+26|0]=r;break g}if(c>>>0>1){break f}if(!Ob(x[b>>2],x[b+8>>2],c)){break f}q=d,r=Ad(b,c),v[q+27|0]=r;break g}ae(e,b,c);i=hc(e+24|0,e);yb(e);j=Mh(d,0);h=x[j>>2];while(1){if($d(h,x[j+4>>2])>>>0<=g>>>0){yb(i);break g}x[27524]=0;k=T(201,i|0)|0;h=x[27524];x[27524]=0;if((h|0)==1){break j}h=x[j>>2];q=Bb(h,g),r=k,w[q>>1]=r;g=g+1|0;continue}}ae(e,b,c);i=hc(e+24|0,e);yb(e);j=Mh(d,1);h=x[j>>2];while(1){if($d(h,x[j+4>>2])>>>0<=g>>>0){yb(i);break g}x[27524]=0;k=T(201,i|0)|0;h=x[27524];x[27524]=0;if((h|0)!=1){h=x[j>>2];q=Bb(h,g),r=k,w[q>>1]=r;g=g+1|0;continue}break}g=P()|0;break i}ae(e,b,c);i=hc(e+24|0,e);yb(e);j=Mh(d,2);h=x[j>>2];while(1){if($d(h,x[j+4>>2])>>>0<=g>>>0){yb(i);break g}x[27524]=0;k=T(201,i|0)|0;h=x[27524];x[27524]=0;if((h|0)!=1){h=x[j>>2];q=Bb(h,g),r=k,w[q>>1]=r;g=g+1|0;continue}break}g=P()|0;break i}ae(e,b,c);i=hc(e+24|0,e);yb(e);j=Mh(d,0);h=x[j>>2];while(1){if($d(h,x[j+4>>2])>>>0<=g>>>0){yb(i);break g}x[27524]=0;k=T(202,i|0)|0;h=x[27524];x[27524]=0;if((h|0)!=1){h=x[j>>2];q=Bb(h,g),r=k,v[q+2|0]=r;g=g+1|0;continue}break}g=P()|0;break i}ae(e,b,c);i=hc(e+24|0,e);yb(e);j=Mh(d,1);h=x[j>>2];while(1){if($d(h,x[j+4>>2])>>>0<=g>>>0){yb(i);break g}x[27524]=0;k=T(202,i|0)|0;h=x[27524];x[27524]=0;if((h|0)!=1){h=x[j>>2];q=Bb(h,g),r=k,v[q+2|0]=r;g=g+1|0;continue}break}g=P()|0;break i}ae(e,b,c);i=hc(e+24|0,e);yb(e);j=Mh(d,2);h=x[j>>2];while(1){if($d(h,x[j+4>>2])>>>0<=g>>>0){yb(i);break g}x[27524]=0;k=T(202,i|0)|0;h=x[27524];x[27524]=0;if((h|0)!=1){h=x[j>>2];q=Bb(h,g),r=k,v[q+2|0]=r;g=g+1|0;continue}break}g=P()|0;break i}if(c>>>0>128){break f}h=d+108|0;ae(e,b,c);i=hc(e+24|0,e);yb(e);while(1){if((g|0)==128){yb(i);break g}x[27524]=0;j=T(202,i|0)|0;k=x[27524];x[27524]=0;if((k|0)!=1){q=Jb(h,g),r=j,v[q|0]=r;g=g+1|0;continue}break}g=P()|0;break i}if(c>>>0>256){break f}h=d+236|0;ae(e,b,c);i=hc(e+24|0,e);yb(e);while(1){if((g|0)==128){yb(i);break g}x[27524]=0;j=T(201,i|0)|0;k=x[27524];x[27524]=0;if((k|0)!=1){q=bc(h,g),r=j,w[q>>1]=r;g=g+1|0;continue}break}g=P()|0;break i}if(c>>>0>32){break f}j=d+492|0;ae(e,b,c);i=hc(e+24|0,e);yb(e);h=Kb(e);while(1){if((c|0)==(g|0)){break h}x[27524]=0;k=T(203,i|0)|0;m=x[27524];x[27524]=0;ka:{if((m|0)==1){break ka}x[27524]=0;Q(204,h|0,k|0)|0;k=x[27524];x[27524]=0;if((k|0)==1){break ka}g=g+1|0;continue}break}g=P()|0;wb(h);break i}if(c>>>0>32){break f}j=d+524|0;ae(e,b,c);i=hc(e+24|0,e);yb(e);h=Kb(e);la:{while(1){if((c|0)!=(g|0)){x[27524]=0;k=T(203,i|0)|0;m=x[27524];x[27524]=0;if((m|0)==1){break la}x[27524]=0;Q(204,h|0,k|0)|0;k=x[27524];x[27524]=0;if((k|0)==1){break la}g=g+1|0;continue}break}Cc(j,h);wb(h);yb(i);break g}g=P()|0;wb(h);break i}if(c>>>0>1){break f}if(!Ob(x[b>>2],x[b+8>>2],c)){break f}q=d,r=Ad(b,c),v[q+34|0]=r;break g}if(c>>>0>2){break f}if(!Ob(x[b>>2],x[b+8>>2],c)){break f}q=d,r=yD(b,c),w[q+12>>1]=r;break g}if(c>>>0>1){break f}if(!Ob(x[b>>2],x[b+8>>2],c)){break f}q=d,r=Ad(b,c),v[q+23|0]=r;break g}if(c>>>0>1){break f}if(!Ob(x[b>>2],x[b+8>>2],c)){break f}q=d,r=Ad(b,c),v[q+24|0]=r;break g}if(c>>>0>1){break f}if(!Ob(x[b>>2],x[b+8>>2],c)){break f}q=d,r=Ad(b,c),v[q+25|0]=r;break g}if(c>>>0>1){break f}if(!Ob(x[b>>2],x[b+8>>2],c)){break f}q=d,r=Ad(b,c),v[q+35|0]=r;break g}if(c>>>0>1){break f}if(!Ob(x[b>>2],x[b+8>>2],c)){break f}q=d,r=Ad(b,c),v[q+36|0]=r;break g}if(c>>>0>1){break f}if(!Ob(x[b>>2],x[b+8>>2],c)){break f}q=d,r=Ad(b,c),v[q+105|0]=r;break g}if(c>>>0>1){break f}if(!Ob(x[b>>2],x[b+8>>2],c)){break f}q=d,r=Ad(b,c),v[q+85|0]=r;break g}if(c>>>0>1){break f}if(!Ob(x[b>>2],x[b+8>>2],c)){break f}q=d,r=Ad(b,c),v[q+65|0]=r;break g}if(c>>>0>1){break f}if(!Ob(x[b>>2],x[b+8>>2],c)){break f}q=d,r=Ad(b,c),v[q+100|0]=r;break g}if(c>>>0>1){break f}if(!Ob(x[b>>2],x[b+8>>2],c)){break f}q=d,r=Ad(b,c),v[q+80|0]=r;break g}if(c>>>0>1){break f}if(!Ob(x[b>>2],x[b+8>>2],c)){break f}q=d,r=Ad(b,c),v[q+60|0]=r;break g}if(c>>>0>1){break f}if(!Ob(x[b>>2],x[b+8>>2],c)){break f}q=d,r=xD(b,c),v[q+33|0]=r;break g}g=1;i=Po(b,c);if(!Oo(i)){break f}v[d+14|0]=i;break f}q=d,r=D(Dv(b,c),1e4)+(A[d+40>>2]%1e4|0)|0,x[q+40>>2]=r;break g}h=(Dv(b,c)>>>0)%1e4|0;g=x[d+40>>2];x[d+40>>2]=h+g-(g>>>0)%1e4;break g}x[e+24>>2]=240;q=e,r=Po(b,c),x[q>>2]=r;Zg(d+48|0,x[Hb(e+24|0,e)>>2]);break g}x[e+24>>2]=240;q=e,r=Po(b,c),x[q>>2]=r;Zg(d+68|0,x[Hb(e+24|0,e)>>2]);break g}x[e+24>>2]=240;q=e,r=Po(b,c),x[q>>2]=r;Zg(d+88|0,x[Hb(e+24|0,e)>>2]);break g}g=P()|0}yb(i);S(g|0);p()}Cc(j,h);wb(h);yb(i)}g=1}ib=e+48|0;if(!g){Yb(b,c);break e}if((Vm(16737)|0)==(f|0)){e=y[d+15|0];v[d+15|0]=0;v[d+100|0]=y[d+100|0]&224|(e>>>5&4|e>>>6&1);v[d+60|0]=e>>>1&2|(e<<1&4|(y[d+60|0]&240|e&1));v[d+80|0]=y[d+80|0]&240|(e>>>4&2|(e>>>2&4|e>>>3&1))}}}l=l+1|0;continue}}}return n|0}function oY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;e=ib-304|0;ib=e;yc(b);if(dr(b,17804)){o=Kb(e+288|0);x[27524]=0;f=Q(234,b|0,o|0)|0;g=x[27524];x[27524]=0;a:{b:{c:{d:{e:{f:{if((g|0)!=1){if(!f){break a}x[27524]=0;f=Q(249,b|0,e+280|0)|0;g=x[27524];x[27524]=0;g:{if((g|0)==1){break g}if(!f){break a}if(!EC(y[e+280|0],y[e+281|0])){break a}f=Ec(DC(e+280|0),kb);g=x[b+8>>2];m=x[b>>2];x[27524]=0;f=W(160,m|0,g|0,f|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break g}if(!f){break a}if(!c){break b}x[27524]=0;R(250,a|0,4096);d=x[27524];x[27524]=0;if((d|0)==1){break g}x[27524]=0;R(251,a+1298308|0,o|0);d=x[27524];x[27524]=0;if((d|0)==1){break g}d=y[e+282|0];w[a+480188>>1]=32;w[a+480192>>1]=d;uh(a,1);x[27524]=0;d=Q(1,e+264|0,9424)|0;f=x[27524];x[27524]=0;h:{i:{j:{k:{l:{m:{n:{o:{p:{if((f|0)!=1){Gb(a+1298344|0,d);xb(d);x[27524]=0;d=Q(1,e+248|0,7053)|0;f=x[27524];x[27524]=0;if((f|0)==1){break p}Gb(a+1298356|0,d);xb(d);x[27524]=0;Y(252,e+48|0);d=x[27524];x[27524]=0;if((d|0)==1){break o}v[e+216|0]=y[e+281|0];x[27524]=0;v[e+8|0]=y[e+280|0];R(253,e+232|0,e+8|0);d=x[27524];x[27524]=0;if((d|0)==1){break n}x[27524]=0;X(254,e+96|0,e+48|0,e+216|0,e+232|0);d=x[27524];x[27524]=0;if((d|0)==1){break m}d=e+96|0;Gb(a+1298368|0,d);xb(d);xb(e+232|0);$b(e+48|0);x[a+1298404>>2]=4;if(y[e+280|0]<2){break i}w[e+96>>1]=8192;x[27524]=0;d=T(198,b|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break k}w[e+48>>1]=d;s=a,t=D(z[pe(e+96|0,e+48|0)>>1],1e4)>>>8|0,x[s+480204>>2]=t;x[27524]=0;v[e+96|0]=1;d=T(210,b|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break j}v[e+48|0]=d;s=a,t=y[mf(e+96|0,e+48|0)|0],x[s+480196>>2]=t;x[27524]=0;Q(192,b|0,3)|0;d=x[27524];x[27524]=0;if((d|0)!=1){x[27524]=0;d=T(198,b|0)|0;f=x[27524];x[27524]=0;if((f|0)!=1){break h}}b=P()|0;break c}b=P()|0;break c}b=P()|0;break c}b=P()|0;break c}b=P()|0;break l}b=P()|0;xb(e+232|0)}$b(e+48|0);break c}b=P()|0;break c}b=P()|0;break c}v[e+96|0]=32;x[27524]=0;d=T(210,b|0)|0;f=x[27524];x[27524]=0;q:{if((f|0)!=1){v[e+48|0]=d;s=a,t=D(y[mf(e+96|0,e+48|0)|0],1e4),x[s+480204>>2]=t;x[27524]=0;v[e+96|0]=1;d=T(210,b|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break q}v[e+48|0]=d;s=a,t=y[mf(e+96|0,e+48|0)|0],x[s+480196>>2]=t;x[27524]=0;d=T(210,b|0)|0;f=x[27524];x[27524]=0;if((f|0)!=1){break h}b=P()|0;break c}b=P()|0;break c}b=P()|0;break c}x[a+480208>>2]=d>>>2&16|12;m=Nb(e+232|0);q=e+96|12;n=Nb(e+216|0);h=a+480190|0;i=1;while(1){r:{s:{d=i&65535;if(d>>>0>z[a+480192>>1]){break s}x[27524]=0;f=W(255,a|0,d|0,0)|0;d=x[27524];x[27524]=0;t:{if((d|0)==1){break t}if(!f){break s}x[27524]=0;d=Q(244,b|0,f+492|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break t}if(!d){break s}x[27524]=0;k=T(210,b|0)|0;d=x[27524];x[27524]=0;u:{v:{w:{if((d|0)!=1){Rb(e+96|0,0,120);if(!k){break r}x:{if(y[e+280|0]){x[27524]=0;d=Q(256,b|0,e+96|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break w}if(!d){break r}if(y[e+280|0]){break x}}d=dc(e+88|0,q,96);g=x[d+4>>2];d=x[d>>2];x[27524]=0;tn(169,e+48|0,b,d,g);d=x[27524];x[27524]=0;if((d|0)==1){break v}if(!x[e+52>>2]){break r}}g=f+236|0;d=0;break u}b=P()|0;break d}b=P()|0;break d}b=P()|0;break d}while(1){if((d|0)!=120){s=bc(g,d),t=(y[(e+96|0)+d|0]+z[h>>1]|0)+1|0,w[s>>1]=t;d=d+1|0;continue}break}x[27524]=0;d=f+48|0;U(257,e+8|0,d|0,b|0);g=x[27524];x[27524]=0;if((g|0)==1){break e}x[27524]=0;g=f+68|0;U(257,e+32|0,g|0,b|0);j=x[27524];x[27524]=0;if((j|0)==1){break e}x[27524]=0;j=f+88|0;U(257,e+80|0,j|0,b|0);l=x[27524];x[27524]=0;if((l|0)==1){break e}x[27524]=0;R(258,b|0,e+72|0);l=x[27524];x[27524]=0;if((l|0)==1){break f}x[f>>2]=(y[e+73|0]|y[e+74|0]<<8)&4095;l=y[e+73|0]|y[e+74|0]<<8;gv(y[e+75|0]|y[e+76|0]<<8,d,0);gv(y[e+75|0]|y[e+76|0]<<8,g,1);gv(y[e+75|0]|y[e+76|0]<<8,j,2);s=e,t=Cb(x[d>>2]),x[s+48>>2]=t;l=l>>>12&3;r=Cb(x[f+52>>2]);while(1){d=x[e+48>>2];if(Mb(d,r)){v[e+44|0]=64;v[e+70|0]=((y[d+2|0]<<6)- -64>>>0)/127;s=d,t=y[Ub(e+44|0,e+70|0)|0],v[s+2|0]=t;Pe(e+48|0);continue}else{s=e,t=Cb(x[g>>2]),x[s+48>>2]=t;d=Cb(x[f+72>>2])}break}while(1){g=x[e+48>>2];if(Mb(g,d)){v[e+44|0]=64;v[e+70|0]=((y[g+2|0]<<6)+128>>>0)/255;s=g,t=y[Ub(e+44|0,e+70|0)|0],v[s+2|0]=t;Pe(e+48|0);continue}break}s=e,t=Cb(x[j>>2]),x[s+48>>2]=t;j=1<<l;l=Cb(x[f+92>>2]);while(1){d=x[e+48>>2];if(Mb(d,l)){g=d;d=v[d+2|0];d=qoa(d^-128,d>>31^-1,j,0);f=kb;y:{if((f|0)>=-1&d>>>0>=4294967292|(f|0)>=0){d=d+4|0;f=d>>>0<4?f+1|0:f;d=((f&7)<<29|d>>>3)&536870911;f=0;break y}f=0-((d>>>0>3)+f|0)|0;d=3-d|0;f=((f&7)<<29|d>>>3)&536870911;d=0-f|0;f=0-((f|0)!=0)|0}s=g,t=Dc(d,f)^128,v[s+2|0]=t;Pe(e+48|0);continue}else{f=z[h>>1]+1|0;w[e+70>>1]=f;d=0;f=f&65535;g=4e3-f|0;g=g>>>0<=4e3?g:0;z:{A:{B:{while(1){if((d|0)==(k|0)){break A}if((d|0)==(g|0)){x[27524]=0;Q(192,b|0,20)|0;d=x[27524];x[27524]=0;if((d|0)!=1){break A}b=P()|0;break d}x[27524]=0;j=d+f|0;Q(244,b|0,((j<<5)+a|0)+946304|0)|0;l=x[27524];x[27524]=0;if((l|0)==1){break z}x[27524]=0;R(259,b|0,e+48|0);l=x[27524];x[27524]=0;C:{if((l|0)==1){break C}x[27524]=0;R(260,e+48|0,(D(j,104)+a|0)+484380|0);j=x[27524];x[27524]=0;if((j|0)==1){break C}x[27524]=0;w[e+44>>1]=y[e+72|0]|d<<8&32512|((y[e+67|0]&3)!=0)<<15;R(261,n|0,e+44|0);j=x[27524];x[27524]=0;if((j|0)==1){break B}d=d+1|0;continue}break}b=P()|0;break d}b=P()|0;break d}x[27524]=0;R(261,m|0,e+70|0);d=x[27524];x[27524]=0;if((d|0)!=1){x[e+48>>2]=3999;x[e+44>>2]=k+z[h>>1];s=h,t=x[rd(e+48|0,e+44|0)>>2],w[s>>1]=t;break r}b=P()|0;break d}b=P()|0;break d}}}b=P()|0;break d}d=Kb(e+96|0);x[27524]=0;f=Q(234,b|0,d|0)|0;g=x[27524];x[27524]=0;D:{E:{F:{G:{H:{if((g|0)!=1){I:{if(f){x[27524]=0;U(11,e+48|0,21,d|0);f=x[27524];x[27524]=0;if((f|0)==1){break I}f=e+48|0;Gb(a+1298320|0,f);xb(f)}wb(d);d=0;J:{while(1){if((d|0)==32){x[27524]=0;d=Q(262,b|0,e+32|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break G}if(!d){break F}d=x[e+32>>2];if(d>>>0<12){break H}f=x[b+8>>2];g=x[b>>2];x[27524]=0;d=W(160,g|0,f|0,d-11|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break G}if(d){break J}break H}f=(d<<5)+a|0;lf(f+480280|0);x[27524]=0;R(235,b|0,f+480289|0);f=x[27524];x[27524]=0;if((f|0)!=1){d=d+1|0;continue}break}b=P()|0;break d}d=x[e+32>>2]-11|0;x[e+80>>2]=d;h=Nb(e+96|0);x[27524]=0;U(238,b|0,h|0,d|0);d=x[27524];x[27524]=0;K:{if((d|0)!=1){x[e+48>>2]=50529027;d=e+48|0;s=e,t=D(x[Hb(e+80|0,d)>>2],85),x[s+72>>2]=t;g=Kb(d);x[e+8>>2]=x[e+36>>2];d=x[Hb(e+72|0,e+8|0)>>2];x[27524]=0;R(46,g|0,d|0);d=x[27524];x[27524]=0;L:{if((d|0)==1){break L}d=0;M:{while(1){f=x[e+80>>2];if(f>>>0<=d>>>0){break M}i=x[h>>2];k=y[Jb(i,d)|0];j=f;f=d+1|0;if(!((k|0)!=255|j-f>>>0<2)){f=v[Jb(i,f)|0];i=y[Jb(i,d+2|0)|0];s=e,t=Eh(g),x[s+8>>2]=t;k=x[pj(e+24|0,e+8|0)>>2];x[27524]=0;X(241,g|0,k|0,i|0,f|0);f=x[27524];x[27524]=0;if((f|0)!=1){d=d+3|0;continue}break L}x[27524]=0;R(47,g|0,k<<24>>24);i=x[27524];x[27524]=0;d=f;if((i|0)!=1){continue}break}break L}x[27524]=0;X(239,e+8|0,4,21,g|0);d=x[27524];x[27524]=0;if((d|0)!=1){N:{f=e+8|0;d=Ac(g,f);wb(f);f=Jc(d);i=Eb(d);x[27524]=0;ea(240,a+1298332|0,f|0,i|0,74,0);f=x[27524];x[27524]=0;if((f|0)==1){break N}wb(d);ec(h);break H}}}b=P()|0;wb(g);break K}b=P()|0}ec(h);break d}}b=P()|0;wb(d);break d}d=y[a+484376|0];f=x[a+484360>>2];x[27524]=0;U(242,Tb(f,d)|0,b|0,y[e+285|0]|y[e+286|0]<<8);d=x[27524];x[27524]=0;if((d|0)==1){break G}i=c&1;if(i){x[27524]=0;R(229,a+484344|0,y[e+283|0]|y[e+284|0]<<8);d=x[27524];x[27524]=0;if((d|0)==1){break G}}h=a+484344|0;f=b;d=0;while(1){O:{if((y[e+283|0]|y[e+284|0]<<8)>>>0>d>>>0){b=x[f+8>>2];g=x[f>>2];x[27524]=0;b=W(160,g|0,b|0,4)|0;g=x[27524];x[27524]=0;if((g|0)==1){break D}if(b){break O}}if(!(c&2)){break F}d=0;c=a+480190|0;while(1){b=z[c>>1];if(d>>>0>=b>>>0){d=0;f=a+480190|0;while(1){if(b>>>0<=d>>>0){break F}c=z[bc(x[n>>2],d)>>1];g=c&255;P:{if(!g){break P}h=x[m>>2];g=g-1&65535;if(Oc(h,x[m+4>>2])>>>0<=g>>>0){break P}j=b;b=z[bc(h,g)>>1]+(c>>>8&127)&65535;if(j>>>0<b>>>0){break P}b=D(b,104);g=b+a|0;c=g+484380|0;h=x[c>>2];if(!_d(h,x[g+484400>>2])){break P}g=b;b=a+484380|0;g=g+b|0;i=z[g+34>>1];b=b+D(d+1|0,104)|0;x[b>>2]=h;w[b+34>>1]=z[b+34>>1]&65534|i&1;if(!Xg(b)){break P}rc(x[b+20>>2],x[g+20>>2],Nj(x[c>>2],z[c+34>>1]))}d=d+1|0;b=z[f>>1];continue}}b=z[bc(x[n>>2],d)>>1];if(b&255){d=d+1|0;continue}d=d+1|0;g=D(d,104)+a|0;b=Zc(e+96|0,w[g+484414>>1]&1?16:8,1,0,b<<16>>16<0?6:0);x[27524]=0;W(223,b|0,g+484380|0,f|0)|0;b=x[27524];x[27524]=0;if((b|0)!=1){continue}break}b=P()|0;break d}x[27524]=0;b=T(161,f|0)|0;g=x[27524];x[27524]=0;Q:{R:{S:{T:{if((g|0)!=1){x[27524]=0;U(194,e+48|0,f|0,b|0);b=x[27524];x[27524]=0;if((b|0)==1){break T}b=e+48|0;g=hc(e+96|0,b);yb(b);if(!i){break R}x[27524]=0;b=T(210,g|0)|0;k=x[27524];x[27524]=0;if((k|0)==1){break Q}x[27524]=0;Q(192,g|0,1)|0;k=x[27524];x[27524]=0;if((k|0)==1){break Q}x[27524]=0;b=W(230,h|0,d&65535,b+1|0)|0;k=x[27524];x[27524]=0;if((k|0)==1){break Q}if(!b){break R}x[27524]=0;b=Q(236,g|0,e+48|0)|0;k=x[27524];x[27524]=0;if((k|0)==1){break E}if(!b){break S}b=x[h>>2];x[27524]=0;R(237,Xb(b,d)|0,e+48|0);b=x[27524];x[27524]=0;if((b|0)!=1){break S}break E}b=P()|0;break d}b=P()|0;break d}b=x[h>>2];x[27524]=0;U(243,Xb(b,d)|0,1,g|0);b=x[27524];x[27524]=0;if((b|0)==1){break E}}yb(g);d=d+1|0;continue}break}break E}b=P()|0;break d}jd(n);jd(m);break b}b=P()|0;yb(g);break d}b=P()|0;break d}i=i+1|0;continue}}b=P()|0;break c}b=P()|0;break c}b=P()|0;break d}b=P()|0}jd(n);jd(m)}wb(o);S(b|0);p()}d=1}wb(o)}ib=e+304|0;return d|0}function vna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0;e=ib-400|0;ib=e;yc(b);g=e+376|0;f=HC(b,g);if(!f){kv(g)}a:{b:{c:{d:{e:{if(!f){break e}if(!_W(e+376|0)){break e}if(!Ob(x[b>>2],x[b+8>>2],Ec(72,0))){break e}if(!c){d=1;break e}zd(a,1);x[a+480208>>2]=x[a+480208>>2]&-25231361|16842752;g=y[e+385|0];w[a+480190>>1]=63;w[a+480188>>1]=g;f:{g:{while(1){if((g&65535)>>>0<=d>>>0){h:{Rb(e+304|0,0,64);d=1;i:{while(1){j:{g=d&65535;if(g>>>0>z[a+480190>>1]){MC(b,a+1298308|0);g=e+296|0;d=ib-16|0;ib=d;k:{if(!Ob(x[b>>2],x[b+8>>2],8)){v[d|0]=0;hi(g,8,d);break k}dn(d+8|0,g);sd(d,b,x[d+8>>2],x[d+12>>2])}ib=d+16|0;n=Nb(e+280|0);g=z[e+386>>1];if(!g){break i}d=0;x[27524]=0;g=W(325,b|0,n|0,D(g,y[e+385|0])<<1)|0;f=x[27524];x[27524]=0;if((f|0)!=1){break j}g=P()|0;break a}f=(D(g,104)+a|0)+484380|0;md(f,1);i=g+(e+304|0)|0;g=Re(b);v[i|0]=g;if(g<<24>>24>=0){C=f,E=YW(b)<<1,x[C>>2]=E}d=d+1|0;continue}break}if(!g){break f}}d=x[n>>2];cc(e+272|0,d,cd(d,x[n+4>>2])>>>1|0);m=Nb(e+256|0);x[27524]=0;R(326,m|0,z[e+388>>1]<<8);d=x[27524];x[27524]=0;if((d|0)==1){break h}d=0;l:{m:{n:{while(1){g=d&65535;d=z[e+388>>1];if(g>>>0>=d>>>0){break m}x[e+208>>2]=d-g;x[e+152>>2]=2e3;d=e+208|0;f=x[rd(d,e+152|0)>>2];d=Nb(d);x[27524]=0;f=W(325,b|0,d|0,f<<8)|0;h=x[27524];x[27524]=0;if((h|0)==1){break l}if(!f){break n}f=Wb(e+248|0,Cb(x[m+4>>2]));h=Cb(x[d>>2]);j=Cb(x[e+212>>2]);f=x[f>>2];x[27524]=0;X(327,m|0,f|0,h|0,j|0);f=x[27524];x[27524]=0;if((f|0)!=1){ec(d);d=g+2e3|0;continue}break}break c}ec(d);d=0;break g}he(e+232|0,x[m>>2],x[m+4>>2]);lg(e+240|0,x[e+232>>2],x[e+236>>2]);q=a+484376|0;d=y[q|0];g=x[a+484360>>2];x[27524]=0;R(328,Tb(g,d)|0,z[e+386>>1]);d=x[27524];x[27524]=0;if((d|0)==1){break d}r=a+484344|0;t=c&1;j=0;while(1){if(z[e+386>>1]<=j>>>0){h=c&2;g=1;o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{while(1){c=g&65535;if(c>>>0>z[a+480190>>1]){break v}x[27524]=0;d=y[c+(e+304|0)|0];U(329,b|0,((c<<5)+a|0)+946304|0,d&63);f=x[27524];x[27524]=0;if((f|0)==1){break t}A:{B:{if(d<<24>>24<0){break B}x[27524]=0;d=T(330,b|0)|0;f=x[27524];x[27524]=0;C:{D:{E:{F:{G:{H:{I:{J:{if((f|0)==1){break J}c=D(c,104)+a|0;f=c+484392|0;x[f>>2]=d<<1;x[27524]=0;d=T(330,b|0)|0;j=x[27524];x[27524]=0;if((j|0)==1){break I}if(d>>>0>=2){x[c+484396>>2]=x[f>>2]+(d<<1);d=c+484414|0;w[d>>1]=z[d>>1]|8}x[27524]=0;d=T(210,b|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break s}v[e+72|0]=d;v[e+176|0]=64;C=c+484410|0,E=y[Ub(e+72|0,e+176|0)|0]<<2,w[C>>1]=E;x[27524]=0;d=T(210,b|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break J}v[c+484417|0]=d<<4;c=c+484380|0;xo(c);if(!x[c>>2]){break B}x[27524]=0;f=T(210,b|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break D}d=0;switch(f|0){case 4:case 5:break C;case 2:case 3:break F;case 1:break G;case 0:break H;default:break g}}g=P()|0;break b}g=P()|0;break b}if(h){f=Nb(e+72|0);j=x[b+8>>2];i=x[b>>2];k=x[c>>2];x[27524]=0;j=W(160,i|0,j|0,k|0)|0;i=x[27524];x[27524]=0;if((i|0)==1){break r}if(!j){break w}d=x[c>>2];x[27524]=0;U(331,b|0,f|0,d|0);d=x[27524];x[27524]=0;if((d|0)==1){break r}C=e,E=Cb(x[f>>2]),x[C+176>>2]=E;j=Cb(x[e+76>>2]);while(1){d=x[e+176>>2];if(Mb(d,j)){i=d;d=y[d|0];v[i|0]=d<<7|(d^-1)>>>1&127;Ie(e+176|0);continue}break}he(e+200|0,x[f>>2],x[e+76>>2]);d=Id(e+192|0);x[27524]=0;j=x[d+4>>2];x[e+16>>2]=x[d>>2];x[e+20>>2]=j;d=Mg(332,e+208|0,x[e+200>>2],x[e+204>>2],e+16|0);j=x[27524];x[27524]=0;K:{if((j|0)!=1){j=Zc(e+176|0,16,1,0,16);x[27524]=0;W(223,j|0,c|0,d|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break K}yb(d);ec(f);break B}g=P()|0;break o}g=P()|0;yb(d);break o}c=x[c>>2];break E}f=Nb(e+72|0);d=x[c>>2];x[27524]=0;U(333,e+176|0,b|0,d|0);d=x[27524];x[27524]=0;L:{M:{N:{if((d|0)!=1){d=e+176|0;j=Om(f,d);ec(d);if(h){he(e+144|0,x[j>>2],x[e+76>>2]);d=Id(e+136|0);x[27524]=0;i=x[d+4>>2];x[e+24>>2]=x[d>>2];x[e+28>>2]=i;d=Mg(332,e+152|0,x[e+144>>2],x[e+148>>2],e+24|0);i=x[27524];x[27524]=0;if((i|0)==1){break N}i=Zc(e+176|0,8,1,0,2);x[27524]=0;W(223,i|0,c|0,d|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break M}yb(d)}ec(j);break B}g=V(30496)|0;if((jb|0)!=(da(30496)|0)){break L}_(g|0)|0;d=0;x[27524]=0;Z(18);a=x[27524];x[27524]=0;if((a|0)!=1){break u}g=P()|0;break L}g=P()|0;break L}g=P()|0;yb(d)}ec(f);break b}if(h){d=Zc(e+72|0,(f|0)==2?8:16,1,0,0);x[27524]=0;W(223,d|0,c|0,b|0)|0;c=x[27524];x[27524]=0;if((c|0)!=1){break B}g=P()|0;break b}c=D(x[c>>2],f-1|0)}x[27524]=0;Q(192,b|0,c|0)|0;c=x[27524];x[27524]=0;if((c|0)!=1){break B}}g=P()|0;break b}j=Nb(e+72|0);d=x[c>>2];x[27524]=0;U(334,e+176|0,b|0,d|0);d=x[27524];x[27524]=0;O:{P:{if((d|0)!=1){i=e+176|0;d=Om(j,i);ec(i);if(!h){break O}if((f|0)!=5){break P}C=e,E=Cb(x[d>>2]),x[C+176>>2]=E;k=Cb(x[e+76>>2]);while(1){i=x[e+176>>2];if(!Mb(i,k)){break P}l=i;i=y[i|0];v[l|0]=y[(i>>>7|0)+26369|0]^i;Ie(e+176|0);continue}}g=V(30496)|0;if((jb|0)!=(da(30496)|0)){break x}_(g|0)|0;d=0;x[27524]=0;Z(18);a=x[27524];x[27524]=0;if((a|0)!=1){break A}g=P()|0;break x}he(e+104|0,x[d>>2],x[e+76>>2]);i=Id(e+96|0);x[27524]=0;k=x[i+4>>2];x[e+32>>2]=x[i>>2];x[e+36>>2]=k;i=Mg(332,e+112|0,x[e+104>>2],x[e+108>>2],e+32|0);k=x[27524];x[27524]=0;if((k|0)==1){break z}f=(f|0)==5;f=Zc(e+176|0,f?16:8,1,0,f?16:1);x[27524]=0;W(223,f|0,c|0,i|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break y}yb(i)}ec(d)}g=g+1|0;continue}break}ec(j);break g}g=P()|0;break x}g=P()|0;yb(i)}ec(j);break b}ec(f);break g}Q:{R:{S:{T:{d=z[e+390>>1]|y[e+392|0]<<16;if(d){c=Nb(e+176|0);x[27524]=0;b=W(325,b|0,c|0,d|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break q}if(!b){break R}he(e- -64|0,x[c>>2],x[c+4>>2]);b=Id(e+56|0);x[27524]=0;g=x[b+4>>2];x[e+8>>2]=x[b>>2];x[e+12>>2]=g;b=Mg(332,e+72|0,x[e+64>>2],x[e+68>>2],e+8|0);g=x[27524];x[27524]=0;if((g|0)==1){break T}x[27524]=0;X(335,a+1298332|0,b|0,d|0,1);d=x[27524];x[27524]=0;if((d|0)==1){break S}yb(b);ec(c)}x[27524]=0;Y(336,e+40|0);b=x[27524];x[27524]=0;if((b|0)!=1){break Q}g=P()|0;break b}g=P()|0;break p}g=P()|0;yb(b);break p}ec(c);d=0;break g}x[27524]=0;U(217,e+176|0,e+40|0,y[e+384|0]);b=x[27524];x[27524]=0;U:{V:{if((b|0)!=1){b=e+176|0;Gb(a+1298344|0,b);xb(b);$b(e+40|0);x[27524]=0;b=Q(1,b|0,10034)|0;c=x[27524];x[27524]=0;if((c|0)==1){break V}Gb(a+1298356|0,b);xb(b);x[27524]=0;b=Q(1,e+40|0,5104)|0;c=x[27524];x[27524]=0;if((c|0)==1){break U}Gb(a+1298368|0,b);xb(b);x[a+1298404>>2]=24;d=1;break g}g=P()|0;$b(e+40|0);break b}g=P()|0;break b}g=P()|0;break b}ec(f);break g}g=P()|0;break b}g=P()|0;break b}g=P()|0;break o}g=P()|0}ec(c);break b}ec(f);break b}C=bc(x[Tb(x[a+484360>>2],y[q|0])>>2],j),E=j,w[C>>1]=E;W:{X:{if(!t){break X}x[27524]=0;s=j&65535;d=W(230,r|0,s|0,64)|0;g=x[27524];x[27524]=0;if((g|0)==1){break W}if(!d){break X}f=z[a+480188>>1];i=0;while(1){d=f&65535;if(d>>>0<=i>>>0){break X}d=bc(x[e+272>>2],D(d,j)+i|0);d=y[d|0]|y[d+1|0]<<8;Y:{if(d>>>0>=z[e+388>>1]){break Y}g=0;u=0-i|0;A=d<<8;d=Xb(x[r>>2],j);d=hd(x[d>>2],x[x[d+48>>2]+12>>2],0,i&65535);while(1){if((g|0)==64){break Y}Nq(e+208|0,x[e+240>>2],x[e+244>>2],(g<<2)+A|0,4);f=x[e+208>>2];h=Jb(f,0);o=y[h|0]&63;v[d|0]=o?o+48|0:0;k=Jb(f,1);v[d+1|0]=y[k|0]<<2&60|y[h|0]>>>6;l=y[k|0];h=Jb(f,2);k=y[Jb(f,3)|0];f=y[h|0];h=k<<4|f>>>4;w[e+72>>1]=h;B=l>>>6|0;l=f<<2&60;f=B|l;Z:{if(!(y[Jb(e+296|0,l>>>3|0)|0]>>>(f&7)&1)|!(f|h)){break Z}v[d+5|0]=h;l=k>>>4|0;v[d+4|0]=l;_:{$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{switch(f|0){case 0:case 1:case 2:case 32:case 33:case 34:Xf(d,f&15,h&255);if(!y[d+4|0]){break Z}v[d+2|0]=f>>>0<32?3:4;break Z;case 9:v[d+3|0]=10;v[d+5|0]=h>>>1;if(h>>>0<512){break Z}v[d+2|0]=15;v[d+4|0]=k>>>5;break Z;case 10:case 42:if(h>>>0>254){break ia}f=f&15;break;case 50:break $;case 48:break aa;case 43:break ba;case 47:break ca;case 17:case 18:case 26:case 27:break da;case 22:case 25:case 28:case 29:case 30:break ea;case 16:case 19:case 20:case 21:case 23:case 31:break fa;case 13:break ga;case 11:case 15:break ha;case 3:case 4:case 5:case 6:case 7:case 12:break ja;default:break _}}Xf(d,f,h&255);break Z}v[d+3|0]=19;v[d+5|0]=l|(f>>>0<32?16:32);if(k&15){v[d+2|0]=3;v[d+4|0]=(h&240)>>>4;break Z}v[d+2|0]=4;v[d+4|0]=h&15;break Z}v[d+3|0]=(f|0)==11?12:16;C=d,E=Uu(h),v[C+5|0]=E;break Z}v[d+3|0]=14;if((h&255)>>>0<64){break Z}v[d+5|0]=0;break Z}v[d+3|0]=19;v[d+5|0]=h&15|f<<4;break Z}v[d+3|0]=19;w[e+152>>1]=15;C=d,E=y[Tc(e+72|0,e+152|0)|0]|f<<4,v[C+5|0]=E;break Z}v[d+3|0]=19;if(h&255){v[d+5|0]=h&15|((f|0)==17?16:(f|0)==26?16:32);if(k>>>0<16){break Z}v[d+2|0]=f>>>0>25?6:5;break Z}v[d+5|0]=l|(f>>>0>25?-80:-96);break Z}if(!h){break _}v[d+3|0]=17;x[e+152>>2]=8;x[e+112>>2]=h+4;C=d,E=Ag(x[Ve(e+152|0,e+112|0)>>2]/8|0),v[C+5|0]=E;break Z}v[d+3|0]=14;k=D(u,6)+d|0;o=z[a+480188>>1];f=0;while(1){if((f|0)==(o|0)){break Z}h=k+D(f,6)|0;if(!y[h+3|0]){v[h+3|0]=12;C=h,E=Uu(s),v[C+5|0]=E}f=f+1|0;continue}}v[d+3|0]=9;f=h&7;if(f){v[d+5|0]=y[f+26361|0];break Z}f=h>>>4|0;if((f|0)==128){break _}v[d+5|0]=f;if(h>>>0<=2047){v[d+5|0]=f^128;break Z}v[d+5|0]=f^-1;break Z}v[d+5|0]=0;v[d+3|0]=0;if(!o){v[d|0]=255;break Z}v[d+3|0]=25;break Z}v[d+3|0]=0}g=g+1|0;f=z[a+480188>>1];d=D(f,6)+d|0;continue}}i=i+1|0;continue}}j=j+1|0;continue}break}g=P()|0;break b}break c}}else{bC(a,d&65535);w[((d<<5)+a|0)+480284>>1]=(d&3)-1>>>0<2?64:192;d=d+1|0;g=z[a+480188>>1];continue}break}g=P()|0;break b}ec(m)}ec(n)}ib=e+400|0;return d|0}g=P()|0;break b}g=P()|0;ec(d)}ec(m)}ec(n);S(g|0);p()}function zH(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,z=0,A=0,F=0,G=0,H=E(0),I=0;e=ib-144|0;ib=e;d=Rb(e,0,144);x[d+76>>2]=-1;x[d+44>>2]=a;x[d+32>>2]=1145;x[d+84>>2]=a;t=c;a=0;h=ib-304|0;ib=h;a:{b:{c:{d:{if(x[d+4>>2]){break d}qx(d);if(x[d+4>>2]){break d}break c}g=y[b|0];if(!g){break a}e:{f:{g:{h:{while(1){i:{c=g&255;j:{if(_k(c)){while(1){g=b;b=b+1|0;if(_k(y[g+1|0])){continue}break}ti(d,0,0);while(1){b=x[d+4>>2];k:{if((b|0)!=x[d+104>>2]){x[d+4>>2]=b+1;b=y[b|0];break k}b=qd(d)}if(_k(b)){continue}break}b=x[d+4>>2];c=x[d+116>>2];if((c|0)>0|(c|0)>=0){b=b-1|0;x[d+4>>2]=b}b=b-x[d+44>>2]|0;c=b>>31;i=b;e=n+x[d+124>>2]|0;b=m+x[d+120>>2]|0;e=b>>>0<m>>>0?e+1|0:e;f=b;b=i+b|0;i=c+e|0;m=b;n=b>>>0<f>>>0?i+1|0:i;break j}l:{m:{n:{if((c|0)==37){c=y[b+1|0];if((c|0)==42){break n}if((c|0)!=37){break m}}ti(d,0,0);o:{if(y[b|0]==37){while(1){c=x[d+4>>2];p:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;g=y[c|0];break p}g=qd(d)}if(_k(g)){continue}break}b=b+1|0;break o}c=x[d+4>>2];if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;g=y[c|0];break o}g=qd(d)}if(y[b|0]!=(g|0)){b=x[d+116>>2];if((b|0)>0|(b|0)>=0){x[d+4>>2]=x[d+4>>2]-1}if((g|0)>=0){break a}f=0;if(u){break a}break c}c=x[d+4>>2]-x[d+44>>2]|0;g=c>>31;f=c;c=n+x[d+124>>2]|0;e=m+x[d+120>>2]|0;c=e>>>0<m>>>0?c+1|0:c;i=e;e=f+e|0;f=c+g|0;m=e;n=e>>>0<i>>>0?f+1|0:f;g=b;break j}l=0;b=b+2|0;break l}if(!(!hk(c)|y[b+2|0]!=36)){e=ib-16|0;x[e+12>>2]=t;c=c-48|0;c=(c>>>0>1?(c<<2)-4|0:0)+t|0;x[e+8>>2]=c+4;l=x[c>>2];b=b+3|0;break l}l=x[t>>2];t=t+4|0;b=b+1|0}c=0;while(1){e=y[b|0];if(hk(e)){b=b+1|0;c=(D(c,10)+e|0)-48|0;continue}break}r=0;if((e|0)==109){o=0;r=(l|0)!=0;e=y[b+1|0];b=b+1|0;a=0}g=b+1|0;k=3;f=r;q:{r:{switch((e&255)-65|0){case 39:e=b+2|0;b=y[b+1|0]==104;g=b?e:g;k=b?-2:-1;break q;case 43:e=b+2|0;b=y[b+1|0]==108;g=b?e:g;k=b?3:1;break q;case 51:case 57:k=1;break q;case 11:k=2;break q;case 41:break q;case 0:case 2:case 4:case 5:case 6:case 18:case 23:case 26:case 32:case 34:case 35:case 36:case 37:case 38:case 40:case 45:case 46:case 47:case 50:case 52:case 55:break r;default:break e}}k=0;g=b}b=y[g|0];e=(b&47)==3;z=e?1:k;p=e?b|32:b;s:{if((p|0)==91){break s}t:{if((p|0)!=110){if((p|0)!=99){break t}c=(c|0)<=1?1:c;break s}AH(l,z,m,n);break j}ti(d,0,0);while(1){b=x[d+4>>2];u:{if((b|0)!=x[d+104>>2]){x[d+4>>2]=b+1;b=y[b|0];break u}b=qd(d)}if(_k(b)){continue}break}b=x[d+4>>2];e=x[d+116>>2];if((e|0)>0|(e|0)>=0){b=b-1|0;x[d+4>>2]=b}b=b-x[d+44>>2]|0;f=b>>31;j=b;e=n+x[d+124>>2]|0;b=m+x[d+120>>2]|0;e=b>>>0<m>>>0?e+1|0:e;i=b;b=j+b|0;n=e+f|0;n=b>>>0<i>>>0?n+1|0:n;m=b}j=c;s=c>>31;ti(d,c,s);b=x[d+4>>2];v:{if((b|0)!=x[d+104>>2]){x[d+4>>2]=b+1;break v}if((qd(d)|0)<0){break f}}b=x[d+116>>2];if((b|0)>0|(b|0)>=0){x[d+4>>2]=x[d+4>>2]-1}b=16;w:{x:{y:{z:{A:{switch(p-88|0){default:b=p-65|0;if(b>>>0>6|!(1<<b&113)){break w}case 9:case 13:case 14:case 15:CH(h+8|0,d,z,0);b=x[d+4>>2]-x[d+44>>2]|0;if(x[d+120>>2]!=(0-b|0)|x[d+124>>2]!=(0-((b>>31)+((b|0)!=0)|0)|0)){break y}break g;case 3:case 11:case 27:if((p|16)==115){Rb(h+32|0,-1,257);v[h+32|0]=0;if((p|0)!=115){break x}v[h+65|0]=0;v[h+46|0]=0;w[h+42>>1]=0;w[h+44>>1]=0;break x}e=y[g+1|0];f=(e|0)==94;Rb(h+32|0,f,257);v[h+32|0]=0;b=f?g+2|0:g+1|0;B:{C:{D:{g=y[(f?2:1)+g|0];if((g|0)!=45){if((g|0)==93){break D}k=(e|0)!=94;break B}k=(e|0)!=94;v[h+78|0]=k;break C}k=(e|0)!=94;v[h+126|0]=k}b=b+1|0}g=b;while(1){e=y[g|0];E:{if((e|0)!=45){if(!e){break f}if((e|0)==93){break x}break E}e=45;f=y[g+1|0];if(!f|(f|0)==93){break E}i=g+1|0;b=y[g-1|0];F:{if(f>>>0<=b>>>0){e=f;break F}while(1){b=b+1|0;v[b+(h+32|0)|0]=k;e=y[i|0];if(e>>>0>b>>>0){continue}break}}g=i}v[(e+h|0)+33|0]=k;g=g+1|0;continue};case 23:b=8;break z;case 12:case 29:b=10;break z;case 1:case 2:case 4:case 5:case 6:case 7:case 8:case 10:case 16:case 18:case 19:case 20:case 21:case 22:case 25:case 26:case 28:case 30:case 31:break w;case 0:case 24:case 32:break z;case 17:break A}}b=0}j=0;i=0;e=0;f=0;s=0;A=ib-16|0;ib=A;G:{if((b|0)==1){x[12e4]=28;break G}while(1){c=x[d+4>>2];H:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break H}c=qd(d)}if(_k(c)){continue}break}I:{J:{switch(c-43|0){case 0:case 2:break J;default:break I}}s=(c|0)==45?-1:0;c=x[d+4>>2];if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break I}c=qd(d)}K:{L:{M:{N:{if(!((b|0)!=0&(b|0)!=16|(c|0)!=48)){c=x[d+4>>2];O:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break O}c=qd(d)}if((c&-33)==88){b=16;c=x[d+4>>2];P:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break P}c=qd(d)}if(y[c+94449|0]<16){break M}b=x[d+116>>2];if((b|0)>0|(b|0)>=0){x[d+4>>2]=x[d+4>>2]-1}ti(d,0,0);break G}if(b){break N}b=8;break M}b=b?b:10;if(b>>>0>y[c+94449|0]){break N}b=x[d+116>>2];if((b|0)>0|(b|0)>=0){x[d+4>>2]=x[d+4>>2]-1}ti(d,0,0);x[12e4]=28;break G}if((b|0)!=10){break M}e=c-48|0;if(e>>>0<=9){b=0;while(1){b=D(b,10)+e|0;f=b>>>0<429496729;c=x[d+4>>2];Q:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break Q}c=qd(d)}e=c-48|0;if(f&e>>>0<=9){continue}break}j=b}R:{if(e>>>0>9){break R}k=qoa(j,0,10,0);f=kb;b=e;while(1){c=x[d+4>>2];S:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break S}c=qd(d)}e=c-48|0;q=e>>>0>9;j=b+k|0;i=j>>>0<b>>>0?f+1|0:f;if((i|0)==429496729&j>>>0>=2576980378|i>>>0>429496729|q){break R}k=qoa(j,i,10,0);f=kb;b=e;if((f|0)==-1&k>>>0<=(b^-1)>>>0|(f|0)!=-1){continue}break}b=10;break L}b=10;if(e>>>0<=9){break L}break K}if(b-1&b){f=y[c+94449|0];if(f>>>0<b>>>0){while(1){e=D(b,e)+f|0;j=e>>>0<119304647;c=x[d+4>>2];T:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break T}c=qd(d)}f=y[c+94449|0];if(j&f>>>0<b>>>0){continue}break}j=e}if(b>>>0<=f>>>0){break L}while(1){k=qoa(j,i,b,0);e=kb;f=f&255;if((e|0)==-1&(f^-1)>>>0<k>>>0){break L}c=f+k|0;e=c>>>0<f>>>0?e+1|0:e;j=c;i=e;c=x[d+4>>2];U:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break U}c=qd(d)}f=y[c+94449|0];if(b>>>0<=f>>>0){break L}Ef(A,b,0,0,0,j,i,0,0);if(!(x[A+8>>2]|x[A+12>>2])){continue}break}break L}k=v[(D(b,23)>>>5&7)+94705|0];e=y[c+94449|0];if(e>>>0<b>>>0){while(1){f=f<<k|e;j=f>>>0<134217728;c=x[d+4>>2];V:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break V}c=qd(d)}e=y[c+94449|0];if(j&e>>>0<b>>>0){continue}break}j=f}if(b>>>0<=e>>>0){break L}f=k;q=f&31;if((f&63)>>>0>=32){f=0;q=-1>>>q|0}else{f=-1>>>q|0;q=f|(1<<q)-1<<32-q}if(!f&j>>>0>q>>>0){break L}while(1){c=k&31;F=e&255;if((k&63)>>>0>=32){e=j<<c;c=0}else{e=(1<<c)-1&j>>>32-c|i<<c;c=j<<c}j=F|c;i=e;c=x[d+4>>2];W:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break W}c=qd(d)}e=y[c+94449|0];if(b>>>0<=e>>>0){break L}if((f|0)==(i|0)&j>>>0<=q>>>0|f>>>0>i>>>0){continue}break}}if(y[c+94449|0]>=b>>>0){break K}while(1){c=x[d+4>>2];X:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break X}c=qd(d)}if(y[c+94449|0]<b>>>0){continue}break}x[12e4]=68;j=-1;i=-1;s=0}b=x[d+116>>2];if((b|0)>0|(b|0)>=0){x[d+4>>2]=x[d+4>>2]-1}b=s;c=b^j;j=c-b|0;e=b>>31;i=(e^i)-((b>>>0>c>>>0)+e|0)|0}ib=A+16|0;b=x[d+4>>2]-x[d+44>>2]|0;if(x[d+120>>2]==(0-b|0)&x[d+124>>2]==(0-((b>>31)+((b|0)!=0)|0)|0)){break g}if(!(!l|(p|0)!=112)){x[l>>2]=j;break w}AH(l,z,j,i);break w}if(!l){break w}b=x[h+16>>2];c=x[h+20>>2];e=x[h+8>>2];f=x[h+12>>2];Y:{switch(z|0){case 0:G=l,H=GE(e,f,b,c),B[G>>2]=H;break w;case 1:G=l,I=mw(e,f,b,c),C[G>>3]=I;break w;case 2:break Y;default:break w}}x[l>>2]=e;x[l+4>>2]=f;x[l+8>>2]=b;x[l+12>>2]=c;break w}i=(p|0)==99;c=i?c+1|0:31;Z:{if((z|0)==1){e=l;if(r){e=Gd(c<<2);if(!e){break h}}x[h+296>>2]=0;x[h+300>>2]=0;b=0;while(1){a=e;_:{while(1){e=x[d+4>>2];$:{if((e|0)!=x[d+104>>2]){x[d+4>>2]=e+1;e=y[e|0];break $}e=qd(d)}if(!y[(e+h|0)+33|0]){break _}v[h+27|0]=e;e=ls(h+28|0,h+27|0,1,h+296|0);if((e|0)==-2){continue}o=0;if((e|0)==-1){break f}if(a){x[(b<<2)+a>>2]=x[h+28>>2];b=b+1|0}if(!((b|0)==(c|0)&r)){continue}break}f=1;b=c;c=b<<1|1;e=Bu(a,c<<2);if(e){continue}break e}break}o=0;c=a;if(h+296|0?x[h+296>>2]:0){break f}break Z}if(r){b=0;e=Gd(c);if(!e){break h}while(1){a=e;while(1){e=x[d+4>>2];aa:{if((e|0)!=x[d+104>>2]){x[d+4>>2]=e+1;e=y[e|0];break aa}e=qd(d)}if(!y[(e+h|0)+33|0]){c=0;o=a;break Z}v[a+b|0]=e;b=b+1|0;if((c|0)!=(b|0)){continue}break}f=1;b=c;c=b<<1|1;e=Bu(a,c);if(e){continue}break}o=a;a=0;break e}b=0;if(l){while(1){a=x[d+4>>2];ba:{if((a|0)!=x[d+104>>2]){x[d+4>>2]=a+1;a=y[a|0];break ba}a=qd(d)}if(y[(a+h|0)+33|0]){v[b+l|0]=a;b=b+1|0;continue}else{c=0;a=l;o=a;break Z}}}while(1){a=x[d+4>>2];ca:{if((a|0)!=x[d+104>>2]){x[d+4>>2]=a+1;a=y[a|0];break ca}a=qd(d)}if(y[(a+h|0)+33|0]){continue}break}a=0;o=0;c=0}e=x[d+4>>2];f=x[d+116>>2];if((f|0)>0|(f|0)>=0){e=e-1|0;x[d+4>>2]=e}f=e-x[d+44>>2]|0;k=f;e=f+x[d+120>>2]|0;f=x[d+124>>2]+(f>>31)|0;f=e>>>0<k>>>0?f+1|0:f;if(!(f|e)|((e|0)!=(j|0)|(f|0)!=(s|0))&(p|0)==99){break i}if(r){x[l>>2]=a}da:{if(i){break da}if(c){x[(b<<2)+c>>2]=0}if(!o){o=0;break da}v[b+o|0]=0}a=c}b=x[d+4>>2]-x[d+44>>2]|0;e=b>>31;i=b;c=n+x[d+124>>2]|0;b=m+x[d+120>>2]|0;c=b>>>0<m>>>0?c+1|0:c;f=b;b=i+b|0;e=c+e|0;m=b;n=b>>>0<f>>>0?e+1|0:e;u=((l|0)!=0)+u|0}b=g+1|0;g=y[g+1|0];if(g){continue}break a}break}a=c;break g}f=1;o=0;a=0;break e}f=r;break b}f=r}if(u){break b}}u=-1}if(!f){break a}Ib(o);Ib(a)}ib=h+304|0;ib=d+144|0;return u}function ria(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;k=ib-208|0;ib=k;if(!au(a)){e=k+48|0;IS(e,a);f=k+176|0;yf(f,e,128,2);e=k+192|0;Fc(e,f);Cc(b+492|0,e);wb(e)}w[c+34>>1]=z[c+34>>1]&65489;p=k+192|0;f=ib-32|0;ib=f;a:{b:{switch(y[a+128|0]-4|0){default:x[f+28>>2]=0;lo(p,0,f+28|0);break a;case 0:case 4:break b}}v[f+28|0]=y[a+129|0];v[f+24|0]=100;e=f+24|0;i=y[Ub(f+28|0,e)|0];v[f+24|0]=y[a+130|0];v[f+20|0]=100;e=y[Ub(e,f+20|0)|0];x[f+28>>2]=e;c:{if(y[a+140|0]&16){g=Fb(y[a+150|0]|y[a+151|0]<<8);l=Fb(y[a+152|0]|y[a+153|0]<<8);m=x[c>>2];r=+(m>>>0)/6553600;i=Lq(r*+((g|i<<16)>>>0));x[f+24>>2]=m-i;s=f,t=Lq(r*+((l|e<<16)>>>0)),x[s+20>>2]=t;s=f,t=x[Hb(f+24|0,f+20|0)>>2],x[s+28>>2]=t;break c}g=x[c>>2];l=x[c+20>>2];if(!_d(g,l)){break c}m=g>>>7|0;i=D(m,(i<<7>>>0)/100|0);x[f+24>>2]=g-i;x[f+20>>2]=D(m,(e<<7>>>0)/100|0);e=x[Hb(f+24|0,f+20|0)>>2];m=z[c+34>>1];g=D(Md(m),g);d:{if(m&1){cc(f+8|0,l,g);l=x[f+8>>2];m=Md(z[c+34>>1]);g=l+(D(m,e+i|0)<<1)|0;n=w[l+(D(i,m)<<1)>>1];m=0-m<<1;while(1){e:{f:{if(e){o=w[g>>1]-n|0;l=o>>31;if((l^o)-l>>>0>=1536){break f}}else{e=0}break e}e=e-1|0;g=g+m|0;continue}break}break d}cc(f,l,g);l=x[f>>2];m=Md(z[c+34>>1]);n=0-m|0;g=l+D(m,e+i|0)|0;m=v[l+D(i,m)|0];while(1){g:{h:{if(e){o=v[g|0]-m|0;l=o>>31;if((l^o)-l>>>0>=6){break h}}else{e=0}break g}e=e-1|0;g=g+n|0;continue}break}}x[f+28>>2]=e}lo(p,i,f+28|0)}ib=f+32|0;p=gc(p);if(!(!x[p>>2]|y[a+128|0]!=4)){w[c+34>>1]=z[c+34>>1]|2;e=x[k+192>>2];x[c+4>>2]=e;x[c+8>>2]=e+x[p>>2]}e=y[a+134|0];if((e-1&255)>>>0<=198){v[k+48|0]=e;v[k+176|0]=100;e=(y[Ub(k+48|0,k+176|0)|0]<<7>>>0)/100|0}else{e=128}v[k+47|0]=e;v[k+48|0]=64;e=k+47|0;f=k+48|0;s=c,t=y[mf(e,f)|0]>>>1|0,w[s+32>>1]=t;v[k+48|0]=64;s=b,t=y[Ub(e,f)|0],x[s+4>>2]=t;x[c+24>>2]=40460;Cl(c,+v[a+139|0]/12+ +(0-y[a+143|0]|0)+ +v[a+138|0]/1536);v[b+34|0]=y[a+142|0]&2?2:1;if(y[a+142|0]&2){Tj(b,127,1);Sj(b,0,1)}i:{if(!_d(x[c>>2],x[c+20>>2])){break i}b=y[a+140|0];if(b&1){b=x[c>>2];e=x[c+20>>2];j:{if(!_d(b,e)|b>>>0<2){break j}k:{l:{switch(Mk(z[c+34>>1])-1|0){case 3:f=0;g=b>>>1|0;while(1){if((f|0)!=(g|0)){oc(e+(f<<2)|0,e+(b+(f^-1)<<2)|0);f=f+1|0;continue}break};break k;case 1:f=0;g=b>>>1|0;while(1){if((f|0)!=(g|0)){Ry(e+(f<<1)|0,e+(b+(f^-1)<<1)|0);f=f+1|0;continue}break};break k;case 0:break l;default:break j}}f=0;g=b>>>1|0;while(1){if((f|0)!=(g|0)){Qi(e+f|0,e+(b+(f^-1)|0)|0);f=f+1|0;continue}break}}yj(c,d)}b=y[a+140|0]}if(b&4){m:{e=x[c>>2];b=x[c+20>>2];if(!_d(e,b)){break m}f=z[c+34>>1];e=D(Md(f),e);n:{o:{switch(an(f)-1|0){case 1:f=0;while(1){if((e|0)!=(f|0)){g=b+(f<<1)|0;w[g>>1]=z[g>>1]^-1;f=f+1|0;continue}break};break n;case 0:break o;default:break m}}f=0;while(1){if((e|0)!=(f|0)){g=b+f|0;v[g|0]=y[g|0]^-1;f=f+1|0;continue}break}}yj(c,d)}}j=y[a+170|0]!=2|y[a+171|0]>100?j:y[a+172|0]<101;b=z[c+34>>1];if(!(!(j|y[a+160|0]!=0|y[a+141|0])|b&1)){e=$t(x[c>>2],Md(b)<<1&254);if(!e){break i}b=e;g=x[c>>2];i=z[c+34>>1];l=D(Md(i),g);f=x[c+20>>2];g=Nj(g,i);i=ib-16|0;ib=i;x[i+12>>2]=l;wc(i+12|0,g);g=x[i+12>>2];while(1){if(g){w[b>>1]=v[f|0]<<8;f=f+1|0;b=b+2|0;g=g-1|0;continue}break}ib=i+16|0;w[c+34>>1]=z[c+34>>1]|1;GS(c,e,x[c>>2],d)}p:{if(v[a+141|0]>=0){break p}cc(k+48|0,x[c+20>>2],D(x[c>>2],Md(z[c+34>>1])));f=x[k+52>>2];e=x[k+48>>2];q:while(1){if((0-v[a+141|0]|0)<=(h|0)){break p}i=w[e>>1];g=bc(e,f);b=e;while(1)if((b|0)==(g|0)){h=h+1|0;continue q}else{i=kd(w[b>>1]-kd(i,1)|0,1);w[b>>1]=i;b=b+2|0;continue}}}r:{if(!j){break r}cc(k+48|0,x[c+20>>2],D(x[c>>2],Md(z[c+34>>1])));h=x[k+52>>2];b=(h|0)/2|0;g=b>>31;n=b;b=y[a+172|0];j=y[a+171|0];e=j;f=0-(b>>>0<e>>>0)|0;b=b-e|0;e=f<<24|b>>>8;i=b<<24;f=n+i|0;b=e+g|0;b=Dc(roa(f,f>>>0<i>>>0?b+1|0:b,h,h>>31),kb);f=b;i=f>>31;b=j<<24;j=b;e=b>>31;b=x[k+48>>2];l=bc(b,h);while(1){if((b|0)==(l|0)){break r}h=w[b>>1];h=qoa(j,e,h,h>>31)+838860800|0;g=kb;s=b,t=Dc(roa(h,h>>>0<838860800?g+1|0:g,1677721600,0),kb),w[s>>1]=t;b=b+2|0;e=e+i|0;h=f+j|0;e=h>>>0<f>>>0?e+1|0:e;j=h;continue}}s:{if(!y[a+160|0]){break s}cc(k+176|0,x[c+20>>2],D(x[c>>2],Md(z[c+34>>1])));b=y[a+163|0];h=y[a+162|0];t:{if(y[a+161|0]<=1){f=0;e=x[k+180>>2];g=0;break t}f=x[k+180>>2];e=(f|0)/2|0;i=e>>31;j=e;e=y[a+164|0];g=0-(h>>>0>e>>>0)|0;e=e-h|0;l=e<<23;j=j+l|0;e=(g<<23|e>>>9)+i|0;f=Dc(roa(j,j>>>0<l>>>0?e+1|0:e,f,f>>31),kb);e=x[k+180>>2];g=(e|0)/2|0;i=g>>31;n=g;g=y[a+165|0];l=0-(b>>>0>g>>>0)|0;j=g-b|0;g=l<<23|j>>>9;l=j<<23;j=n+l|0;g=g+i|0;g=Dc(roa(j,j>>>0<l>>>0?g+1|0:g,e,e>>31),kb)}i=b<<23;j=h<<23;l=(k+48|0)+((y[a+160|0]&2)<<2)|0;h=0;b=x[k+176>>2];m=bc(b,e);e=0;while(1){if((b|0)==(m|0)){break s}n=(w[b>>1]>>1)-e|0;x[k+56>>2]=n;o=n;n=(j|0)/8388608|0;h=kd(D(o,n),8)+h|0;x[k+52>>2]=h;e=kd(D(h,n),6)+e|0;e=kd(kd(D(e,(i|0)/8388608|0),6)+e|0,2);x[k+48>>2]=e;s=b,t=dd(x[l>>2]),w[s>>1]=t;b=b+2|0;i=g+i|0;j=f+j|0;continue}}u:{if(v[a+141|0]<=0){break u}cc(k+48|0,x[c+20>>2],D(x[c>>2],Md(z[c+34>>1])));h=0;f=x[k+52>>2];e=x[k+48>>2];v:while(1){if(v[a+141|0]<=(h|0)){break u}i=w[e>>1];g=bc(e,f);b=e;while(1)if((b|0)==(g|0)){h=h+1|0;continue v}else{i=((w[b>>1]<<1)+i|0)/3|0;w[b>>1]=i;b=b+2|0;continue}}}b=x[c+20>>2];f=z[c+34>>1];e=D(x[c>>2],Md(f));w:{if(f&1){cc(k+32|0,b,e);j=ib-16|0;ib=j;b=x[k+32>>2];i=bc(b,x[k+36>>2]);m=ib-16|0;ib=m;x[m+12>>2]=b;q=j+8|0;e=lo(q,b,m+12|0);x:{if((b|0)==(i|0)){break x}f=b+2|0;if((i|0)==(f|0)){break x}s=(uk(z[f>>1],z[x[e>>2]>>1])?0:4)+e|0,t=f,x[s>>2]=t;g=e+4|0;while(1){h=f+2|0;if((i|0)==(h|0)){break x}l=z[f+2>>1];f=f+4|0;if((i|0)==(f|0)){if(!uk(l,z[x[e>>2]>>1])){e=g;if(uk(l,z[x[e>>2]>>1])){break x}}x[e>>2]=h;break x}n=z[x[e>>2]>>1];o=z[f>>1];y:{if(uk(o,l)){if(uk(o,n)){x[e>>2]=f}if(uk(l,z[x[g>>2]>>1])){continue}break y}if(uk(l,n)){x[e>>2]=h}h=f;if(uk(o,z[x[g>>2]>>1])){continue}}x[g>>2]=h;continue}}ib=m+16|0;x[j+4>>2]=0-w[x[j+8>>2]>>1];s=j,t=w[x[gc(q)>>2]>>1],x[s>>2]=t;z:{e=x[Ve(j+4|0,j)>>2];if((e|0)>32766|!e){break z}while(1){if((b|0)==(i|0)){break z}w[b>>1]=(D(w[b>>1],32767)|0)/(e|0);b=b+2|0;continue}}break w}cc(k+24|0,b,e);j=ib-16|0;ib=j;b=x[k+24>>2];i=Jb(b,x[k+28>>2]);m=ib-16|0;ib=m;x[m+12>>2]=b;q=j+8|0;e=lo(q,b,m+12|0);A:{if((b|0)==(i|0)){break A}f=b+1|0;if((i|0)==(f|0)){break A}s=(ul(y[f|0],y[x[e>>2]])?0:4)+e|0,t=f,x[s>>2]=t;g=e+4|0;while(1){h=f+1|0;if((i|0)==(h|0)){break A}l=y[f+1|0];f=f+2|0;if((i|0)==(f|0)){if(!ul(l,y[x[e>>2]])){e=g;if(ul(l,y[x[e>>2]])){break A}}x[e>>2]=h;break A}n=y[x[e>>2]];o=y[f|0];B:{if(ul(o,l)){if(ul(o,n)){x[e>>2]=f}if(ul(l,y[x[g>>2]])){continue}break B}if(ul(l,n)){x[e>>2]=h}h=f;if(ul(o,y[x[g>>2]])){continue}}x[g>>2]=h;continue}}ib=m+16|0;x[j+4>>2]=0-v[x[j+8>>2]];s=j,t=v[x[gc(q)>>2]],x[s>>2]=t;C:{e=x[Ve(j+4|0,j)>>2];if((e|0)>126|!e){break C}while(1){if((b|0)==(i|0)){break C}v[b|0]=(D(v[b|0],127)|0)/(e|0);b=b+1|0;continue}}}ib=j+16|0;D:{if((y[a+134|0]-101&255)>>>0>98){break D}f=z[c+34>>1];e=D(x[c>>2],Md(f));b=x[c+20>>2];if(f&1){h=k+16|0;x[h>>2]=b;x[h+4>>2]=(b+(e<<1)|0)-b>>1;b=(3276800-(y[a+134|0]<<14)|0)/100|0;g=0-b|0;f=32768-b|0;e=x[h>>2];j=bc(e,x[h+4>>2]);while(1){if((e|0)!=(j|0)){h=w[e>>1];E:{if((h|0)>(b|0)){n=f+((D(b,h-b|0)|0)/(f|0)|0)|0;break E}n=((D(b,b+h|0)|0)/(f|0)|0)-f|0;if((g|0)>(h|0)){break E}n=(D(f,h)|0)/(b|0)|0}s=e,t=dd(n),w[s>>1]=t;e=e+2|0;continue}break}break D}h=yn(k+8|0,b,b+e|0);e=x[h>>2];b=(3276800-(y[a+134|0]<<14)|0)/100|0;g=0-b|0;f=32768-b|0;j=Jb(e,x[h+4>>2]);while(1){if((e|0)!=(j|0)){h=v[e|0]<<8;F:{if((h|0)>(b|0)){n=f+((D(b,h-b|0)|0)/(f|0)|0)|0;break F}n=((D(b,b+h|0)|0)/(f|0)|0)-f|0;if((g|0)>(h|0)){break F}n=(D(f,h)|0)/(b|0)|0}s=e,t=FU((n|0)/256|0),v[s|0]=t;e=e+1|0;continue}break}}FS(c);if(y[a+128|0]!=8){break i}b=y[a+131|0];if(!b){break i}e=x[p>>2];if(!e){break i}s=Bb(c+68|0,0),t=x[k+192>>2]+D(e,b+1|0)|0,x[s>>2]=t;b=x[k+192>>2];x[c+12>>2]=b;x[c+16>>2]=b+x[p>>2];g=x[p>>2];h=y[a+131|0];if(g>>>0>268435456/(h>>>0)>>>0){break i}f=x[c>>2];e=D(g,h);if(f>>>0>268435456-e>>>0){break i}f=e+f|0;e=Mk(z[c+34>>1]);i=$t(f,e);if(!i){break i}j=b+D(g,h+1|0)|0;x[c>>2]=f;b=i;i=x[c+20>>2];h=x[k+192>>2];g=rc(b,i,D(e,h+x[p>>2]|0));l=i+D(e,h)|0;a=y[a+131|0];b=0;while(1){if((a|0)==(b|0)){rc(g+D(e,j)|0,i+D(e,h+x[p>>2]|0)|0,D(e,f-j|0));GS(c,g,f,d)}else{b=b+1|0;m=x[p>>2];rc(g+D(e,h+D(b,m)|0)|0,l,D(e,m));continue}break}}ib=k+208|0}function _da(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;d=ib-784|0;ib=d;yc(b);a:{b:{c:{d:{e:{f:{if(!ii(b,d+776|0)){break f}if(!mO(x[d+776>>2],x[d+780>>2])){break f}if(!eB(b,d+768|0)){break f}g=x[d+768>>2];if(!lO(g)){break f}g:{if((g|0)==1179012417){f=1;e=1313423693;break g}if((g|0)!=538987841){break f}f=2;e=1414090313}m=te(d+744|0,b);j=Nb(d+728|0);h:{i:{j:{k:{l:{m:{n:{if(!c){x[27524]=0;X(857,d+136|0,m|0,f|0,e|0);b=x[27524];x[27524]=0;if((b|0)!=1){break n}a=P()|0;break a}x[27524]=0;U(858,d+136|0,m|0,f|0);b=x[27524];x[27524]=0;if((b|0)==1){break m}}b=d+136|0;lu(j,b);Zd(b);x[27524]=0;U(859,d+704|0,j|0,e|0);b=x[27524];x[27524]=0;if((b|0)!=1){x[27524]=0;b=T(182,x[d+704>>2])|0;e=x[27524];x[27524]=0;if((e|0)==1){break l}f=0;if(!b){break h}x[27524]=0;b=Q(860,d+704|0,d+624|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break l}if(!b){break h}b=y[d+689|0];if(!b){break h}x[27524]=0;f=W(160,x[d+704>>2],x[d+712>>2],b|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break l}if(!c|f^1){break h}x[27524]=0;R(250,a|0,8388608);b=x[27524];x[27524]=0;if((b|0)==1){break l}x[a+480208>>2]=y[d+688|0]<<4&16^28;w[d+136>>1]=y[d+689|0];w[d+496>>1]=127;q=a,r=z[Tc(d+136|0,d+496|0)>>1],w[q+480188>>1]=r;x[a+480196>>2]=y[d+690|0];x[a+480204>>2]=D(y[d+691|0],1e4);x[a+480200>>2]=y[d+696|0]<<1;x[27524]=0;R(140,a+1298344|0,((g|0)==1179012417?16947:16913)|0);b=x[27524];x[27524]=0;if((b|0)==1){break l}x[27524]=0;b=Q(1,d+608|0,13214)|0;e=x[27524];x[27524]=0;if((e|0)==1){break j}Gb(a+1298356|0,b);xb(b);x[a+1298404>>2]=4;b=d+496|0;KA(b,2,d+624|0);x[27524]=0;R(226,d+136|0,b|0);b=x[27524];x[27524]=0;if((b|0)==1){break k}k=(g|0)!=1179012417;b=d+136|0;Ac(a+1298308|0,b);wb(b);l=(g|0)==1179012417;b=0;while(1){o:{p:{q:{if(z[a+480188>>1]<=b>>>0){b=Cb(x[j>>2]);f=Cb(x[j+4>>2]);e=ib-16|0;ib=e;x[e+8>>2]=b;while(1){r:{if(!Mb(b,f)){break r}if(oX(1380209231,x[b>>2],x[b+4>>2])){break r}b=x[Qm(e+8|0)>>2];continue}break}ib=e+16|0;if(Mb(b,Cb(x[j+4>>2]))){break q}break i}f=(b<<5)+a|0;h=f+480280|0;lf(h);x[27524]=0;e=T(210,d+704|0)|0;n=x[27524];x[27524]=0;s:{t:{if((n|0)!=1){if(l){break s}if(e>>>0<129){break t}break p}a=P()|0;break b}w[f+480284>>1]=e<<1;break o}if(e<<24>>24<0){break p}x[d+136>>2]=e<<2;x[d+496>>2]=256;q=f+480284|0,r=x[rd(d+136|0,d+496|0)>>2],w[q>>1]=r;break o}x[27524]=0;U(859,d+136|0,j|0,1380209231);b=x[27524];x[27524]=0;u:{if((b|0)!=1){x[27524]=0;b=T(210,d+136|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break u}e=y[a+484376|0];f=x[a+484360>>2];x[27524]=0;ea(344,Tb(f,e)|0,d+136|0,b+1&255,255,254);b=x[27524];x[27524]=0;if((b|0)==1){break u}yb(d+136|0);break i}a=P()|0;break b}a=P()|0;yb(d+136|0);break b}x[h>>2]=1024}b=b+1|0;continue}}a=P()|0;break a}a=P()|0;break a}a=P()|0;break b}a=P()|0;break b}a=P()|0;break b}v:{if(!(c&1)){break v}w[d+56>>1]=0;x[27524]=0;U(861,d+560|0,j|0,1414807888);b=x[27524];x[27524]=0;if((b|0)==1){break c}b=x[d+564>>2];e=x[d+560>>2];x[27524]=0;f=a+484344|0;R(229,f|0,Kf(e,b)&65535);b=x[27524];x[27524]=0;w:{if((b|0)!=1){q=d,r=Cb(x[d+560>>2]),x[q+88>>2]=r;l=Cb(x[d+564>>2]);x:{y:{z:{A:{B:{while(1){b=x[d+88>>2];if(!Mb(b,l)){k=a+484348|0;b=0;break x}b=te(d+136|0,b);x[27524]=0;e=T(210,b|0)|0;h=x[27524];x[27524]=0;if((h|0)!=1){x[27524]=0;w[d+480>>1]=e;e=T(161,b|0)|0;h=x[27524];x[27524]=0;if((h|0)==1){break B}x[27524]=0;U(194,d+496|0,b|0,e|0);e=x[27524];x[27524]=0;if((e|0)==1){break A}e=hc(d+584|0,d+496|0);x[27524]=0;h=x[e+12>>2];x[d+8>>2]=x[e+8>>2];x[d+12>>2]=h;x[d+16>>2]=x[e+16>>2];h=x[e+4>>2];x[d>>2]=x[e>>2];x[d+4>>2]=h;X(862,d|0,z[d+480>>1],k|0,a|0);e=x[27524];x[27524]=0;if((e|0)==1){break z}yb(d+496|0);q=d,r=z[pe(d+56|0,d+480|0)>>1],w[q+56>>1]=r;yb(b);Uf(d+88|0);continue}break}a=P()|0;break y}a=P()|0;break y}a=P()|0;break y}a=P()|0;yb(d+496|0)}yb(b);break w}while(1){e=b&65535;if(e>>>0>=z[d+56>>1]){Sc(d+560|0);break v}C:{if(!Ce(x[a+484344>>2],x[k>>2],e)){x[27524]=0;W(230,f|0,e|0,64)|0;e=x[27524];x[27524]=0;if((e|0)==1){break C}}b=b+1|0;continue}break}a=P()|0;break w}a=P()|0}Sc(d+560|0);break b}D:{if((g|0)==1179012417){x[27524]=0;U(861,d+88|0,j|0,1414745673);b=x[27524];x[27524]=0;if((b|0)==1){break d}q=d,r=Cb(x[d+88>>2]),x[q+120>>2]=r;g=c&2;k=d+504|0;l=Cb(x[d+92>>2]);e=a+480190|0;while(1){b=x[d+120>>2];if(!Mb(b,l)){Sc(d+88|0);break D}c=te(d+560|0,b);x[27524]=0;b=Q(863,c|0,d+136|0)|0;f=x[27524];x[27524]=0;if((f|0)!=1){E:{if(!b){break E}b=y[d+137|0];if((b|0)==255){break E}x[27524]=0;f=W(255,a|0,b+1|0,0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break e}if(!f){break E}h=z[e>>1];b=0;x[27524]=0;U(864,d+136|0,f|0,h|0);f=x[27524];x[27524]=0;if((f|0)==1){break e}while(1){if(y[d+166|0]<=b>>>0){break E}F:{if(!bi(z[e>>1])){break F}x[27524]=0;f=Q(865,c|0,d+496|0)|0;h=x[27524];x[27524]=0;if((h|0)==1){break e}if(!f){break F}f=z[e>>1]+1|0;w[e>>1]=f;if(x[d+496>>2]!=1347240275){break F}h=d+480|0;Pi(h,2,k);x[27524]=0;R(226,d+56|0,h|0);h=x[27524];x[27524]=0;G:{if((h|0)!=1){f=f&65535;h=d+56|0;Cc(((f<<5)+a|0)+946304|0,h);wb(h);x[27524]=0;f=(D(f,104)+a|0)+484380|0;U(866,d+496|0,d+136|0,f|0);h=x[27524];x[27524]=0;if((h|0)==1){break e}if(!g){break G}h=d+56|0;kO(h,z[d+534>>1]);x[27524]=0;W(223,h|0,f|0,c|0)|0;f=x[27524];x[27524]=0;if((f|0)!=1){break F}break e}break e}h=z[f+34>>1];f=x[f>>2];x[27524]=0;Q(192,c|0,Nj(f,h)|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break e}}b=b+1|0;continue}}yb(c);Uf(d+120|0);continue}break}break e}x[27524]=0;U(861,d+480|0,j|0,1179011410);b=x[27524];x[27524]=0;if((b|0)!=1){q=d,r=Cb(x[d+480>>2]),x[q+472>>2]=r;k=c&2;l=d+496|4;h=Cb(x[d+484>>2]);f=a+480190|0;H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{while(1){b=x[d+472>>2];if(!Mb(b,h)){Sc(d+480|0);break D}c=te(d+560|0,b);x[27524]=0;b=T(161,c|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break Q}R:{S:{if((b|0)!=538986817){break S}x[27524]=0;b=Q(867,c|0,d+464|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break P}if(!(b&x[d+464>>2]==1414745673)){break S}x[27524]=0;b=Q(868,c|0,d+136|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break O}if(!b){break S}b=y[d+141|0];if((b|0)==255){break S}x[27524]=0;b=W(255,a|0,b+1|0,0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break N}if(!b){break S}e=z[f>>1];x[27524]=0;U(869,d+136|0,b|0,e|0);b=x[27524];x[27524]=0;if((b|0)==1){break N}x[27524]=0;U(858,d+496|0,c|0,2);b=x[27524];x[27524]=0;if((b|0)==1){break R}x[27524]=0;U(861,d+120|0,d+496|0,1179011410);b=x[27524];x[27524]=0;if((b|0)==1){break M}Zd(d+496|0);q=d,r=Cb(x[d+120>>2]),x[q+112>>2]=r;n=Cb(x[d+124>>2]);T:{U:{while(1){b=x[d+112>>2];if(!Mb(b,n)){break T}b=te(d+88|0,b);x[27524]=0;e=T(161,b|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break L}V:{W:{if((e|0)!=538989377){break W}e=z[f>>1];if(!bi(e)){break W}g=z[d+460>>1];w[d+460>>1]=g-1;if(!g){yb(b);break T}i=e+1|0;w[f>>1]=i;x[27524]=0;e=Q(867,b|0,d+80|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break K}if(!(e&x[d+80>>2]==1347240275)){break U}x[27524]=0;U(194,d+496|0,b|0,x[d+84>>2]);e=x[27524];x[27524]=0;X:{if((e|0)!=1){g=d+496|0;e=hc(d+56|0,g);yb(g);x[27524]=0;g=Q(870,e|0,g|0)|0;o=x[27524];x[27524]=0;if((o|0)==1){break V}if(g){break X}yb(e);yb(b);break T}a=P()|0;break I}g=d+24|0;Se(g,2,l);x[27524]=0;R(226,d+40|0,g|0);g=x[27524];x[27524]=0;if((g|0)==1){break J}g=i&65535;i=d+40|0;Cc(((g<<5)+a|0)+946304|0,i);wb(i);x[27524]=0;g=(D(g,104)+a|0)+484380|0;U(871,d+496|0,d+136|0,g|0);i=x[27524];x[27524]=0;if((i|0)==1){break V}Y:{if(!k){break Y}x[27524]=0;Q(159,e|0,x[d+496>>2]+4|0)|0;i=x[27524];x[27524]=0;if((i|0)==1){break V}i=d+40|0;kO(i,z[d+536>>1]);x[27524]=0;W(223,i|0,g|0,e|0)|0;g=x[27524];x[27524]=0;if((g|0)!=1){break Y}break J}yb(e)}yb(b);Uf(d+112|0);continue}break}break J}yb(b)}Sc(d+120|0)}yb(c);Uf(d+472|0);continue}break}a=P()|0;break H}a=P()|0;break H}a=P()|0;break H}a=P()|0;break H}a=P()|0;break H}a=P()|0;Zd(d+496|0);break H}a=P()|0;break I}a=P()|0;break I}a=P()|0;yb(e)}yb(b);Sc(d+120|0)}yb(c);Sc(d+480|0);break b}a=P()|0;break b}f=1}yb(d+704|0);Zd(j);yb(m)}ib=d+784|0;return f|0}a=P()|0;yb(c);Sc(d+88|0);break b}a=P()|0;break b}a=P()|0}yb(d+704|0)}Zd(j);yb(m);S(a|0);p()}function Gt(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=ib-32|0;ib=h;x[h+28>>2]=c;a:{if((c|0)<=0){break a}j=x[b+104>>2];b:{c:{d:{e:{f:{g:{h:{k=x[b+656>>2];i:{if(!(!k|x[a+480180>>2]!=16777216)){m=x[k+44>>2]!=0;break i}if(!k){break h}}if((c|0)>128){break g}i=c-1|0;l=z[bc(k+236|0,i)>>1];j:{if((l-1&65535)>>>0<=3998){j=(D(l,104)+a|0)+484380|0;break j}Ab(h+16|0,a+1074312|0,43);if(!zb(x[x[h+16>>2]>>2],x[h+20>>2])){break j}if(!uj(x[b+656>>2])){break a}}i=y[Jb(k+108|0,i)|0];x[h+28>>2]=i;if(i>>>0<=120){break f}c=i;break g}i=c;n=0;if(c>>>0<121){break e}}k:{if(!(x[a+480180>>2]&16777248?(c|0)!=255:0)){Yn(a,b);if(d){break k}Ab(h+16|0,a+1074312|0,100);if(!zb(x[x[h+16>>2]>>2],x[h+20>>2])|!(y[a+480208|0]&4)|!y[b+789|0]){break k}x[b+88>>2]=x[b+88>>2]&-6145;break k}if(!z[a+480192>>1]){break k}x[b+88>>2]=x[b+88>>2]|4096}l:{if((c|0)!=254){break l}d=x[b+88>>2];c=a+480180|0;if(!(!(d&512)|x[c>>2]!=2)){x[b+88>>2]=d|2048;break l}x[b+88>>2]=d|2101248;m:{if(x[c>>2]&16777248){if(!z[a+480192>>1]){break m}Ab(h+16|0,a+1074312|0,50);if(zb(x[x[h+16>>2]>>2],x[h+20>>2])){break m}}x[b+688>>2]=0}Ab(h+16|0,a+1074312|0,50);if(zb(x[x[h+16>>2]>>2],x[h+20>>2])){x[b+8>>2]=0;x[b+12>>2]=0}x[b+696>>2]=0}Ab(h+16|0,a+1074312|0,20);if(!zb(x[x[h+16>>2]>>2],x[h+20>>2])){break a}v[b+797|0]=0;v[b+802|0]=0;break a}n=0;if(!m){break e}if(d){l=y[b+797|0];if(l){break d}}x[b+708>>2]=0;n=1}if(d){break c}n:{o:{if(!(!(x[a+480180>>2]&1048588)|!j)){w[b+770>>1]=v[j+36|0];w[b+772>>1]=v[j+37|0];break o}if(!j){break n}}Ab(h+16|0,a+1074312|0,24);m=0;l=1;if(!zb(x[x[h+16>>2]>>2],x[h+20>>2])){break b}x[b+704>>2]=x[j+24>>2];break b}j=0;l=0;m=0;break b}l=D((x[x[k+44>>2]+36>>2]<<16>>16)+1|0,(i<<16>>16)-(l<<16>>16)|0)-x[b+852>>2]|0;x[b+708>>2]=l;x[b+852>>2]=0-l;n=1}l=(j|0)!=0;m=1;if(Gi(x[b+8>>2],x[b+12>>2])){break b}m=a+1074312|0;Ab(h+16|0,m,54);p:{if(!zb(x[x[h+16>>2]>>2],x[h+20>>2])){break p}if(uj(x[b+656>>2])){Ab(h+8|0,m,117);if(!zb(x[x[h+8>>2]>>2],x[h+12>>2])){break p}}x[b+700>>2]=0;break a}Ab(h+16|0,m,39);m=(zb(x[x[h+16>>2]>>2],x[h+20>>2])^-1)&d}q:{if(Nm(x[a+480180>>2])){x[h+28>>2]=w[b+770>>1]+i;re(h+28|0,12,131);break q}dU(h+28|0)}i=a+1074312|0;Ab(h+16|0,i,34);r:{if(zb(x[x[h+16>>2]>>2],x[h+20>>2])){d=El(c);break r}d=x[h+28>>2]}v[b+797|0]=d;v[b+851|0]=y[b+851|0]&183|64;if(!(x[a+480180>>2]&16777250?0:m)){v[b+803|0]=0}d=nh(a,x[h+28>>2],w[b+772>>1],x[b+704>>2]);v[b+831|0]=0;Ab(h+16|0,i,48);if(zb(x[x[h+16>>2]>>2],x[h+20>>2])){XP(a,b,k,j)}Ab(h+16|0,i,115);if(!(!zb(x[x[h+16>>2]>>2],x[h+20>>2])|!k|!y[k+26|0])){if(!z[b+784>>1]){w[b+784>>1]=z[b+692>>1]+1}WP(b+692|0,c,y[k+26|0],y[k+27|0])}s:{if(e^1|m){break s}x[b+776>>2]=0;x[b+780>>2]=0;if(!k){break s}Ab(h+16|0,i,29);if(zb(x[x[h+16>>2]>>2],x[h+20>>2])){v[b+798|0]=y[k+16|0]}if(!(y[k+60|0]&8)){tj(b+724|0)}if(!(y[k+80|0]&8)){tj(b+732|0)}if(!(y[k+100|0]&8)){tj(b+740|0)}if(y[k+20|0]){c=Et(Xn(a));o=y[k+20|0];Ab(h+16|0,i,28);o=((D(c,o)<<16>>16)/64<<16)+65536>>16;t:{if(zb(x[x[h+16>>2]>>2],x[h+20>>2])){c=x[b+752>>2];break t}c=(x[b+688>>2]+1|0)/2|0}w[b+776>>1]=(D(c,o)|0)/199}u:{if(!y[k+19|0]){break u}q=b,r=(D(Et(Xn(a)),y[k+19|0])<<16>>16)/32|0,w[q+778>>1]=r;Ab(h+16|0,i,28);if(zb(x[x[h+16>>2]>>2],x[h+20>>2])|z[b+784>>1]){break u}w[b+784>>1]=z[b+692>>1]+1}c=y[k+23|0];if(c){o=Et(Xn(a));p=y[b+837|0];v[b+796|0]=p+1;w[b+780>>1]=(D(p,(D(c,o+1|0)<<16>>16)/128<<16>>16)+1|0)/128}c=y[k+24|0];if(!c){break s}o=Et(Xn(a));p=y[b+838|0];v[b+795|0]=p+1;w[b+782>>1]=(D(p,(D(c,o+1|0)<<16>>16)/128<<16>>16)+1|0)/128}if(!l){break a}l=0;v:{w:{if(!d){break w}if(!(x[b+700>>2]?m:0)){x[b+700>>2]=d}x:{y:{if(!n){if(!m){Ab(h+16|0,i,69);if(zb(x[x[h+16>>2]>>2],x[h+20>>2])){break y}Ab(h+8|0,i,46);if(zb(x[x[h+8>>2]>>2],x[h+12>>2])|x[a+480180>>2]==1){break y}}x[b+708>>2]=d;v[b+851|0]=y[b+851|0]&239}if(!m){break y}if(x[b+76>>2]|y[a+480180|0]&2){break x}}x[b+104>>2]=j;c=x[j>>2];x[b+84>>2]=c;x[b+76>>2]=c;x[b+80>>2]=0;x[b>>2]=0;x[b+4>>2]=0;z:{A:{if(!(x[a+480208>>2]&2097152)){Ab(h+16|0,i,96);if(!zb(x[x[h+16>>2]>>2],x[h+20>>2])){break A}}if(y[b+789|0]){break A}x[h+16>>2]=x[b+76>>2]-1;q=b,r=x[Hb(b+660|0,h+16|0)>>2],x[q+4>>2]=r;break z}x[b+660>>2]=0}c=z[j+34>>1];d=c&1023;n=d|x[b+88>>2]&-525056;x[b+88>>2]=n;B:{C:{if(c&8){x[b+80>>2]=x[j+12>>2];c=x[j+16>>2];x[b+88>>2]=(d&16?n|4:n&-524295)|2;x[b+84>>2]=c;if(A[b+76>>2]>c>>>0){break C}break B}if(!(d&2)){break B}x[b+80>>2]=x[j+4>>2];c=x[j+8>>2];x[b+84>>2]=c;if(A[b+76>>2]<=c>>>0){break B}}x[b+76>>2]=c}Ab(h+16|0,i,83);if(!(!zb(x[x[h+16>>2]>>2],x[h+20>>2])|x[b+80>>2])){c=x[j>>2];x[b+84>>2]=c;x[b+76>>2]=c}c=x[b+88>>2];D:{if(!(c&128)){break D}d=x[b+76>>2];if(!d){break D}x[b+4>>2]=d-1;x[b+88>>2]=c|128}E:{if(y[b+822|0]>3){break E}Ab(h+16|0,i,21);c=x[a+480180>>2];F:{G:{if(!(zb(x[x[h+16>>2]>>2],x[h+20>>2])|!(c&16777248))){j=16;if(x[a+480208>>2]&4){break G}break F}j=32;if((c|0)==16){break F}}if(c&67633152){break E}j=0}v[b+819|0]=j}Ab(h+16|0,i,21);if(zb(x[x[h+16>>2]>>2],x[h+20>>2])|y[b+825|0]>3){break x}v[b+820|0]=0}d=x[b>>2];if(A[b+76>>2]<=A[b+4>>2]){c=x[b+80>>2];x[b>>2]=d;x[b+4>>2]=c}if(!m){break w}l=1;if(!(x[a+480180>>2]&17301536)|(x[b+696>>2]?0:y[b+89|0]&16)){break w}c=1;if(!(y[a+480208|0]&8)){break v}c=1;if(!y[b+789|0]){break v}}if(!(x[b+696>>2]|(!(x[a+480180>>2]&17301536)|!(y[b+89|0]&16)))){ym(b);Ab(h+16|0,i,21);if(!zb(x[x[h+16>>2]>>2],x[h+20>>2])){v[b+818|0]=0;x[b+756>>2]=0}x[b+696>>2]=65536;x[b+88>>2]=x[b+88>>2]&-4097}H:{if(!l){j=y[b+789|0];break H}j=y[b+789|0];if(!(y[a+480208|0]&8)){break H}c=1;if(!(j&255)){break v}}if(!(j&255?0:x[a+480180>>2]&1048580)){x[b+696>>2]=65536;x[b+88>>2]=x[b+88>>2]&-4097}c=l}Ab(h+16|0,i,40);I:{if(!(!c|!zb(x[x[h+16>>2]>>2],x[h+20>>2])|(y[b+789|0]?y[a+480208|0]&8:0))){d=x[b+88>>2]&-4194305;break I}d=x[b+88>>2]&-4196353}x[b+88>>2]=d;J:{if(c){break J}w[b+842>>1]=65535;x[b+88>>2]=d&-6324225|2097152;Ab(h+16|0,i,23);K:{if(zb(x[x[h+16>>2]>>2],x[h+20>>2])){break K}Ab(h+8|0,i,22);if(zb(x[x[h+8>>2]>>2],x[h+12>>2])){break K}Ab(h+16|0,i,52);if(zb(x[x[h+16>>2]>>2],x[h+20>>2])){break K}Ab(h+8|0,i,71);if(zb(x[x[h+8>>2]>>2],x[h+12>>2])){break K}v[b+839|0]=0;v[b+808|0]=0}if(e){v[b+818|0]=0;x[b+756>>2]=0}x[b+20>>2]=0;x[b+24>>2]=0;d=x[a+480208>>2]&8192;L:{M:{if(k){e=1;l=y[k+22|0];N:{if(!Ue(l)){e=!(d>>>13|0);break N}q=b,r=Wm(l),v[q+838|0]=r}d=y[k+21|0];if(Ue(d)){q=b,r=Wm(d),v[q+837|0]=r;break M}if(e){break M}j=(e|0)!=0;break L}x[b+776>>2]=0;x[b+780>>2]=0;j=!d;break L}j=1;d=y[k+25|0];if((d|0)==255){break L}v[b+845|0]=d}O:{if(y[b+837|0]>=127){Ab(h+16|0,i,36);if(!zb(x[x[h+16>>2]>>2],x[h+20>>2])){break O}}if(!j){break O}if((fq(a,b,1,256)|0)<0|!(y[b+89|0]&2)){break O}d=x[a+1298300>>2];if(!Ed(d)|(g|0)==65535){break O}jq(d,g,y[b+837|0]>>>1|0,1)}if(!(y[b+89|0]&2)){break J}if(!Ed(x[a+1298300>>2])|(g|0)==65535){break J}Ab(h+16|0,i,111);if(zb(x[x[h+16>>2]>>2],x[h+20>>2])){pk(x[a+1298300>>2],g);break J}Ab(h+16|0,i,110);if(!zb(x[x[h+16>>2]>>2],x[h+20>>2])){break J}_z(x[a+1298300>>2],g,0,1,0)}d=x[b+88>>2];P:{Q:{R:{if(f){x[b+88>>2]=d&-1025;break R}if(!(d&1024)){break R}if(y[a+24618|0]&16){break Q}}a=x[b+104>>2];if(!(!a|!(y[a+35|0]&4)|f)){break Q}a=x[b+656>>2];if(!a|(!(y[a+15|0]&2)|f)){break P}}x[b+700>>2]=0}if(c){break a}w[b+136>>1]=0;x[b+132>>2]=4194304;x[b+112>>2]=0;x[b+116>>2]=0}ib=h+32|0}function GN(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;k=ib-336|0;ib=k;n=h;p=i&65535;o=d;m=e&65535;r=(e^i)&-2147483648;t=i>>>16&32767;u=e>>>16&32767;a:{b:{if(t-32767>>>0>4294934529&u-32767>>>0>=4294934530){break b}j=e&2147483647;if(!(!d&(j|0)==2147418112?!(b|c):j>>>0<2147418112)){y=d;r=e|32768;break a}e=i&2147483647;if(!(!h&(e|0)==2147418112?!(f|g):e>>>0<2147418112)){y=h;r=i|32768;b=f;c=g;break a}if(!(b|d|(j^2147418112|c))){if(!(f|h|(e^2147418112|g))){b=0;c=0;r=2147450880;break a}r=r|2147418112;b=0;c=0;break a}if(!(f|h|(e^2147418112|g))){b=0;c=0;break a}if(!(b|d|(c|j))){b=!(f|h|(e|g));y=b?0:y;r=b?2147450880:r;b=0;c=0;break a}if(!(f|h|(e|g))){r=r|2147418112;b=0;c=0;break a}if((j|0)==65535|j>>>0<65535){i=b;d=!(m|o);h=d<<6;j=G(d?b:o)+32|0;b=G(d?c:m);b=h+((b|0)==32?j:b)|0;Sf(k+320|0,i,c,o,m,b-15|0);l=16-b|0;o=x[k+328>>2];m=x[k+332>>2];c=x[k+324>>2];b=x[k+320>>2]}if(e>>>0>65535){break b}d=!(n|p);e=d<<6;h=G(d?f:n)+32|0;d=G(d?g:p);d=e+((d|0)==32?h:d)|0;Sf(k+304|0,f,g,n,p,d-15|0);l=(d+l|0)-16|0;n=x[k+312>>2];p=x[k+316>>2];f=x[k+304>>2];g=x[k+308>>2]}e=p|65536;E=e;F=n;d=n;j=e<<15|d>>>17;e=d<<15|g>>>17;d=0-e|0;h=j;i=1963258675-(j+((e|0)!=0)|0)|0;Ef(k+288|0,e,j,0,0,d,i,0,0);j=x[k+296>>2];Ef(k+272|0,0-j|0,0-(x[k+300>>2]+((j|0)!=0)|0)|0,0,0,d,i,0,0);d=x[k+280>>2];i=d<<1|x[k+276>>2]>>>31;d=x[k+284>>2]<<1|d>>>31;Ef(k+256|0,i,d,0,0,e,h,0,0);j=d;d=x[k+264>>2];Ef(k+240|0,i,j,0,0,0-d|0,0-(x[k+268>>2]+((d|0)!=0)|0)|0,0,0);i=x[k+248>>2];j=i<<1|x[k+244>>2]>>>31;d=x[k+252>>2]<<1|i>>>31;Ef(k+224|0,j,d,0,0,e,h,0,0);i=d;d=x[k+232>>2];Ef(k+208|0,j,i,0,0,0-d|0,0-(x[k+236>>2]+((d|0)!=0)|0)|0,0,0);d=x[k+216>>2];i=d<<1|x[k+212>>2]>>>31;d=x[k+220>>2]<<1|d>>>31;Ef(k+192|0,i,d,0,0,e,h,0,0);j=d;d=x[k+200>>2];Ef(k+176|0,i,j,0,0,0-d|0,0-(x[k+204>>2]+((d|0)!=0)|0)|0,0,0);d=e;i=x[k+184>>2];e=i<<1|x[k+180>>2]>>>31;s=e-1|0;i=(x[k+188>>2]<<1|i>>>31)-!e|0;Ef(k+160|0,d,h,0,0,s,i,0,0);d=f;j=g<<15|d>>>17;Ef(k+144|0,d<<15,j,0,0,s,i,0,0);h=x[k+172>>2];p=x[k+160>>2];e=x[k+152>>2];d=p+e|0;n=x[k+164>>2];j=n+x[k+156>>2]|0;j=d>>>0<e>>>0?j+1|0:j;e=d;d=j;n=(n|0)==(d|0)&e>>>0<p>>>0|d>>>0<n>>>0;j=n+x[k+168>>2]|0;h=j>>>0<n>>>0?h+1|0:h;p=!d&e>>>0>1|(d|0)!=0;n=p+j|0;j=h;h=n;Ef(k+112|0,s,i,0,0,0-h|0,0-(((h|0)!=0)+(h>>>0<p>>>0?j+1|0:j)|0)|0,0,0);Ef(k+128|0,1-e|0,0-((e>>>0>1)+d|0)|0,0,0,s,i,0,0);L=(u-t|0)+l|0;e=x[k+116>>2];B=e;d=x[k+112>>2];j=e<<1|d>>>31;C=d<<1;q=j;d=j;h=x[k+140>>2];z=h;e=x[k+136>>2];j=h<<1|e>>>31;i=e<<1|x[k+132>>2]>>>31;h=i+C|0;d=d+j|0;d=h>>>0<i>>>0?d+1|0:d;e=d;d=d-(h>>>0<13927)|0;n=d;l=0;j=m|65536;M=j;N=o;d=o;j=j<<1|d>>>31;Q=d<<1;R=j;H=j;w=qoa(n,l,j,0);d=kb;v=d;j=b;d=c<<1|j>>>31;t=j<<1;s=d;p=d;j=0;u=j;i=h-13927|0;l=(e|0)==(n|0)&i>>>0<h>>>0|e>>>0>n>>>0;m=(e|0)==(q|0)&h>>>0<C>>>0|e>>>0<q>>>0;d=x[k+120>>2];h=x[k+124>>2]<<1|d>>>31;e=z>>>31|0;d=e+(d<<1|B>>>31)|0;j=h;j=d>>>0<e>>>0?j+1|0:j;e=d;d=m+d|0;j=d>>>0<e>>>0?j+1|0:j;e=d;d=l+d|0;l=d>>>0<e>>>0?j+1|0:j;e=d;d=d-1|0;I=l-!e|0;C=0;j=qoa(p,u,I,C);e=j+w|0;h=kb+v|0;h=e>>>0<j>>>0?h+1|0:h;l=(h|0)==(v|0)&e>>>0<w>>>0|h>>>0<v>>>0;j=0;w=l;q=d;d=o;O=c>>>31|0;v=O|d<<1;z=0;l=qoa(q,j,v,z);d=l+e|0;j=kb+h|0;j=d>>>0<l>>>0?j+1|0:j;o=d;m=j;e=(j|0)==(h|0)&d>>>0<e>>>0|h>>>0>j>>>0;d=w+e|0;l=0;l=d>>>0<e>>>0?1:l;e=qoa(H,u,I,C);d=e+d|0;j=kb+l|0;w=d;d=d>>>0<e>>>0?j+1|0:j;l=qoa(H,u,q,z);h=kb;D=qoa(v,z,I,C);e=D+l|0;j=kb+h|0;j=e>>>0<D>>>0?j+1|0:j;D=e;e=j;j=(h|0)==(j|0)&l>>>0>D>>>0|h>>>0>j>>>0;l=w+e|0;d=d+j|0;h=l;l=h>>>0<e>>>0?d+1|0:d;e=0;d=e+o|0;j=m+D|0;j=d>>>0<e>>>0?j+1|0:j;e=j;m=(j|0)==(m|0)&d>>>0<o>>>0|j>>>0<m>>>0;h=m+h|0;j=l;w=h;l=h>>>0<m>>>0?j+1|0:j;o=d;m=e;D=i;h=qoa(i,0,v,z);e=kb;i=qoa(n,u,p,u);d=i+h|0;j=kb+e|0;j=d>>>0<i>>>0?j+1|0:j;e=(e|0)==(j|0)&d>>>0<h>>>0|e>>>0>j>>>0;h=j;J=w;B=e;K=t&-2;i=qoa(q,z,K,0);e=i+d|0;j=kb+j|0;j=e>>>0<i>>>0?j+1|0:j;w=e;i=e;e=j;i=(j|0)==(h|0)&d>>>0>i>>>0|h>>>0>j>>>0;d=B+i|0;h=0;h=d>>>0<i>>>0?1:h;j=d;i=d+o|0;d=h+m|0;B=i;h=i;d=h>>>0<j>>>0?d+1|0:d;i=d;h=(d|0)==(m|0)&h>>>0<o>>>0|d>>>0<m>>>0;d=J+h|0;j=l;J=d;o=d>>>0<h>>>0?j+1|0:j;P=qoa(H,u,D,y);H=kb;h=qoa(I,C,K,y);d=h+P|0;j=kb+H|0;I=d;m=qoa(n,u,v,z);l=d+m|0;h=d>>>0<h>>>0?j+1|0:j;d=h+kb|0;d=l>>>0<m>>>0?d+1|0:d;v=l;m=qoa(p,u,q,z);j=l+m|0;l=kb+d|0;C=j;l=j>>>0<m>>>0?l+1|0:l;m=0;q=(d|0)==(l|0)&v>>>0>j>>>0|d>>>0>l>>>0;j=(d|0)==(h|0)&v>>>0<I>>>0|d>>>0<h>>>0;d=j+((h|0)==(H|0)&I>>>0<P>>>0|h>>>0<H>>>0)|0;h=0;d=q+d|0;q=l|0;h=q+B|0;j=(d|m)+i|0;j=h>>>0<q>>>0?j+1|0:j;q=h;d=h;m=j;h=(i|0)==(j|0)&d>>>0<B>>>0|i>>>0>j>>>0;d=h+J|0;j=o;v=d;i=d>>>0<h>>>0?j+1|0:j;B=qoa(n,u,K,y);n=kb;h=qoa(p,u,D,y);d=h+B|0;j=kb+n|0;j=d>>>0<h>>>0?j+1|0:j;o=0;h=(j|0)==(n|0)&d>>>0<B>>>0|j>>>0<n>>>0;n=j;d=j+w|0;j=(h|o)+e|0;h=d;j=d>>>0<n>>>0?j+1|0:j;n=(e|0)==(j|0)&d>>>0<w>>>0|e>>>0>j>>>0;e=0+d|0;d=j;l=C+d|0;l=e>>>0<o>>>0?l+1|0:l;e=(d|0)==(l|0)&e>>>0<h>>>0|d>>>0>l>>>0;d=n+e|0;j=0;j=d>>>0<e>>>0?1:j;e=d;d=d+q|0;j=j+m|0;j=d>>>0<e>>>0?j+1|0:j;e=j;j=(m|0)==(j|0)&d>>>0<q>>>0|j>>>0<m>>>0;h=j+v|0;l=i;l=h>>>0<j>>>0?l+1|0:l;i=l;c:{if((l|0)==131071|l>>>0<131071){N=Q|O;M=z|R;Ef(k+80|0,d,e,h,i,f,g,F,E);j=b<<17;b=0;c=x[k+88>>2];m=b-c|0;l=x[k+80>>2];p=x[k+84>>2];n=(l|p)!=0;o=m-n|0;m=(j-(x[k+92>>2]+(b>>>0<c>>>0)|0)|0)-(m>>>0<n>>>0)|0;n=0-l|0;p=0-(((l|0)!=0)+p|0)|0;b=L+16382|0;break c}d=(e&1)<<31|d>>>1;e=h<<31|e>>>1;h=(i&1)<<31|h>>>1;i=i>>>1|0;Ef(k+96|0,d,e,h,i,f,g,F,E);m=0;n=x[k+104>>2];p=m-n|0;l=x[k+96>>2];s=x[k+100>>2];t=(l|s)!=0;o=p-t|0;m=((b<<16)-(x[k+108>>2]+(m>>>0<n>>>0)|0)|0)-(p>>>0<t>>>0)|0;n=0-l|0;p=0-(((l|0)!=0)+s|0)|0;t=b;s=c;b=L+16383|0}if((b|0)>=32767){r=r|2147418112;b=0;c=0;break a}d:{if((b|0)>0){c=o;l=m<<1|c>>>31;o=c<<1|p>>>31;m=l;t=h;s=i&65535|b<<16;b=n;l=p<<1|b>>>31;b=b<<1;break d}if((b|0)<=-113){b=0;c=0;break a}xm(k- -64|0,d,e,h,i,1-b|0);Sf(k+48|0,t,s,N,M,b+112|0);d=x[k+64>>2];e=x[k+68>>2];t=x[k+72>>2];s=x[k+76>>2];Ef(k+32|0,f,g,F,E,d,e,t,s);c=x[k+40>>2];i=c<<1;c=x[k+44>>2]<<1|c>>>31;b=x[k+56>>2];h=x[k+36>>2];o=h>>>31|i;i=b-o|0;l=x[k+60>>2]-((b>>>0<o>>>0)+c|0)|0;c=x[k+32>>2];h=h<<1|c>>>31;c=c<<1;j=x[k+52>>2];b=x[k+48>>2];m=(h|0)==(j|0)&c>>>0>b>>>0|h>>>0>j>>>0;o=i-m|0;m=l-(i>>>0<m>>>0)|0;i=b;b=b-c|0;l=j-((c>>>0>i>>>0)+h|0)|0}Ef(k+16|0,f,g,F,E,3,0,0,0);Ef(k,f,g,F,E,5,0,0,0);j=0;h=l+j|0;n=d&1;c=b+n|0;h=c>>>0<b>>>0?h+1|0:h;i=c;b=i;g=(g|0)==(h|0)&b>>>0>f>>>0|g>>>0<h>>>0;c=(h|0)==(j|0)&b>>>0<n>>>0|h>>>0<j>>>0;b=c+o|0;l=m;l=b>>>0<c>>>0?l+1|0:l;f=b;c=(l|0)==(E|0);c=c&(b|0)==(F|0)?g:c&b>>>0>F>>>0|l>>>0>E>>>0;b=c+d|0;j=e;j=b>>>0<c>>>0?j+1|0:j;c=b;b=j;e=(j|0)==(e|0)&c>>>0<d>>>0|e>>>0>j>>>0;d=e+t|0;j=s;j=d>>>0<e>>>0?j+1|0:j;o=d;d=x[k+20>>2];g=(d|0)==(h|0)&A[k+16>>2]<i>>>0|d>>>0<h>>>0;d=x[k+28>>2];e=x[k+24>>2];g=j>>>0<2147418112&((e|0)==(f|0)&(d|0)==(l|0)?g:(d|0)==(l|0)&e>>>0<f>>>0|d>>>0<l>>>0);e=g+c|0;d=b;d=e>>>0<g>>>0?d+1|0:d;c=(b|0)==(d|0)&c>>>0>e>>>0|b>>>0>d>>>0;b=o+c|0;j=b>>>0<c>>>0?j+1|0:j;g=b;b=x[k+4>>2];h=(b|0)==(h|0)&A[k>>2]<i>>>0|b>>>0<h>>>0;b=x[k+12>>2];c=x[k+8>>2];c=j>>>0<2147418112&((c|0)==(f|0)&(b|0)==(l|0)?h:(b|0)==(l|0)&c>>>0<f>>>0|b>>>0<l>>>0);b=c+e|0;l=b>>>0<c>>>0?d+1|0:d;c=l;f=(d|0)==(l|0)&b>>>0<e>>>0|d>>>0>l>>>0;e=g+f|0;d=j;y=e|y;r=r|(e>>>0<f>>>0?d+1|0:d)}x[a>>2]=b;x[a+4>>2]=c;x[a+8>>2]=y;x[a+12>>2]=r;ib=k+336|0}function Ena(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0;e=ib+-64|0;ib=e;yc(a);a:{b:{if(b>>>0<=2){H=e,I=Re(a),v[H+56|0]=I;Yb(a,2);H=e,I=_g(a),w[H+58>>1]=I;H=e,I=Jg(a),x[H+60>>2]=I;break b}Ao(a,e+56|0);if(b>>>0>5){break a}}v[e+57|0]=0}c:{q=d+484344|0;E=Bd(z[e+58>>1],1,1024);o=hC(q,E);if((o|0)==65535){break c}b=Xb(x[d+484344>>2],o);m=qf(x[b>>2],x[x[b+48>>2]+12>>2],0);f=z[d+480188>>1];w[e>>1]=f-1;w[e+40>>1]=y[e+56|0];F=z[Tc(e,e+40|0)>>1];g=F+1|0;b=g&65535;f=b>>>0<f>>>0?f:b;while(1)if((b|0)==(f|0)){v[c+13|0]=y[e+57|0]>>>4;b=y[c+12|0];v[e|0]=0;b=(b|0)!=0;u=Io(e+40|0,g,e);G=d+480188|0;d:while(1){if((k|0)==(E|0)){ec(u);break c}e:{f:{f=Jb(x[u>>2],0);d=y[f|0];g:{if(!d){x[27524]=0;f=T(210,a|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break e}g=f<<24>>24;if((g|0)<0){x[27524]=0;f=T(210,a|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break e}H=Jb(x[u>>2],0),I=f,v[H|0]=I}v[e|0]=0;h:{i:{f=g&63;if(!f){break i}x[27524]=0;i=T(210,a|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break h}v[e|0]=i;j:{k:{switch(f-1|0){case 0:v[c+12|0]=0;v[e+36|0]=1;H=c,I=y[mf(e+36|0,e)|0],v[H+14|0]=I;v[c+15|0]=0;break j;case 1:if(!i){break i}v[c+15|0]=i;v[c+12|0]=1;b=y[c+13|0];if(!b){break j}v[c+14|0]=D(D(b,i),15);break j;case 2:v[c+13|0]=i>>>4;if(i>>>0>=16){b=y[c+12|0];i=0;x[e+36>>2]=0;x[e+32>>2]=0;s=0;if(b){break g}break f}i=0;v[c+12|0]=0;x[e+36>>2]=0;x[e+32>>2]=0;s=0;if(b&1){break g}break f;case 3:s=0;x[e+36>>2]=0;x[e+32>>2]=0;if(b&1){break g}break f;case 5:if(!i){break i}b=(y[c+12|0]?15:14)+c|0;d=y[b|0];v[b|0]=d>>>0>=256-i>>>0?-1:d+i|0;break j;case 6:break k;default:break i}}if(!i){break i}b=(y[c+12|0]?15:14)+c|0;d=y[b|0];v[b|0]=d>>>0<=i+1>>>0?1:d-i|0}i=0;x[e+36>>2]=0;x[e+32>>2]=0;break g}i=0;x[e+36>>2]=0;x[e+32>>2]=0;s=0;if(b&1){break g}break f}break e}v[f|0]=d-1;i=0;x[e+36>>2]=0;x[e+32>>2]=0;s=0;if(!(b&1)){break f}}d=y[c+13|0];b=y[c+12|0];if(b){s=0;if(!d){break f}}l:{if(b){x[e>>2]=1;x[e+24>>2]=D(d,y[c+15|0])<<1;d=x[Ve(e,e+24|0)>>2];break l}d=D(y[c+14|0],30)+30|0}b=255;f=0;m=0;while(1){m:{if(b){g=D(b,d);m=(g|0)/48|0;if(g-1536>>>0>=10752){break m}f=b}x[e+32>>2]=m;x[e+36>>2]=f;re(e+32|0,32,255);s=1;x[e>>2]=1;H=c,I=x[Ve(e,e+36|0)>>2],v[H+16|0]=I;break f}b=b-1|0;continue}}B=k-1|0;C=1;b=Xb(x[q>>2],o);b=hd(x[b>>2],x[x[b+48>>2]+12>>2],k,1);while(1){h=C&65535;if(h>>>0>F>>>0){if(s){ue(Xb(x[q>>2],o),Kh(zo(Te(Me(e,17,y[e+32|0]),k),0)));ue(Xb(x[q>>2],o),Kh(Te(Me(e,16,y[e+36|0]),k)))}if(i>>>0>=16){ue(Xb(x[q>>2],o),wX(Te(Me(e,20,i>>>4|224),k)))}b=i&15;if(b){ue(Xb(x[q>>2],o),wX(Te(Me(e,20,Bd((D(b,y[c+16|0])>>>0)/15&255,1,15)|96),k)))}k=k+1|0;b=0;continue d}n:{o:{p:{q:{r:{f=Jb(x[u>>2],h);d=y[f|0];if(!d){x[27524]=0;f=T(210,a|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break e}g=f<<24>>24;if((g|0)<0){x[27524]=0;f=T(210,a|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break e}H=Jb(x[u>>2],h),I=f,v[H|0]=I}m=1;l=g&255;if(l&64){x[27524]=0;f=T(210,a|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break e}v[b+1|0]=f;m=!f}if(!(l&32)){f=y[b|0];break r}x[27524]=0;f=T(210,a|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break e}v[b|0]=f;if((f-1&255)>>>0<=107){d=El(f+24|0);v[b|0]=d;H=Hd(x[c>>2],h),I=d,v[H+1|0]=I;f=y[b|0];break o}if((f+127&255)>>>0<=107){d=El((f&127)+24|0);H=Hd(x[c>>2],h),I=d,v[H|0]=I;v[b|0]=0;break q}if((f|0)!=255){break r}f=254;break p}v[f|0]=d-1;break n}if(f&255){break o}}if(!y[b+1|0]){f=0;break o}f=y[Hd(x[c>>2],h)+1|0];v[b+1|0]=0}v[b|0]=f}if(Wc(f)){H=Hd(x[c>>2],h),I=0,v[H+5|0]=I}v[e+23|0]=0;v[e+22|0]=0;if(l&16){v[b+2|0]=1;x[27524]=0;f=T(210,a|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break e}v[b+4|0]=f+2>>>2}f=0;A=0;t=0;s:{if(!(l&8)){break s}x[27524]=0;g=T(210,a|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break e}x[27524]=0;t=T(210,a|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break e}t:{switch(g-1|0){case 0:v[b|0]=254;break s;case 1:v[b|0]=255;break s;case 2:d=Hd(x[c>>2],h);v[b|0]=y[d+1|0];v[d+5|0]=0;break s;case 3:d=Yu(t,y[c+16|0]);t=d?d|-48:0;A=d?20:0;if(y[b|0]){break s}d=Hd(x[c>>2],h);v[b|0]=y[d+1|0];v[d+5|0]=0;break s;case 4:v[e|0]=1;H=e,I=Yu(t,y[c+16|0]),v[H+24|0]=I;t=y[mf(e,e+24|0)|0];H=Hd(x[c>>2],h),I=0,v[H+5|0]=I;A=15;break s;case 5:case 6:case 7:case 8:u:{if(!k){break u}if((g|0)==y[Hd(x[c>>2],h)+4|0]){break u}if(!ue(Xb(x[q>>2],o),Pm(zo(Te(Me(e,20,(g+122|160)&255),B),h)))){break u}H=Hd(x[c>>2],h),I=g,v[H+4|0]=I}d=Hd(x[c>>2],h);if(!y[b|0]){v[b|0]=y[d+1|0]}v[d+5|0]=0;A=10;break s;case 9:break t;default:break s}}d=Hd(x[c>>2],h);g=y[d+5|0];v[d+5|0]=g^1;t=g?-98:-97;A=20}v:{w:{x:{if(!(l&4)){break x}x[27524]=0;r=T(210,a|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break e}x[27524]=0;j=T(210,a|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break e}v[e+23|0]=j;g=1;f=1;y:{switch(r-1|0){case 0:gC(e,j<<24>>24<<3,128);d=y[b|0];if(Wc(d)){H=b,I=El(d+x[e>>2]|0),v[H|0]=I}v[e+23|0]=y[e+4|0]^128;f=35;break x;case 1:d=Yu(j,y[c+16|0]);v[e+23|0]=d;if(!d){break w}v[e+23|0]=d|208;f=20;break v;case 3:case 4:H=e,I=uX(j,y[c+16|0],1),v[H+23|0]=I;f=(r|0)==4?2:3;break v;case 5:if(!y[b|0]){H=b,I=y[Hd(x[c>>2],h)|0],v[H|0]=I}H=e,I=uX(j,y[c+16|0],0),v[H+23|0]=I;f=4;break v;case 6:H=b,I=El(j+25|0),v[H|0]=I;v[e+23|0]=255;f=4;break v;case 7:case 8:case 9:z:{if(!k){break z}if((r|0)==y[Hd(x[c>>2],h)+2|0]){break z}if(!ue(Xb(x[q>>2],o),Pm(zo(Te(Me(e,20,(r-8|48)&255),B),h)))){break z}H=Hd(x[c>>2],h),I=r,v[H+2|0]=I}H=e,I=fC(j,y[c+16|0]),v[H+23|0]=I;f=5;break v;case 10:H=e,I=tX(j,y[c+16|0]),v[H+23|0]=I;f=18;break v;case 11:d=Yu(j,y[c+16|0]);v[e+23|0]=d;if(d){v[e+23|0]=d|192;f=20;break v}v[b|0]=254;break w;case 2:break v;default:break y}}f=0}g=0;break v}f=0}n=0;r=1;A:{if(l&2){x[27524]=0;j=T(210,a|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break e}x[27524]=0;l=T(210,a|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break e}v[e+22|0]=l;n=9;r=0;d=0;B:{switch(j-1|0){case 0:case 1:d=1;H=e,I=sX(l,y[c+16|0],(j|0)==1),v[H+22|0]=I;n=11;break A;case 2:H=e,I=tX(l,y[c+16|0]),v[H+22|0]=I;d=1;n=18;break A;case 3:case 4:case 5:C:{if(!k){break C}if((j|0)==y[Hd(x[c>>2],h)+3|0]){break C}if(!ue(Xb(x[q>>2],o),Pm(zo(Te(Me(e,20,(j-4|64)&255),B),h)))){break C}H=Hd(x[c>>2],h),I=j,v[H+3|0]=I}H=e,I=fC(l,y[c+16|0]),v[H+22|0]=I;d=1;n=8;break A;case 7:case 8:H=e,I=sX(l,y[c+16|0],(j|0)==8),v[H+22|0]=I;d=1;n=29;break A;case 9:H=e,I=fC(l,y[c+16|0]),v[H+22|0]=I;d=1;n=27;break A;case 6:break A;default:break B}}n=0;r=1}d=0}if(g){rX(b,k,z[G>>1],f,e+23|0)}if(d){rX(b,k,z[G>>1],n,e+22|0)}D:{E:{F:{G:{H:{if(!m){break H}if(!Wc(y[b|0])){break H}if(!f){break G}if(!r|(f|0)==4){break H}v[e+22|0]=255;n=4}d=b+2|0;if(y[b+2|0]!=1){break D}if(f){break F}v[e+23|0]=y[b+4|0];f=13;break E}v[e+23|0]=255;d=b+2|0;f=4;if(y[b+2|0]!=1){break D}}if(n){break D}v[e+22|0]=y[b+4|0];n=13}v[d|0]=0}g=Bg(e);Fo(e+24|0,g,f,y[e+23|0],n,y[e+22|0]);I:{if(y[d|0]){break I}f=y[e+2|0];if(!f){break I}v[b+2|0]=f;v[b+4|0]=y[e+4|0]}m=y[e+3|0];J:{if(A){Fo(e+24|0,g,m&255,y[e+5|0],A,t&255);K:{if(y[d|0]){break K}d=y[e+2|0];if(!d){break K}v[b+2|0]=d;v[b+4|0]=y[e+4|0]}m=y[e+3|0];break J}if(!(m&255)){break n}}v[b+3|0]=m;v[b+5|0]=y[e+5|0]}b=b+6|0;C=C+1|0;continue}}break}a=P()|0;ec(u);S(a|0);p()}else{v[m+D(b,6)|0]=254;b=b+1|0;continue}}ib=e- -64|0;return o|0}function QZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,w=0,B=0;e=ib-1472|0;ib=e;yc(b);ap(a);a:{b:{c:{if(!Cr(b,e+1448|0)){break c}if(!DE(e+1448|0)){break c}if(!c){j=1;break c}if(!Br(x[b>>2],z[e+1466>>1]|z[e+1468>>1]<<16)){break c}if(!Br(x[b>>2],(z[e+1466>>1]|z[e+1468>>1]<<16)+(z[e+1460>>1]<<2)|0)){break c}ew(a);w=e,B=dw(),x[w+72>>2]=B;c=e+72|0;cw(_j(x[a+4>>2])+32|0,c);Ar(c);m=x[_j(x[a+4>>2])+32>>2];x[e+1444>>2]=z[e+1462>>1]|z[e+1464>>1]<<16;w=e,B=bh(x[b>>2]),x[w+1184>>2]=B;x[e+1144>>2]=214748364;d=e+1184|0;w=e,B=D(x[Hb(d,e+1144|0)>>2],20),x[w+72>>2]=B;wn(m,x[Hb(e+1444|0,c)>>2]);Rb(d,0,256);s=Nb(e+1168|0);while(1){d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{j=z[e+1460>>1]<=t>>>0;if(!j){x[27524]=0;c=Q(159,b|0,(z[e+1466>>1]|z[e+1468>>1]<<16)+(t<<2)|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break s}if(!c){break h}c=x[b+8>>2];d=x[b>>2];x[27524]=0;c=W(160,d|0,c|0,4)|0;d=x[27524];x[27524]=0;if((d|0)==1){break s}if(!c){break h}x[27524]=0;c=T(161,b|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break r}x[27524]=0;d=Q(159,b|0,c|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break r}if(!d){break h}x[27524]=0;d=Q(162,b|0,e+1144|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break q}if(!d){break h}x[27524]=0;d=W(163,b|0,s|0,z[e+1156>>1])|0;f=x[27524];x[27524]=0;if((f|0)==1){break q}if(!d){break h}f=x[s>>2];g=x[b>>2];x[27524]=0;d=z[e+1156>>1];g=T(164,g|0)|0;i=x[27524];x[27524]=0;if((i|0)==1){break p}i=c+20|0;if(g>>>0<=i+(d<<3)>>>0){break h}c=d?f:0;f=z[e+1156>>1];g=i+(f<<3)|0;d=0;i=z[e+1158>>1];if(!(i&1)){while(1){if(d>>>0>=f>>>0){break d}if(!c){break h}f=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);i=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[27524]=0;f=fa(165,i|0,f|0,m|0,x[e+1444>>2])|0;i=x[27524];x[27524]=0;if((i|0)==1){break o}if(!f){break h}x[27524]=0;f=Q(159,b|0,g|0)|0;i=x[27524];x[27524]=0;if((i|0)==1){break o}if(!f){break h}f=dc(e+1136|0,Jb(x[m>>2],y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24)),y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24));i=x[f+4>>2];f=x[f>>2];x[27524]=0;tn(166,e+72|0,b,f,i);f=x[27524];x[27524]=0;if((f|0)==1){break n}if(x[e+76>>2]!=(y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24))){break h}d=d+1|0;c=c+8|0;f=z[e+1156>>1];continue}}t:{if(i&4){if(!c){break h}d=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);f=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[27524]=0;d=fa(165,f|0,d|0,m|0,x[e+1444>>2])|0;f=x[27524];x[27524]=0;if((f|0)==1){break m}if(!d){break h}n=Jb(x[m>>2],y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24));l=(y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24))&-2;if(!l){break h}x[27524]=0;f=z[e+1162>>1];d=Q(159,b|0,g+z[e+1160>>1]|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break l}if(!d){break h}d=x[b+8>>2];g=x[b>>2];x[27524]=0;d=W(160,g|0,d|0,x[e+1148>>2]-z[e+1160>>1]|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break l}if(!d){break h}x[27524]=0;U(167,e+48|0,b|0,x[e+1148>>2]-z[e+1160>>1]|0);d=x[27524];x[27524]=0;if((d|0)==1){break b}d=e+48|0;k=zr(e+72|0,d);yb(d);r=0;i=0;while(1){g=0;u:{while(1){if(z[e+1156>>1]<=(i&65535)>>>0){break e}x[27524]=0;d=Q(168,k|0,f+1|0)|0;h=x[27524];x[27524]=0;if((h|0)==1){break u}h=f&15;o=z[(h<<1)+25984>>1];v:{w:{if(o>>>0<=d>>>0){x[27524]=0;h=y[h+26032|0];q=Q(168,k|0,h|0)|0;u=x[27524];x[27524]=0;if((u|0)==1){break u}d=q+(d-o<<h)|0;if((d|0)!=(f|0)){f=d&15;break v}x[27524]=0;d=Q(168,k|0,4)|0;h=x[27524];x[27524]=0;if((h|0)==1){break u}if((d|0)==15){x[27524]=0;h=Q(168,k|0,1)|0;d=x[27524];x[27524]=0;if((d|0)==1){break u}d=65535;if(!h){break w}break e}d=d+65520|0}if(d>>>0>65535){break v}}d=d&1?0-(d+1>>>1|0)|0:d>>>1|0;q=g+n|0;h=z[e+1158>>1];x:{if(h&2){r=d+r|0;d=r;break x}d=h&512?d:d^32768}o=d>>>8|0;h=h&1024;v[q+1|0]=h?d:o;v[q|0]=h?o:d;g=g+2|0}if(g>>>0<l>>>0){continue}break}i=i+1|0;if(i>>>0>=z[e+1156>>1]){break e}d=(i<<3)+c|0;g=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);l=y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24);x[27524]=0;g=fa(165,g|0,l|0,m|0,x[e+1444>>2])|0;l=x[27524];x[27524]=0;if((l|0)==1){break u}if(!g){break t}l=(y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24))&-2;if(!l){break t}n=Jb(x[m>>2],y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24));continue}break}j=V(30496)|0;if((jb|0)==(da(30496)|0)){_(j|0)|0;x[27524]=0;Z(18);c=x[27524];x[27524]=0;if((c|0)!=1){break e}j=P()|0}yb(k);break a}if(!c){break h}d=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);f=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[27524]=0;d=fa(165,f|0,d|0,m|0,x[e+1444>>2])|0;f=x[27524];x[27524]=0;if((f|0)==1){break k}if(!d){break h}r=Jb(x[m>>2],y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24));if(z[e+1160>>1]>256){break h}n=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);f=z[e+1162>>1];x[27524]=0;d=Q(159,b|0,g|0)|0;g=x[27524];x[27524]=0;y:{z:{if((g|0)!=1){if(!d){break h}d=dc(e+40|0,e+1184|0,z[e+1160>>1]);g=x[d+4>>2];d=x[d>>2];x[27524]=0;tn(169,e+72|0,b,d,g);d=x[27524];x[27524]=0;if((d|0)==1){break z}d=z[e+1160>>1];if(d>>>0>A[e+76>>2]){break h}g=x[b+8>>2];i=x[b>>2];x[27524]=0;d=W(160,i|0,g|0,x[e+1148>>2]-d|0)|0;g=x[27524];x[27524]=0;if((g|0)!=1){break y}}j=P()|0;break a}j=P()|0;break a}if(!d){break h}x[27524]=0;U(167,e+48|0,b|0,x[e+1148>>2]-z[e+1160>>1]|0);d=x[27524];x[27524]=0;if((d|0)==1){break f}d=e+48|0;k=zr(e+72|0,d);yb(d);l=0;i=0;while(1){g=0;A:{while(1){if(z[e+1156>>1]<=(l&65535)>>>0){break g}x[27524]=0;d=Q(168,k|0,f+1|0)|0;h=x[27524];x[27524]=0;if((h|0)==1){break A}h=f&7;o=y[h+26016|0];B:{C:{if(o>>>0<=d>>>0){x[27524]=0;h=y[h+26024|0];q=Q(168,k|0,h|0)|0;u=x[27524];x[27524]=0;if((u|0)==1){break A}d=q+(d-o<<h)|0;if((d|0)!=(f|0)){f=d&7;break B}x[27524]=0;d=Q(168,k|0,3)|0;h=x[27524];x[27524]=0;if((h|0)==1){break A}if((d|0)==7){x[27524]=0;h=Q(168,k|0,1)|0;d=x[27524];x[27524]=0;if((d|0)==1){break A}d=255;if(!h){break C}break g}d=d+248|0}if(d>>>0>255){break B}}d=y[(e+1184|0)+d|0];h=d+i|0;q=d;d=z[e+1158>>1]&2;v[g+r|0]=d?h:q;i=d?h:i;g=g+1|0}if(g>>>0<n>>>0){continue}break}l=l+1|0;if(l>>>0>=z[e+1156>>1]){break g}d=(l<<3)+c|0;g=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);n=y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24);x[27524]=0;g=fa(165,g|0,n|0,m|0,x[e+1444>>2])|0;n=x[27524];x[27524]=0;if((n|0)==1){break A}if(!g){break j}n=y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24);r=Jb(x[m>>2],y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24));continue}break}j=V(30496)|0;if((jb|0)==(da(30496)|0)){_(j|0)|0;x[27524]=0;Z(18);c=x[27524];x[27524]=0;if((c|0)!=1){break g}j=P()|0}yb(k);break a}yb(k);break h}he(e+24|0,x[m>>2],x[m+4>>2]);lg(e+32|0,x[e+24>>2],x[e+28>>2]);b=Id(e+16|0);x[27524]=0;c=x[b+4>>2];x[e+8>>2]=x[b>>2];x[e+12>>2]=c;b=Mg(170,e+72|0,x[e+32>>2],x[e+36>>2],e+8|0);c=x[27524];x[27524]=0;if((c|0)==1){break i}fd(_j(x[a+4>>2])+12|0,b);yb(b);break h}j=P()|0;break a}j=P()|0;break a}j=P()|0;break a}j=P()|0;break a}j=P()|0;break a}j=P()|0;break a}j=P()|0;break a}j=P()|0;break a}j=P()|0;break a}yb(k);break h}j=P()|0;break a}we(s);break c}yb(k);break d}j=P()|0;break a}yb(k)}t=t+1|0;continue}}ib=e+1472|0;return j|0}j=P()|0}we(s);S(j|0);p()}function Dja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0,F=0,G=0;d=ib-1344|0;ib=d;yc(b);e=ib-16|0;ib=e;ZT(e+8|0,d+232|0);h=x[e+12>>2];kc(e,x[b>>2],x[b+8>>2],x[e+8>>2],x[e+12>>2]);j=x[e+4>>2];if((j|0)==(h|0)){Yb(b,x[e+12>>2])}ib=e+16|0;a:{if((h|0)!=(j|0)){break a}if(!$T(d+232|0)){break a}if(!Ob(x[b>>2],x[b+8>>2],Ec(_T(x[d+1336>>2]),kb))){break a}if(!c){l=1;break a}yc(b);b=te(d+232|0,b);x[27524]=0;R(624,d+216|0,b|0);e=x[27524];x[27524]=0;b:{c:{d:{e:{f:{g:{h:{i:{if((e|0)!=1){yb(b);x[27524]=0;U(625,d+200|0,d+216|0,1196314451);b=x[27524];x[27524]=0;if((b|0)==1){break i}x[27524]=0;U(625,d+184|0,d+216|0,1280331091);b=x[27524];x[27524]=0;if((b|0)==1){break h}if(pc(x[d+200>>2],x[d+204>>2])){break b}if(!pc(x[d+184>>2],x[d+188>>2])){break g}break b}c=P()|0;yb(b);break d}c=P()|0;break e}c=P()|0;break f}x[27524]=0;R(250,a|0,1);b=x[27524];x[27524]=0;j:{k:{l:{m:{if((b|0)!=1){gg(a);x[a+480188>>2]=4;x[a+480208>>2]=25231360;F=d,G=Cb(x[d+184>>2]),x[F+48>>2]=G;g=c&2;m=Cb(x[d+188>>2]);e=a+480190|0;n:{o:{while(1){h=x[d+48>>2];if(!Mb(h,m)){break o}b=z[e>>1];if(!bi(b)){break o}b=b+1|0;w[e>>1]=b;x[27524]=0;b=D(b&65535,104)+a|0;j=b+484380|0;R(281,j|0,1);i=x[27524];x[27524]=0;p:{q:{if((i|0)!=1){x[27524]=0;i=Q(626,h|0,d+232|0)|0;l=x[27524];x[27524]=0;if((l|0)==1){break q}if(!i){break c}if(nu(d+232|0)){break p}break c}c=P()|0;break j}c=P()|0;break j}x[27524]=0;i=Q(55,d+168|0,d+232|0)|0;l=x[27524];x[27524]=0;if((l|0)==1){break n}Cc(((z[e>>1]<<5)+a|0)+946304|0,i);wb(i);i=x[d+268>>2];x[j>>2]=i;x[b+484388>>2]=i;x[b+484384>>2]=x[d+264>>2];i=b+484414|0;w[i>>1]=z[i>>1]|2;w[b+484410>>1]=255;r:{if(g){b=Zc(d+16|0,8,1,0,0);x[27524]=0;W(223,b|0,j|0,h|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break r}}Uf(d+48|0);continue}break}c=P()|0;break j}F=d,G=Cb(x[d+200>>2]),x[F+160>>2]=G;s=a+484344|0;t=c&1;u=a+484360|0;E=Cb(x[d+204>>2]);o=a+484376|0;q=a+480190|0;A=a+484380|0;B=a+946304|0;c=1;l=1;while(1){s:{t:{u:{v:{w:{x:{b=x[d+160>>2];if(!Mb(b,E)){break x}if(!(c&1)){x[27524]=0;c=T(276,u|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break w}if(!c){break x}}Ic(Tb(x[a+484360>>2],y[o|0]));x[27524]=0;c=Q(627,b|0,d+232|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break v}if(!(c&!z[d+1318>>1])|x[d+1320>>2]-5>>>0<4294967292){break c}c=y[o|0];e=x[a+484360>>2];x[27524]=0;U(5,d+48|0,4,d+232|0);h=x[27524];x[27524]=0;if((h|0)==1){break k}x[27524]=0;R(277,Tb(e,c)|0,d+48|0);c=x[27524];x[27524]=0;if((c|0)==1){break l}xb(d+48|0);y:{if(t){x[27524]=0;U(194,d+48|0,b|0,x[d+1328>>2]);b=x[27524];x[27524]=0;if((b|0)!=1){break y}c=P()|0;break j}x[27524]=0;b=T(178,d+112|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break m}nE(d+48|0,b)}b=d+48|0;m=hc(d+136|0,b);yb(b);if(!t){yb(d+112|0)}Rb(d+48|0,0,64);c=1;z:{A:{B:{while(1){if((c|0)==32){break B}b=(D(c,34)+d|0)+198|0;e=b+32|0;Xm(d,e);C:{D:{if(Bj(y[x[d>>2]])){break D}h=y[b- -64|0];if(h>>>0>15){break A}b=y[b+65|0];if(b>>>0>64){break A}if(!nu(e)){break A}j=b<<2;i=h<<4;h=0;b=1;E:{while(1){g=b&65535;e=z[q>>1];if(g>>>0>e>>>0){break E}x[27524]=0;U(528,d+16|0,x[d>>2],x[d+4>>2]);e=x[27524];x[27524]=0;if((e|0)==1){break C}e=ib-32|0;ib=e;k=d+16|0;ye(e+24|0,k);XT(e+16|0,((g<<5)+a|0)+946304|0);f=x[e+20>>2];x[e+8>>2]=x[e+16>>2];x[e+12>>2]=f;f=x[e+24>>2];r=x[e+12>>2];n=x[e+28>>2];if((r|0)==(n|0)){f=(CV(f,n,x[e+8>>2],r)|0)!=0}else{f=1}ib=e+32|0;wb(k);F:{G:{if(f){break G}F=bc(d+48|0,c),G=b,w[F>>1]=G;e=D(g,104)+a|0;g=e+484410|0;f=z[g>>1];if((f|0)==255){break F}h=b;if(y[e+484417|0]!=(i&255)){break G}if((f|0)==(j|0)){break F}}b=b+1|0;continue}break}v[e+484417|0]=i;w[g>>1]=j;break D}h=h&65535;if(!h){break D}if(!bi(e)){break D}b=e+1|0;w[q>>1]=b;F=bc(d+48|0,c),G=b,w[F>>1]=G;b=D(z[q>>1],104)+A|0;Jm(b);e=D(h,104)+A|0;g=no(b,e);w[b+30>>1]=j;v[b+37|0]=i;QU(g,e);e=(h<<5)+B|0;h=x[e+4>>2];b=(z[q>>1]<<5)+B|0;x[b>>2]=x[e>>2];x[b+4>>2]=h;h=x[e+28>>2];x[b+24>>2]=x[e+24>>2];x[b+28>>2]=h;h=x[e+20>>2];x[b+16>>2]=x[e+16>>2];x[b+20>>2]=h;h=x[e+12>>2];x[b+8>>2]=x[e+8>>2];x[b+12>>2]=h}c=c+1|0;continue}break}break u}i=0;x[d+40>>2]=0;x[d+32>>2]=0;x[d+36>>2]=0;x[d+24>>2]=0;x[d+28>>2]=0;x[d+16>>2]=0;x[d+20>>2]=0;e=64;j=65535;r=z[d+1320>>1];h=0;H:while(1){I:{if(h){break I}b=x[m>>2];x[27524]=0;b=W(160,b|0,x[d+144>>2],1)|0;c=x[27524];x[27524]=0;if((c|0)==1){break z}if(b){break I}c=j;b=e;break t}b=e+1|0;J:{if(e>>>0<63){e=b;break J}x[27524]=0;j=Q(363,s|0,64)|0;c=x[27524];x[27524]=0;if((c|0)==1){break z}c=65535;if((j|0)==65535){break t}b=y[o|0];c=x[a+484360>>2];e=0;x[27524]=0;R(526,Tb(c,b)|0,j|0);b=x[27524];x[27524]=0;if((b|0)==1){break z}}b=0;c=Xb(x[s>>2],j&65535);c=hd(x[c>>2],x[x[c+48>>2]+12>>2],e,0);while(1){if((b|0)==(r|0)){continue H}g=(d+16|0)+D(b,7)|0;f=y[g+6|0];K:{if(f){v[g+6|0]=f-1;f=y[g+4|0]|y[g+5|0]<<8;v[c+4|0]=f;v[c+5|0]=f>>>8;g=y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24);v[c|0]=g;v[c+1|0]=g>>>8;v[c+2|0]=g>>>16;v[c+3|0]=g>>>24;h=h-1|0;break K}f=x[m>>2];x[27524]=0;f=W(160,f|0,x[d+144>>2],1)|0;k=x[27524];x[27524]=0;if((k|0)==1){break u}if(!f){break K}if(x[d+144>>2]==x[d+1324>>2]){i=Tb(x[a+484360>>2],y[o|0]);_e(i,jC(x[i>>2],x[i+4>>2]));i=e}x[27524]=0;f=T(210,m|0)|0;k=x[27524];x[27524]=0;L:{if((k|0)!=1){f=f<<24>>24;if((f|0)>=0){break L}f=f&127;v[g+6|0]=f;k=y[g+4|0]|y[g+5|0]<<8;v[c+4|0]=k;v[c+5|0]=k>>>8;g=y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24);v[c|0]=g;v[c+1|0]=g>>>8;v[c+2|0]=g>>>16;v[c+3|0]=g>>>24;h=f+h|0;break K}break u}if((f-1&255)>>>0<=35){v[c|0]=f+48}x[27524]=0;f=T(210,m|0)|0;k=x[27524];x[27524]=0;M:{N:{if((k|0)!=1){f=f<<24>>24;F=c,G=y[bc(d+48|0,f&31)|0],v[F+1|0]=G;if((f|0)>=0){break N}v[c+3|0]=y[g+3|0];v[c+5|0]=y[g+5|0];break M}break u}x[27524]=0;R(264,d|0,m|0);f=x[27524];x[27524]=0;O:{if((f|0)!=1){f=y[d|0];if(f>>>0>19){break M}n=f<<1;C=y[n+26960|0];v[c+3|0]=C;k=y[Lc(d)|0];v[c+5|0]=k;if((C|0)!=16|k>>>0<32){break O}v[c+3|0]=17;break M}break u}if(819137>>>f&1){break M}v[c+5|0]=y[n+26961|0]|k&15}f=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[g|0]=f;v[g+1|0]=f>>>8;v[g+2|0]=f>>>16;v[g+3|0]=f>>>24;f=y[c+4|0]|y[c+5|0]<<8;v[g+4|0]=f;v[g+5|0]=f>>>8}c=c+6|0;b=b+1|0;continue}}}l=0;break s}break u}Lj(u,0);x[27524]=0;b=Q(1,d+232|0,6470)|0;c=x[27524];x[27524]=0;P:{if((c|0)!=1){Gb(a+1298344|0,b);xb(b);x[27524]=0;b=Q(1,d+48|0,6772)|0;c=x[27524];x[27524]=0;if((c|0)==1){break P}Gb(a+1298356|0,b);xb(b);x[a+1298404>>2]=4;l=1;break b}c=P()|0;break j}c=P()|0;break j}c=P()|0;break j}c=P()|0;break j}c=P()|0;yb(m);break j}Q:{if(!((i|0)!=0|b>>>0<63)){break Q}c=c&65535;if((c|0)==65535){break Q}ue(Xb(x[s>>2],c),Kh(Te(Me(d,14,i&255),b)))}c=32}yb(m);if(c>>>0<32){break b}Uf(d+160|0);c=0;continue}}c=P()|0;break j}c=P()|0;break j}c=P()|0;break j}c=P()|0;xb(d+48|0);break j}c=P()|0}Sc(d+184|0)}Sc(d+200|0)}Zd(d+216|0)}S(c|0);p()}l=0}Sc(d+184|0);Sc(d+200|0);Zd(d+216|0)}ib=d+1344|0;return l|0}function Ina(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;e=ib-288|0;ib=e;yc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if(!AX(b,e+216|0)){break p}if(!BX(e+216|0)){break p}if(!c){d=1;break p}zd(a,131072);d=ib-16|0;ib=d;i=e+128|0;f=xc(d,3913);$c(i,f);xb(f);ib=d+16|0;x[27524]=0;U(309,e+176|0,i|0,e+216|4);d=x[27524];x[27524]=0;q:{if((d|0)!=1){d=e+176|0;Gb(a+1298344|0,d);xb(d);i=e+128|0;$b(i);f=xc(d,11054);Gb(a+1298356|0,f);xb(f);x[a+1298404>>2]=4;rC(i,3,e+229|0);Fc(d,i);Ac(a+1298308|0,d);wb(d);f=e+104|0;Hj(f,3,e+259|0);Fc(i,f);x[27524]=0;U(11,d|0,4,i|0);d=x[27524];x[27524]=0;if((d|0)==1){break b}d=e+176|0;Gb(a+1298320|0,d);xb(d);wb(e+128|0);d=Bo(d);o=d,q=Bd(y[e+279|0],1,31),x[o+8>>2]=q;o=d,q=Bd(y[e+280|0],1,12),x[o+4>>2]=q;x[d>>2]=y[e+281|0]+1900;i=a+1298412|0;Ic(i);kC(i,d);g=e+136|0;i=Nb(e+160|0);r:{s:{t:{while(1){d=x[b+8>>2];f=x[b>>2];x[27524]=0;d=W(160,f|0,d|0,8)|0;f=x[27524];x[27524]=0;u:{v:{w:{x:{y:{if((f|0)!=1){if(!d){break r}x[27524]=0;R(310,b|0,e- -64|0);d=x[27524];x[27524]=0;if((d|0)==1){break y}d=x[e+68>>2];z:{l=y[e+220|0];switch(l-3|0){case 1:break x;case 0:break z;default:break w}}f=2;if(x[e+64>>2]!=1431389523){break v}break u}b=P()|0;break c}b=P()|0;break c}f=4;if(x[e+64>>2]!=1431389523){break v}break u}f=0;if(l>>>0>7){break u}}d=x[e+64>>2]==1146113363?-1:d;f=0}l=x[e+68>>2];x[e+128>>2]=x[e+64>>2];x[e+132>>2]=l;x[27524]=0;U(194,e+104|0,b|0,d|0);d=x[27524];x[27524]=0;if((d|0)==1){break t}hc(g,e+104|0);x[27524]=0;R(311,i|0,e+128|0);d=x[27524];x[27524]=0;if((d|0)==1){break s}yd(e+128|0);yb(e+104|0);x[27524]=0;Q(192,b|0,f|0)|0;d=x[27524];x[27524]=0;if((d|0)!=1){continue}break}b=P()|0;break c}b=P()|0;break c}b=P()|0;yd(e+128|0);yb(e+104|0);break c}x[27524]=0;l=T(178,e+128|0)|0;b=x[27524];x[27524]=0;A:{B:{C:{if((b|0)!=1){x[27524]=0;U(312,e+104|0,i|0,1431389523);b=x[27524];x[27524]=0;if((b|0)==1){break C}d=e+104|0;b=fd(l,d);yb(d);w[e+102>>1]=0;w[e+100>>1]=65534;if(y[e+220|0]<3){break A}x[27524]=0;d=T(198,b|0)|0;f=x[27524];x[27524]=0;if((f|0)!=1){break B}break e}b=P()|0;break c}b=P()|0;break d}w[e+102>>1]=d;if(y[e+220|0]<4){break A}x[27524]=0;d=T(198,b|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break e}w[e+100>>1]=y[e+220|0]==4?d?d:-2:d}d=y[a+484376|0];f=x[a+484360>>2];x[27524]=0;g=T(206,b|0)|0;h=x[27524];x[27524]=0;if((h|0)==1){break e}x[27524]=0;U(242,Tb(f,d)|0,b|0,g>>>1|0);d=x[27524];x[27524]=0;if((d|0)==1){break e}d=Tb(x[a+484360>>2],y[a+484376|0]);d=jC(x[d>>2],x[d+4>>2]);Mf(e+102|0,d);Mf(e+100|0,d);x[27524]=0;U(312,e+104|0,i|0,1414807888);d=x[27524];x[27524]=0;if((d|0)==1){break h}d=e+104|0;b=fd(b,d);yb(d);d=x[b>>2];x[27524]=0;d=T(182,d|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break e}if(!(c&1)|d^1){break q}x[27524]=0;R(313,b|0,e|0);d=x[27524];x[27524]=0;if((d|0)==1){break i}o=a+480188|0,q=Bd(y[e+2|0],1,32)+1|0,w[o>>1]=q;x[27524]=0;d=Q(222,e+88|0,z[e>>1])|0;f=x[27524];x[27524]=0;if((f|0)==1){break j}o=e,q=Cb(x[d>>2]),x[o+40>>2]=q;g=Cb(x[d+4>>2]);D:{E:{while(1){h=x[e+40>>2];if(!Mb(h,g)){f=z[a+480188>>1];x[27524]=0;f=Q(314,e+104|0,f|0)|0;g=x[27524];x[27524]=0;if((g|0)!=1){g=a+484376|0;h=Tb(x[a+484360>>2],y[g|0]);h=Gl(x[h>>2],x[h+4>>2]);x[27524]=0;k=a+484344|0;R(229,k|0,h|0);h=x[27524];x[27524]=0;if((h|0)==1){break g}g=Tb(x[a+484360>>2],y[g|0]);o=e,q=Cb(x[g>>2]),x[o+64>>2]=q;h=Cb(x[g+4>>2]);F:{while(1){G:{g=x[e+64>>2];if(!Mb(g,h)){g=y[a+484376|0];h=x[a+484360>>2];x[27524]=0;j=Tb(h,g);h=z[e+100>>1];g=Q(315,j|0,h|0)|0;j=x[27524];x[27524]=0;if((j|0)!=1){break G}break g}j=x[d>>2];n=Kf(j,x[d+4>>2]);m=z[g>>1];if(n>>>0>m>>>0){x[27524]=0;j=fa(316,Yg(j,m)|0,y[e+220|0],f|0,a|0)|0;m=x[27524];x[27524]=0;if((m|0)==1){break F}w[g>>1]=j}Ye(e- -64|0);continue}break}H:{if(!g){break H}g=Tb(x[a+484360>>2],y[a+484376|0]);j=z[e+102>>1];if(!j){if(jC(x[g>>2],x[g+4>>2])>>>0<=h>>>0){break H}}g=Xb(x[k>>2],z[bc(x[g>>2],h)>>1]);ue(g,Pm(Te(Me(e- -64|0,12,j&255),x[g+12>>2]-1|0)))}Ck(f);Sc(d);break q}break g}b=P()|0;break f}x[27524]=0;f=y[e+220|0]<3?9:8;Q(192,b|0,f-4|0)|0;k=x[27524];x[27524]=0;if((k|0)!=1){x[27524]=0;k=T(161,b|0)|0;j=x[27524];x[27524]=0;if((j|0)==1){break E}Gg(b,f);x[27524]=0;U(194,e- -64|0,b|0,f+k|0);f=x[27524];x[27524]=0;if((f|0)==1){break D}j=h;f=e- -64|0;h=hc(e+104|0,f);fd(j,h);yb(h);yb(f);Uf(e+40|0);continue}break}b=P()|0;break f}b=P()|0;break f}b=P()|0;break f}b=P()|0;$b(e+128|0);break a}x[27524]=0;U(312,e- -64|0,i|0,1196641603);d=x[27524];x[27524]=0;if((d|0)==1){break n}d=e- -64|0;b=fd(b,d);yb(d);d=x[b>>2];x[27524]=0;d=T(182,d|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break e}if(d){x[27524]=0;Q(192,b|0,1)|0;d=x[27524];x[27524]=0;if((d|0)==1){break e}x[27524]=0;d=T(206,b|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break e}x[27524]=0;ea(317,a+1298332|0,b|0,d|0,40,0);d=x[27524];x[27524]=0;if((d|0)==1){break e}}x[27524]=0;U(312,e- -64|0,i|0,1146113363);d=x[27524];x[27524]=0;if((d|0)==1){break k}x[27524]=0;U(312,e+40|0,i|0,1229999443);d=x[27524];x[27524]=0;if((d|0)==1){break o}d=e+40|0;b=fd(b,d);yb(d);x[27524]=0;d=T(210,b|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break m}h=a+480190|0;w[h>>1]=d;k=!(c&2);f=1;I:{while(1){J:{c=f&65535;if(c>>>0>(d&65535)>>>0){break I}d=30;K:{L:{M:{if(y[e+220|0]>=2){x[27524]=0;d=T(210,b|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break M}}x[27524]=0;U(318,b|0,((c<<5)+a|0)+946304|0,d|0);d=x[27524];x[27524]=0;if((d|0)==1){break M}x[27524]=0;R(319,b|0,e+24|0);d=x[27524];x[27524]=0;if((d|0)==1){break L}x[27524]=0;g=D(c,104)+a|0;j=g+484380|0;R(320,e+24|0,j|0);c=x[27524];x[27524]=0;if((c|0)==1){break L}d=y[e+220|0];if(d>>>0>=8){x[27524]=0;R(321,b|0,g+484423|0);c=x[27524];x[27524]=0;if((c|0)==1){break L}d=y[e+220|0]}x[27524]=0;Q(192,b|0,((d&255)>>>0>1?6:2)|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break L}x[27524]=0;c=T(161,e- -64|0)|0;d=x[27524];x[27524]=0;if((d|0)!=1){x[27524]=0;U(194,e|0,e- -64|0,c|0);c=x[27524];x[27524]=0;if((c|0)!=1){break K}}b=P()|0;break l}b=P()|0;break l}b=P()|0;break l}c=hc(e+40|0,e);yb(e);d=x[c>>2];x[27524]=0;d=T(182,d|0)|0;m=x[27524];x[27524]=0;if((m|0)!=1){N:{if(k|d^1){break N}d=Zc(e,w[g+484414>>1]&1?16:8,1,0,(y[e+39|0]&12)==4?7:0);x[27524]=0;W(223,d|0,j|0,c|0)|0;d=x[27524];x[27524]=0;if((d|0)!=1){break N}break J}yb(c);f=f+1|0;d=z[h>>1];continue}}break}b=P()|0;yb(c);break l}gg(a);x[a+480204>>2]=12e5;x[a+480208>>2]=24;x[a+480196>>2]=6;x[a+480200>>2]=256;x[a+480228>>2]=48;x[a+480232>>2]=48;x[27524]=0;d=1;W(268,a+1074312|0,114,1)|0;a=x[27524];x[27524]=0;if((a|0)==1){break m}yb(e- -64|0);yb(b);Zd(i)}ib=e+288|0;return d|0}b=P()|0;break l}b=P()|0;break d}b=P()|0}yb(e- -64|0);break d}b=P()|0;break d}b=P()|0;break d}b=P()|0;break d}b=P()|0;break d}b=P()|0;Ck(f)}Sc(d);break d}b=P()|0}yb(l)}Zd(i);break a}b=P()|0;wb(e+128|0)}S(b|0);p()}function dka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,Q=0,R=0,T=0,V=0,X=0,Y=0,Z=0,_=0,$=0,aa=0;d=ib-336|0;ib=d;a:{if(!bd(b,1080)){break a}if(!so(b,d+332|0)){break a}zd(a,1);m=CU(d+312|0);if(!BU(d+332|0,m)){break a}f=z[m+10>>1];if(!f|f>>>0>127){break a}if(!c){g=1;break a}s=a+480188|0;w[s>>1]=f;q=y[m+14|0];F=y[m+13|0];h=y[m+12|0];G=1;if(!qe(d+332|0,26890)){G=qe(d+332|0,26895)}if(y[m+15|0]){Lb(a+1074312|0,5,1);f=z[a+480188>>1]}g=d+332|0;t=qe(g,16704);e=1;if(!qe(g,17468)){e=qe(d+332|0,13544)}A=(f&65535)==8&(F|0)!=0;bd(b,0);vB(b,a+1298308|0,20);w[a+480190>>1]=31;l=(h|0)!=0;r=a+480188|0;g=1;f=t;while(1)if((g|0)==32){b:{c:{d:{e:{f:{g:{N=x[m+4>>2];if(N>>>0>=H>>>0){h=d+176|0;xU(b,h);bd(b,z[m+8>>1]);g=y[d+177|0];e=128;j=a+484376|0;Uq(Tb(x[a+484360>>2],y[j|0]),h|2,128);h=!g&f;k=h?k:0;f=y[d+176|0];h:{if(f>>>0>128){break h}e=f;if(f){break h}f=x[Tb(x[a+484360>>2],y[a+484376|0])>>2];g=128;while(1){e=g;if(e>>>0<2){e=1;break h}g=e-1|0;if(!z[bc(f,g)>>1]){continue}break}}o=wU(b,Tb(x[a+484360>>2],y[j|0]),e&65535,i,s,k,0);I=1;i:{if(!(h&z[a+480188>>1]==8)){I=(q|0)!=0;break i}x[m>>2]=11159}j:{if(!A){break j}f=Tb(x[a+484360>>2],y[a+484376|0]);$=d,aa=Cb(x[f>>2]),x[$+160>>2]=aa;h=Cb(x[f+4>>2]);while(1){f=x[d+160>>2];if(!Mb(f,h)){break j}w[f>>1]=z[f>>1]>>>1;Ye(d+160|0);continue}}f=a+484376|0;_e(Tb(x[a+484360>>2],y[f|0]),y[d+177|0]);O=e-1|0;e=y[d+177|0];k:{if((O&65535)>>>0>=e>>>0){g=z[s>>1];if((e|0)!=120|(g|0)!=4){break k}}_e(Tb(x[a+484360>>2],y[f|0]),0);g=z[a+480188>>1]}x[a+480260>>2]=56;x[a+480264>>2]=13696;x[a+480204>>2]=125e4;x[a+480196>>2]=6;k=0;x[a+480208>>2]=0;$=a,aa=Vb(256/((g&65535)>>>0)|0,32,128),x[$+480228>>2]=aa;uh(a,0);v[d+175|0]=0;l:{if(l&1){q=1;e=1;break l}q=1;e=0;l=0;h=t;m:while(1){n:{r=0;if(o>>>0<=(l&65535)>>>0){break n}g=0;while(1)if((g|0)==256){l=l+1|0;continue m}else{f=d+144|0;j=Bg(d+160|0);$u(f,b,j);i=Lc(f);n=OB(y[j|0]);o:{p:{q:{r:{j=y[d+144|0];if((j-7&255)>>>0<3){h=0;break r}f=y[i|0];if(!((j|0)!=14|f>>>0<=1)){h=0;break q}if(!((j|0)==15&(f&255)>>>0>31)){h=n?h:0;if((j|0)!=13){break r}r=r+1|0;if((r&65535)>>>0<2){break o}}h=0;break o}if((j|0)==8){break p}if((j|0)!=14){break o}f=y[i|0]}if((f&240)!=128){break o}v[d+80|0]=f<<4;$=d,aa=y[mf(d+175|0,d+80|0)|0],v[$+175|0]=aa;break o}$=d,aa=y[mf(d+175|0,i)|0],v[$+175|0]=aa;f=v[i|0];if((f|0)>=0){k=1;break o}e=(f|0)!=-92&f>>>0>4294967183|e}q=n&q;g=g+1|0;continue}}break}f=k^-1;k=0;k=(e|f)&1?k:y[d+175|0]>47;e=h&1}j=e;bd(b,z[m+8>>1]);e=z[a+480188>>1];n=a+484344|0;J=o+A&65535;Fg(n,J);Q=A?4:e;o=a+1074312|0;Z=k^1;_=c&1;l=0;k=0;s:{t:{u:{while(1){if((l|0)==(J|0)){break t}v:{if(A){e=(l&65534)>>>1|0;f=l&1;if(!f){if(!vh(n,e,64)){break t}}g=Xb(x[n>>2],e);e=f<<2;break v}if(!vh(n,l&65535,64)){break t}g=Xb(x[n>>2],l);e=0}h=0;r=hd(x[g>>2],x[x[g+48>>2]+12>>2],0,e);if(!_){K=0;L=0;break s}e=z[s>>1];v[d+80|0]=0;f=e;e=d+80|0;B=Io(d+160|0,f,e);f=z[s>>1];x[27524]=0;v[d+80|0]=0;E=W(583,d+144|0,f|0,e|0)|0;e=x[27524];x[27524]=0;if((e|0)!=1){M=0;w:{x:while(1){y:{if((M|0)==64){break w}g=0;f=0;R=0;while(1){if((g|0)==(Q|0)){M=M+1|0;K=f&R|K;r=D(z[s>>1],6)+r|0;continue x}x[27524]=0;h=D(g,6)+r|0;U(584,d+80|0,b|0,h|0);e=x[27524];x[27524]=0;if((e|0)!=1){e=y[d+80|0];u=Lc(d+80|0);i=y[u|0];if(e|i){z:{if(!(!F|(e&255)!=14)){e=0;v[u|0]=0;v[d+80|0]=0;i=y[u|0];break z}if(!F|(e&255)!=15|(i&255)>>>0<32){break z}i=31;v[u|0]=31;e=y[d+80|0]}Xf(h,e&255,i&255)}e=1;A:{B:{C:{D:{E:{i=y[h+3|0];switch(i-14|0){case 2:break A;case 0:break D;case 3:break E;default:break C}}k=y[h+5|0]<100|k;R=1;break B}if(!j){break B}v[h+5|0]=0;break B}if(!((i|0)!=9|Z)){e=y[h+5|0];if((e|0)==164){v[h+3|0]=20;v[h+5|0]=145;break B}$=h,aa=Ag(e<<1),v[$+5|0]=aa;break B}if((i|0)!=19){break B}e=y[h+5|0];if(e>>>0>15){break B}i=e&1;e=!i;u=!i;i=T&1;T=(i|0)==(e|0)?T:u;L=((e|0)!=(i|0))+L|0}e=f}F:{if(!y[h|0]){f=y[h+1|0];if(!f|A){break F}i=y[Jb(x[B>>2],g)|0];if(!i|(f|0)==(i|0)){break F}i=Jb(x[E>>2],g);f=y[i|0]+1|0;v[i|0]=f;if((f&255)>>>0<4){break F}x[27524]=0;W(268,o|0,85,1)|0;f=x[27524];x[27524]=0;if((f|0)!=1){break F}break y}$=Jb(x[E>>2],g),aa=0,v[$|0]=aa}f=y[h+1|0];if(f){$=Jb(x[B>>2],g),aa=f,v[$|0]=aa}g=g+1|0;f=e;continue}break}}break}f=P()|0;ec(E);break u}ec(E);ec(B);l=l+1|0;continue}break}f=P()|0}ec(B);break b}h=k}G:{H:{I:{if((q^-1|V)&1){break I}J:{if(qe(d+332|0,16704)){break J}if(qe(d+332|0,17473)){break J}if(!qe(d+332|0,13534)){break I}}x[a+480208>>2]=x[a+480208>>2]|2162688;e=Lb(Lb(Lb(o,85,1),91,1),92,1);K:{if(y[d+175|0]>47){break K}e=Lb(e,84,1);if(y[d+177|0]==127){break K}Lb(e,83,1)}if(!(q&1)){break G}break H}if(q&1){break H}if(!(y[d+177|0]==127&(O&65535)>>>0<129&t)){break G}x[m>>2]=8442;break G}if((L|0)>6|I){break G}x[a+480208>>2]=x[a+480208>>2]|8388608}if((t|I)==1){Lb(o,89,1)}if(G){Lb(o,84,1)}L:{if(!(c&2)){break L}bd(b,z[m+8>>1]+(D(J,Q)<<8)|0);f=(q&t^1|X)&1;g=1;while(1){if((g|0)==32){break L}k=D(g,104)+a|0;c=k+484380|0;e=x[c>>2];if(e){i=2;if(!G){i=vU(b,13843)?10:0;e=x[c>>2]}j=Zc(d+160|0,8,1,0,i);e=yB(j,e)+x[b+8>>2]|0;if(!f){$=c,aa=x[Yc(c,k+484388|0)>>2],x[$>>2]=aa}Eg(j,c,b);bd(b,e)}g=g+1|0;continue}}M:{if((h&t^-1|K)&1){break M}b=uU(d+120|0,0);c=x[b+20>>2];x[d+40>>2]=x[b+16>>2];x[d+44>>2]=c;c=x[b+12>>2];x[d+32>>2]=x[b+8>>2];x[d+36>>2]=c;c=x[b+4>>2];x[d+24>>2]=x[b>>2];x[d+28>>2]=c;b=d+160|0;ru(b,a,0,d+24|0);Y=C[x[d+160>>2]>>3];Li(b);if(!(Y>=480)){break M}c=Lb(o,5,1);b=tU(d+96|0,Y);e=x[b+20>>2];x[d+16>>2]=x[b+16>>2];x[d+20>>2]=e;e=x[b+12>>2];x[d+8>>2]=x[b+8>>2];x[d+12>>2]=e;e=x[b+4>>2];x[d>>2]=x[b>>2];x[d+4>>2]=e;b=d+160|0;ru(b,a,0,d);e=y[x[d+160>>2]+26|0];Li(b);if(e){fg(c,5);break M}x[m>>2]=17056}b=d+332|0;e=b;f=gc(b);c=b;while(1){if((e|0)!=(f|0)){h=y[e|0];v[c|0]=h>>>0<=32?32:h;c=c+1|0;e=e+1|0;continue}break}_f(d+80|0,16809);x[27524]=0;b=W(585,d+48|0,b|0,f|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break g}x[27524]=0;U(11,d- -64|0,1,b|0);c=x[27524];x[27524]=0;if((c|0)==1){break f}x[27524]=0;U(149,d+160|0,d+80|0,d- -64|0);c=x[27524];x[27524]=0;if((c|0)==1){break e}c=d+160|0;Gb(a+1298344|0,c);xb(c);xb(d- -64|0);wb(b);$b(d+80|0);b=xc(c,12282);Gb(a+1298356|0,b);xb(b);b=x[m>>2];if(b){Vl(a+1298368|0,b)}x[a+1298404>>2]=28}g=H>>>0<=N>>>0;break a}f=P()|0;break c}f=P()|0;break d}f=P()|0;xb(d- -64|0)}wb(b)}$b(d+80|0)}S(f|0);p()}else{j=D(g,104)+a|0;h=j+484380|0;o=UA(b,d+176|0,h,((g<<5)+a|0)+946304|0,z[r>>1]==4);h=x[h>>2];N:{if(e){v[j+484417|0]=0-(y[d+200|0]<<3);break N}l=h>>>0<65536&l}j=Fb(z[d+198>>1]);O:{if(j){V=!Fb(z[d+204>>1])|V;break O}X=y[d+201|0]==64|X}n=f&1;f=0;P:{if(!n){break P}k=(j<<1)+k|0;n=y[d+200|0];f=!n;if(n|!j){break P}f=y[d+201|0]==64}H=o+H|0;i=h+i|0;g=g+1|0;continue}}ib=d+336|0;return g|0}function Taa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=E(0),f=E(0),g=E(0),h=E(0),i=0,j=E(0),k=E(0),l=0,m=0,n=0,o=E(0),p=0,q=0,r=0,s=0,t=0,u=E(0),w=E(0),z=0,A=0,C=0,D=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=E(0),Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=E(0),Z=0,_=0,$=E(0);a:{if(!y[a+5046|0]){break a}g=B[a+4268>>2];RM(a);if(g==B[a+4268>>2]){break a}iy(a)}b:{if(!y[a+5045|0]){break b}if(!fi(a+44|0)){break b}i=x[a+44>>2];p=Hc(i,0);q=Hc(i,1);i=x[a+56>>2];l=Hc(i,0);m=Hc(i,1);c:{if(!(!y[a+5044|0]|(!d|y[a+4264|0]&2))){B[l>>2]=B[a+5036>>2];B[m>>2]=B[a+5040>>2];v[a+5044|0]=0;q=q+4|0;p=p+4|0;m=m+4|0;l=l+4|0;n=d-1|0;break c}n=d}r=n;s=a+4888|0;t=a+4864|0;U=a+4504|0;V=a+4960|0;W=a+4868|0;X=a+4892|0;C=a+4628|0;D=a+4604|0;Q=a+4916|0;F=a+4532|0;G=a+4508|0;H=a+4772|0;I=a+4748|0;R=a+4940|0;J=a+4676|0;K=a+4652|0;L=a+4724|0;M=a+4700|0;S=a+4844|0;N=a+4580|0;O=a+4556|0;T=a+4820|0;d:{while(1){if(!r){break d}g=B[p>>2];g=E(E(E(B[a+5008>>2]-g)*B[a+4276>>2])+g);B[a+5008>>2]=g;_=Mc(x[a+4864>>2],x[W>>2],x[a+4880>>2]),$=g,B[_>>2]=$;g=B[q>>2];g=E(E(E(B[a+5012>>2]-g)*B[a+4276>>2])+g);B[a+5012>>2]=g;_=Mc(x[a+4888>>2],x[X>>2],x[a+4904>>2]),$=g,B[_>>2]=$;g=E(E(E(E(E(Vh(t,x[a+4356>>2])*E(.6800000071525574))+E(Vh(t,x[a+4360>>2])*E(-.5)))-E(Vh(t,x[a+4364>>2])*E(.6200000047683716)))+E(Vh(t,x[a+4368>>2])*E(-.5)))-E(Vh(t,x[a+4372>>2])*E(.6200000047683716)));if(v[a+4264|0]&1){e=g;g=E(B[Mc(x[a+4816>>2],x[T>>2],x[a+4836>>2])>>2]+E(e*E(.6180340051651001)));_=Mc(x[a+4816>>2],x[T>>2],x[a+4832>>2]),$=E(e-E(g*E(.6180340051651001))),B[_>>2]=$}u=B[a+4280>>2];_=a,$=E(Vh(t,x[a+4352>>2])+B[a+5020>>2]),B[_+5020>>2]=$;e=E(Vh(s,x[a+4376>>2])+B[a+5024>>2]);B[a+5024>>2]=e;f=B[a+5020>>2];h=E(E(E(B[a+4980>>2]-B[Mc(x[a+4624>>2],x[C>>2],x[a+4644>>2])>>2])*B[a+4444>>2])+B[Mc(x[a+4624>>2],x[C>>2],x[a+4644>>2])>>2]);B[a+4980>>2]=h;P=E(h*B[a+4440>>2]);k=E(e*E(.7070000171661377));j=E(f*E(-.7070000171661377));f=E(k+j);h=B[a+4272>>2];e=E(P+E(f*h));_=Mc(x[a+4624>>2],x[C>>2],x[a+4640>>2]),$=E(f-E(h*e)),B[_>>2]=$;f=E(E(E(B[a+4976>>2]-B[Mc(x[a+4600>>2],x[D>>2],x[a+4620>>2])>>2])*B[a+4436>>2])+B[Mc(x[a+4600>>2],x[D>>2],x[a+4620>>2])>>2]);B[a+4976>>2]=f;h=B[a+4272>>2];f=E(E(f*B[a+4432>>2])+E(e*h));_=Mc(x[a+4600>>2],x[D>>2],x[a+4616>>2]),$=E(e-E(h*f)),B[_>>2]=$;w=E(E(e*E(-.15000000596046448))+E(f*E(-.20000000298023224)));if(v[a+4264|0]&1){e=E(E(E(B[a+4972>>2]-B[Mc(x[a+4576>>2],x[N>>2],x[a+4596>>2])>>2])*B[a+4428>>2])+B[Mc(x[a+4576>>2],x[N>>2],x[a+4596>>2])>>2]);B[a+4972>>2]=e;h=B[a+4272>>2];e=E(E(e*B[a+4424>>2])+E(f*h));_=Mc(x[a+4576>>2],x[N>>2],x[a+4592>>2]),$=E(f-E(h*e)),B[_>>2]=$;f=E(E(E(B[a+4968>>2]-B[Mc(x[a+4552>>2],x[O>>2],x[a+4572>>2])>>2])*B[a+4420>>2])+B[Mc(x[a+4552>>2],x[O>>2],x[a+4572>>2])>>2]);B[a+4968>>2]=f;h=B[a+4272>>2];f=E(E(f*B[a+4416>>2])+E(e*h));_=Mc(x[a+4552>>2],x[O>>2],x[a+4568>>2]),$=E(e-E(h*f)),B[_>>2]=$;w=E(E(E(e*E(.3499999940395355))+w)+E(f*E(-.3799999952316284)))}_=Mc(x[a+4912>>2],x[Q>>2],x[a+4928>>2]),$=f,B[_>>2]=$;e=E(B[Mc(x[a+4912>>2],x[Q>>2],x[a+4932>>2])>>2]*B[a+4496>>2]);B[a+5028>>2]=E(E(B[a+5028>>2]-e)*B[a+4500>>2])+e;e=E(E(E(B[a+4964>>2]-B[Mc(x[a+4528>>2],x[F>>2],x[a+4548>>2])>>2])*B[a+4412>>2])+B[Mc(x[a+4528>>2],x[F>>2],x[a+4548>>2])>>2]);B[a+4964>>2]=e;f=B[a+5028>>2];o=B[a+4272>>2];h=E(E(f*o)+E(e*B[a+4408>>2]));_=Mc(x[a+4528>>2],x[F>>2],x[a+4544>>2]),$=E(f-E(o*h)),B[_>>2]=$;e=E(E(E(B[a+4960>>2]-B[Mc(x[a+4504>>2],x[G>>2],x[a+4524>>2])>>2])*B[a+4404>>2])+B[Mc(x[a+4504>>2],x[G>>2],x[a+4524>>2])>>2]);B[a+4960>>2]=e;f=E(e*B[a+4400>>2]);e=B[a+4272>>2];o=E(f+E(h*e));_=Mc(x[a+4504>>2],x[G>>2],x[a+4520>>2]),$=E(h-E(e*o)),B[_>>2]=$;B[a+5020>>2]=o;e=E(E(E(E(E(Vh(s,x[a+4380>>2])*E(.7070000171661377))+E(Vh(s,x[a+4384>>2])*E(-.6000000238418579)))-E(Vh(s,x[a+4388>>2])*E(.5)))+E(Vh(s,x[a+4392>>2])*E(-.6000000238418579)))-E(Vh(s,x[a+4396>>2])*E(.5)));if(v[a+4264|0]&1){f=e;e=E(B[Mc(x[a+4840>>2],x[S>>2],x[a+4860>>2])>>2]+E(e*E(.6180340051651001)));_=Mc(x[a+4840>>2],x[S>>2],x[a+4856>>2]),$=E(f-E(e*E(.6180340051651001))),B[_>>2]=$}Y=B[a+4280>>2];f=E(E(E(B[a+5004>>2]-B[Mc(x[a+4768>>2],x[H>>2],x[a+4788>>2])>>2])*B[a+4492>>2])+B[Mc(x[a+4768>>2],x[H>>2],x[a+4788>>2])>>2]);B[a+5004>>2]=f;P=E(f*B[a+4488>>2]);f=E(j-k);j=B[a+4272>>2];k=E(P+E(f*j));_=Mc(x[a+4768>>2],x[H>>2],x[a+4784>>2]),$=E(f-E(j*k)),B[_>>2]=$;f=E(E(E(B[a+5e3>>2]-B[Mc(x[a+4744>>2],x[I>>2],x[a+4764>>2])>>2])*B[a+4484>>2])+B[Mc(x[a+4744>>2],x[I>>2],x[a+4764>>2])>>2]);B[a+5e3>>2]=f;j=B[a+4272>>2];f=E(E(f*B[a+4480>>2])+E(k*j));_=Mc(x[a+4744>>2],x[I>>2],x[a+4760>>2]),$=E(k-E(j*f)),B[_>>2]=$;k=E(E(E(h*E(.3799999952316284))+E(k*E(-.15000000596046448)))+E(f*E(-.20000000298023224)));if(v[a+4264|0]&1){h=E(E(E(B[a+4996>>2]-B[Mc(x[a+4720>>2],x[L>>2],x[a+4740>>2])>>2])*B[a+4476>>2])+B[Mc(x[a+4720>>2],x[L>>2],x[a+4740>>2])>>2]);B[a+4996>>2]=h;j=B[a+4272>>2];h=E(E(h*B[a+4472>>2])+E(f*j));_=Mc(x[a+4720>>2],x[L>>2],x[a+4736>>2]),$=E(f-E(j*h)),B[_>>2]=$;f=E(E(E(B[a+4992>>2]-B[Mc(x[a+4696>>2],x[M>>2],x[a+4716>>2])>>2])*B[a+4468>>2])+B[Mc(x[a+4696>>2],x[M>>2],x[a+4716>>2])>>2]);B[a+4992>>2]=f;j=B[a+4272>>2];f=E(E(f*B[a+4464>>2])+E(h*j));_=Mc(x[a+4696>>2],x[M>>2],x[a+4712>>2]),$=E(h-E(j*f)),B[_>>2]=$;k=E(E(E(h*E(.3499999940395355))+k)+E(f*E(-.3799999952316284)))}Z=q+4|0;n=p+4|0;h=E(g*u);w=E(w-E(o*E(.3799999952316284)));o=E(e*Y);_=Mc(x[a+4936>>2],x[R>>2],x[a+4952>>2]),$=f,B[_>>2]=$;g=E(B[Mc(x[a+4936>>2],x[R>>2],x[a+4956>>2])>>2]*B[a+4496>>2]);B[a+5032>>2]=E(E(B[a+5032>>2]-g)*B[a+4500>>2])+g;g=E(E(E(B[a+4988>>2]-B[Mc(x[a+4672>>2],x[J>>2],x[a+4692>>2])>>2])*B[a+4460>>2])+B[Mc(x[a+4672>>2],x[J>>2],x[a+4692>>2])>>2]);B[a+4988>>2]=g;e=B[a+5032>>2];f=B[a+4272>>2];g=E(E(e*f)+E(g*B[a+4456>>2]));_=Mc(x[a+4672>>2],x[J>>2],x[a+4688>>2]),$=E(e-E(f*g)),B[_>>2]=$;f=B[a+4284>>2];e=E(E(E(B[a+4984>>2]-B[Mc(x[a+4648>>2],x[K>>2],x[a+4668>>2])>>2])*B[a+4452>>2])+B[Mc(x[a+4648>>2],x[K>>2],x[a+4668>>2])>>2]);B[a+4984>>2]=e;u=B[a+4272>>2];e=E(E(e*B[a+4448>>2])+E(g*u));_=Mc(x[a+4648>>2],x[K>>2],x[a+4664>>2]),$=E(g-E(u*e)),B[_>>2]=$;B[a+5024>>2]=e;e=E(-e);u=B[a+4288>>2];i=U;e:{f:{while(1){if((i|0)==(V|0)){g:{e=E(o+E(E(E(e*E(.3799999952316284))+k)*u));g=E(h+E(E(E(g*E(.3799999952316284))+w)*f));if(!(y[a+4264|0]&2)){break g}p=n;n=Z;break f}}else{z=x[i+16>>2];A=z-1|0;x[i+16>>2]=A;if((z|0)<=0){x[i+16>>2]=A+x[i+12>>2]}z=x[i+20>>2];A=z-1|0;x[i+20>>2]=A;if((z|0)<=0){x[i+20>>2]=A+x[i+12>>2]}i=i+24|0;continue}break}B[l>>2]=E(g+B[a+5036>>2])*E(.5);B[m>>2]=E(e+B[a+5040>>2])*E(.5);B[a+5040>>2]=e;B[a+5036>>2]=g;if((r|0)==1){break e}r=r-1|0;p=p+8|0;m=m+4|0;l=l+4|0;n=q+8|0}q=n;B[l>>2]=g;B[m>>2]=e;r=r-1|0;m=m+4|0;l=l+4|0;continue}break}v[a+5044|0]=1}n=a;a=x[a+56>>2];zi(n,b,c,Hc(a,0),Hc(a,1),d)}}function SL(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=ib-32|0;ib=f;d=Kc(f+16|0,11496);e=mh(c,d);wb(d);a:{b:{c:{d:{e:{if(e){jl(a,x[b+24>>2]+1298356|0);break e}d=Kc(f+16|0,10914);e=mh(c,d);wb(d);if(e){jl(a,x[b+24>>2]+1298344|0);break e}d=Kc(f+16|0,11326);e=mh(c,d);wb(d);if(e){jl(a,x[b+24>>2]+1298392|0);break e}d=Kc(f+16|0,10906);e=mh(c,d);wb(d);if(e){jl(a,x[b+24>>2]+1298380|0);break e}d=Kc(f+16|0,8191);e=mh(c,d);wb(d);if(e){c=f+16|0;d=x[x[b+24>>2]+480184>>2];b=32640;f:{g:{while(1){if((b|0)==32688){break g}if((d|0)!=x[b>>2]){b=b+12|0;continue}break}en(c,0,x[b+8>>2]);break f}Kb(c)}x[27524]=0;R(1021,a|0,c|0);a=x[27524];x[27524]=0;if((a|0)==1){break d}xb(f+16|0);break e}d=Kc(f+16|0,10891);e=mh(c,d);wb(d);if(e){j=x[x[b+24>>2]+480184>>2];c=ib+-64|0;ib=c;b=32640;h=zg(c+48|0);l=f+16|0;d=Kb(l);while(1){if((b|0)!=32688){if(x[b>>2]==(j|0)){e=x[b+4>>2];x[27524]=0;e=Q(1,c+32|0,e|0)|0;g=x[27524];x[27524]=0;h:{i:{j:{k:{l:{m:{if((g|0)!=1){x[27524]=0;U(851,c+24|0,h|0,e|0);g=x[27524];x[27524]=0;if((g|0)==1){break k}if(!y[c+28|0]){break h}if(!yh(x[d+4>>2],y[d+11|0])){x[27524]=0;g=Q(1,c+8|0,17749)|0;k=x[27524];x[27524]=0;if((k|0)==1){break m}x[27524]=0;Q(99,d|0,g|0)|0;k=x[27524];x[27524]=0;if((k|0)==1){break l}xb(g)}x[27524]=0;Q(99,d|0,e|0)|0;g=x[27524];x[27524]=0;if((g|0)!=1){break h}b=P()|0;break j}b=P()|0;break i}b=P()|0;break j}b=P()|0;xb(g);break j}b=P()|0}xb(e)}xb(d);uO(h);S(b|0);p()}xb(e)}b=b+12|0;continue}break}uO(h);ib=c- -64|0;x[27524]=0;R(1021,a|0,l|0);a=x[27524];x[27524]=0;if((a|0)!=1){xb(f+16|0);break e}c=P()|0;xb(f+16|0);break a}d=Kc(f+16|0,8257);e=mh(c,d);wb(d);if(e){jl(a,x[b+24>>2]+1298368|0);break e}d=Kc(f+16|0,5623);e=mh(c,d);wb(d);if(e){jl(a,x[b+24>>2]+1298320|0);break e}d=Kc(f+16|0,11900);e=mh(c,d);wb(d);if(e){c=f+16|0;Pg(c,x[b+24>>2]+1298308|0);b=x[b+24>>2];x[27524]=0;U(1015,a|0,b|0,c|0);a=x[27524];x[27524]=0;if((a|0)!=1){wb(f+16|0);break e}c=P()|0;wb(f+16|0);break a}d=Kc(f+16|0,11269);e=mh(c,d);wb(d);if(e){g=x[b+24>>2];b=g+1298412|0;d=x[b+4>>2];n:{if(!pc(x[b>>2],d)){b=ib-32|0;ib=b;x[b+8>>2]=0;x[b+12>>2]=0;x[b+16>>2]=0;x[b>>2]=0;x[b+4>>2]=0;x[b+24>>2]=0;x[b+28>>2]=0;c=1;e=d-40|0;o:{if(x[e>>2]!=x[b>>2]|x[e+4>>2]!=x[b+4>>2]|(x[e+8>>2]!=x[b+8>>2]|x[e+12>>2]!=x[b+12>>2])){break o}if(x[e+16>>2]!=x[b+16>>2]){break o}c=x[e+24>>2]!=x[b+24>>2]|x[e+28>>2]!=x[b+28>>2]}ib=b+32|0;if(c){break n}}Kb(a);break e}h=f+16|0;g=x[g+1298408>>2];d=ib-512|0;ib=d;j=x[e+32>>2];p:{if(j){c=2147483647;i=Be(+(j>>>0)/18.2);b=-1;q:{if(i>=0x8000000000000000){break q}c=-2147483648;b=0;if(i<=-0x8000000000000000){break q}if(F(i)<0x8000000000000000){c=F(i)>=1?~~(i>0?H(J(i*2.3283064365386963e-10),4294967295):K((i-+(~~i>>>0>>>0))*2.3283064365386963e-10))>>>0:0;b=~~i>>>0;break q}b=0}if((g|0)==1){g=x[e+28>>2];x[d+184>>2]=x[e+24>>2];x[d+188>>2]=g;g=x[e+20>>2];x[d+176>>2]=x[e+16>>2];x[d+180>>2]=g;g=x[e+12>>2];x[d+168>>2]=x[e+8>>2];x[d+172>>2]=g;g=x[e+4>>2];x[d+160>>2]=x[e>>2];x[d+164>>2]=g;ut(d+480|0,d+160|0);e=x[d+508>>2];x[d+152>>2]=x[d+504>>2];x[d+156>>2]=e;e=x[d+500>>2];x[d+144>>2]=x[d+496>>2];x[d+148>>2]=e;e=x[d+492>>2];x[d+136>>2]=x[d+488>>2];x[d+140>>2]=e;e=x[d+484>>2];x[d+128>>2]=x[d+480>>2];x[d+132>>2]=e;e=tP(uP(d+128|0),kb)+b|0;c=c+kb|0;rP(d+448|0,sP(e,b>>>0>e>>>0?c+1|0:c),kb);b=x[d+476>>2];x[d+120>>2]=x[d+472>>2];x[d+124>>2]=b;b=x[d+468>>2];x[d+112>>2]=x[d+464>>2];x[d+116>>2]=b;b=x[d+460>>2];x[d+104>>2]=x[d+456>>2];x[d+108>>2]=b;b=x[d+452>>2];x[d+96>>2]=x[d+448>>2];x[d+100>>2]=b;qH(h,d+96|0);break p}g=x[e+28>>2];x[d+312>>2]=x[e+24>>2];x[d+316>>2]=g;g=x[e+20>>2];x[d+304>>2]=x[e+16>>2];x[d+308>>2]=g;g=x[e+12>>2];x[d+296>>2]=x[e+8>>2];x[d+300>>2]=g;g=x[e+4>>2];x[d+288>>2]=x[e>>2];x[d+292>>2]=g;ut(d+416|0,d+288|0);e=x[d+444>>2];x[d+280>>2]=x[d+440>>2];x[d+284>>2]=e;e=x[d+436>>2];x[d+272>>2]=x[d+432>>2];x[d+276>>2]=e;e=x[d+428>>2];x[d+264>>2]=x[d+424>>2];x[d+268>>2]=e;e=x[d+420>>2];x[d+256>>2]=x[d+416>>2];x[d+260>>2]=e;e=tP(uP(d+256|0),kb)+b|0;c=c+kb|0;rP(d+352|0,sP(e,b>>>0>e>>>0?c+1|0:c),kb);b=x[d+380>>2];x[d+248>>2]=x[d+376>>2];x[d+252>>2]=b;b=x[d+372>>2];x[d+240>>2]=x[d+368>>2];x[d+244>>2]=b;b=x[d+364>>2];x[d+232>>2]=x[d+360>>2];x[d+236>>2]=b;b=x[d+356>>2];x[d+224>>2]=x[d+352>>2];x[d+228>>2]=b;ut(d+384|0,d+224|0);b=x[d+412>>2];x[d+216>>2]=x[d+408>>2];x[d+220>>2]=b;b=x[d+404>>2];x[d+208>>2]=x[d+400>>2];x[d+212>>2]=b;b=x[d+396>>2];x[d+200>>2]=x[d+392>>2];x[d+204>>2]=b;b=x[d+388>>2];x[d+192>>2]=x[d+384>>2];x[d+196>>2]=b;ZH(h,d+192|0);break p}if((g|0)==1){b=x[e+28>>2];x[d+56>>2]=x[e+24>>2];x[d+60>>2]=b;b=x[e+20>>2];x[d+48>>2]=x[e+16>>2];x[d+52>>2]=b;b=x[e+12>>2];x[d+40>>2]=x[e+8>>2];x[d+44>>2]=b;b=x[e+4>>2];x[d+32>>2]=x[e>>2];x[d+36>>2]=b;ut(d+320|0,d+32|0);b=x[d+348>>2];x[d+24>>2]=x[d+344>>2];x[d+28>>2]=b;b=x[d+340>>2];x[d+16>>2]=x[d+336>>2];x[d+20>>2]=b;b=x[d+332>>2];x[d+8>>2]=x[d+328>>2];x[d+12>>2]=b;b=x[d+324>>2];x[d>>2]=x[d+320>>2];x[d+4>>2]=b;qH(h,d);break p}b=x[e+28>>2];x[d+88>>2]=x[e+24>>2];x[d+92>>2]=b;b=x[e+20>>2];x[d+80>>2]=x[e+16>>2];x[d+84>>2]=b;b=x[e+12>>2];x[d+72>>2]=x[e+8>>2];x[d+76>>2]=b;b=x[e+4>>2];x[d+64>>2]=x[e>>2];x[d+68>>2]=b;ZH(h,d- -64|0)}ib=d+512|0;x[27524]=0;R(1021,a|0,h|0);a=x[27524];x[27524]=0;if((a|0)!=1){xb(f+16|0);break e}c=P()|0;xb(f+16|0);break a}d=Kc(f+16|0,12169);e=mh(c,d);wb(d);if(e){c=f+16|0;aS(c,x[b+24>>2]+1298332|0);r:{if(!Qe(c)){break r}d=x[x[b+24>>2]+480180>>2];s:{t:{if((d|0)==33554432){break t}c=1;if((d|0)==32){break s}if((d|0)==16384){break t}if((d|0)==16777216){break s}}c=2}u:{switch(c-1|0){case 0:x[27524]=0;R(1022,f|0,b|0);c=x[27524];x[27524]=0;if((c|0)!=1){Ac(f+16|0,f);wb(f);break r}break b;case 1:break u;default:break r}}if(Qe(f+16|0)){x[27524]=0;R(1023,f|0,b|0);c=x[27524];x[27524]=0;if((c|0)==1){break b}Ac(f+16|0,f);wb(f)}if(!Qe(f+16|0)){break r}x[27524]=0;R(1022,f|0,b|0);c=x[27524];x[27524]=0;if((c|0)==1){break b}Ac(f+16|0,f);wb(f)}b=x[b+24>>2];x[27524]=0;U(1015,a|0,b|0,f+16|0);a=x[27524];x[27524]=0;if((a|0)!=1){wb(f+16|0);break e}break b}d=Kc(f+16|0,5475);e=mh(c,d);wb(d);if(e){c=f+16|0;aS(c,x[b+24>>2]+1298332|0);b=x[b+24>>2];x[27524]=0;U(1015,a|0,b|0,c|0);a=x[27524];x[27524]=0;if((a|0)!=1){wb(f+16|0);break e}c=P()|0;wb(f+16|0);break a}d=c;c=Kc(f+16|0,7283);d=mh(d,c);wb(c);if(d){a=Kb(a);m=f,n=Cb(x[b+68>>2]),x[m+16>>2]=n;b=Cb(x[b+72>>2]);c=1;while(1){d=x[f+16>>2];if(!Mb(d,b)){break e}if(!(c&1)){x[27524]=0;Q(947,a|0,21601)|0;c=x[27524];x[27524]=0;if((c|0)==1){break c}}x[27524]=0;Q(806,a|0,d|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break c}yq(f+16|0);c=0;continue}}Kc(a,21631)}ib=f+32|0;return}c=P()|0;xb(f+16|0);break a}c=P()|0;wb(a);break a}c=P()|0;wb(f+16|0)}S(c|0);p()}function kia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;g=ib-288|0;ib=g;e=ib-128|0;ib=e;f=te(g+104|0,c);x[27524]=0;n=T(178,f+20|0)|0;c=x[27524];x[27524]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{if((c|0)!=1){x[27524]=0;q=T(178,f+40|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break B}x[27524]=0;r=T(178,f+60|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break A}x[27524]=0;i=T(178,f+80|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break z}x[27524]=0;o=T(178,f+100|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break y}x[27524]=0;k=T(178,f+120|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break x}j=Nb(f+140|0);yc(f);x[f+172>>2]=1873739776;w[f+176>>1]=0;x[27524]=0;d=Q(775,f|0,e+112|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break w}if(!d){break n}d=x[e+112>>2];if((d|0)!=1414744396&(d|0)!=1179011410){break n}c=x[e+120>>2];if((c|0)!=1163280727&(c|0)!=1702257015){break n}v[f+176|0]=(d|0)==1414744396;x[27524]=0;U(776,e+96|0,f|0,2);c=x[27524];x[27524]=0;if((c|0)==1){break v}h=x[e+96>>2];C:{if(Wq(h,x[e+100>>2])>>>0<4){break C}c=Hy(h,1);d=x[c+4>>2];c=x[c>>2];ci(e+40|0,c,d);if(x[e+40>>2]!=1635017060){break C}ci(e- -64|0,c,d);if(!(v[e+68|0]&1)){break C}c=Hy(h,2);ci(e+24|0,x[c>>2],x[c+4>>2]);if(x[e+28>>2]){break C}c=Hy(h,3);ci(e+88|0,x[c>>2],x[c+4>>2]);if(x[e+88>>2]){break C}x[27524]=0;Q(159,f|0,12)|0;c=x[27524];x[27524]=0;if((c|0)==1){break u}x[27524]=0;U(776,e+40|0,f|0,1);c=x[27524];x[27524]=0;if((c|0)==1){break t}c=e+40|0;lu(e+96|0,c);Zd(c)}x[27524]=0;U(777,e- -64|0,e+96|0,544501094);c=x[27524];x[27524]=0;if((c|0)==1){break s}x[27524]=0;d=Q(778,e- -64|0,f+156|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break k}if(!d){break o}d=z[f+156>>1];if((d|0)!=1){break q}x[27524]=0;d=T(206,e- -64|0)|0;c=x[27524];x[27524]=0;if((c|0)!=1){break r}break k}d=P()|0;break b}d=P()|0;break c}d=P()|0;break d}d=P()|0;break e}d=P()|0;break f}d=P()|0;break g}d=P()|0;break h}d=P()|0;break h}d=P()|0;break i}d=P()|0;break i}d=P()|0;break i}if((d|0)==4){x[27524]=0;h=T(201,e- -64|0)|0;c=x[27524];x[27524]=0;D:{if((c|0)!=1){x[27524]=0;d=T(201,e- -64|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break D}if((h|0)!=2|(d|0)!=1){break p}v[f+177|0]=1;break p}d=P()|0;break j}d=P()|0;break j}d=z[f+156>>1]}if((d&65535)!=65534){break p}x[27524]=0;d=Q(779,e- -64|0,e+40|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break l}if(!d){break o}c=x[e+60>>2];x[e+16>>2]=x[e+56>>2];x[e+20>>2]=c;c=x[e+52>>2];x[e+8>>2]=x[e+48>>2];x[e+12>>2]=c;c=e+24|0;x[c>>2]=y[e+8|0]|y[e+9|0]<<8|(y[e+10|0]<<16|y[e+11|0]<<24);w[c+4>>1]=y[e+12|0]|y[e+13|0]<<8;w[c+6>>1]=y[e+14|0]|y[e+15|0]<<8;s=c,t=IA(y[e+16|0]|y[e+17|0]<<8|(y[e+18|0]<<16|y[e+19|0]<<24),y[e+20|0]|y[e+21|0]<<8|(y[e+22|0]<<16|y[e+23|0]<<24)),x[s+8>>2]=t;x[c+12>>2]=kb;w[f+172>>1]=x[c>>2]}x[27524]=0;U(777,e+40|0,e+96|0,1635017060);c=x[27524];x[27524]=0;E:{F:{G:{H:{I:{J:{if((c|0)!=1){c=e+40|0;m=fd(n,c);yb(c);c=x[m>>2];x[27524]=0;d=T(182,c|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break k}if(!d){x[27524]=0;U(777,e+40|0,e+96|0,544039792);c=x[27524];x[27524]=0;if((c|0)==1){break J}c=e+40|0;fd(m,c);yb(c)}x[27524]=0;U(777,e+40|0,e+96|0,1952670054);c=x[27524];x[27524]=0;if((c|0)==1){break I}x[27524]=0;d=T(161,e+40|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break H}x[f+152>>2]=d;yb(e+40|0);if(x[f+152>>2]?z[f+156>>1]==17:0){break E}h=z[f+158>>1];d=pO(h,z[f+170>>1]);if(!d){break E}c=z[f+168>>1];if((c>>>0)/(h>>>0)>>>0<d<<1>>>0?c:0){break G}c=x[m>>2];x[27524]=0;d=T(164,c|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break k}c=pO(z[f+158>>1],z[f+170>>1]);break F}d=P()|0;break j}d=P()|0;break j}d=P()|0;break j}d=P()|0;yb(e+40|0);break j}c=x[m>>2];x[27524]=0;d=T(164,c|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break k}c=z[f+168>>1]}x[f+152>>2]=(d>>>0)/((c&65535)>>>0)}x[27524]=0;d=Q(780,f|0,e+96|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break k}w[f+174>>1]=d;x[27524]=0;R(781,f|0,e+96|0);c=x[27524];x[27524]=0;if((c|0)==1){break k}x[27524]=0;U(777,e+40|0,e+96|0,1886221175);c=x[27524];x[27524]=0;if((c|0)==1){break m}c=e+40|0;fd(o,c);yb(c)}yb(e- -64|0);Zd(e+96|0)}ib=e+128|0;break a}d=P()|0;break j}d=P()|0;break j}d=P()|0}yb(e- -64|0)}Zd(e+96|0)}Zd(j);yb(k)}yb(o)}yb(i)}yb(r)}yb(q)}yb(n)}yb(f);S(d|0);p()}c=x[f+20>>2];x[27524]=0;d=T(720,c|0)|0;c=x[27524];x[27524]=0;K:{L:{if((c|0)!=1){M:{if(!d|(z[f+158>>1]-3&65535)>>>0<65534){break M}N:{O:{c=z[f+170>>1];P:{if(!c){if((sk(f)|0)==85){break P}break M}if(c>>>0>31){break O}}if((sk(f)|0)!=3){break N}break M}if(c>>>0>64){break M}}d=sk(f);c=30256;while(1){Q:{R:{if((c|0)!=30280){if((d|0)!=x[c>>2]){break R}}else{c=30280}break Q}c=c+4|0;continue}break}if((c|0)==30280){break M}Kt(a,b);x[27524]=0;d=Q(55,g+88|0,21631)|0;c=x[27524];x[27524]=0;S:{T:{U:{V:{W:{if((c|0)!=1){h=Cc(((b<<5)+a|0)+946304|0,d);wb(d);x[27524]=0;d=D(b,104)+a|0;i=d+484380|0;R(281,i|0,0);c=x[27524];x[27524]=0;if((c|0)==1){break W}x[i>>2]=x[f+152>>2];x[d+484404>>2]=x[f+160>>2];c=x[a+1298404>>2];x[27524]=0;X(721,f|0,i|0,c|0,h|0);c=x[27524];x[27524]=0;if((c|0)==1){break W}te(g- -64|0,f+20|0);d=z[f+158>>1];j=Zc(g+56|0,8,d>>>0>1?2:1,0,0);c=sk(f);if((c|0)!=17|d>>>0>2){break U}wc(i,268435456);c=D(b,104)+a|0;b=c+484414|0;w[b>>1]=z[b>>1]&65470|((d|0)==2)<<6|1;if(Xg(i)){break V}break S}l=P()|0;break K}l=P()|0;break K}j=x[c+484400>>2];h=x[i>>2];k=te(g+32|0,g- -64|0);d=z[f+158>>1];c=z[f+168>>1];x[27524]=0;b=x[k+12>>2];x[g+16>>2]=x[k+8>>2];x[g+20>>2]=b;x[g+24>>2]=x[k+16>>2];b=x[k+4>>2];x[g+8>>2]=x[k>>2];x[g+12>>2]=b;ea(722,j|0,h|0,g+8|0,c|0,d|0);b=x[27524];x[27524]=0;if((b|0)==1){break L}yj(i,a);break T}if((c|0)==85){x[27524]=0;c=W(563,a|0,b|0,g- -64|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break L}if(c){break T}break S}X:{Y:{Z:{if(lS(z[f+156>>1])){break Z}_:{if(!Qd(y[f+177|0])){break _}if((sk(f)|0)!=1|z[f+170>>1]!=32|z[f+168>>1]!=d<<2){break _}ne(j,32);b=12;break Y}if((sk(f)|0)!=1|z[f+170>>1]!=24|z[f+168>>1]!=d<<2){break Z}ne(j,32);b=13;break Y}if((sk(f)&65534)!=6){break X}ne(j,16);b=(sk(f)|0)==6?17:16}jg(j,b);x[27524]=0;W(223,j|0,i|0,g- -64|0)|0;b=x[27524];x[27524]=0;if((b|0)!=1){break T}break L}d=z[f+170>>1];c=d-1|0;b=c&-8;h=b&31;ne(j,(c>>>0>=64?8:(b&63)>>>0>=32?1074268168>>>h|0:((1<<h)-1&1074268168)<<32-h|538447880>>>h)&255);if(d>>>0<9){jg(j,1)}if((sk(f)|0)==3){jg(j,3)}x[27524]=0;W(223,j|0,i|0,g- -64|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break L}}jA(i,x[a+480180>>2]);yj(i,a);l=1}yb(g- -64|0)}kS(f);ib=g+288|0;return l|0}l=P()|0;break K}l=P()|0;yb(g- -64|0)}kS(f);S(l|0);p()}function rja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0;d=ib-304|0;ib=d;yc(b);a:{b:{c:{d:{if(!mu(b,d+208|0)){break d}if(!ST(d+208|0)){break d}if(!Ob(x[b>>2],x[b+8>>2],Ec(RT(d+208|0),kb))){break d}if(!c){g=1;break d}if(!bd(b,y[d+212|0])){break d}zd(a,268435456);gg(a);x[a+480208>>2]=4;Lb(a+1074312|0,114,1);f=d+88|0;i=xc(f,15303);Gb(a+1298344|0,i);xb(i);i=xc(f,10220);Gb(a+1298356|0,i);xb(i);x[a+1298404>>2]=4;i=d+16|0;yf(i,d+208|6,48,3);Fc(f,i);Ac(a+1298308|0,f);wb(f);f=y[d+262|0];w[a+480188>>1]=f+1;x[a+480228>>2]=y[d+265|0];x[a+480204>>2]=D(y[d+266|0],1e4);x[a+480196>>2]=y[d+267|0];while(1){if((e|0)==(f|0)){e:{w[a+480190>>1]=y[d+300|0];f=z[d+302>>1];i=d+192|0;x[i>>2]=0;x[i+4>>2]=0;sc(i+8|0);if(f){Gk(i,f);lB(i,f)}x[27524]=0;U(637,b|0,i|0,z[d+302>>1]);f=x[27524];x[27524]=0;if((f|0)==1){break b}A=Nb(d+176|0);s=Nb(d+160|0);x[27524]=0;W(413,b|0,A|0,y[d+301|0])|0;f=x[27524];x[27524]=0;if((f|0)==1){break c}x[27524]=0;W(413,b|0,s|0,y[d+300|0])|0;f=x[27524];x[27524]=0;if((f|0)==1){break c}q=c&2;t=d+126|0;n=d+88|6;f=0;f:{while(1){e=f;if(e>>>0>=y[d+300|0]){g=1;if(!(c&1)){break e}x[d+68>>2]=0;r=a+484376|0;Ic(Tb(x[a+484360>>2],y[r|0]));G=d,H=Cb(x[i>>2]),x[G+64>>2]=H;u=a+484344|0;C=Cb(x[i+4>>2]);E=a+484348|0;break f}x[27524]=0;f=e+1|0;h=D(f,104)+a|0;k=h+484380|0;R(281,k|0,0);g=x[27524];x[27524]=0;g:{if((g|0)!=1){g=Bb(x[s>>2],e);g=y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24);if(!g){continue}x[27524]=0;g=Q(159,b|0,g|0)|0;j=x[27524];x[27524]=0;h:{if((j|0)==1){break h}if(!g){continue}x[27524]=0;g=Q(638,b|0,d+88|0)|0;j=x[27524];x[27524]=0;if((j|0)==1){break h}if(!g){continue}g=d+72|0;Se(g,2,n);x[27524]=0;R(226,d+16|0,g|0);g=x[27524];x[27524]=0;if((g|0)==1){break c}g=d+16|0;Cc(((f<<5)+a|0)+946304|0,g);wb(g);j=d+72|0;Bk(j,2,t);x[27524]=0;R(226,g|0,j|0);g=x[27524];x[27524]=0;if((g|0)==1){break c}g=d+16|0;Fe(h+484423|0,g);wb(g);g=y[d+138|0];if(g>>>0<=15){w[h+484408>>1]=D(g,17);g=h+484414|0;w[g>>1]=z[g>>1]|32}v[d+16|0]=y[d+139|0];v[d+72|0]=64;G=h+484412|0,H=y[Ub(d+16|0,d+72|0)|0],w[G>>1]=H;x[h+484404>>2]=y[d+141|0]|y[d+142|0]<<8;m=h+484384|0;g=y[d+147|0]|y[d+148|0]<<8|(y[d+149|0]<<16|y[d+150|0]<<24);x[m>>2]=g;r=h+484388|0;j=y[d+151|0]|y[d+152|0]<<8|(y[d+153|0]<<16|y[d+154|0]<<24);x[r>>2]=j;u=y[d+155|0]|y[d+156|0]<<8|(y[d+157|0]<<16|y[d+158|0]<<24);x[k>>2]=u;l=y[d+140|0];if(l&1){g=g>>>1|0;x[m>>2]=g;j=j>>>1|0;x[r>>2]=j;x[k>>2]=u>>>1}i:{if(g>>>0>=j>>>0){break i}h=h+484414|0;g=z[h>>1];w[h>>1]=g|2;if(!(l&2)){break i}w[h>>1]=g|6}Jk(k);if(!q){continue}e=Bb(x[s>>2],e);e=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);x[27524]=0;Q(159,b|0,e+y[d+92|0]|0)|0;e=x[27524];x[27524]=0;if((e|0)!=1){break g}}break c}break c}e=Zc(d+16|0,v[d+140|0]&1?16:8,1,0,1);x[27524]=0;W(223,e|0,k|0,b|0)|0;e=x[27524];x[27524]=0;if((e|0)!=1){continue}break}break c}while(1){j:{k:{k=x[d+64>>2];if(!Mb(k,C)){b=x[d+68>>2];c=b&63;if(!c){break k}f=y[a+484376|0];e=x[a+484360>>2];x[27524]=0;b=b>>>6|0;f=Q(315,Tb(e,f)|0,b&65535)|0;e=x[27524];x[27524]=0;if((e|0)!=1){if(!f){break k}b=z[bc(x[Tb(x[a+484360>>2],y[a+484376|0])>>2],b&65535)>>1];f=x[a+484344>>2];x[27524]=0;R(639,Xb(f,b)|0,c|0);b=x[27524];x[27524]=0;if((b|0)!=1){break k}}break c}c=y[k+3|0];if(y[k+2|0]>y[d+262|0]|c>>>0>=y[d+301|0]){break j}c=Bb(x[A>>2],c);c=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[27524]=0;c=Q(159,b|0,c|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break c}if(!c){break j}x[27524]=0;R(640,b|0,d+88|0);c=x[27524];x[27524]=0;if((c|0)==1){break c}e=y[d+92|0];if(!e){break j}f=y[k|0]|y[k+1|0]<<8;v[d+16|0]=y[d+93|0];v[d+72|0]=y[d+262|0]-y[k+2|0];j=y[Ub(d+16|0,d+72|0)|0];x[d+60>>2]=e+f;G=d,H=x[Yc(d+68|0,d+60|0)>>2],x[G+68>>2]=H;x[d+40>>2]=0;x[d+44>>2]=0;x[d+32>>2]=0;x[d+36>>2]=0;x[d+24>>2]=0;x[d+28>>2]=0;x[d+16>>2]=0;x[d+20>>2]=0;c=f&63;q=f>>>6|0;t=0;while(1){if((e&255)>>>0<=t>>>0){break j}e=Tb(x[a+484360>>2],y[r|0]);h=c>>>0>63;q=h+q|0;f=q&65535;if(Oc(x[e>>2],x[e+4>>2])>>>0<=f>>>0){x[27524]=0;R(328,e|0,q+1&65535);e=x[27524];x[27524]=0;if((e|0)==1){break c}x[27524]=0;n=Q(363,u|0,64)|0;e=x[27524];x[27524]=0;if((e|0)==1){break c}e=Tb(x[a+484360>>2],y[r|0]);G=bc(x[e>>2],f),H=n,w[G>>1]=H}m=x[a+484344>>2];o=x[E>>2];n=z[bc(x[e>>2],f)>>1];if(!Ce(m,o,n)){break j}f=0;e=Xb(m,n);m=h?0:c;e=hd(x[e>>2],x[x[e+48>>2]+12>>2],m,y[k+2|0]);l:{while(1){if((f|0)==(j|0)){c=y[d+93|0];if(c>>>0<=j>>>0){break l}x[27524]=0;Q(192,b|0,D(c-j|0,5)|0)|0;c=x[27524];x[27524]=0;if((c|0)!=1){break l}break c}x[27524]=0;R(641,d+72|0,b|0);c=x[27524];x[27524]=0;if((c|0)!=1){c=d+72|0;h=Lc(c);F=Ze(c);l=Si(c);o=gc(c);c=y[d+72|0];B=c-1&255;m:{if(B>>>0<=142){c=(D((c&240)>>>4|0,12)+(c&15)|0)+13|0;v[e|0]=c;v[(d+16|0)+f|0]=c;break m}v[e|0]=0}c=y[h|0];v[e+2|0]=1;v[e+1|0]=c;c=y[F|0];n:{if((c|0)!=255){v[e+4|0]=c;break n}v[e+2|0]=0}c=y[l|0];o:{if(c>>>0>22){break o}v[e+3|0]=y[c+27008|0];h=y[o|0];v[e+5|0]=h;c=e+5|0;p:{switch(y[l|0]-4|0){case 3:v[c|0]=h&3|64;break o;case 4:v[c|0]=h&3|48;break o;case 7:l=x[i>>2];if(tc(l,x[i+4>>2])>>>0<=h>>>0){break o}o=c;c=Bb(l,h);c=y[c|0]|y[c+1|0]<<8;v[o|0]=c>>>6;h=Xb(x[a+484344>>2],n);h=hd(x[h>>2],x[x[h+48>>2]+12>>2],m,z[a+480188>>1]-1&65535);v[h+5|0]=c&63;v[h+3|0]=14;break o;case 8:o=c;c=x[d+60>>2];v[o|0]=c>>>6;h=Xb(x[a+484344>>2],n);h=hd(x[h>>2],x[x[h+48>>2]+12>>2],m,z[a+480188>>1]-1&65535);v[h+5|0]=c&63;v[h+3|0]=14;break o;case 10:v[c|0]=h&15|128;break o;case 12:v[d+15|0]=15;G=c,H=y[Ub(c,d+15|0)|0]|208,v[G|0]=H;break o;case 13:v[d+15|0]=15;G=c,H=y[Ub(c,d+15|0)|0]|192,v[G|0]=H;break o;case 14:v[d+15|0]=15;G=c,H=y[Ub(c,d+15|0)|0]|224,v[G|0]=H;break o;case 0:case 16:case 17:if(!(h&15)){break o}l=h&240;if(!l|(l|0)==240){break o}v[c|0]=h|15;break o;case 9:case 18:break p;default:break o}}if(B>>>0<143){break o}v[e|0]=y[(d+16|0)+f|0]}e=e+6|0;f=f+1|0;continue}break}break c}c=m+1|0;t=t+1|0;e=y[d+92|0];continue}}a=Tb(x[a+484360>>2],y[a+484376|0]);G=d,H=Cb(x[a>>2]),x[G+88>>2]=H;b=Cb(x[a+4>>2]);c=65535;while(1){a=x[d+88>>2];if(!Mb(a,b)){break e}if(z[a>>1]==65535){q:{if((c&65535)!=65535){break q}x[27524]=0;c=Q(363,u|0,64)|0;f=x[27524];x[27524]=0;if((f|0)!=1){break q}break c}w[a>>1]=c}Ye(d+88|0);continue}}Pe(d- -64|0);continue}}}else{w[((e<<5)+a|0)+480284>>1]=D(y[(d+e|0)+268|0],17);e=e+1|0;continue}break}uc(s);uc(A);uc(i)}ib=d+304|0;return g|0}a=P()|0;uc(s);uc(A);break a}a=P()|0}uc(i);S(a|0);p()}function aQ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=E(0),r=0,s=0,t=0,u=0,C=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=E(0),S=E(0),T=0,U=0,V=0,W=E(0),X=0;n=ib-48|0;ib=n;v[n+40|0]=0;j=b+223848|0;k=n+40|0;Yi(j,Xh(e,Bi(e,jo(e),k))+1|0);he(k,x[j>>2],x[b+223852>>2]);j=ib-16|0;ib=j;v[j+15|0]=0;dc(n+32|0,e,Xh(e,Bi(e,jo(e),j+15|0)));ib=j+16|0;G=x[n+32>>2];H=x[n+36>>2];j=0;i=ib-16|0;ib=i;I=a+906300|0;r=a+1074312|0;o=D(c,872)+b|0;J=o+1415|0;K=o+1304|0;L=o+1392|0;u=o+1368|0;C=o+1364|0;M=o+1336|0;N=o+1308|0;O=o+1300|0;P=o+1280|0;Q=o+1402|0;g=o+1466|0;R=E(y[g|0]);S=E(f>>>0);F=o+616|0;l=x[o+1272>>2];T=a+480188|0;p=1;m=255;while(1){if((s|0)!=(H|0)&A[k+4>>2]>j>>>0){h=y[Jb(G,s)|0];e=h-48|0;a:{b:{if((e&255)>>>0<=9){break b}if((h-65&255)>>>0<=5){e=h-55|0;break b}c:{d:{e:{switch(h-97|0){case 2:f:{e=Ql(a,b,c,3,0)-1|0;if((e&255)>>>0>249){break f}e=x[Nd(I,e)>>2];if(!e){break f}e=rz(e,47528,44584);if(!e){break f}e=lb[x[x[e>>2]+192>>2]](e,F,c)|0;h=(e|0)!=255;e=h?e:0;if(h|!l){break b}break c}if(l){break c}e=0;break b;case 21:Ab(i+8|0,r,28);g:{if(!zb(x[x[i+8>>2]>>2],x[i+12>>2])){Ab(i,r,1);e=0;if(!zb(x[x[i>>2]>>2],x[i+4>>2])){break g}}e=w[L>>1]}h=D(x[u>>2],x[C>>2]);e=D(x[a+1074456>>2],e+x[K>>2]|0);e=Vb((Dc(roa(qoa(h,h>>31,e,e>>31),kb,1048576,0),kb)|0)/2|0,1,127);break d;case 20:e=D(x[u>>2],x[C>>2]);h=e;t=e>>31;e=D(x[a+1074456>>2],x[M>>2]);e=Vb((Dc(roa(qoa(h,t,e,e>>31),kb,67108864,0),kb)|0)/2|0,1,127);break d;case 23:x[i+8>>2]=x[N>>2]/2;x[i>>2]=127;e=x[rd(i+8|0,i)>>2];break d;case 24:x[i+8>>2]=x[O>>2]/2;x[i>>2]=127;e=x[rd(i+8|0,i)>>2];break d;case 0:e=0;if(!l){break d}h=z[l+28>>1];if(!h){break d}e=h-1>>>7&127;break d;case 1:e=0;if(!l){break d}h=z[l+28>>1];if(!h){break d}e=h-1&127;break d;case 14:e=x[P>>2]>>>8|0;break d;case 7:e=(z[T>>1]<=c>>>0?y[Q|0]-1|0:c)&127;break d;case 12:e=y[o+704|0]>>>7|0;break d;case 15:e=0;if(!l){break d}h=y[l+30|0];if(!h){break d}e=h-1&127;break d;case 25:h:{if(!d|v[g|0]<0){break h}i:{if(j>>>0<3){break i}e=x[k>>2];if(y[Jb(e,j-3|0)|0]!=240){break i}if(y[Jb(e,j-2|0)|0]>239){break h}}q=$p(b,R,S);j:{if(q<E(4294967296)&q>=E(0)){e=~~q>>>0;break j}e=0}v[g|0]=e;m=128;break d}m=(m&255)==255?f:m;e=f;break d;case 18:k:{if(!j){e=0;break k}h=x[k>>2];e=j;while(1){e=e-1|0;t=Jb(h,e);if(!e){break k}if(y[t|0]!=240){continue}break}}if(j-e>>>0<5){break a}t=x[k>>2];if(y[Jb(t,e)|0]!=240){break a}e=e+5|0;h=0;while(1){if((e|0)!=(j|0)){h=y[Jb(t,e)|0]+h|0;e=e+1|0;continue}break};e=0-h&127;break d;case 13:break e;default:break a}}e=y[J|0];e=Wc(e)?e-1|0:0}h=p^-1;p=1;j=(h&1)+j|0;U=Jb(x[k>>2],j),V=e,v[U|0]=V;j=j+1|0;break a}e=z[F+786>>1];h=y[l+31|0];e=(e?e-1|0:c)&15;l:{if((h|0)==17){break l}e=zj(h)?h-1&15:0}}h=Jb(x[k>>2],j);m:{if(p&1){v[h|0]=e;break m}v[h|0]=y[h|0]<<4|e;j=j+1|0}p=p^1}s=s+1|0;continue}else{if(m<<24>>24>=0){v[g|0]=m}cc(i+8|0,x[k>>2],((p^-1)&1)+j|0);e=x[i+12>>2];x[k>>2]=x[i+8>>2];x[k+4>>2]=e;ib=i+16|0}break}o=x[n+44>>2];j=0;n:while(1){p=0;while(1){e=j;o:{p:{q:{r:{while(1){if(A[n+44>>2]<=e>>>0){break o}f=x[n+40>>2];i=Jb(f,e);g=v[i|0];if((g|0)==-16){g=e;if(o-g>>>0>=4){j=4;if((y[Jb(f,e+1|0)|0]&254)==240){break p}}s:{while(1){g=g+1|0;if(o>>>0<=g>>>0){break s}if(y[Jb(f,g)|0]!=247){continue}break}j=(g-e|0)+1|0;if(j){break p}}U=Jb(f,o),V=247,v[U|0]=V;o=o+1|0;j=o-e|0;break q}if((g|0)<0){break r}if(p&255){e=e-1|0;U=Jb(f,e),V=p,v[U|0]=V;continue}break}j=j+1|0;continue n}U=n,V=cS(g&255),x[U+16>>2]=V;x[n+28>>2]=o-e;j=x[Hb(n+16|0,n+28|0)>>2]}if(!j){break o}f=x[n+40>>2];i=Jb(f,e)}s=y[i|0];Nq(n+16|0,f,x[n+44>>2],e,j);f=dc(n+8|0,x[n+16>>2],x[n+20>>2]);g=x[f+4>>2];x[n>>2]=x[f>>2];x[n+4>>2]=g;i=ib-32|0;ib=i;k=x[n+4>>2];t:{if(!k){break t}l=Qd(y[b+223884|0]);u:{f=x[n>>2];m=Jb(f,0);g=y[m|0]-250|0;if(g>>>0>5|!(1<<g&37)){break u}h=z[a+480188>>1];g=0;while(1){if((g|0)==(h|0)){break u}r=(D(g,872)+b|0)+1453|0;v[r|0]=127;v[r+1|0]=0;g=g+1|0;continue}}v:{if((k|0)!=4|y[m|0]!=240){break v}g=y[Jb(f,1)|0];if((g&254)!=240){break v}k=(D(c,872)+b|0)+616|0;m=Jb(f,2);h=y[Jb(f,3)|0];f=h<<24>>24;w:{x:{y:{z:{A:{B:{m=y[m|0];switch(m|0){case 3:break y;case 2:break z;case 1:break A;case 0:break B;default:break x}}if((g|0)==241|(f|0)<0){break x}g=D(c,872)+b|0;m=g+1453|0;if(d){f=qh($p(b,E(y[m|0]),E((f&255)>>>0)))}v[m|0]=f;v[g+1412|0]=0;f=fq(a,k,!(x[g+704>>2]&32768),256);if((f|0)<0|!(y[g+705|0]&2)){break t}g=x[a+1298300>>2];if(l|Ed(g)^1){break t}jq(g,c,f>>>2&255,1);break t}if((g|0)==241|(f|0)<0){break x}g=D(c,872)+b|0;l=g+1454|0;if(d){f=qh($p(b,E(y[l|0]),E((f&255)>>>0)))}v[l|0]=f;v[g+1411|0]=0;fq(a,k,!(x[g+704>>2]&32768),256);break t}if((g|0)==241){break w}if(f>>>0>31){break t}g=D(c,872)+b|0;v[g+1461|0]=(f&240)>>>4;fq(a,k,!(x[g+704>>2]&32768),256);break t}if((g|0)==241){break w}g=(f|0)<0;f=Ql(a,b,c,3,0)-1|0;if(g|(f&255)>>>0>249){break t}v[i+24|0]=f;g=Nd(a+906300|0,f&255);f=x[g>>2];if(!f){break t}q=E(E(127-h|0)/E(127));if(l){k=0;g=ib-16|0;ib=g;U=g,V=Ej(i+24|0),x[U>>2]=V;f=ib-16|0;ib=f;l=b+223860|0;h=qz(l,f+12|0,y[i+24|0]);m=x[h>>2];if(!m){k=ib-16|0;ib=k;m=gc(l);r=sh(f,mc(24),th(k+8|0,m));m=x[r>>2];u=y[x[g>>2]];x[m+20>>2]=0;v[m+16|0]=u;U=gc(r),V=1,v[U+4|0]=V;ib=k+16|0;Tg(l,x[f+12>>2],h,x[f>>2]);m=ce(f);zk(f);k=1}Sg(g+8|0,x[Wb(f,m)>>2],k);ib=f+16|0;f=ud(x[g+8>>2]);ib=g+16|0;B[f+4>>2]=q;break t}if(!d){vt(x[f+20>>2],q);break t}vt(x[f+20>>2],$p(b,B[g+144>>2],q));break t}if(m<<24>>24<0){break w}if((g|0)!=241){break t}}h=Ql(a,b,c,3,0)-1|0;if((f|0)<0|(h&255)>>>0>249){break t}k=x[Nd(a+906300|0,h&255)>>2];if(!k){break t}g=(g|0)==241?m+128|0:m&127;q=E(E((f&255)>>>0)/E(127));if(l){U=pQ(b+223872|0,IP(i+24|0,h,g)),W=q,B[U>>2]=W;break t}f=x[k>>2];if(!d){lb[x[f+44>>2]](k,g,q);break t}V=k,X=g,W=$p(b,E(lb[x[f+48>>2]](k,g)),q),U=x[x[k>>2]+44>>2],lb[U](V|0,X|0,E(W));break t}if(l){break t}l=z[a+480188>>1];C:{if(l>>>0>c>>>0){g=c+1|0;break C}g=z[(D(c,872)+b|0)+1402>>1];if(!g){break t}}if(y[(D(c,872)+b|0)+707|0]&4|l>>>0<(g&65535)>>>0){break t}g=Ql(a,b,c,3,0)-1|0;if((g&255)>>>0>249){break t}g=x[Nd(a+906300|0,g)>>2];if(!g){break t}l=y[m|0];if((l|0)==240){lg(i+16|0,x[n>>2],x[n+4>>2]);f=x[x[g>>2]+72>>2];k=x[i+20>>2];x[i>>2]=x[i+16>>2];x[i+4>>2]=k;lb[f|0](g,i)|0;break t}U=i,X=cS(l),x[U+24>>2]=X;x[i+12>>2]=k;k=i+24|0;l=x[Hb(k,i+12|0)>>2];x[i+24>>2]=0;rc(k,f,l);lb[x[x[g>>2]+68>>2]](g,x[i+24>>2])|0}ib=i+32|0;p=s>>>0<240?s:p;j=e+j|0;continue}break}break}ib=n+48|0}function cJ(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;h=ib-272|0;ib=h;a:{b:{if(g){wf(h+256|0,f,32);x[27524]=0;W(531,h+240|0,f|0,32)|0;k=x[27524];x[27524]=0;if((k|0)!=1){break b}f=P()|0;break a}Kb(h+256|0);Kb(h+240|0)}c:{d:{e:{f:{g:{h:{i:{j:{if(Fs(c)){k=x[b+24>>2];i=x[k+484344>>2];if(Ce(i,x[k+484348>>2],c&65535)){break j}}x[27524]=0;U(1113,a|0,h+256|0,h+240|0);a=x[27524];x[27524]=0;if((a|0)!=1){break i}f=P()|0;break c}c=Xb(i,c);if(!(!((e|0)<0|x[c+12>>2]<=(d|0)|(d|0)<0)&z[k+480188>>1]>e>>>0)){x[27524]=0;U(1113,a|0,h+256|0,h+240|0);a=x[27524];x[27524]=0;if((a|0)!=1){break i}f=P()|0;break c}c=hd(x[c>>2],x[x[c+48>>2]+12>>2],d,e&65535);Vf(h+256|0);Vf(h+240|0);k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{d=y[c|0];if(!Wc(d)){if(!Wp(d)){break A}}e=y[c+1|0];k=x[b+24>>2];x[27524]=0;X(1114,h+208|0,k|0,d|0,e|0);d=x[27524];x[27524]=0;e=1;if((d|0)==1){break y}x[27524]=0;R(1021,h+224|0,h+208|0);d=x[27524];x[27524]=0;if((d|0)!=1){break z}f=P()|0;break v}e=0;x[27524]=0;Q(55,h+224|0,16742)|0;d=x[27524];x[27524]=0;if((d|0)==1){break x}}x[27524]=0;k=Q(806,h+256|0,h+224|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break w}wb(h+224|0);if(e){xb(h+208|0)}e=9906;d=y[c|0];if(!Wc(d)){e=Wp(d)?10216:16742}x[27524]=0;d=Q(55,h+224|0,e|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break u}x[27524]=0;e=Q(806,h+240|0,d|0)|0;i=x[27524];x[27524]=0;if((i|0)==1){break t}wb(d);if(f-6>>>0>4294967290){break l}x[27524]=0;d=Q(55,h+192|0,17802)|0;i=x[27524];x[27524]=0;if((i|0)==1){break s}x[27524]=0;i=Q(806,k|0,d|0)|0;l=x[27524];x[27524]=0;if((l|0)==1){break r}wb(d);x[27524]=0;d=Q(55,h+176|0,17802)|0;l=x[27524];x[27524]=0;if((l|0)==1){break q}x[27524]=0;l=Q(806,e|0,d|0)|0;j=x[27524];x[27524]=0;if((j|0)==1){break p}wb(d);d=c+1|0;B:{if(y[c+1|0]){x[27524]=0;R(548,h+160|0,d|0);j=x[27524];x[27524]=0;if((j|0)!=1){break B}break d}x[27524]=0;Q(55,h+160|0,16747)|0;j=x[27524];x[27524]=0;if((j|0)==1){break d}}x[27524]=0;j=Q(806,i|0,h+160|0)|0;i=x[27524];x[27524]=0;if((i|0)==1){break o}i=h+160|0;wb(i);d=y[d|0];x[27524]=0;d=Q(55,i|0,(d?10710:16747)|0)|0;i=x[27524];x[27524]=0;if((i|0)==1){break n}x[27524]=0;l=Q(806,l|0,d|0)|0;i=x[27524];x[27524]=0;if((i|0)!=1){break m}f=P()|0;wb(d);break c}f=P()|0;break c}f=P()|0;break c}f=P()|0;wb(h+224|0);if(!e){break c}}xb(h+208|0);break c}f=P()|0;break c}f=P()|0;wb(d);break c}f=P()|0;break c}f=P()|0;wb(d);break c}f=P()|0;break c}f=P()|0;wb(d);break c}f=P()|0;wb(h+160|0);break c}f=P()|0;break c}wb(d);if(f-9>>>0>4294967287){break l}C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{i=oh(y[c|0]);O:{if(i){x[27524]=0;m=Q(55,h+128|0,17802)|0;d=x[27524];x[27524]=0;if((d|0)==1){break N}d=y[c+4|0];n=y[c+2|0];x[27524]=0;o=h,q=nk(n,d)&255,x[o+96>>2]=q;R(547,h+112|0,h+96|0);d=x[27524];x[27524]=0;if((d|0)==1){break M}d=0;x[27524]=0;U(977,h+144|0,m|0,h+112|0);m=x[27524];x[27524]=0;if((m|0)!=1){break O}f=P()|0;break G}d=y[c+2|0];if(d){d=hO(x[x[x[b+24>>2]+8>>2]+88>>2],d);x[27524]=0;d=W(531,h+128|0,1,d|0)|0;m=x[27524];x[27524]=0;if((m|0)==1){break E}x[27524]=0;R(548,h+112|0,c+4|0);m=x[27524];x[27524]=0;if((m|0)==1){break L}x[27524]=0;U(977,h+144|0,d|0,h+112|0);m=x[27524];x[27524]=0;d=1;if((m|0)!=1){break O}f=P()|0;break J}d=0;x[27524]=0;Q(55,h+144|0,16746)|0;m=x[27524];x[27524]=0;if((m|0)==1){break e}}x[27524]=0;j=Q(806,j|0,h+144|0)|0;m=x[27524];x[27524]=0;if((m|0)==1){break K}wb(h+144|0);if(d){wb(h+112|0);wb(h+128|0)}if(i){wb(h+112|0);wb(h+128|0)}d=5491;if(!oh(y[c|0])){d=y[c+2|0]?5487:16746}x[27524]=0;d=Q(55,h+144|0,d|0)|0;i=x[27524];x[27524]=0;if((i|0)==1){break D}x[27524]=0;i=Q(806,l|0,d|0)|0;l=x[27524];x[27524]=0;if((l|0)!=1){break C}f=P()|0;wb(d);break c}f=P()|0;break c}f=P()|0;break F}f=P()|0;break I}f=P()|0;wb(h+144|0);if(!d){break H}}wb(h+112|0)}wb(h+128|0)}if(!i){break c}}wb(h+112|0)}wb(h+128|0);break c}f=P()|0;break c}f=P()|0;break c}wb(d);if(f-13>>>0>4294967283){break l}x[27524]=0;d=Q(55,h+96|0,17802)|0;l=x[27524];x[27524]=0;P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{if((l|0)!=1){x[27524]=0;l=Q(806,j|0,d|0)|0;j=x[27524];x[27524]=0;if((j|0)==1){break Z}wb(d);x[27524]=0;d=Q(55,h+80|0,17802)|0;j=x[27524];x[27524]=0;if((j|0)==1){break Y}x[27524]=0;i=Q(806,i|0,d|0)|0;j=x[27524];x[27524]=0;if((j|0)==1){break X}wb(d);_:{if(oh(y[c|0])){d=y[c+5|0];j=y[c+3|0];b=0;x[27524]=0;o=h,q=nk(j,d)&4095,x[o+16>>2]=q;R(1115,h- -64|0,h+16|0);d=x[27524];x[27524]=0;if((d|0)!=1){break _}f=P()|0;break c}d=y[c+3|0];if(d){b=gO(x[x[x[b+24>>2]+8>>2]+84>>2],d);x[27524]=0;b=W(531,h+48|0,1,b|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break W}x[27524]=0;R(548,h+32|0,c+5|0);d=x[27524];x[27524]=0;if((d|0)==1){break V}x[27524]=0;U(977,h- -64|0,b|0,h+32|0);d=x[27524];x[27524]=0;b=1;if((d|0)!=1){break _}f=P()|0;break S}b=0;x[27524]=0;Q(55,h- -64|0,16742)|0;d=x[27524];x[27524]=0;if((d|0)==1){break U}}x[27524]=0;Q(806,l|0,h- -64|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break T}wb(h- -64|0);if(b){wb(h+32|0);wb(h+48|0)}b=11074;if(!oh(y[c|0])){b=y[c+3|0]?11074:16742}x[27524]=0;b=Q(55,h- -64|0,b|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break Q}x[27524]=0;Q(806,i|0,b|0)|0;c=x[27524];x[27524]=0;if((c|0)!=1){break P}f=P()|0;wb(b);break c}f=P()|0;break c}f=P()|0;wb(d);break c}f=P()|0;break c}f=P()|0;wb(d);break c}f=P()|0;break c}f=P()|0;break R}f=P()|0;break c}f=P()|0;wb(h- -64|0);if(!b){break c}}wb(h+32|0)}wb(h+48|0);break c}f=P()|0;break c}wb(b);if(!f){break k}}$:{aa:{ba:{ca:{b=Eb(k);da:{if(b>>>0>f>>>0){x[27524]=0;X(134,h+16|0,k|0,0,f|0);b=x[27524];x[27524]=0;if((b|0)!=1){b=h+16|0;Ac(k,b);wb(b);break da}f=P()|0;break c}if(!g){break da}x[27524]=0;b=W(531,h+16|0,f-b|0,32)|0;c=x[27524];x[27524]=0;if((c|0)==1){break ca}x[27524]=0;Q(806,k|0,b|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break ba}wb(b)}b=Eb(e);if(b>>>0<=f>>>0){break $}x[27524]=0;X(134,h|0,e|0,0,f|0);b=x[27524];x[27524]=0;if((b|0)==1){break aa}Ac(e,h);wb(h);break k}f=P()|0;break c}f=P()|0;wb(b);break c}f=P()|0;break c}if(!g){break k}x[27524]=0;b=W(531,h|0,f-b|0,32)|0;c=x[27524];x[27524]=0;if((c|0)==1){break h}x[27524]=0;Q(806,e|0,b|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break g}wb(b)}x[27524]=0;U(1113,a|0,k|0,e|0);a=x[27524];x[27524]=0;if((a|0)==1){break f}}wb(h+240|0);wb(h+256|0);ib=h+272|0;return}f=P()|0;break c}f=P()|0;wb(b);break c}f=P()|0;break c}f=P()|0;break c}f=P()|0}wb(h+240|0)}wb(h+256|0);S(f|0);p()}function cq(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=ib-16|0;ib=g;i=z[a+480192>>1]>=c>>>0?x[((c<<2)+a|0)+900380>>2]:i;s=x[b+752>>2];k=y[b+802|0];a:{if(!k){Ab(g+8|0,a+1074312|0,11);if(zb(x[x[g+8>>2]>>2],x[g+12>>2])){break a}}b:{c:{if(!i){break c}if(!Wc(k)){break c}d:{l=k-1|0;k=bc(i+236|0,l);if(z[k>>1]){break d}Ab(g+8|0,a+1074312|0,43);if(!zb(x[x[g+8>>2]>>2],x[g+12>>2])){break d}if(zj(y[i+31|0])){break d}x[b+656>>2]=i;break a}if(y[Jb(i+108|0,l)|0]>120){break a}l=z[k>>1];l=(l-1&65535)>>>0<3999?(D(l,104)+a|0)+484380|0:0;break b}l=(D(c,104)+a|0)+484380|0;if(!z[a+480192>>1]){break b}if(k>>>0>250){break a}Ab(g+8|0,a+1074312|0,43);if(zb(x[x[g+8>>2]>>2],x[g+12>>2])){if(i){l=0;if(zj(y[i+31|0])){break b}}v[b+803|0]=0;x[b+656>>2]=0;break a}l=0}k=x[b+104>>2];n=(k|0)!=0&(k|0)!=(l|0);h=x[b+656>>2];p=!i|x[a+480180>>2]!=16777216?p:x[i+44>>2]!=0;q=d^1;k=(h|0)!=(i|0);if((q|k|n)==1){w[b+774>>1]=0}o=!n;if(!(o|(k|!(d&p)))){break a}e:{if(!(d&n)){break e}r=a+1074312|0;Ab(g+8|0,r,32);if(!(!zb(x[x[g+8>>2]>>2],x[g+12>>2])|!(y[a+480208|0]&8))){l=x[b+8>>2]|x[b+12>>2]?x[b+104>>2]:l}j=x[a+480180>>2];f:{if(!(i?k|!(j&1048580):1)|(j|0)==268435456){break f}if((j|0)==1){if(Gi(x[b+8>>2],x[b+12>>2])){break f}}Ab(g+8|0,r,79);if(!zb(x[x[g+8>>2]>>2],x[g+12>>2])){break e}if(!Gi(x[b+8>>2],x[b+12>>2])){break e}}m=1}g:{if(!x[b+16>>2]|(k|!z[a+480192>>1]|o)){break g}Ab(g+8|0,a+1074312|0,87);if(!zb(x[x[g+8>>2]>>2],x[g+12>>2])){break g}m=Wc(y[b+788|0])^1|m}o=(h|0)!=(i|0);h:{if(Gi(x[b+8>>2],x[b+12>>2])|!(x[a+480180>>2]&16777248)){break h}if(i){if(zj(y[i+31|0])){break h}}o=1}i:{j:{k:{if(!(n|o)|!d){break k}Ab(g+8|0,a+1074312|0,61);if(!zb(x[x[g+8>>2]>>2],x[g+12>>2])){break k}j=x[b+656>>2];if(j){break j}j=0;h=x[b+104>>2];k=0;if(h){break i}}x[b+656>>2]=i;j=i;h=l;k=o;break i}h=x[b+104>>2];k=0}l:{m:{n:{if(!e){break n}o:{if(y[a+480180|0]&3){if(h){if(_d(x[h>>2],x[h+20>>2])){break o}}if(!uj(j)){break n}}if(!h){break m}}if(w[h+34>>1]<0){break n}x[b+688>>2]=z[h+30>>1]}i=(h|0)!=0;if(!(n&m)|!h){break l}Ab(g+8|0,a+1074312|0,85);if(zb(x[x[g+8>>2]>>2],x[g+12>>2])){w[b+772>>1]=v[h+37|0]}i=1;if(x[a+480180>>2]!=2){break l}if(!_d(x[h>>2],x[h+20>>2])){break l}x[b+704>>2]=x[h+24>>2];break l}if(!(!j|!y[j+34|0])){i=x[b+688>>2];if(j){i=x[j+4>>2]<<2}x[b+688>>2]=i;i=0;break l}i=0;x[b+688>>2]=0}if(m){break a}v[b+803|0]=0;p:{if(!j){break p}Ab(g+8|0,a+1074312|0,29);if(!((zb(x[x[g+8>>2]>>2],x[g+12>>2])^-1)&i|y[j+34|0]|k)){break p}v[b+798|0]=y[j+16|0]}m=64;x[b+752>>2]=64;if(h){m=z[h+32>>1];x[b+752>>2]=m}if(j){x[b+752>>2]=D(x[j+4>>2],m)>>>6}q:{if(!(x[a+480180>>2]&1048580?e:1)){break q}Ab(g+8|0,a+1074312|0,48);if(zb(x[x[g+8>>2]>>2],x[g+12>>2])){break q}XP(a,b,j,h)}r:{s:{t:{u:{if(!f){break u}f=a+1074312|0;Ab(g+8|0,f,19);v:{w:{x:{y:{z:{A:{B:{C:{if(zb(x[x[g+8>>2]>>2],x[g+12>>2])){if(!x[b+76>>2]){e=1;break B}if(!(!c|q)){e=(y[a+480208|0]&8)>>>3|0;if(e){break B}break C}e=0;if(c){break C}break B}D:{c=x[a+480180>>2]&17301536;e=1;E:{if(!d|!c){break E}c=1;e=1;if(y[a+480208|0]&8){break E}e=1;if(!x[b+76>>2]){break E}if(!(y[b+89|0]&16)){break D}e=!x[b+696>>2]}if(!j|(k|!c)){break z}if(!e){break v}c=x[b+88>>2];x[b+88>>2]=c|2097152;if(c&6144){break y}break A}if((k|!j)!=1){break v}break w}if(d){break B}if(!(y[b+89|0]&24)){e=0;break B}e=(y[a+480208|0]&4)>>>2|0}if(k|!x[b+696>>2]){break z}if(!e){break w}c=x[b+88>>2];x[b+88>>2]=c|2097152;if(!j){break x}if(c&2048){break y}}if(!(y[j+60|0]&8)){tj(b+724|0)}if(!(y[j+80|0]&8)){tj(b+732|0)}if(y[j+100|0]&8){break x}tj(b+740|0);break x}if(!e){break w}x[b+88>>2]=x[b+88>>2]|2097152;if(!j){break x}}ym(b)}Ab(g+8|0,f,21);if(zb(x[x[g+8>>2]>>2],x[g+12>>2])){break u}v[b+818|0]=0;x[b+756>>2]=0;break u}if(!j){break t}}if(v[j+60|0]&1){break u}Ab(g+8|0,f,32);if(zb(x[x[g+8>>2]>>2],x[g+12>>2])){tj(b+724|0);break u}ym(b)}c=0;if(h){break s}if(!j){break r}c=1;if(zj(y[j+31|0])){break s}break r}c=0;if(!h){break r}}F:{if(!(!d|(i^1|x[b+104>>2]!=(h|0)))){e=x[a+480180>>2];if(x[b+76>>2]?e&16777250:0){break a}G:{H:{if((e|0)!=4){break H}Ab(g+8|0,a+1074312|0,40);if(!zb(x[x[g+8>>2]>>2],x[g+12>>2])|y[b+789|0]){break H}e=x[b+88>>2];break G}e=x[b+88>>2]&-6145}x[b+88>>2]=e&-640;break F}x[b+88>>2]=x[b+88>>2]&-6145;f=a+1074312|0;Ab(g+8|0,f,18);I:{J:{K:{if(!zb(x[x[g+8>>2]>>2],x[g+12>>2])){if(x[a+480180>>2]&16777248){break J}if(x[b+104>>2]==(h|0)){break K}break J}if(x[b+104>>2]!=(h|0)){break J}}e=-640;if(!k){break I}}e=-768}x[b+88>>2]=e&x[b+88>>2];if(!j){break F}v[b+730|0]=y[j+60|0];v[b+738|0]=y[j+80|0];v[b+746|0]=y[j+100|0];L:{if((y[j+100|0]&17)!=17){break L}Ab(g+8|0,f,36);if(zb(x[x[g+8>>2]>>2],x[g+12>>2])|y[b+837|0]){break L}v[b+837|0]=127}e=y[j+21|0];if(Ue(e)){t=b,u=Wm(e),v[t+837|0]=u}e=y[j+22|0];if(!Ue(e)){break F}t=b,u=Wm(e),v[t+838|0]=u}if(c){x[b+76>>2]=0;x[b+104>>2]=0;break a}M:{if(x[b+76>>2]|!d){break M}c=a+1074312|0;Ab(g+8|0,c,54);if(!zb(x[x[g+8>>2]>>2],x[g+12>>2])){Ab(g,c,39);if(!zb(x[x[g>>2]>>2],x[g+4>>2])){break M}}x[b+8>>2]=0;x[b+12>>2]=0}N:{if(y[b+788|0]!=255){break N}Ab(g+8|0,a+1074312|0,100);if(!zb(x[x[g+8>>2]>>2],x[g+12>>2])|(!(y[a+480208|0]&4)|!n)){break N}c=x[b+104>>2];if(c){x[b+88>>2]=x[b+88>>2]|z[c+34>>1]&1023}x[b+752>>2]=s;x[b+688>>2]=z[h+30>>1];if(!(y[h+34|0]&32)){break a}lq(b,z[h+28>>1],a);break a}x[b+104>>2]=h;x[b+76>>2]=x[h>>2];x[b+80>>2]=x[h+4>>2];x[b+84>>2]=x[h+8>>2];c=a+1074312|0;Ab(g+8|0,c,83);if(!(!zb(x[x[g+8>>2]>>2],x[g+12>>2])|x[b+80>>2])){x[b+84>>2]=x[h>>2]}x[b+88>>2]=x[b+88>>2]|z[h+34>>1]&1023;Ab(g+8|0,c,21);if(zb(x[x[g+8>>2]>>2],x[g+12>>2])){v[b+818|0]=0;x[b+756>>2]=0}O:{P:{if(p){x[b+704>>2]=x[h+24>>2];v[b+851|0]=y[b+851|0]|64;d=0;break P}if(!(n|q)){d=x[a+480180>>2];if(d&5){break O}}x[b+704>>2]=x[h+24>>2];d=v[h+37|0]}w[b+772>>1]=d;d=x[a+480180>>2]}if(Nm(d)){d=v[h+36|0]}else{d=0}w[b+770>>1]=d;Ab(g+8|0,c,69);if(!(zb(x[x[g+8>>2]>>2],x[g+12>>2])|x[a+480180>>2]==1)){x[b+708>>2]=0}x[b+852>>2]=0;i=x[b+88>>2];if(i&8){x[b+80>>2]=x[h+12>>2];x[b+84>>2]=x[h+16>>2];i=i>>>2&4|i|2;x[b+88>>2]=i}Q:{if(!(i&2)){i=x[b+76>>2];break Q}i=x[b+76>>2];c=x[b+84>>2];if(i>>>0<=c>>>0){break Q}x[b+76>>2]=c;i=c}if(!(x[a+480180>>2]&16777248)|A[b+4>>2]<i>>>0){break a}x[b>>2]=0;x[b+4>>2]=0;break a}x[b+752>>2]=0;x[b+104>>2]=0}ib=g+16|0}function Vma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0;e=ib-272|0;ib=e;yc(b);d=ib-16|0;ib=d;i=e+112|0;CW(d+8|0,i);g=x[d+12>>2];kc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);h=x[d+4>>2];if((h|0)==(g|0)){Yb(b,x[d+12>>2])}ib=d+16|0;d=(g|0)==(h|0);if(!d){BW(i)}a:{if(!d){break a}if(!DW(e+112|0)){break a}if(!c){f=1;break a}zd(a,x[(z[e+228>>1]<<2)+26400>>2]);x[a+480208>>2]=x[a+480208>>2]|16777216;d=e+48|0;f=xc(d,13067);Gb(a+1298344|0,f);xb(f);f=xc(d,10251);Gb(a+1298356|0,f);xb(f);f=ib-16|0;ib=f;g=e+8|0;i=xc(f,4392);$c(g,i);xb(i);ib=f+16|0;x[27524]=0;X(233,d|0,g|0,y[e+191|0],e+188|0);d=x[27524];x[27524]=0;b:{if((d|0)!=1){d=e+48|0;Gb(a+1298368|0,d);xb(d);f=e+8|0;$b(f);Vl(a+1298392|0,(z[e+228>>1]<<2)+26448|0);Vl(a+1298380|0,x[(z[e+228>>1]<<2)+26496>>2]);x[a+1298404>>2]=4;Se(f,2,e+112|4);Fc(d,f);Ac(a+1298308|0,d);wb(d);Se(f,2,e+148|0);Fc(d,f);c:{if(Jq(d,9688)){x[27524]=0;U(11,e+8|0,4,e+48|0);d=x[27524];x[27524]=0;if((d|0)==1){break c}d=e+8|0;Gb(a+1298320|0,d);xb(d)}wb(e+48|0);w[a+480188>>1]=32;d=0;d:{while(1){if((d|0)!=32){g=(d<<5)+a|0;i=g+480280|0;lf(i);f=y[(d+e|0)+193|0];e:{if(f>>>0<=15){x[e+48>>2]=f<<4|8;x[e+8>>2]=256;u=g+480284|0,A=x[rd(e+48|0,e+8|0)>>2],w[u>>1]=A;break e}if((f|0)!=16){if((f|0)!=255){break e}w[a+480188>>1]=d;break d}w[g+480284>>1]=128;x[i>>2]=256}d=d+1|0;continue}break}d=z[a+480188>>1]}f=0;if(!(d&65535)){break a}x[e+48>>2]=y[e+225|0]<<2;x[e+8>>2]=256;u=a,A=x[Hb(e+48|0,e+8|0)>>2],x[u+480200>>2]=A;x[a+480196>>2]=y[e+226|0];x[a+480204>>2]=D(y[e+227|0],1e4);if(bd(b,z[e+230>>1]|z[e+232>>1]<<16)){wo(Tb(x[a+484360>>2],y[a+484376|0]),b,y[e+234|0]+1|0,255,254)}if(!bd(b,x[e+240>>2])){break a}l=a+480190|0;d=y[e+248|0]+1|0;w[l>>1]=d;m=e+80|0;n=a+480180|0;i=1;while(1){f:{g:{j=i&65535;if(j>>>0>(d&65535)>>>0){break g}d=ib-16|0;ib=d;g=e+48|0;cc(d+8|0,g,62);f=x[d+12>>2];kc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);h=x[d+4>>2];if((h|0)==(f|0)){Yb(b,x[d+12>>2])}ib=d+16|0;d=(f|0)==(h|0);if(!d){Rb(g,0,62)}if(!d){break g}d=0;f=D(j,104)+a|0;k=f+484380|0;md(k,0);h=e+32|0;Se(h,2,e+48|0);g=e+8|0;Fc(g,h);Cc(((j<<5)+a|0)+946304|0,g);wb(g);Bk(h,2,m);Fc(g,h);Fe(f+484423|0,g);wb(g);g=z[e+106>>1];x[f+484404>>2]=g;if(!Nm(x[n>>2])){break f}while(1){if((d|0)==16){break f}if((g|0)==z[(d<<1)+26544>>1]){v[f+484417|0]=d<<4;break f}else{d=d+1|0;continue}}}h:{if(!(c&2)){break h}if(!bd(b,x[e+244>>2])){break h}d=1;f=a+480190|0;while(1){g=d&65535;if(g>>>0>z[f>>1]){break h}g=D(g,104)+a|0;Eg(Zc(e+48|0,w[g+484414>>1]&1?16:8,1,0,1),g+484380|0,b);d=d+1|0;continue}}n=a+484344|0;Fg(n,y[e+239|0]+1|0);f=Iq(a);d=ib-16|0;ib=d;x[d+12>>2]=0;qt(d+12|0,f);k=x[d+12>>2];ib=d+16|0;bd(b,y[e+235|0]|y[e+236|0]<<8|(y[e+237|0]<<16|y[e+238|0]<<24));q=c&1;r=a+480188|0;s=a+480180|0;j=0;m=1;i:{j:{k:{while(1){if(y[e+239|0]<j>>>0){if(x[a+480180>>2]==1){break k}c=x[a+480208>>2]&-8454145;break j}l:{d=_g(b);if(d>>>0>=3){c=e+8|0;ae(c,b,d-2|0);h=hc(e+48|0,c);yb(c);m:{if(!q){break m}c=x[h>>2];x[27524]=0;c=T(182,c|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break l}if(!c){break m}x[27524]=0;c=W(230,n|0,j&65535,64)|0;d=x[27524];x[27524]=0;if((d|0)==1){break l}l=0;if(!c){break m}while(1){if((l|0)==64){break m}c=Xb(x[n>>2],j);t=qf(x[c>>2],x[x[c+48>>2]+12>>2],l);n:{o:while(1){x[27524]=0;c=T(210,h|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break i}if(!c){break n}d=c&31;if(d>>>0>=z[r>>1]){break n}f=D(d,6)+t|0;if(c&32){x[27524]=0;R(264,e+8|0,h|0);d=x[27524];x[27524]=0;if((d|0)==1){break i}g=Lc(e+8|0);d=y[e+8|0];if(d){d=(d&127)-1|0;v[e+8|0]=d;d=(D((d&240)>>>4|0,12)+(d&15)|0)+13|0;v[f|0]=d;m=OB(d)&m}v[f+1|0]=y[g|0]}if(!(c&64)){continue}v[f+2|0]=0;v[f+3|0]=0;g=f+5|0;while(1){c=x[h>>2];x[27524]=0;c=W(160,c|0,x[e+56>>2],2)|0;d=x[27524];x[27524]=0;if((d|0)==1){break i}if(!c){continue o}o=y[f+5|0];c=y[f+3|0];x[27524]=0;R(264,e+8|0,h|0);d=x[27524];x[27524]=0;if((d|0)!=1){i=y[Lc(e+8|0)|0];v[g|0]=i;d=y[(y[e+8|0]&31)+26576|0];v[f+3|0]=d;p:{q:{r:{s:{t:{switch(d-2|0){case 0:case 1:if(i>>>0<224){break r}d=223;if(x[s>>2]!=1){break s}break r;case 11:v[e+32|0]=64;u=g,A=y[Ub(g,e+32|0)|0],v[u|0]=A;if(!AW(x[k+88>>2])){break r}v[f+2|0]=1;v[f+4|0]=y[g|0];v[f+3|0]=c;v[g|0]=o;d=c;break q;case 17:u:{switch(((i&240)>>>4|0)-8|0){case 0:v[f+3|0]=2;v[g|0]=i&15|224;break p;case 1:v[f+3|0]=3;v[g|0]=i&15|224;break p;default:break u}}if(Qu(x[k+84>>2],19)){break r}nv(f);break r;case 13:d=x[k+84>>2];if(Qu(d,15)){break r}if(!Qu(d,19)){break r}v[f+3|0]=19;v[g|0]=i&15|144;break p;case 18:d=145;if((i|0)==1){break s}if((i&240)==128){if(Qu(x[k+84>>2],20)){break r}v[f+3|0]=19;break p}v[f+3|0]=0;break p;case 4:case 5:break t;default:break q}}d=i&240;if(!d){break r}}v[g|0]=d}d=y[f+3|0]}if((d&255)!=20){break p}d=y[g|0];if(y[f+2|0]|(d&240)!=128){break p}v[f+2|0]=2;v[f+4|0]=(((d&15)<<6|8)>>>0)/15;v[f+3|0]=c;v[g|0]=o}if(!(y[e+8|0]&32)){continue o}continue}break}break}break i}l=l+1|0;continue}}yb(h)}j=j+1|0;continue}break}break i}c=x[a+480208>>2]&-8454145|(z[a+480188>>1]==4?m&1?8454144:0:0)}x[a+480208>>2]=c;f=1;if(!(y[e+253|0]|y[e+254|0]<<8|(y[e+255|0]<<16|y[e+256|0]<<24))){break a}if(!bd(b,y[e+249|0]|y[e+250|0]<<8|(y[e+251|0]<<16|y[e+252|0]<<24))){break a}cC(a+1298332|0,b,y[e+253|0]|y[e+254|0]<<8|(y[e+255|0]<<16|y[e+256|0]<<24),4);break a}d=P()|0;yb(h);break b}w[f+484412>>1]=64;g=y[e+93|0]|y[e+94|0]<<8|(y[e+95|0]<<16|y[e+96|0]<<24);x[k>>2]=g;d=y[e+105|0];if(d&2){h=f+484414|0;w[h>>1]=z[h>>1]|1;x[k>>2]=g>>>1}x[f+484384>>2]=y[e+97|0]|y[e+98|0]<<8|(y[e+99|0]<<16|y[e+100|0]<<24);x[f+484388>>2]=(y[e+101|0]|y[e+102|0]<<8|(y[e+103|0]<<16|y[e+104|0]<<24))-1;if(d&1){g=f+484414|0;w[g>>1]=z[g>>1]|2}v:{w:{if(!(d&4)){break w}g=y[e+108|0];if((g|0)==255){break w}v[e+8|0]=g;v[e+32|0]=64;u=f+484410|0,A=y[Ub(e+8|0,e+32|0)|0]<<2,w[u>>1]=A;break v}g=f+484414|0;w[g>>1]=z[g>>1]|32768}x:{if(d&8){d=f+484414|0;g=z[d>>1]|32;w[d>>1]=g;j=f+484408|0;f=y[e+109|0];if(f>>>0<=15){x[e+32>>2]=256;x[e+8>>2]=f<<4|8;h=x[rd(e+8|0,e+32|0)>>2]}else{h=128}w[j>>1]=h;w[d>>1]=g&65279|((f|0)==16)<<8;break x}w[f+484408>>1]=128}i=i+1|0;d=z[l>>1];continue}}d=P()|0;wb(e+48|0);break b}d=P()|0;$b(e+8|0)}S(d|0);p()}ib=e+272|0;return f|0}function LY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;e=ib-224|0;ib=e;yc(b);a:{b:{c:{d:{if(!cD(b,e+176|0)){break d}if(!fD(e+176|0)){break d}if(!c){n=1;break d}zd(a,2048);gg(a);d=ib-16|0;ib=d;f=e+8|0;h=xc(d,3947);$c(f,h);xb(h);ib=d+16|0;x[27524]=0;U(217,e+80|0,f|0,y[e+179|0]);d=x[27524];x[27524]=0;e:{f:{g:{h:{i:{j:{k:{if((d|0)!=1){d=e+80|0;Gb(a+1298344|0,d);xb(d);f=e+8|0;$b(f);h=xc(d,11058);Gb(a+1298356|0,h);xb(h);x[a+1298404>>2]=4;h=a+480188|0;w[h>>1]=y[e+216|0];w[a+480190>>1]=y[e+212|0];Se(f,2,e+176|4);Fc(d,f);Ac(a+1298308|0,d);wb(d);d=y[e+179|0];l:{if(d>>>0>=9){if(d>>>0>=11){f=(d|0)==11?16:32;d=0;while(1){if((d|0)==(f|0)){break l}h=Ev(b);m:{if((h|0)==100){x[((d<<5)+a|0)+480280>>2]=256;break m}x[e+80>>2]=(h<<1)+128;x[e+8>>2]=0;x[e+160>>2]=256;t=((d<<5)+a|0)+480284|0,u=x[Oj(e+80|0,e+8|0,e+160|0)>>2],w[t>>1]=u}d=d+1|0;continue}}f=e+80|0;d=ib-16|0;ib=d;n:{if(!Ob(x[b>>2],x[b+8>>2],16)){SC(f);break n}uv(d+8|0,f);sd(d,b,x[d+8>>2],x[d+12>>2])}ib=d+16|0;d=0;while(1){if((d|0)==16){break l}w[((d<<5)+a|0)+480284>>1]=v[(e+80|0)+d|0]&1?64:192;d=d+1|0;continue}}w[h>>1]=4;Gg(b,1);uh(a,1)}o:{if(y[e+179|0]>=13){d=e+80|0;xv(d,b);f=Lc(d);d=y[e+80|0];if(d>>>0<=31){v[e+80|0]=125;d=125}x[a+480204>>2]=D(d,1e4);x[a+480196>>2]=y[f|0];break o}x[a+480196>>2]=6;x[a+480204>>2]=125e4}Dg(Tb(x[a+484360>>2],y[a+484376|0]),y[e+213|0]);l=Nb(e+160|0);f=y[e+179|0];r=x[b+8>>2]+((f>>>0>13)<<1)|0;d=0;p:{if(f>>>0<14){break p}x[27524]=0;R(218,l|0,y[e+213|0]);f=x[27524];x[27524]=0;if((f|0)!=1){break p}d=P()|0;break b}q:{r:{s:{while(1){t:{if(y[e+213|0]<=d>>>0){d=0;if(y[e+179|0]!=10){break s}m=x[b+8>>2];k=a+480190|0;d=1;while(1){j=z[k>>1];if(j>>>0<(d&65535)>>>0){break t}x[27524]=0;f=Q(219,b|0,e+80|0)|0;h=x[27524];x[27524]=0;if((h|0)==1){break r}if(f){f=0;u:{if(y[e+212|0]<(y[e+126|0]|y[e+127|0]<<8|(y[e+128|0]<<16|y[e+129|0]<<24))>>>0|y[e+80|0]>1){break u}h=y[e+130|0]|y[e+131|0]<<8|(y[e+132|0]<<16|y[e+133|0]<<24);if(h>>>0>1048576|y[e+136|0]>64|h>>>0<(y[e+137|0]|y[e+138|0]<<8|(y[e+139|0]<<16|y[e+140|0]<<24))>>>0){break u}f=h>>>0>=(y[e+141|0]|y[e+142|0]<<8|(y[e+143|0]<<16|y[e+144|0]<<24))>>>0}if(!f){break t}}d=d+1|0;continue}}t=bc(x[Tb(x[a+484360>>2],y[a+484376|0])>>2],d),u=d,w[t>>1]=u;if(y[e+179|0]>=14){x[27524]=0;f=T(198,b|0)|0;h=x[27524];x[27524]=0;if((h|0)==1){break q}t=bc(x[l>>2],d),u=f,w[t>>1]=u}f=z[a+480188>>1];x[27524]=0;Q(192,b|0,f<<1)|0;f=x[27524];x[27524]=0;if((f|0)==1){break q}d=d+1|0;continue}break}x[27524]=0;Q(159,b|0,m|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break c}d=j>>>0>=(d&65535)>>>0}j=a+480190|0;f=z[j>>1];x[27524]=0;x[e+80>>2]=0;m=W(220,e- -64|0,f|0,e+80|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break k}n=d?59:65;k=e+80|1;f=1;v:{while(1){h=f&65535;if(h>>>0>z[j>>1]){h=Nb(e+48|0);x[27524]=0;n=W(221,b|0,h|0,z[e+214>>1])|0;d=x[27524];x[27524]=0;w:{if((d|0)!=1){if(!n){break e}d=0;k=0;f=x[h>>2];if(!pc(f,x[h+4>>2])){f=Cb(f);g=Cb(x[h+4>>2]);k=ib-16|0;ib=k;x:{if(!Mb(f,g)){break x}x[k+8>>2]=f;while(1){j=x[Ye(k+8|0)>>2];if(!Mb(j,g)){break x}f=Lk(y[f|0]|y[f+1|0]<<8,y[j|0]|y[j+1|0]<<8)?j:f;continue}}ib=k+16|0;k=y[f|0]|y[f+1|0]<<8}x[27524]=0;j=Q(222,e+32|0,k|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break w}y:{while(1){if((d|0)==(k|0)){if(!(c&2)){break j}i=Zc(e+80|0,8,1,0,1);o=a+480190|0;f=z[o>>1];g=1;z:{A:while(1){q=g&65535;if(q>>>0>(f&65535)>>>0){break j}d=x[b+8>>2];f=x[b>>2];x[27524]=0;d=W(160,f|0,d|0,1)|0;f=x[27524];x[27524]=0;if((f|0)==1){break z}if(!d){break j}s=x[b+8>>2];d=0;while(1){f=z[o>>1];if(f>>>0<=d>>>0){g=g+1|0;continue A}if((q|0)!=x[Bb(x[m>>2],d)>>2]){d=d+1|0;continue}x[27524]=0;Q(159,b|0,s|0)|0;f=x[27524];x[27524]=0;if((f|0)!=1){x[27524]=0;d=d+1|0;W(223,i|0,(D(d,104)+a|0)+484380|0,b|0)|0;f=x[27524];x[27524]=0;if((f|0)!=1){continue}}break}break}d=P()|0;break i}d=P()|0;break i}x[27524]=0;f=T(198,b|0)|0;g=x[27524];x[27524]=0;B:{if((g|0)==1){break B}x[27524]=0;Q(192,b|0,1)|0;g=x[27524];x[27524]=0;if((g|0)==1){break B}if(f){x[27524]=0;U(194,e+8|0,b|0,D(f,3)+(y[e+179|0]==1?3:0)|0);f=x[27524];x[27524]=0;if((f|0)==1){break y}g=e+8|0;f=hc(e+80|0,g);fd(Yg(x[j>>2],d),f);yb(f);yb(g)}d=d+1|0;continue}break}d=P()|0;break i}d=P()|0;break i}d=P()|0;break h}d=P()|0;break h}C:{D:{if(y[e+179|0]<=9){x[27524]=0;R(224,b|0,e+80|0);g=x[27524];x[27524]=0;E:{F:{if((g|0)==1){break F}x[27524]=0;R(225,e+80|0,(D(h,104)+a|0)+484380|0);g=x[27524];x[27524]=0;if((g|0)==1){break F}g=e+48|0;Se(g,2,k);x[27524]=0;R(226,e+8|0,g|0);g=x[27524];x[27524]=0;if((g|0)==1){break E}break D}d=P()|0;break g}d=P()|0;break g}x[27524]=0;U(227,b|0,e+80|0,n|0);g=x[27524];x[27524]=0;if((g|0)==1){break C}x[27524]=0;U(228,e+80|0,(D(h,104)+a|0)+484380|0,d|0);g=x[27524];x[27524]=0;if((g|0)==1){break C}g=e+48|0;Se(g,2,k);x[27524]=0;R(226,e+8|0,g|0);g=x[27524];x[27524]=0;if((g|0)==1){break v}}g=e+8|0;Cc(((h<<5)+a|0)+946304|0,g);wb(g);t=Bb(x[m>>2],h-1|0),u=z[e+126>>1]|z[e+128>>1]<<16,x[t>>2]=u;f=f+1|0;continue}break}d=P()|0;break g}d=P()|0;break g}d=P()|0;break b}d=P()|0;break b}d=P()|0;$b(e+8|0);break a}d=P()|0;break b}if(!(c&1)){break f}x[27524]=0;g=a+484344|0;R(229,g|0,y[e+213|0]);c=x[27524];x[27524]=0;G:{if((c|0)!=1){f=a+480188|0;a=0;while(1){H:{if(y[e+213|0]<=a>>>0){break f}d=64;c=x[l>>2];if(Oc(c,x[l+4>>2])>>>0>a>>>0){d=z[bc(c,a)>>1]}x[27524]=0;c=W(230,g|0,a&65535,d&65535)|0;d=x[27524];x[27524]=0;if((d|0)==1){break G}I:{if(c){c=z[f>>1];x[27524]=0;Q(159,b|0,D(((y[e+179|0]>13)<<1)+(c<<1)|0,a)+r|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break G}c=Nb(e+80|0);d=z[f>>1];x[27524]=0;i=W(221,b|0,c|0,d|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break I}d=0;J:{if(!i){break J}while(1){if(z[f>>1]<=d>>>0){break J}K:{i=bc(x[c>>2],d);i=y[i|0]|y[i+1|0]<<8;if(!i|i>>>0>z[e+214>>1]){break K}i=bc(x[h>>2],i-1|0);i=(y[i|0]|y[i+1|0]<<8)-1&65535;if(i>>>0>=k>>>0){break K}o=x[g>>2];q=x[j>>2];x[27524]=0;U(231,Xb(o,a)|0,d&65535,Yg(q,i)|0);i=x[27524];x[27524]=0;if((i|0)!=1){break K}break H}d=d+1|0;continue}}jd(c)}a=a+1|0;continue}}break}d=P()|0;jd(c);break i}d=P()|0;break i}d=P()|0}Sc(j)}jd(h)}uc(m);break b}Sc(j)}jd(h);uc(m);jd(l)}ib=e+224|0;return n|0}d=P()|0}jd(l)}S(d|0);p()}function u1(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,w=0,z=0,A=0,B=0,C=0,D=0;l=ib-560|0;ib=l;x[l+548>>2]=k;x[l+552>>2]=b;a:{b:{if(gk(a,l+552|0)){x[f>>2]=x[f>>2]|4;a=0;break b}x[l+96>>2]=1186;b=l+96|0;s=xe(l+136|0,l+144|0,b);m=x[s>>2];x[l+132>>2]=m;x[l+128>>2]=m+400;w=Kb(b);n=Kb(l+80|0);q=Kb(l- -64|0);o=Kb(l+48|0);t=Kb(l+32|0);x[27524]=0;na(1195,c|0,d|0,l+120|0,l+116|0,l+112|0,w|0,n|0,q|0,o|0,l+28|0);b=x[27524];x[27524]=0;if((b|0)!=1){x[j>>2]=x[i>>2];A=e&512;B=A>>>9|0;k=x[l+28>>2];e=0;while(1){c:{d:{e:{f:{g:{if((e|0)==4){break g}x[27524]=0;b=Q(1169,a|0,l+552|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break a}if(!b){break g}h:{i:{j:{k:{l:{switch(v[(l+120|0)+e|0]){case 1:if((e|0)==3){break c}b=x[a>>2];x[27524]=0;b=T(1171,b|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break a}x[27524]=0;b=W(1196,h|0,1,b|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break a}if(b){x[27524]=0;R(1197,l+16|0,a|0);b=x[27524];x[27524]=0;if((b|0)!=1){x[27524]=0;R(49,t|0,x[l+16>>2]);b=x[27524];x[27524]=0;if((b|0)!=1){break k}}break a}x[f>>2]=x[f>>2]|4;a=0;break d;case 4:break h;case 2:break i;case 3:break j;case 0:break l;default:break c}}if((e|0)==3){break c}}while(1){x[27524]=0;b=Q(1169,a|0,l+552|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break a}if(!b){break c}b=x[a>>2];x[27524]=0;b=T(1171,b|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break a}x[27524]=0;b=W(1196,h|0,1,b|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break a}if(!b){break c}x[27524]=0;R(1197,l+16|0,a|0);b=x[27524];x[27524]=0;if((b|0)!=1){x[27524]=0;R(49,t|0,x[l+16>>2]);b=x[27524];x[27524]=0;if((b|0)!=1){continue}}break}break a}m:{if(!Eb(q)){break m}b=x[a>>2];x[27524]=0;b=T(1171,b|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break a}if((b|0)!=x[vc(q)>>2]){break m}x[27524]=0;T(1173,a|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break a}v[g|0]=0;r=Eb(q)>>>0>1?q:r;break c}n:{if(!Eb(o)){break n}b=x[a>>2];x[27524]=0;b=T(1171,b|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break a}if((b|0)!=x[vc(o)>>2]){break n}x[27524]=0;T(1173,a|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break a}v[g|0]=1;r=Eb(o)>>>0>1?o:r;break c}c=Eb(q);b=Eb(o);o:{if(c){if(!b){break o}x[f>>2]=x[f>>2]|4;a=0;break d}if(!b){break c}}C=g,D=!Eb(o),v[C|0]=D;break c}if(!(e>>>0<2|r|((e|0)==2&y[l+123|0]!=0|B))){r=0;break c}c=Wb(l+16|0,ke(n));p:{if(!e|y[(e+l|0)+119|0]>1){break p}q:{while(1){b=Zk(n);d=x[c>>2];if(!Mb(d,b)){break q}b=x[d>>2];x[27524]=0;b=W(1196,h|0,1,b|0)|0;d=x[27524];x[27524]=0;if((d|0)!=1){if(!b){break q}Pe(c);continue}break}break a}b=ke(n);b=vu(x[c>>2],b);if(Eb(t)>>>0>=b>>>0){d=Dm(Zk(t),0-b|0);z=Zk(t);u=ke(n);b=ib-16|0;ib=b;x[b>>2]=u;x[b+8>>2]=d;while(1){r:{u=Mb(d,z);if(!u){break r}if(!pc(x[d>>2],x[x[b>>2]>>2])){break r}d=Pe(b+8|0);Pe(b);d=x[d>>2];continue}break}ib=b+16|0;if(u^1){break p}}C=c,D=x[Wb(l+8|0,ke(n))>>2],x[C>>2]=D}x[l+8>>2]=x[c>>2];s:{while(1){b=Zk(n);if(!Mb(x[l+8>>2],b)){break s}x[27524]=0;b=Q(1169,a|0,l+552|0)|0;c=x[27524];x[27524]=0;t:{if((c|0)==1){break t}if(!b){break s}b=x[a>>2];x[27524]=0;b=T(1171,b|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break t}if((b|0)!=x[x[l+8>>2]>>2]){break s}x[27524]=0;T(1173,a|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break a}Pe(l+8|0);continue}break}break a}if(!A){break c}b=Zk(n);if(!Mb(x[l+8>>2],b)){break c}x[f>>2]=x[f>>2]|4;a=0;break d}b=0;z=x[l+112>>2];d=m;u:{while(1){v:{x[27524]=0;c=Q(1169,a|0,l+552|0)|0;m=x[27524];x[27524]=0;if((m|0)==1){break v}if(!c){break u}c=x[a>>2];x[27524]=0;c=T(1171,c|0)|0;m=x[27524];x[27524]=0;if((m|0)==1){break a}x[27524]=0;m=W(1196,h|0,64,c|0)|0;u=x[27524];x[27524]=0;if((u|0)==1){break a}w:{if(m){m=x[j>>2];if((m|0)==x[l+548>>2]){x[27524]=0;U(1198,i|0,j|0,l+548|0);m=x[27524];x[27524]=0;if((m|0)==1){break a}m=x[j>>2]}x[j>>2]=m+4;x[m>>2]=c;b=b+1|0;break w}if(!Eb(w)|!b|(c|0)!=(z|0)){break u}if(x[l+128>>2]==(d|0)){x[27524]=0;U(1192,s|0,l+132|0,l+128|0);c=x[27524];x[27524]=0;if((c|0)==1){break a}d=x[l+132>>2]}c=d+4|0;x[l+132>>2]=c;x[d>>2]=b;d=c;b=0}x[27524]=0;T(1173,a|0)|0;c=x[27524];x[27524]=0;if((c|0)!=1){continue}}break}break a}if(!b|x[s>>2]==(d|0)){break f}if(x[l+128>>2]==(d|0)){x[27524]=0;U(1192,s|0,l+132|0,l+128|0);c=x[27524];x[27524]=0;if((c|0)==1){break a}d=x[l+132>>2]}m=d+4|0;x[l+132>>2]=m;x[d>>2]=b;break e}x[l+28>>2]=k;x:{if(!r){break x}k=1;while(1){if(Eb(r)>>>0<=k>>>0){break x}x[27524]=0;b=Q(1170,a|0,l+552|0)|0;c=x[27524];x[27524]=0;y:{if((c|0)==1){break y}z:{if(!b){b=x[a>>2];x[27524]=0;b=T(1171,b|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break y}if((b|0)==x[Hi(r,k)>>2]){break z}}x[f>>2]=x[f>>2]|4;a=0;break d}x[27524]=0;T(1173,a|0)|0;b=x[27524];x[27524]=0;k=k+1|0;if((b|0)!=1){continue}}break}break a}a=1;b=x[s>>2];if((b|0)==(m|0)){break d}a=0;x[l+16>>2]=0;Of(w,b,m,l+16|0);if(x[l+16>>2]){x[f>>2]=x[f>>2]|4;break d}a=1;break d}m=d}A:{if((k|0)<=0){break A}x[27524]=0;b=Q(1170,a|0,l+552|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break a}B:{if(!b){b=x[a>>2];x[27524]=0;b=T(1171,b|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break a}if((b|0)==x[l+116>>2]){break B}}x[f>>2]=x[f>>2]|4;a=0;break d}x[27524]=0;b=T(1173,a|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break a}while(1){if((k|0)<=0){k=0;break A}x[27524]=0;c=Q(1170,b|0,l+552|0)|0;d=x[27524];x[27524]=0;C:{if((d|0)==1){break C}D:{if(!c){c=x[b>>2];x[27524]=0;c=T(1171,c|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break C}x[27524]=0;c=W(1196,h|0,64,c|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break C}if(c){break D}}x[f>>2]=x[f>>2]|4;a=0;break d}if(x[j>>2]==x[l+548>>2]){x[27524]=0;U(1198,i|0,j|0,l+548|0);c=x[27524];x[27524]=0;if((c|0)==1){break C}}c=x[b>>2];x[27524]=0;c=T(1171,c|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break C}d=x[j>>2];x[j>>2]=d+4;x[d>>2]=c;x[27524]=0;T(1173,b|0)|0;c=x[27524];x[27524]=0;k=k-1|0;if((c|0)!=1){continue}}break}break a}if(x[j>>2]!=x[i>>2]){break c}x[f>>2]=x[f>>2]|4;a=0}Gc(t);Gc(o);Gc(q);Gc(n);wb(w);Uc(s);break b}e=e+1|0;continue}}break a}ib=l+560|0;return a|0}a=P()|0;Gc(t);Gc(o);Gc(q);Gc(n);wb(w);Uc(s);S(a|0);p()}function B1(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,w=0,z=0,A=0,B=0,C=0,D=0;l=ib-560|0;ib=l;x[l+548>>2]=k;x[l+552>>2]=b;a:{b:{if(jj(a,l+552|0)){x[f>>2]=x[f>>2]|4;a=0;break b}x[l+104>>2]=1186;b=l+104|0;s=xe(l+136|0,l+144|0,b);m=x[s>>2];x[l+132>>2]=m;x[l+128>>2]=m+400;u=Kb(b);n=Kb(l+88|0);q=Kb(l+72|0);o=Kb(l+56|0);t=Kb(l+40|0);x[27524]=0;na(1189,c|0,d|0,l+120|0,l+119|0,l+118|0,u|0,n|0,q|0,o|0,l+36|0);b=x[27524];x[27524]=0;if((b|0)!=1){x[j>>2]=x[i>>2];z=e&512;A=z>>>9|0;e=x[l+36>>2];c=h;h=0;while(1){c:{d:{e:{f:{g:{if((h|0)==4){break g}x[27524]=0;b=Q(1153,a|0,l+552|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break a}if(!b){break g}h:{i:{j:{k:{l:{switch(v[(l+120|0)+h|0]){case 1:if((h|0)==3){break c}b=x[a>>2];x[27524]=0;b=T(1155,b|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break a}if(Bh(x[c+8>>2],1,b)){x[27524]=0;R(1190,l+24|0,a|0);b=x[27524];x[27524]=0;if((b|0)!=1){x[27524]=0;R(47,t|0,v[l+24|0]);b=x[27524];x[27524]=0;if((b|0)!=1){break k}}break a}x[f>>2]=x[f>>2]|4;a=0;break d;case 4:break h;case 2:break i;case 3:break j;case 0:break l;default:break c}}if((h|0)==3){break c}}while(1){x[27524]=0;b=Q(1153,a|0,l+552|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break a}if(!b){break c}b=x[a>>2];x[27524]=0;b=T(1155,b|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break a}if(!Bh(x[c+8>>2],1,b)){break c}x[27524]=0;R(1190,l+24|0,a|0);b=x[27524];x[27524]=0;if((b|0)!=1){x[27524]=0;R(47,t|0,v[l+24|0]);b=x[27524];x[27524]=0;if((b|0)!=1){continue}}break}break a}m:{if(!Eb(q)){break m}b=x[a>>2];x[27524]=0;b=T(1155,b|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break a}if(y[Qc(q,0)|0]!=(b&255)){break m}x[27524]=0;T(1157,a|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break a}v[g|0]=0;r=Eb(q)>>>0>1?q:r;break c}n:{if(!Eb(o)){break n}b=x[a>>2];x[27524]=0;b=T(1155,b|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break a}if(y[Qc(o,0)|0]!=(b&255)){break n}x[27524]=0;T(1157,a|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break a}v[g|0]=1;r=Eb(o)>>>0>1?o:r;break c}d=Eb(q);b=Eb(o);o:{if(d){if(!b){break o}x[f>>2]=x[f>>2]|4;a=0;break d}if(!b){break c}}C=g,D=!Eb(o),v[C|0]=D;break c}if(!(h>>>0<2|r|((h|0)==2&y[l+123|0]!=0|A))){r=0;break c}C=l,D=ke(n),x[C+16>>2]=D;d=pj(l+24|0,l+16|0);p:{if(!h|y[(h+l|0)+119|0]>1){break p}while(1){q:{C=l,D=Eh(n),x[C+16>>2]=D;if(!Fi(d,l+16|0)){break q}if(!Bh(x[c+8>>2],1,v[x[d>>2]])){break q}Ie(d);continue}break}C=l,D=ke(n),x[C+16>>2]=D;b=Rn(d,l+16|0);if(Eb(t)>>>0>=b>>>0){C=l,D=Eh(t),x[C+16>>2]=D;k=Op(l+16|0,0-b|0);w=Eh(t);B=ke(n);b=ib-32|0;ib=b;x[b+16>>2]=w;x[b+24>>2]=k;x[b+8>>2]=B;while(1){k=Fi(b+24|0,b+16|0);if(!(!k|y[x[b+24>>2]]!=y[x[b+8>>2]])){Ie(b+24|0);Ie(b+8|0);continue}break}ib=b+32|0;if(k^1){break p}}C=l,D=ke(n),x[C+8>>2]=D;C=d,D=x[pj(l+16|0,l+8|0)>>2],x[C>>2]=D}x[l+16>>2]=x[d>>2];r:{while(1){C=l,D=Eh(n),x[C+8>>2]=D;if(!Fi(l+16|0,l+8|0)){break r}x[27524]=0;b=Q(1153,a|0,l+552|0)|0;d=x[27524];x[27524]=0;s:{if((d|0)==1){break s}if(!b){break r}b=x[a>>2];x[27524]=0;b=T(1155,b|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break s}if(y[x[l+16>>2]]!=(b&255)){break r}x[27524]=0;T(1157,a|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break a}Ie(l+16|0);continue}break}break a}if(!z){break c}C=l,D=Eh(n),x[C+8>>2]=D;if(!Fi(l+16|0,l+8|0)){break c}x[f>>2]=x[f>>2]|4;a=0;break d}b=0;w=y[l+118|0];d=m;t:{while(1){u:{x[27524]=0;k=Q(1153,a|0,l+552|0)|0;m=x[27524];x[27524]=0;if((m|0)==1){break u}if(!k){break t}k=x[a>>2];x[27524]=0;k=T(1155,k|0)|0;m=x[27524];x[27524]=0;if((m|0)==1){break a}v:{if(Bh(x[c+8>>2],64,k)){m=x[j>>2];if((m|0)==x[l+548>>2]){x[27524]=0;U(1191,i|0,j|0,l+548|0);m=x[27524];x[27524]=0;if((m|0)==1){break a}m=x[j>>2]}x[j>>2]=m+1;v[m|0]=k;b=b+1|0;break v}if(!Eb(u)|!b|(w|0)!=(k&255)){break t}if(x[l+128>>2]==(d|0)){x[27524]=0;U(1192,s|0,l+132|0,l+128|0);d=x[27524];x[27524]=0;if((d|0)==1){break a}d=x[l+132>>2]}k=d+4|0;x[l+132>>2]=k;x[d>>2]=b;d=k;b=0}x[27524]=0;T(1157,a|0)|0;k=x[27524];x[27524]=0;if((k|0)!=1){continue}}break}break a}if(!b|x[s>>2]==(d|0)){break f}if(x[l+128>>2]==(d|0)){x[27524]=0;U(1192,s|0,l+132|0,l+128|0);d=x[27524];x[27524]=0;if((d|0)==1){break a}d=x[l+132>>2]}m=d+4|0;x[l+132>>2]=m;x[d>>2]=b;break e}x[l+36>>2]=e;w:{if(!r){break w}k=1;while(1){if(Eb(r)>>>0<=k>>>0){break w}x[27524]=0;b=Q(1154,a|0,l+552|0)|0;c=x[27524];x[27524]=0;x:{if((c|0)==1){break x}y:{if(!b){b=x[a>>2];x[27524]=0;b=T(1155,b|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break x}if(y[ng(r,k)|0]==(b&255)){break y}}x[f>>2]=x[f>>2]|4;a=0;break d}x[27524]=0;T(1157,a|0)|0;b=x[27524];x[27524]=0;k=k+1|0;if((b|0)!=1){continue}}break}break a}a=1;b=x[s>>2];if((b|0)==(m|0)){break d}a=0;x[l+24>>2]=0;Of(u,b,m,l+24|0);if(x[l+24>>2]){x[f>>2]=x[f>>2]|4;break d}a=1;break d}m=d}z:{if((e|0)<=0){break z}x[27524]=0;b=Q(1154,a|0,l+552|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break a}A:{if(!b){b=x[a>>2];x[27524]=0;b=T(1155,b|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break a}if(y[l+119|0]==(b&255)){break A}}x[f>>2]=x[f>>2]|4;a=0;break d}x[27524]=0;b=T(1157,a|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break a}while(1){if((e|0)<=0){e=0;break z}x[27524]=0;d=Q(1154,b|0,l+552|0)|0;k=x[27524];x[27524]=0;B:{if((k|0)==1){break B}C:{if(!d){d=x[b>>2];x[27524]=0;d=T(1155,d|0)|0;k=x[27524];x[27524]=0;if((k|0)==1){break B}if(Bh(x[c+8>>2],64,d)){break C}}x[f>>2]=x[f>>2]|4;a=0;break d}if(x[j>>2]==x[l+548>>2]){x[27524]=0;U(1191,i|0,j|0,l+548|0);d=x[27524];x[27524]=0;if((d|0)==1){break B}}d=x[b>>2];x[27524]=0;d=T(1155,d|0)|0;k=x[27524];x[27524]=0;if((k|0)==1){break B}k=x[j>>2];x[j>>2]=k+1;v[k|0]=d;x[27524]=0;T(1157,b|0)|0;d=x[27524];x[27524]=0;e=e-1|0;if((d|0)!=1){continue}}break}break a}if(x[j>>2]!=x[i>>2]){break c}x[f>>2]=x[f>>2]|4;a=0}wb(t);wb(o);wb(q);wb(n);wb(u);Uc(s);break b}h=h+1|0;continue}}break a}ib=l+560|0;return a|0}a=P()|0;wb(t);wb(o);wb(q);wb(n);wb(u);Uc(s);S(a|0);p()}function yea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;g=ib+-64|0;ib=g;d=x[b>>2];x[27524]=0;f=T(182,d|0)|0;d=x[27524];x[27524]=0;a:{b:{c:{d:{if((d|0)==1){break d}e:{f:{if(f){l=Nb(g+48|0);x[27524]=0;e=(c|0)!=0;f=W(828,l|0,b|0,e|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break e}d=4;g:{h:{i:{j:{if(f){break j}x[27524]=0;f=W(829,l|0,b|0,e|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break e}d=5;if(f){break j}x[27524]=0;f=W(830,l|0,b|0,e|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break e}d=6;if(f){break j}f=0;x[27524]=0;e=W(831,l|0,b|0,e|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break e}d=3;if(!e){break i}}if(!c){d=1;f=0;break h}f=x[l>>2];if(!pc(f,x[l+4>>2])){Pv(b,f+12|0)}f=d}d=31568;k:{while(1){e=d;if((e|0)!=32108){h=x[e+8>>2];i=(h>>1)+a|0;d=x[e+4>>2];d=h&1?x[x[i>>2]+d>>2]:d;x[27524]=0;h=W(d|0,i|0,b|0,c|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break c}d=e+12|0;if(!h){continue}break k}break}x[a+480180>>2]=0;x[a+480184>>2]=0}if(!c){d=(e|0)!=32108;f=0;break h}if(!(x[a+480184>>2]|!f)){x[a+480184>>2]=f}x[27524]=0;f=1;R(771,a+1298264|0,1);e=x[27524];x[27524]=0;d=1;if((e|0)==1){break g}}SO(l);if(f){break f}break a}break c}x[27524]=0;R(250,a|0,0);d=x[27524];x[27524]=0;if((d|0)==1){break d}x[27524]=0;R(771,a+1298264|0,1);d=x[27524];x[27524]=0;if((d|0)==1){break d}x[a+1074304>>2]=19988503;x[a+1298408>>2]=0}d=0;while(1){if((d|0)==127){d=1;while(1){f=d&65535;if(f>>>0>z[a+480190>>1]){f=0;i=a+480180|0;d=0;l:{while(1){e=d&65535;if(e>>>0>z[a+480192>>1]){m:{w[a+480192>>1]=f;d=a+480204|0;if(A[a+480204>>2]>=1e4){break m}x[d>>2]=125e4;break l}}else{e=x[((e<<2)+a|0)+900380>>2];if(e){h=x[i>>2];wc(e,65536);wc(e+4|0,64);wc(e+8|0,256);Mf(e+28|0,16384);Ff(e+30|0,128);Ff(e+31|0,17);if(y[e+16|0]>=4){v[e+16|0]=0}if(y[e+17|0]>=5){v[e+17|0]=0}if(y[e+18|0]>=3){v[e+18|0]=0}Ff(e+19|0,64);Ff(e+20|0,100);j=224;f=v[e+26|0];n:{if((f|0)>=-32){j=32;if((f|0)<33){break n}}v[e+26|0]=j}Ff(e+23|0,64);Ff(e+24|0,64);lA(e+48|0,64);lA(e+68|0,64);lA(e+88|0,(h|0)==4096?255:64);h=e+108|0;j=0;while(1){o:{if((j|0)==128){if(!Oo(y[e+14|0])){v[e+14|0]=5}if(y[e+34|0]>=251){v[e+34|0]=0}break o}f=Jb(h,j);if((y[f|0]-121&255)>>>0<=135){v[f|0]=j+1}j=j+1|0;continue}break}f=d}d=d+1|0;continue}break}wc(d,65535e4)}if(!x[a+480196>>2]){x[a+480196>>2]=6}e=a+480216|0;f=a+480220|0;d=x[a+480216>>2];if(!(d|y[a+480224|0]!=2)){x[e>>2]=1;d=1}if(A[a+480220>>2]<d>>>0){x[f>>2]=d}wc(e,65536);wc(f,65536);wc(a+480200|0,256);p:{f=a+480248|0;if(!pc(x[f>>2],x[a+480252>>2])){d=x[e>>2];x[27524]=0;R(832,f|0,d|0);d=x[27524];x[27524]=0;if((d|0)==1){break p}}x[a+1074416>>2]=x[a+480196>>2];x[a+1074420>>2]=x[a+480204>>2];d=x[a+480220>>2];f=a+1074408|0;x[f>>2]=x[a+480216>>2];x[f+4>>2]=d;x[a+1074456>>2]=x[a+480200>>2];Cz(a+1074376|0);d=a+1074446|0;w[d>>1]=0;w[d+2>>1]=0;w[d+4>>1]=0;w[d+6>>1]=65535;x[a+1074392>>2]=-2;d=a+1074384|0;x[d>>2]=0;x[d+4>>2]=0;x[a+1074380>>2]=0;d=a+1074424|0;x[d>>2]=0;x[d+4>>2]=0;x[a+1074432>>2]=0;d=a+1074396|0;x[d>>2]=0;x[d+4>>2]=0;if(Nm(x[a+480180>>2])){x[27524]=0;Q(269,a+1074312|0,7)|0;d=x[27524];x[27524]=0;if((d|0)==1){break p}}w[a+480276>>1]=0;Yp(a);o=g,q=Cb(x[a+484360>>2]),x[o+48>>2]=q;f=Cb(x[a+484364>>2]);while(1){e=x[g+48>>2];if(!Mb(e,f)){q:{r:{l=x[a+480180>>2];if(l){qt(a+8|0,Iq(a));if(x[a+1074308>>2]){x[27524]=0;Y(833,a|0);d=x[27524];x[27524]=0;if((d|0)==1){break p}}n=Nb(g+48|0);s:{if((c&12)!=12){break s}i=a+906300|0;h=a+1298472|0;d=0;t:{u:{v:{w:{x:{y:{while(1){if((d|0)==250){break s}z:{k=Nd(i,d);e=k+16|0;A:{if(!Gi(x[e>>2],x[k+20>>2])){break A}x[27524]=0;R(834,k|0,a|0);c=x[27524];x[27524]=0;B:{if((c|0)!=1){m=x[k>>2];if(!m){break B}f=x[k+148>>2];c=x[x[m>>2]+56>>2];x[27524]=0;R(c|0,m|0,f|0);c=x[27524];x[27524]=0;if((c|0)!=1){break A}}a=P()|0;break q}j=Cb(x[n>>2]);f=Cb(x[n+4>>2]);m=ib-16|0;ib=m;x[m+8>>2]=j;while(1){C:{if(!Mb(j,f)){break C}c=x[j>>2];if((y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24))==(y[k+20|0]|y[k+21|0]<<8|(y[k+22|0]<<16|y[k+23|0]<<24))){c=(y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24))==(y[k+16|0]|y[k+17|0]<<8|(y[k+18|0]<<16|y[k+19|0]<<24))}else{c=0}if(c){break C}j=x[Pe(m+8|0)>>2];continue}break}ib=m+16|0;if(Mb(j,Cb(x[n+4>>2]))){break A}x[27524]=0;x[g+32>>2]=e;R(835,n|0,g+32|0);c=x[27524];x[27524]=0;if((c|0)==1){break z}x[27524]=0;f=Q(1,g+16|0,17678)|0;c=x[27524];x[27524]=0;if((c|0)==1){break y}x[27524]=0;R(836,g|0,k|0);c=x[27524];x[27524]=0;if((c|0)==1){break x}x[27524]=0;U(2,g+32|0,f|0,g|0);c=x[27524];x[27524]=0;if((c|0)==1){break w}c=x[h>>2];x[27524]=0;U(380,c|0,2,g+32|0);c=x[27524];x[27524]=0;if((c|0)==1){break v}xb(g+32|0);xb(g);xb(f)}d=d+1|0;continue}break}a=P()|0;break q}a=P()|0;break q}a=P()|0;break t}a=P()|0;break u}a=P()|0;xb(g+32|0)}xb(g)}xb(f);break q}c=y[a+1074368|0];x[27524]=0;R(837,a|0,c|0);a=x[27524];x[27524]=0;if((a|0)==1){break r}uc(n)}d=(l|0)!=0;break a}a=P()|0}uc(n);break b}x[27524]=0;Y(838,e|0);d=x[27524];x[27524]=0;if((d|0)!=1){if(Oc(x[e>>2],x[e+4>>2])>>>0<=z[e+28>>1]){_e(e,0)}gA(g+48|0);continue}break}a=P()|0;break b}a=P()|0;break b}h=D(f,104)+a|0;i=h+484380|0;D:{if(_d(x[i>>2],x[h+484400>>2])){yj(i,a);break D}e=h+484414|0;f=z[e>>1];if(f&16384){break D}x[i>>2]=0;x[i+4>>2]=0;x[i+16>>2]=0;x[i+8>>2]=0;x[i+12>>2]=0;w[e>>1]=f&65505}f=h+484412|0;if(z[f>>1]>=65){w[f>>1]=64}E:{F:{if(!(y[h+484415|0]&2)){break F}if(!qk(x[a+1298300>>2])){break F}x[27524]=0;Y(839,a|0);f=x[27524];x[27524]=0;if((f|0)==1){break E}}d=d+1|0;continue}break}a=P()|0;break b}e=(d<<5)+a|0;Mf(e+480286|0,64);f=e+480284|0;if(z[f>>1]>=257){w[f>>1]=128}f=e+480288|0;if(y[f|0]>=251){v[f|0]=0}io((D(d,872)+a|0)+1074992|0,a,d&65535,134217728);d=d+1|0;continue}}break c}a=P()|0;break b}a=P()|0;SO(l)}yb(b);S(a|0);p()}yb(b);ib=g- -64|0;return d|0}function W3(a,b,c,d,e,f){a=a|0;b=+b;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,z=0,A=0,B=0,C=0,E=0;n=ib-560|0;ib=n;x[n+44>>2]=0;o(+b);g=j(1)|0;j(0)|0;a:{if((g|0)<0){u=1;A=5299;b=-b;o(+b);g=j(1)|0;j(0)|0;break a}if(e&2048){u=1;A=5302;break a}u=e&1;A=u?5305:5300;E=!u}b:{if((g&2146435072)==2146435072){d=u+3|0;Pf(a,32,c,d,e&-65537);Bf(a,A,u);f=f&32;Bf(a,b!=b?f?9916:13787:f?11046:14153,3);Pf(a,32,c,d,e^8192);i=(c|0)<(d|0)?d:c;break b}z=n+16|0;c:{d:{e:{b=yI(b,n+44|0);b=b+b;if(b!=0){g=x[n+44>>2];x[n+44>>2]=g-1;t=f|32;if((t|0)!=97){break e}break c}t=f|32;if((t|0)==97){break c}l=x[n+44>>2];m=(d|0)<0?6:d;break d}l=g-29|0;x[n+44>>2]=l;b=b*268435456;m=(d|0)<0?6:d}r=(n+48|0)+((l|0)>=0?288:0)|0;h=r;while(1){if(b<4294967296&b>=0){d=~~b>>>0}else{d=0}x[h>>2]=d;h=h+4|0;b=(b-+(d>>>0))*1e9;if(b!=0){continue}break}f:{if((l|0)<=0){d=l;g=h;k=r;break f}k=r;d=l;while(1){d=(d|0)>=29?29:d;g=h-4|0;g:{if(k>>>0>g>>>0){break g}i=0;while(1){q=x[g>>2];p=d&31;B=i;if((d&63)>>>0>=32){i=q<<p;q=0}else{i=(1<<p)-1&q>>>32-p;q=q<<p}p=B+q|0;i=i+C|0;i=p>>>0<q>>>0?i+1|0:i;i=soa(p,i,1e9,0);q=qoa(i,kb,-1e9,0)+p|0;x[g>>2]=q;g=g-4|0;if(k>>>0<=g>>>0){continue}break}if(!i){break g}k=k-4|0;x[k>>2]=i}while(1){g=h;if(k>>>0<g>>>0){h=g-4|0;if(!x[h>>2]){continue}}break}d=x[n+44>>2]-d|0;x[n+44>>2]=d;h=g;if((d|0)>0){continue}break}}if((d|0)<0){w=((m+25>>>0)/9|0)+1|0;p=(t|0)==102;while(1){d=0-d|0;i=(d|0)>=9?9:d;h:{if(g>>>0<=k>>>0){h=x[k>>2];break h}q=1e9>>>i|0;C=-1<<i^-1;d=0;h=k;while(1){B=d;d=x[h>>2];x[h>>2]=B+(d>>>i|0);d=D(q,d&C);h=h+4|0;if(h>>>0<g>>>0){continue}break}h=x[k>>2];if(!d){break h}x[g>>2]=d;g=g+4|0}d=i+x[n+44>>2]|0;x[n+44>>2]=d;k=(!h<<2)+k|0;h=p?r:k;g=g-h>>2>(w|0)?h+(w<<2)|0:g;if((d|0)<0){continue}break}}d=0;i:{if(g>>>0<=k>>>0){break i}d=D(r-k>>2,9);h=10;i=x[k>>2];if(i>>>0<10){break i}while(1){d=d+1|0;h=D(h,10);if(i>>>0>=h>>>0){continue}break}}h=(m-((t|0)!=102?d:0)|0)-((t|0)==103&(m|0)!=0)|0;if((h|0)<(D(g-r>>2,9)-9|0)){i=h+9216|0;p=(i|0)/9|0;l=((((l|0)<0?4:292)+n|0)+(p<<2)|0)-4048|0;h=10;i=i+D(p,-9)|0;if((i|0)<=7){while(1){h=D(h,10);i=i+1|0;if((i|0)!=8){continue}break}}p=x[l>>2];w=(p>>>0)/(h>>>0)|0;i=D(w,h);q=l+4|0;j:{if((i|0)==(p|0)&(q|0)==(g|0)){break j}p=p-i|0;k:{if(!(w&1)){b=9007199254740992;if(!(v[l-4|0]&1)|((h|0)!=1e9|k>>>0>=l>>>0)){break k}}b=9007199254740994}s=(g|0)==(q|0)?1:1.5;q=h>>>1|0;s=p>>>0<q>>>0?.5:(q|0)==(p|0)?s:1.5;if(!(y[A|0]!=45|E)){s=-s;b=-b}x[l>>2]=i;if(b+s==b){break j}d=h+i|0;x[l>>2]=d;if(d>>>0>=1e9){while(1){x[l>>2]=0;l=l-4|0;if(l>>>0<k>>>0){k=k-4|0;x[k>>2]=0}d=x[l>>2]+1|0;x[l>>2]=d;if(d>>>0>999999999){continue}break}}d=D(r-k>>2,9);h=10;i=x[k>>2];if(i>>>0<10){break j}while(1){d=d+1|0;h=D(h,10);if(i>>>0>=h>>>0){continue}break}}h=l+4|0;g=g>>>0>h>>>0?h:g}while(1){h=g;i=g>>>0<=k>>>0;if(!i){g=h-4|0;if(!x[g>>2]){continue}}break}l:{if((t|0)!=103){l=e&8;break l}g=m?m:1;l=(g|0)>(d|0)&(d|0)>-5;m=(l?d^-1:-1)+g|0;f=(l?-1:-2)+f|0;l=e&8;if(l){break l}g=-9;m:{if(i){break m}p=x[h-4>>2];if(!p){break m}i=10;g=0;if((p>>>0)%10|0){break m}while(1){l=g;g=g+1|0;i=D(i,10);if(!((p>>>0)%(i>>>0)|0)){continue}break}g=l^-1}i=D(h-r>>2,9);if((f&-33)==70){l=0;g=(g+i|0)-9|0;g=(g|0)>0?g:0;m=(g|0)>(m|0)?m:g;break l}l=0;g=((d+i|0)+g|0)-9|0;g=(g|0)>0?g:0;m=(g|0)>(m|0)?m:g}i=-1;t=l|m;if(((t?2147483645:2147483646)|0)<(m|0)){break b}p=(((t|0)!=0)+m|0)+1|0;q=f&-33;n:{if((q|0)==70){if((p^2147483647)<(d|0)){break b}g=(d|0)>0?d:0;break n}g=d>>31;g=In((g^d)-g|0,0,z);if((z-g|0)<=1){while(1){g=g-1|0;v[g|0]=48;if((z-g|0)<2){continue}break}}w=g-2|0;v[w|0]=f;v[g-1|0]=(d|0)<0?45:43;g=z-w|0;if((g|0)>(p^2147483647)){break b}}d=g+p|0;if((d|0)>(u^2147483647)){break b}f=d+u|0;Pf(a,32,c,f,e);Bf(a,A,u);Pf(a,48,c,f,e^65536);o:{p:{q:{if((q|0)==70){g=n+16|0;d=g|8;l=g|9;i=k>>>0>r>>>0?r:k;k=i;while(1){g=In(x[k>>2],0,l);r:{if((i|0)!=(k|0)){if(n+16>>>0>=g>>>0){break r}while(1){g=g-1|0;v[g|0]=48;if(n+16>>>0<g>>>0){continue}break}break r}if((g|0)!=(l|0)){break r}v[n+24|0]=48;g=d}Bf(a,g,l-g|0);k=k+4|0;if(r>>>0>=k>>>0){continue}break}if(t){Bf(a,16748,1)}if((m|0)<=0|h>>>0<=k>>>0){break q}while(1){g=In(x[k>>2],0,l);if(g>>>0>n+16>>>0){while(1){g=g-1|0;v[g|0]=48;if(n+16>>>0<g>>>0){continue}break}}Bf(a,g,(m|0)>=9?9:m);g=m-9|0;k=k+4|0;if(h>>>0<=k>>>0){break p}d=(m|0)>9;m=g;if(d){continue}break}break p}s:{if((m|0)<0){break s}i=h>>>0>k>>>0?h:k+4|0;g=n+16|0;d=g|8;r=g|9;h=k;while(1){g=In(x[h>>2],0,r);if((r|0)==(g|0)){v[n+24|0]=48;g=d}t:{if((h|0)!=(k|0)){if(n+16>>>0>=g>>>0){break t}while(1){g=g-1|0;v[g|0]=48;if(n+16>>>0<g>>>0){continue}break}break t}Bf(a,g,1);g=g+1|0;if(!(l|m)){break t}Bf(a,16748,1)}B=g;g=r-g|0;Bf(a,B,(g|0)>(m|0)?m:g);m=m-g|0;h=h+4|0;if(i>>>0<=h>>>0){break s}if((m|0)>=0){continue}break}}Pf(a,48,m+18|0,18,0);Bf(a,w,z-w|0);break o}g=m}Pf(a,48,g+9|0,9,0)}Pf(a,32,c,f,e^8192);i=(c|0)<(f|0)?f:c;break b}m=(f<<26>>31&9)+A|0;u:{if(d>>>0>11){break u}g=12-d|0;s=16;while(1){s=s*16;g=g-1|0;if(g){continue}break}if(y[m|0]==45){b=-(s+(-b-s));break u}b=b+s-s}l=u|2;k=f&32;h=x[n+44>>2];g=h>>31;g=In((g^h)-g|0,0,z);if((z|0)==(g|0)){v[n+15|0]=48;g=n+15|0}r=g-2|0;v[r|0]=f+15;v[g-1|0]=(h|0)<0?45:43;i=e&8;h=n+16|0;while(1){f=h;if(F(b)<2147483648){g=~~b}else{g=-2147483648}v[h|0]=k|y[g+92336|0];b=(b-+(g|0))*16;h=f+1|0;if(!(!(i|(d|0)>0)&b==0|(h-(n+16|0)|0)!=1)){v[f+1|0]=46;h=f+2|0}if(b!=0){continue}break}i=-1;p=z-r|0;f=p+l|0;if((2147483645-f|0)<(d|0)){break b}v:{w:{if(!d){break w}k=h-(n+16|0)|0;if((k-2|0)>=(d|0)){break w}g=d+2|0;break v}k=h-(n+16|0)|0;g=k}d=g+f|0;Pf(a,32,c,d,e);Bf(a,m,l);Pf(a,48,c,d,e^65536);Bf(a,n+16|0,k);Pf(a,48,g-k|0,0,0);Bf(a,r,p);Pf(a,32,c,d,e^8192);i=(c|0)<(d|0)?d:c}ib=n+560|0;return i|0}function _ia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=ib-272|0;ib=e;yc(b);d=ib-16|0;ib=d;f=e+120|0;DT(d+8|0,f);g=x[d+12>>2];kc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);h=x[d+4>>2];if((h|0)==(g|0)){Yb(b,x[d+12>>2])}ib=d+16|0;d=(g|0)==(h|0);if(!d){CT(f)}a:{b:{c:{d:{if(!d){break d}if(!ET(e+120|0)){break d}if(!c){i=1;break d}zd(a,4194304);d=e+32|0;g=xc(d,17015);Gb(a+1298344|0,g);xb(g);g=xc(d,10075);Gb(a+1298356|0,g);xb(g);x[a+1298404>>2]=4;n=a,o=Bd(z[e+198>>1],z[e+200>>1],127),w[n+480188>>1]=o;g=y[e+189|0];x[a+480228>>2]=(g|0)==255?48:g;x[a+480196>>2]=y[e+187|0];x[a+480204>>2]=D(y[e+188|0],1e4);g=e+96|0;yf(g,e+120|4,59,3);Fc(d,g);Ac(a+1298308|0,d);wb(d);d=z[e+202>>1]|z[e+204>>1]<<16;e:{if(d>>>0<5){break e}if(!bd(b,d-4|0)){break e}if(!Lh(b,14253)){break e}wo(Tb(x[a+484360>>2],y[a+484376|0]),b,z[e+192>>1],65535,65535)}f:{d=z[e+206>>1]|z[e+208>>1]<<16;if(d>>>0<5){break f}if(!bd(b,d-4|0)){break f}if(!Lh(b,13782)){break f}d=0;while(1){if((d|0)==32){break f}g=(d<<5)+a|0;lf(g+480280|0);n=g+480284|0,o=((((Re(b)^-1)&15)<<8|8)>>>0)/15|0,w[n>>1]=o;d=d+1|0;continue}}d=z[e+214>>1]|z[e+216>>1]<<16;g:{if(d>>>0<5){break g}if(!bd(b,d-4|0)){break g}if(!Lh(b,14110)){break g}d=e+32|0;ae(d,b,z[e+196>>1]<<6);k=c&2;h=a+480190|0;g=hc(e+96|0,d);yb(d);j=e+45|0;d=0;h:{while(1){if(z[e+196>>1]<=(d&65535)>>>0){break h}x[27524]=0;f=Q(667,g|0,e+32|0)|0;i=x[27524];x[27524]=0;if((i|0)==1){break b}if(!f){break h}f=y[e+77|0]|y[e+78|0]<<8;w[e+30>>1]=f;i:{j:{if((f-1&65535)>>>0>3998){break j}f=D(f,104)+a|0;i=f+484380|0;if(_d(x[i>>2],x[f+484400>>2])){break j}n=h,o=z[pe(h,e+30|0)>>1],w[n>>1]=o;x[27524]=0;R(668,e+32|0,i|0);f=x[27524];x[27524]=0;if((f|0)==1){break i}pW(e,1,j);x[27524]=0;R(226,e+16|0,e|0);f=x[27524];x[27524]=0;if((f|0)==1){break b}f=e+16|0;Cc(((z[e+30>>1]<<5)+a|0)+946304|0,f);wb(f);if(!k){break j}x[27524]=0;Q(159,b|0,y[e+69|0]|y[e+70|0]<<8|(y[e+71|0]<<16|y[e+72|0]<<24))|0;f=x[27524];x[27524]=0;if((f|0)==1){break i}i=1;l=e+16|0;f=y[e+79|0];m=Zc(l,f&4?16:8,1,0,0);k:{l:{if(f&8){break l}i=2;if(f&16){break l}if(f&127){break k}}jg(m,i)}x[27524]=0;W(223,l|0,(D(z[e+30>>1],104)+a|0)+484380|0,b|0)|0;f=x[27524];x[27524]=0;if((f|0)!=1){break j}break b}d=d+1|0;continue}break}break b}yb(g)}i=1;if(!(c&1)){break d}m:{c=z[e+210>>1]|z[e+212>>1]<<16;if(c>>>0<5){break m}if(!bd(b,c-4|0)){break m}if(!Lh(b,13632)){break m}k=a+484344|0;Fg(k,z[e+194>>1]);f=0;while(1){if(z[e+194>>1]<=f>>>0){break m}if(!eB(b,e+16|0)){break m}n:{d=z[e+16>>1];if(d>>>0>3){c=e+96|0;ae(c,b,(d+15&131056)-4|0);g=hc(e+32|0,c);yb(c);x[27524]=0;c=W(230,k|0,f&65535,y[e+18|0])|0;d=x[27524];x[27524]=0;if((d|0)==1){break n}h=0;o:{if(!c){break o}while(1){p:{c=x[g>>2];x[27524]=0;d=W(160,c|0,x[e+40>>2],1)|0;c=x[27524];x[27524]=0;q:{if((c|0)!=1){c=y[e+18|0];if(!(d&c>>>0>(h&255)>>>0)){break p}x[27524]=0;c=T(210,g|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break c}d=c<<24>>24;if(d){break q}h=h+1|0;continue}break c}c=x[a+484344>>2];w[e+96>>1]=d&31;w[e>>1]=z[a+480188>>1]-1;c=Xb(c,f);c=hd(x[c>>2],x[x[c+48>>2]+12>>2],h,z[Tc(e+96|0,e)>>1]);if((d|0)<0){x[27524]=0;R(264,e+96|0,g|0);j=x[27524];x[27524]=0;if((j|0)==1){break c}v[c|0]=y[e+96|0]+36;n=c,o=y[Lc(e+96|0)|0],v[n+1|0]=o}d=d&255;if(d&64){v[c+2|0]=1;x[27524]=0;j=T(210,g|0)|0;l=x[27524];x[27524]=0;if((l|0)==1){break c}v[e+96|0]=j;v[e|0]=64;n=c,o=y[Ub(e+96|0,e)|0],v[n+4|0]=o}if(!(d&32)){continue}x[27524]=0;R(264,e+96|0,g|0);d=x[27524];x[27524]=0;r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{if((d|0)!=1){d=y[Lc(e+96|0)|0];v[c+5|0]=d;switch(y[e+96|0]-1|0){case 71:break s;case 70:break t;case 69:break u;case 60:break v;case 59:break w;case 52:break x;case 51:break y;case 50:break z;case 49:break A;case 42:break B;case 41:break C;case 40:break D;case 39:break E;case 30:break F;case 29:break G;case 22:break H;case 21:break I;case 20:break J;case 19:break K;case 16:break L;case 15:break M;case 14:break N;case 13:break O;case 12:break P;case 11:break Q;case 10:break R;case 9:break S;case 3:break T;case 2:break U;case 1:break V;case 0:break W;default:break r}}break c}v[c+3|0]=11;v[c+5|0]=d<<4|15;continue}v[c+3|0]=11;v[c+5|0]=d<<4;continue}v[c+3|0]=11;v[c+5|0]=d|240;continue}v[c+3|0]=11;v[c+5|0]=d&15;continue}v[c+3|0]=2;v[c+5|0]=d|240;continue}v[c+3|0]=2;continue}v[c+3|0]=3;v[c+5|0]=d|240;continue}v[c+3|0]=3;continue}v[c+3|0]=4;continue}v[c+3|0]=20;v[c+5|0]=d|16;continue}v[c+3|0]=6;v[c+5|0]=d<<4;continue}v[c+3|0]=6;v[c+5|0]=d&15;continue}v[c+3|0]=5;continue}v[c+3|0]=20;v[c+5|0]=d|48;continue}v[c+3|0]=7;v[c+5|0]=d<<4;continue}v[c+3|0]=7;v[c+5|0]=d&15;continue}v[c+3|0]=8;continue}v[c+3|0]=20;v[c+5|0]=d|64;continue}v[c+3|0]=10;x[27524]=0;d=T(210,g|0)|0;j=x[27524];x[27524]=0;if((j|0)!=1){v[c+5|0]=d;x[27524]=0;Q(192,g|0,1)|0;c=x[27524];x[27524]=0;if((c|0)!=1){continue}}break c}v[c+3|0]=15;v[c+5|0]=d&15;continue}v[c+3|0]=20;v[c+5|0]=d|192;continue}v[c+3|0]=20;v[c+5|0]=d|208;continue}v[c+3|0]=12;continue}v[c+3|0]=14;continue}v[c+3|0]=20;v[c+5|0]=d|176;continue}v[c+3|0]=20;v[c+5|0]=d|224;continue}v[c+3|0]=16;continue}v[c+3|0]=17;continue}v[c+3|0]=1;continue}v[c+3|0]=20;v[c+5|0]=d&15|32;continue}v[c+3|0]=20;v[c+5|0]=d&15|128;continue}v[c+3|0]=0;continue}break}if((c|0)==64){break o}ue(Xb(x[k>>2],f),Kh(Te(Me(e+96|0,14,0),c-1|0)))}yb(g)}f=f+1|0;continue}break}break c}c=z[e+218>>1]|z[e+220>>1]<<16;if(!c){break d}bd(b,c);cC(a+1298332|0,b,_g(b),4)}ib=e+272|0;return i|0}a=P()|0;break a}a=P()|0}yb(g);S(a|0);p()}function Oma(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;k=ib-128|0;ib=k;v[k+127|0]=d;a:{if(!c|(e|0)<0&c>>>0>=176){break a}v[b+5|0]=d;v[k+8|0]=15;l=k+127|0;p=k+8|0;j=p;o=y[Ub(l,j)|0];v[k+8|0]=14;l=y[Ub(l,j)|0];x[k+8>>2]=d+31>>>5;x[k+120>>2]=14;r=k+120|0;n=x[rd(j,r)>>2];x[k+8>>2]=d+127>>>7;x[k+120>>2]=14;q=c&15;j=q<<8|d;p=rd(p,r);b:{switch((c>>>4|0)-2|0){case 0:v[b+2|0]=1;v[b+4|0]=j>>>2;break a;case 1:v[b+2|0]=1;if(!j){v[b+4|0]=0;break a}s=b,t=Ag(MB(j)>>>2|0),v[s+4|0]=t;break a;case 2:v[b+3|0]=9;v[b+5|0]=j>>>4;break a;case 3:v[b+3|0]=23;v[b+5|0]=j+1>>>5;break a;case 4:v[b+3|0]=23;if(j){a=Ag(MB(j)>>>5|0)}else{a=0}v[b+5|0]=a;break a;case 5:v[b+5|0]=q;v[b+3|0]=15;break a;case 6:v[b+3|0]=15;if((e|0)>=0){if(y[b+2|0]){break a}v[b+2|0]=2;s=b,t=Dc(((q<<6|7)>>>0)/15|0,0),v[s+4|0]=t;break a}v[b+2|0]=1;v[b+5|0]=q;v[b+4|0]=d+3>>>2;break a;case 7:v[b+3|0]=10;c:{if((e|0)>5){break c}if(!j){v[b+5|0]=1;break a}c=Gq(a,f,g);if(!c){break c}a=Oi(a,c);c=z[a+34>>1];if(c&1){j=j>>>1|0;x[k+120>>2]=j}if(!(c&2)){break c}c=x[a>>2];if(c>>>0>=j<<8>>>0){break c}x[k+120>>2]=x[a+4>>2]+8>>>8;wc(k+120|0,c-1>>>8|0);j=x[k+120>>2]}v[b+5|0]=j;if(y[b+2|0]|j>>>0<256){break a}v[b+2|0]=15;x[k+116>>2]=j>>>8;LB(k+8|0);x[k+112>>2]=9;s=b,t=x[Hb(k+116|0,k+112|0)>>2],v[s+4|0]=t;break a;default:break b}}j=x[p>>2];d:{switch(c-160|0){default:e:{switch(c-1|0){case 0:case 1:case 2:case 3:case 6:case 10:case 14:Xf(b,c,d);f:{switch(y[b+3|0]-16|0){case 1:x[h>>2]=D(y[b+5|0],1e4);break a;case 0:break f;default:break a}}a=y[b+5|0];if(!a){break a}x[i>>2]=a;break a;case 4:v[b+3|0]=4;if(y[b+2|0]){break a}v[b+4|0]=0;v[b+2|0]=8;break a;case 5:v[b+3|0]=5;if(y[b+2|0]){break a}v[b+4|0]=0;v[b+2|0]=11;break a;case 7:if(!Wc(y[b|0])|!d){break a}v[b+3|0]=35;v[b+5|0]=(d>>>1&120|128)-(d<<3&120);e=a+480192|0;if(z[e>>1]){break a}w[k+8>>1]=255;c=z[Tc(a+480190|0,k+8|0)>>1];w[e>>1]=c;b=1;while(1){d=b&65535;if(d>>>0>(c&65535)>>>0){break a}c=hv(a,d,d);if(c){v[c+33|0]=2;d=(d<<5)+a|0;f=d+946304|0;g=x[f+4>>2];x[c+492>>2]=x[f>>2];x[c+496>>2]=g;f=d+946312|0;g=x[f+4>>2];x[c+500>>2]=x[f>>2];x[c+504>>2]=g;f=d+946320|0;g=x[f+4>>2];x[c+508>>2]=x[f>>2];x[c+512>>2]=g;d=d+946328|0;f=x[d+4>>2];x[c+516>>2]=x[d>>2];x[c+520>>2]=f;Tj(c,127,1);Sj(c,0,1)}b=b+1|0;c=z[e>>1];continue};case 8:v[b+3|0]=19;v[b+5|0]=o|208;break a;case 9:v[b+3|0]=25;break a;case 11:if(d>>>0>2){break a}v[b+3|0]=19;v[b+5|0]=d|64;break a;case 12:v[b+3|0]=14;break a;case 13:if(d>>>0>2){break a}v[b+3|0]=19;v[b+5|0]=d|112;break a;case 15:v[b+3|0]=1;break a;case 16:case 17:v[b+3|0]=19;v[b+5|0]=l|c<<4;break a;case 18:v[b+3|0]=15;break a;case 19:v[b+3|0]=11;v[b+5|0]=l<<4;break a;case 20:v[b+5|0]=l;v[b+3|0]=11;break a;case 23:v[b+3|0]=6;v[b+5|0]=l<<4;break a;case 24:v[b+5|0]=l;v[b+3|0]=6;break a;case 27:v[b+3|0]=7;v[b+5|0]=l<<4;break a;case 28:break e;default:break a}}v[b+5|0]=l;v[b+3|0]=7;break a;case 0:if(!d){break a}v[b+3|0]=24;v[b+5|0]=n<<4;break a;case 1:if(!d){break a}v[b+5|0]=n;v[b+3|0]=24;break a;case 4:v[b+3|0]=11;v[b+5|0]=l<<4|15;break a;case 5:v[b+3|0]=11;v[b+5|0]=l|240;break a;case 6:if(!d){break a}v[b+3|0]=24;v[b+5|0]=n<<4|15;break a;case 7:if(!d){break a}v[b+3|0]=24;v[b+5|0]=n|240;break a;case 8:if(!d){break a}v[b+3|0]=16;x[i>>2]=d;break a;case 9:if((e|0)>5){break a}a=x[h>>2];if(a>>>0<1e4){break a}v[b+3|0]=17;m=122925/(+(a>>>0)/1e4)+ +((d<<1)-256|0);s=b,t=Ak(245850/(m+m)),v[s+5|0]=t;break a;case 10:v[b+3|0]=19;v[b+5|0]=o|224;break a;case 12:v[b+3|0]=28;v[b+5|0]=o|16;break a;case 13:v[b+3|0]=28;v[b+5|0]=o|32;break a;case 14:v[b+3|0]=29;v[b+5|0]=l<<3&240;break a;case 15:v[b+3|0]=29;v[b+5|0]=(l&254)>>>1;break a;case 16:v[b+3|0]=18;break a;case 17:v[b+3|0]=19;v[b+5|0]=o|176;break a;case 18:case 19:v[b+3|0]=20;v[b+5|0]=d?120:119;break a;case 20:v[b+3|0]=20;v[b+5|0]=d?125:123;break a;case 21:v[b+3|0]=20;v[b+5|0]=d?122:121;break a;case 22:v[b+3|0]=20;v[b+5|0]=d?126:123;break a;case 26:v[b+3|0]=10;v[b+5|0]=d+15>>>4;break a;case 27:v[b+5|0]=1;v[b+3|0]=10;break a;case 30:case 31:if(!d|(!g|!f)){break a}o=x[h>>2];if(o>>>0<1e4){break a}l=x[i>>2];if(!l){break a}i=Gq(a,f,g);if(!i){break a}j=Oi(a,i);n=z[j+34>>1];g:{if(!(n&2)){i=x[j>>2];break g}i=x[j+8>>2]-((e|0)<6?x[j+4>>2]:0)|0;if(!(n&4)){break g}i=i<<((e|0)>5)}if(!i|(e|0)<6&i>>>0<1024){break a}n=x[j+24>>2];if(!n){break a}h:{if(z[a+480192>>1]<g>>>0){break h}a=x[((g<<2)+a|0)+900380>>2];if(!a){break h}m=+(y[Jb(a+108|0,f-1|0)|0]-f|0)}a=(c|0)==190;m=ki(m/12+(a?(e|0)<6?+v[j+37|0]/-1536:-0:-0))*+(n>>>0);if(a){v[b+3|0]=17;a=Ak(m*.5*(+(D(d,l)>>>0)*2.5)/+(i>>>0));v[b+5|0]=a;x[h>>2]=D(a,1e4);break a}m=Pu(YG(+(i>>>0)/m/(+(D(d,l)>>>0)*2.5/(+(o>>>0)/1e4)))*12+61,1,120);i:{if(m<4294967296&m>=0){a=~~m>>>0;break i}a=0}c=Wc(y[b|0]);v[b|0]=a;m=(m-J(m))*64+128;j:{if(m<4294967296&m>=0){a=~~m>>>0;break j}a=0}v[b+5|0]=a;if((a|0)!=128){v[b+3|0]=35}if(c){break a}if(!y[b+2|0]){v[b+4|0]=9;v[b+2|0]=11;break a}v[b+5|0]=255;v[b+3|0]=4;break a;case 32:a=d>>>4|0;if(a-1>>>0>1){break a}v[b+3|0]=20;v[b+5|0]=a-99;break a;case 34:v[b+3|0]=21;v[b+5|0]=d<<2;break a;case 35:v[b+3|0]=21;s=b,t=Ag(MB(d<<4)>>>6|0),v[s+5|0]=t;break a;case 36:case 38:v[b+3|0]=22;v[b+5|0]=j<<4;break a;case 37:case 39:v[b+5|0]=j;v[b+3|0]=22;break a;case 40:v[b+3|0]=22;v[b+5|0]=l<<4|15;break a;case 2:case 3:case 11:case 23:case 24:case 25:case 28:case 29:case 33:break a;case 41:break d}}v[b+3|0]=22;v[b+5|0]=l|240}ib=k+128|0}function jia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;d=ib-208|0;ib=d;yc(c);a:{if(!yo(c,d+192|0)){break a}if(Qb(d+192|0,13813,4)){break a}f=d+200|0;if(Qb(f,14186,4)){if(Qb(f,14290,4)){break a}}e=ib-32|0;ib=e;i=d+176|0;g=Nb(i);b:{c:{d:{e:{f:{while(1){h=x[c+8>>2];j=x[c>>2];x[27524]=0;h=W(160,j|0,h|0,8)|0;j=x[27524];x[27524]=0;if((j|0)==1){break d}if(!h){break e}x[27524]=0;R(793,e|0,c|0);h=x[27524];x[27524]=0;if((h|0)!=1){x[27524]=0;R(794,g|0,e|0);h=x[27524];x[27524]=0;if((h|0)==1){break f}yd(e);continue}break}a=P()|0;break c}a=P()|0;yd(e);break c}ib=e+32|0;break b}a=P()|0}Zd(g);S(a|0);p()}x[27524]=0;U(723,d+152|0,i|0,1129270605);c=x[27524];x[27524]=0;g:{h:{i:{j:{k:{l:{m:{if((c|0)!=1){x[27524]=0;c=Q(724,d+152|0,d+128|0)|0;e=x[27524];x[27524]=0;n:{o:{if((e|0)!=1){if(!c){break g}if(!ac(z[d+130>>1]|z[d+132>>1]<<16)){break g}if((Fb(z[d+128>>1])-3&65535)>>>0<65534){break g}if((Fb(z[d+134>>1])-65&65535)>>>0<65472){break g}x[d+124>>2]=1162760014;c=1;if(!Qb(f,14290,4)){x[27524]=0;c=Q(612,d+152|0,d+124|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break o}if(!c){break g}c=x[d+124>>2]!=1936684916}x[27524]=0;U(723,d+104|0,d+176|0,1397968452);e=x[27524];x[27524]=0;p:{q:{if((e|0)!=1){x[27524]=0;k=Q(725,d+104|0,d+96|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break p}if(k){break q}break h}c=P()|0;break j}f=(Fb(z[d+134>>1])-1|0)/8|0;g=f<<3;e=g&31;g=Zc(d+88|0,(f>>>0>=8?8:(g&63)>>>0>=32?1074268168>>>e|0:((1<<e)-1&1074268168)<<32-e|538447880>>>e)&255,(Fb(z[d+128>>1])|0)==2?2:1,c,0);c=x[d+124>>2];r:{if((c|0)!=544694642){s:{t:{if(!((c|0)==842222662|(c|0)==842230886|(c|0)==875973702)){if((c|0)==2002873461){break s}if((c|0)==1463897153){break t}if((c|0)==1463897173){break s}if((c|0)==2002873441){break t}if((c|0)!=875981926){break r}}jg(g,3);break r}jg(g,17);ne(g,16);break r}jg(g,16);ne(g,16);break r}jg(g,1)}c=x[d+96>>2];x[27524]=0;c=W(160,x[d+104>>2],x[d+112>>2],ac(c)|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break l}if(c){c=x[d+96>>2];x[27524]=0;Q(192,d+104|0,ac(c)|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break l}}Kt(a,b);x[27524]=0;c=D(b,104)+a|0;i=c+484380|0;R(281,i|0,0);e=x[27524];x[27524]=0;u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{if((e|0)==1){break D}s=i,t=ac(z[d+130>>1]|z[d+132>>1]<<16),x[s>>2]=t;j=c+484404|0;c=y[d+138|0]|y[d+139|0]<<8|(y[d+140|0]<<16|y[d+141|0]<<24);f=c<<24|c<<8&16711680|(c>>>8&65280|c>>>24);h=30-y[d+137|0]|0;e=0;while(1){c=f;if(h&255){f=c>>>1|0;h=h-1|0;e=c;continue}break}x[j>>2]=c+(e&1);x[27524]=0;W(223,g|0,i|0,d+104|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break D}x[27524]=0;U(723,d- -64|0,d+176|0,1296126539);c=x[27524];x[27524]=0;if((c|0)==1){break C}x[27524]=0;c=T(182,x[d+64>>2])|0;e=x[27524];x[27524]=0;if((e|0)==1){break B}if(!c){break u}x[27524]=0;U(723,d+16|0,d+176|0,1229869908);c=x[27524];x[27524]=0;if((c|0)==1){break A}x[27524]=0;c=Q(726,d+16|0,d+40|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break z}yb(d+16|0);if(!c){break u}x[27524]=0;f=T(275,d- -64|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break y}e=Nb(d+16|0);x[27524]=0;R(727,e|0,f|0);c=x[27524];x[27524]=0;if((c|0)==1){break w}c=0;while(1){if((c|0)==(f|0)){break x}x[27524]=0;g=Q(728,d- -64|0,d|0)|0;h=x[27524];x[27524]=0;if((h|0)==1){break w}if(!g){break x}x[27524]=0;R(729,e|0,d|0);g=x[27524];x[27524]=0;if((g|0)==1){break w}x[27524]=0;Q(192,d- -64|0,y[d+6|0]|1)|0;g=x[27524];x[27524]=0;if((g|0)==1){break w}c=c+1|0;continue}}c=P()|0;break k}c=P()|0;break k}c=P()|0;break m}c=P()|0;break m}c=P()|0;yb(d+16|0);break m}c=P()|0;break m}c=Fb(z[d+48>>1]);if(c){f=(D(b,104)+a|0)+484414|0;w[f>>1]=z[f>>1]&65511|((c|0)==2)<<4|8}c=Fb(z[d+54>>1]);if(c){f=(D(b,104)+a|0)+484414|0;w[f>>1]=z[f>>1]&65529|((c|0)==2?4:2)|2}s=d,t=Cb(x[e>>2]),x[s>>2]=t;c=D(b,104)+a|0;g=c+484388|0;h=c+484384|0;j=c+484396|0;l=c+484392|0;m=Cb(x[e+4>>2]);n=z[d+50>>1];o=z[d+52>>1];q=z[d+56>>1];r=z[d+58>>1];while(1){c=x[d>>2];if(!Mb(c,m)){break v}f=Fb(y[c|0]|y[c+1|0]<<8);if((f|0)==(Fb(n)|0)){s=l,t=ac(y[c+2|0]|y[c+3|0]<<8|(y[c+4|0]<<16|y[c+5|0]<<24)),x[s>>2]=t;f=Fb(y[c|0]|y[c+1|0]<<8)}if((Fb(o)|0)==(f|0)){s=j,t=ac(y[c+2|0]|y[c+3|0]<<8|(y[c+4|0]<<16|y[c+5|0]<<24)),x[s>>2]=t;f=Fb(y[c|0]|y[c+1|0]<<8)}if((Fb(q)|0)==(f|0)){s=h,t=ac(y[c+2|0]|y[c+3|0]<<8|(y[c+4|0]<<16|y[c+5|0]<<24)),x[s>>2]=t;f=Fb(y[c|0]|y[c+1|0]<<8)}if((f|0)==(Fb(r)|0)){s=g,t=ac(y[c+2|0]|y[c+3|0]<<8|(y[c+4|0]<<16|y[c+5|0]<<24)),x[s>>2]=t}x[d>>2]=x[d>>2]+7;continue}}c=P()|0;DQ(e);break m}Jk(i);DQ(e)}x[27524]=0;U(723,d+16|0,d+176|0,1312902469);c=x[27524];x[27524]=0;if((c|0)==1){break n}x[27524]=0;c=T(182,x[d+16>>2])|0;e=x[27524];x[27524]=0;E:{if((e|0)==1){break E}F:{if(c){x[27524]=0;c=T(164,x[d+16>>2])|0;e=x[27524];x[27524]=0;if((e|0)==1){break E}x[27524]=0;U(318,d+16|0,((b<<5)+a|0)+946304|0,c|0);b=x[27524];x[27524]=0;if((b|0)!=1){break F}break E}x[27524]=0;c=Q(55,d|0,21631)|0;e=x[27524];x[27524]=0;if((e|0)==1){break E}Cc(((b<<5)+a|0)+946304|0,c);wb(c)}jA(i,x[a+480180>>2]);yj(i,a);yb(d+16|0);yb(d- -64|0);break h}c=P()|0;yb(d+16|0);break m}c=P()|0;break k}c=P()|0;break j}c=P()|0;break j}c=P()|0;break m}c=P()|0;break i}yb(d- -64|0);break k}c=P()|0}yb(d+104|0)}yb(d+152|0)}Zd(d+176|0);S(c|0);p()}yb(d+104|0)}yb(d+152|0);Zd(d+176|0)}ib=d+208|0;return k|0}function Kia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0;e=ib-224|0;ib=e;yc(b);a:{if(!qu(b,e+160|0)){break a}if(!eT(e+160|0)){break a}if(!Ob(x[b>>2],x[b+8>>2],Ec(dT(e+160|0),kb))){break a}if(!c){d=1;break a}zd(a,256);f=e+144|0;Hj(f,2,e+160|0);d=e+48|0;Fc(d,f);Ac(a+1298308|0,d);wb(d);f=z[e+210>>1];x[a+480260>>2]=64;x[a+480264>>2]=32767;w[a+480188>>1]=4;w[a+480190>>1]=f;Lb(a+1074312|0,107,1);f=y[e+203|0];f=f?f:96;k=CA(f);x[a+480196>>2]=f>>>4;x[a+480204>>2]=k;v[e+48|0]=64;C=a,E=y[Ub(e+202|0,d)|0]<<2,x[C+480200>>2]=E;d=0;b:{c:{d:{e:{f:{g:{while(1){if((d|0)==4){h:{k=Nb(e+144|0);m=Nb(e+128|0);x[27524]=0;Q(159,b|0,z[e+192>>1]<<4)|0;d=x[27524];x[27524]=0;i:{if((d|0)==1){break i}x[27524]=0;W(221,b|0,k|0,z[e+208>>1])|0;d=x[27524];x[27524]=0;if((d|0)==1){break i}x[27524]=0;Q(159,b|0,z[e+194>>1]<<4)|0;d=x[27524];x[27524]=0;if((d|0)==1){break i}x[27524]=0;W(221,b|0,m|0,z[e+210>>1])|0;d=x[27524];x[27524]=0;if((d|0)==1){break i}x[27524]=0;Q(159,b|0,(z[e+196>>1]<<4)+32|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break i}d=a+484376|0;f=y[d|0];g=x[a+484360>>2];x[27524]=0;R(328,Tb(g,f)|0,z[e+212>>1]);f=x[27524];x[27524]=0;if((f|0)==1){break i}d=Tb(x[a+484360>>2],y[d|0]);C=e,E=Cb(x[d>>2]),x[C+48>>2]=E;d=Cb(x[d+4>>2]);j:{while(1){f=x[e+48>>2];if(!Mb(f,d)){d=0;if(!gT(Tb(x[a+484360>>2],y[a+484376|0]))){break b}g=c&2;j=e+48|1;d=1;break j}x[27524]=0;g=T(210,b|0)|0;j=x[27524];x[27524]=0;k:{if((j|0)==1){break k}w[f>>1]=g;x[27524]=0;Q(192,b|0,4)|0;f=x[27524];x[27524]=0;if((f|0)==1){break k}Ye(e+48|0);continue}break}b=P()|0;break c}l:{m:{n:{o:{while(1){f=d&65535;if(f>>>0>z[e+210>>1]){break l}i=bc(x[m>>2],f-1|0);i=y[i|0]|y[i+1|0]<<8;x[27524]=0;i=Q(159,b|0,i<<4)|0;h=x[27524];x[27524]=0;p:{if((h|0)!=1){if(i){break p}d=0;break b}b=P()|0;break c}x[27524]=0;Q(676,b|0,e+48|0)|0;i=x[27524];x[27524]=0;if((i|0)==1){break o}x[27524]=0;i=(D(f,104)+a|0)+484380|0;U(677,e+48|0,i|0,0);h=x[27524];x[27524]=0;if((h|0)==1){break o}h=e+16|0;Bk(h,2,j);x[27524]=0;R(226,e+32|0,h|0);h=x[27524];x[27524]=0;if((h|0)==1){break n}h=((f<<5)+a|0)+946304|0;f=e+32|0;Cc(h,f);wb(f);q:{r:{if(!g|!x[e+64>>2]){break r}f=uT(e+48|0);x[27524]=0;f=Q(159,b|0,f|0)|0;h=x[27524];x[27524]=0;if((h|0)==1){break m}if(!f){break r}f=e+32|0;sT(f,y[e+78|0],y[e+79|0],1);x[27524]=0;W(223,f|0,i|0,b|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break q}}d=d+1|0;continue}break}b=P()|0;break c}b=P()|0;break c}b=P()|0;break c}b=P()|0;break c}v[e+15|0]=1;d=x[k>>2];s:{if(pc(d,x[k+4>>2])|z[e+188>>1]==26){break s}f=y[d|0]|y[d+1|0]<<8;d=0;x[27524]=0;f=Q(159,b|0,f<<4)|0;g=x[27524];x[27524]=0;if((g|0)==1){break h}if(!f){break b}x[27524]=0;d=T(198,b|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break h}if((d|0)!=z[e+188>>1]){break s}v[e+15|0]=0}n=c&1;if(n){x[27524]=0;R(229,a+484344|0,z[e+208>>1]);c=x[27524];x[27524]=0;if((c|0)==1){break h}}i=a+484344|0;c=e+48|0;q=c|5;r=c|4;s=c|2;t=c|1;u=a+480188|0;f=0;while(1){t:{if(!n|z[e+208>>1]<=f>>>0){break t}x[27524]=0;c=W(230,i|0,f&65535,64)|0;d=x[27524];x[27524]=0;if((d|0)==1){break g}if(!c){break t}c=bc(x[k>>2],f);c=y[c|0]|y[c+1|0]<<8;x[27524]=0;c=Q(159,b|0,c<<4)|0;d=x[27524];x[27524]=0;if((d|0)==1){break g}d=0;if(!c){break b}if(!y[e+15|0]){x[27524]=0;c=T(198,b|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break g}if(c>>>0>2112){break b}}w[e+16>>1]=65535;x[e+32>>2]=63;u:while(1){c=Xb(x[i>>2],f);A=qf(x[c>>2],x[x[c+48>>2]+12>>2],d);v:while(1){c=d;while(1){if(c>>>0<=63){x[27524]=0;d=T(210,b|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break f}h=d<<24>>24;if(!h){d=64;if(c>>>0>62){continue v}d=c+1|0;continue u}d=h&31;g=D(d,6)+A|0;l=Bg(e+48|0);j=d>>>0<z[u>>1];o=j?g:l;l=h&255;if(l&32){x[27524]=0;R(264,e|0,b|0);d=x[27524];x[27524]=0;w:{x:{y:{if((d|0)!=1){B=Lc(e);d=y[e|0];if(d>>>0>239){break y}d=rT((D(d>>>4|0,12)+(d&15)|0)+37|0);break x}b=P()|0;break c}z:{switch(d-254|0){case 0:break x;case 1:break z;default:break w}}d=0}v[o|0]=d}v[(j?g+1|0:t)|0]=y[B|0]}if(l&64){x[27524]=0;d=T(210,b|0)|0;l=x[27524];x[27524]=0;if((l|0)==1){break e}v[e|0]=d;v[(j?g+2|0:s)|0]=1;v[e+14|0]=64;C=j?g+4|0:r,E=y[Ub(e,e+14|0)|0],v[C|0]=E}if((h|0)>=0){continue}x[27524]=0;R(264,e|0,b|0);d=x[27524];x[27524]=0;if((d|0)==1){break d}C=j?g+5|0:q,E=y[Lc(e)|0],v[C|0]=E;fT(o,y[e|0],c,255,e+16|0,e+32|0);continue}break}break}break}c=z[e+16>>1];if((c|0)!=65535){ue(Xb(x[i>>2],f),Pm(Te(Me(e+48|0,12,c&255),x[e+32>>2])))}f=f+1|0;continue}break}x[27524]=0;b=Q(1,e+48|0,6091)|0;c=x[27524];x[27524]=0;A:{B:{C:{if((c|0)!=1){Gb(a+1298344|0,b);xb(b);x[27524]=0;b=Q(1,e+32|0,5277)|0;c=x[27524];x[27524]=0;if((c|0)==1){break C}Gb(a+1298356|0,b);xb(b);x[a+1298404>>2]=4;x[27524]=0;R(679,e|0,4408);b=x[27524];x[27524]=0;if((b|0)==1){break B}x[27524]=0;U(309,e+16|0,e|0,e+15|0);b=x[27524];x[27524]=0;if((b|0)==1){break A}b=a+1298368|0;a=e+16|0;Gb(b,a);xb(a);$b(e);d=1;break b}b=P()|0;break c}b=P()|0;break c}b=P()|0;break c}b=P()|0;$b(e);break c}b=P()|0;break c}}else{f=(d<<5)+a|0;lf(f+480280|0);w[f+480284>>1]=d&1?64:192;d=d+1|0;continue}break}b=P()|0;break c}b=P()|0;break c}b=P()|0;break c}b=P()|0;break c}b=P()|0}jd(m);jd(k);S(b|0);p()}jd(m);jd(k)}ib=e+224|0;return d|0}function wI(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,z=0,A=0,B=0,E=0,F=0,G=0;j=ib-80|0;ib=j;x[j+76>>2]=b;E=j+55|0;s=j+56|0;a:{b:{c:{d:{e:while(1){k=b;if((p^2147483647)<(h|0)){break d}p=h+p|0;f:{g:{h:{h=k;i=y[h|0];if(i){while(1){i:{b=i&255;j:{if(!b){b=h;break j}if((b|0)!=37){break i}i=h;while(1){if(y[i+1|0]!=37){b=i;break j}h=h+1|0;m=y[i+2|0];b=i+2|0;i=b;if((m|0)==37){continue}break}}h=h-k|0;B=p^2147483647;if((h|0)>(B|0)){break d}if(a){Bf(a,k,h)}if(h){continue e}x[j+76>>2]=b;h=b+1|0;q=-1;i=v[b+1|0];if(!(!hk(i)|y[b+2|0]!=36)){q=i-48|0;t=1;h=b+3|0}x[j+76>>2]=h;n=0;i=v[h|0];b=i-32|0;k:{if(b>>>0>31){m=h;break k}m=h;b=1<<b;if(!(b&75913)){break k}while(1){m=h+1|0;x[j+76>>2]=m;n=b|n;i=v[h+1|0];b=i-32|0;if(b>>>0>=32){break k}h=m;b=1<<b;if(b&75913){continue}break}}l:{if((i|0)==42){b=v[m+1|0];m:{if(!(!hk(b)|y[m+2|0]!=36)){x[((b<<2)+e|0)-192>>2]=10;i=m+3|0;t=1;b=x[((v[m+1|0]<<3)+d|0)-384>>2];break m}if(t){break h}i=m+1|0;if(!a){x[j+76>>2]=i;t=0;r=0;break l}b=x[c>>2];x[c>>2]=b+4;t=0;b=x[b>>2]}r=b;x[j+76>>2]=i;if((r|0)>=0){break l}r=0-r|0;n=n|8192;break l}r=vI(j+76|0);if((r|0)<0){break d}i=x[j+76>>2]}h=0;l=-1;n:{if(y[i|0]!=46){b=i;A=0;break n}if(y[i+1|0]==42){b=v[i+2|0];o:{if(!(!hk(b)|y[i+3|0]!=36)){x[((b<<2)+e|0)-192>>2]=10;b=i+4|0;l=x[((v[i+2|0]<<3)+d|0)-384>>2];break o}if(t){break h}b=i+2|0;l=0;if(!a){break o}i=x[c>>2];x[c>>2]=i+4;l=x[i>>2]}x[j+76>>2]=b;A=(l^-1)>>>31|0;break n}x[j+76>>2]=i+1;l=vI(j+76|0);b=x[j+76>>2];A=1}while(1){o=h;m=28;u=b;h=v[b|0];if(h-123>>>0<4294967238){break c}b=u+1|0;h=y[(h+D(o,58)|0)+91807|0];if(h-1>>>0<8){continue}break}x[j+76>>2]=b;p:{q:{if((h|0)!=27){if(!h){break c}if((q|0)>=0){x[(q<<2)+e>>2]=h;h=(q<<3)+d|0;i=x[h+4>>2];x[j+64>>2]=x[h>>2];x[j+68>>2]=i;break q}if(!a){break f}uI(j- -64|0,h,c,g);break p}if((q|0)>=0){break c}}h=0;if(!a){continue e}}i=n&-65537;n=n&8192?i:n;q=0;z=5289;m=s;r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{h=v[u|0];h=o?(h&15)==3?h&-33:h:h;switch(h-88|0){case 11:break r;case 9:case 13:case 14:case 15:break s;case 27:break x;case 12:case 17:break A;case 23:break B;case 0:case 32:break C;case 24:break D;case 22:break E;case 29:break F;case 1:case 2:case 3:case 4:case 5:case 6:case 7:case 8:case 10:case 16:case 18:case 19:case 20:case 21:case 25:case 26:case 28:case 30:case 31:break g;default:break G}}H:{switch(h-65|0){case 0:case 4:case 5:case 6:break s;case 2:break v;case 1:case 3:break g;default:break H}}if((h|0)==83){break w}break g}o=x[j+64>>2];i=x[j+68>>2];z=5289;break z}h=0;I:{switch(o&255){case 0:x[x[j+64>>2]>>2]=p;continue e;case 1:x[x[j+64>>2]>>2]=p;continue e;case 2:k=x[j+64>>2];x[k>>2]=p;x[k+4>>2]=p>>31;continue e;case 3:w[x[j+64>>2]>>1]=p;continue e;case 4:v[x[j+64>>2]]=p;continue e;case 6:x[x[j+64>>2]>>2]=p;continue e;case 7:break I;default:continue e}}k=x[j+64>>2];x[k>>2]=p;x[k+4>>2]=p>>31;continue e}l=l>>>0<=8?8:l;n=n|8;h=120}k=s;F=h&32;o=x[j+64>>2];i=x[j+68>>2];if(o|i){while(1){k=k-1|0;v[k|0]=F|y[(o&15)+92336|0];G=!i&o>>>0>15|(i|0)!=0;u=i;i=i>>>4|0;o=(u&15)<<28|o>>>4;if(G){continue}break}}if(!(n&8)|!(x[j+64>>2]|x[j+68>>2])){break y}z=(h>>>4|0)+5289|0;q=2;break y}h=s;k=x[j+68>>2];i=k;o=x[j+64>>2];if(i|o){while(1){h=h-1|0;v[h|0]=o&7|48;u=!i&o>>>0>7|(i|0)!=0;k=i;i=i>>>3|0;o=(k&7)<<29|o>>>3;if(u){continue}break}}k=h;if(!(n&8)){break y}h=s-k|0;l=(h|0)<(l|0)?l:h+1|0;break y}h=x[j+68>>2];i=h;o=x[j+64>>2];if((h|0)<0){i=0-(i+((o|0)!=0)|0)|0;o=0-o|0;x[j+64>>2]=o;x[j+68>>2]=i;q=1;z=5289;break z}if(n&2048){q=1;z=5290;break z}q=n&1;z=q?5291:5289}k=In(o,i,s)}if((l|0)<0?A:0){break d}n=A?n&-65537:n;i=x[j+64>>2];h=x[j+68>>2];if(!((i|h)!=0|l)){k=s;m=k;l=0;break g}h=!(h|i)+(s-k|0)|0;l=(h|0)<(l|0)?l:h;break g}h=x[j+64>>2];k=h?h:17049;h=l>>>0>=2147483647?2147483647:l;m=at(k,0,h);h=m?m-k|0:h;m=h+k|0;if((l|0)>=0){n=i;l=h;break g}n=i;l=h;if(y[m|0]){break d}break g}if(l){i=x[j+64>>2];break u}h=0;Pf(a,32,r,0,n);break t}x[j+12>>2]=0;x[j+8>>2]=x[j+64>>2];i=j+8|0;x[j+64>>2]=i;l=-1}h=0;J:{while(1){k=x[i>>2];if(!k){break J}k=tI(j+4|0,k);m=(k|0)<0;if(!(m|k>>>0>l-h>>>0)){i=i+4|0;h=h+k|0;if(l>>>0>h>>>0){continue}break J}break}if(m){break b}}m=61;if((h|0)<0){break c}Pf(a,32,r,h,n);if(!h){h=0;break t}m=0;i=x[j+64>>2];while(1){k=x[i>>2];if(!k){break t}k=tI(j+4|0,k);m=k+m|0;if(m>>>0>h>>>0){break t}Bf(a,j+4|0,k);i=i+4|0;if(h>>>0>m>>>0){continue}break}}Pf(a,32,r,h,n^8192);h=(h|0)<(r|0)?r:h;continue e}if((l|0)<0?A:0){break d}m=61;h=lb[f|0](a,C[j+64>>3],r,l,n,h)|0;if((h|0)>=0){continue e}break c}v[j+55|0]=x[j+64>>2];l=1;k=E;n=i;break g}i=y[h+1|0];h=h+1|0;continue}}if(a){break a}if(!t){break f}h=1;while(1){a=x[(h<<2)+e>>2];if(a){uI((h<<3)+d|0,a,c,g);p=1;h=h+1|0;if((h|0)!=10){continue}break a}break}p=1;if(h>>>0>=10){break a}while(1){if(x[(h<<2)+e>>2]){break h}h=h+1|0;if((h|0)!=10){continue}break}break a}m=28;break c}o=m-k|0;l=(l|0)>(o|0)?l:o;if((l|0)>(q^2147483647)){break d}m=61;i=l+q|0;h=(i|0)<(r|0)?r:i;if((B|0)<(h|0)){break c}Pf(a,32,h,i,n);Bf(a,z,q);Pf(a,48,h,i,n^65536);Pf(a,48,l,o,0);Bf(a,k,o);Pf(a,32,h,i,n^8192);continue}break}p=0;break a}m=61}x[12e4]=m}p=-1}ib=j+80|0;return p}function Vla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0;f=ib-224|0;ib=f;if(Lh(b,13828)){if(d){v[d|0]=1}k=a+480204|0;n=a+480216|0;o=a+480220|0;q=a+480224|0;l=a+1074368|0;t=a+480228|0;u=a+480232|0;r=a+480200|0;m=a+480268|0;B=a+1298320|0;C=a+480248|0;E=Iu(a+1074312|0);F=a+480180|0;G=a+484376|0;H=a+480190|0;a:{b:{c:{d:{e:{f:{g:{h:{while(1){if(!Ob(x[b>>2],x[b+8>>2],7)){break a}e=Jg(b);g=_g(b);if((e|0)==(y[21607]|y[21608]<<8|(y[21609]<<16|y[21610]<<24))){Gg(b,6);break a}if(!(e&1616928864)|e&-2139062144){break a}if(!Ob(x[b>>2],x[b+8>>2],g)){break a}d=f+176|0;ae(d,b,g);h=hc(f+200|0,d);yb(d);i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{if((e|0)!=1127099950){if((e|0)==1129797166){break v}if((e|0)==1130917459){break o}if((e|0)==1145525806){break t}d=u;if((e|0)==1448301654){break s}if((e|0)==1196316499){break m}if((e|0)==1213486401){break p}if((e|0)==1280530262){break u}if((e|0)==1297303086){break l}if((e|0)==1347243310){break w}if((e|0)==1347244882){break q}if((e|0)!=1380340804){if((e|0)==1380986414){break r}d=n;if((e|0)==1380991534){break s}d=o;if((e|0)==1380994350){break s}if((e|0)==1397052739){break n}d=t;if((e|0)==1397768494){break s}if((e|0)==1414344238){break k}if((e|0)!=1146367534){break j}x[27524]=0;U(444,h|0,g|0,f+176|0);d=x[27524];x[27524]=0;if((d|0)==1){break i}x[k>>2]=D(x[f+176>>2],1e4)+(A[k>>2]%1e4|0);break j}x[27524]=0;U(444,h|0,g|0,f+176|0);d=x[27524];x[27524]=0;if((d|0)!=1){d=x[k>>2];x[k>>2]=d-((d>>>0)%1e4|0)+A[f+176>>2]%1e4;break j}e=P()|0;break b}if(c){break j}x[27524]=0;w[f+176>>1]=0;U(445,h|0,g|0,f+176|0);d=x[27524];x[27524]=0;if((d|0)!=1){I=a,J=Bd(z[f+176>>1],z[a+480188>>1],127),w[I+480188>>1]=J;break j}e=P()|0;break b}x[27524]=0;U(446,h|0,g|0,l|0);d=x[27524];x[27524]=0;if((d|0)!=1){break j}break c}x[27524]=0;x[f+176>>2]=0;U(444,h|0,g|0,f+176|0);d=x[27524];x[27524]=0;if((d|0)!=1){x[a+1074304>>2]=x[f+176>>2];break j}e=P()|0;break b}x[27524]=0;x[f+176>>2]=0;U(444,h|0,g|0,f+176|0);d=x[27524];x[27524]=0;if((d|0)==1){break h}d=x[f+176>>2];if(!d){break j}x[a+1074308>>2]=d;break j}d=r}x[27524]=0;U(444,h|0,g|0,d|0);d=x[27524];x[27524]=0;if((d|0)==1){break c}break j}if(x[F>>2]==4){break j}x[27524]=0;U(445,h|0,g|0,f+176|0);d=x[27524];x[27524]=0;if((d|0)!=1){_e(Tb(x[a+484360>>2],y[G|0]),z[f+176>>1]);break j}e=P()|0;break b}x[27524]=0;U(447,h|0,g|0,m|0);d=x[27524];x[27524]=0;if((d|0)==1){break c}if(Oo(y[m|0])){break j}v[m|0]=5;break j}d=Kb(f+176|0);e=x[h>>2];x[27524]=0;e=T(164,e|0)|0;g=x[27524];x[27524]=0;x:{if((g|0)==1){break x}x[27524]=0;U(448,h|0,d|0,e|0);e=x[27524];x[27524]=0;if((e|0)==1){break x}x[27524]=0;U(11,f+160|0,0,d|0);e=x[27524];x[27524]=0;if((e|0)==1){break x}e=f+160|0;Gb(B,e);xb(e);wb(d);break j}e=P()|0;wb(d);break b}if(g&1|g>>>0>126){break j}d=64;w[f+176>>1]=(g>>>1|0)- -64;w[f+160>>1]=127;e=z[Tc(f+176|0,f+160|0)>>1];i=e>>>0<=64?64:e;while(1){if((d|0)==(i|0)){break j}x[27524]=0;R(264,f+176|0,h|0);e=x[27524];x[27524]=0;if((e|0)==1){break g}e=y[f+176|0];y:{if((e|0)==255){break y}j=y[Lc(f+176|0)|0];g=(d<<5)+a|0;s=g+480284|0;w[s>>1]=128;w[g+480286>>1]=j;g=g+480280|0;j=(e&128)<<3;x[g>>2]=j;e=e&127;if(e>>>0<65){w[s>>1]=e<<2;break y}if((e|0)!=100){break y}x[g>>2]=j|256}d=d+1|0;continue}}if(g>>>0<3){break j}x[27524]=0;d=T(198,h|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break f}if(!d|d>>>0>z[H>>1]){break j}d=(D(d,104)+a|0)+484448|0;g=PV(d);while(1){if((d|0)==(g|0)){break j}e=x[h>>2];x[27524]=0;i=W(160,e|0,x[f+208>>2],4)|0;e=x[27524];x[27524]=0;z:{if((e|0)!=1){e=268435456;if(!i){break z}x[27524]=0;e=T(161,h|0)|0;i=x[27524];x[27524]=0;if((i|0)!=1){break z}}e=P()|0;break b}x[d>>2]=e;d=d+4|0;continue}}if(g>>>0<3){break j}x[27524]=0;R(449,f|0,h|0);d=x[27524];x[27524]=0;A:{B:{C:{D:{if((d|0)!=1){x[27524]=0;U(450,f+176|0,x[f>>2],x[f+4>>2]);d=x[27524];x[27524]=0;if((d|0)==1){break D}x[27524]=0;d=Q(90,f+16|0,f+176|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break C}wb(f+176|0);ec(f);e=x[h>>2];x[27524]=0;T(164,e|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break A}x[27524]=0;R(451,d|0,C|0);e=x[27524];x[27524]=0;if((e|0)==1){break A}Cf(d);break j}e=P()|0;break b}e=P()|0;break B}e=P()|0;wb(f+176|0)}ec(f);break b}e=P()|0;Cf(d);break b}e=0;g=Iu(E);E:while(1){d=x[h>>2];x[27524]=0;d=W(160,d|0,x[f+208>>2],1)|0;i=x[27524];x[27524]=0;if((i|0)==1){break d}if(!(d&e>>>0<119)){break j}x[27524]=0;i=T(210,h|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break e}d=0;while(1){if((d|0)==8){continue E}F:{if(!(i>>>d&1)|e>>>0>118){break F}x[27524]=0;W(268,g|0,e|0,1)|0;j=x[27524];x[27524]=0;if((j|0)!=1){break F}e=P()|0;break b}e=e+1|0;d=d+1|0;continue}}}x[27524]=0;U(452,h|0,g|0,q|0);d=x[27524];x[27524]=0;if((d|0)==1){break c}}yb(h);continue}break}e=P()|0;break b}e=P()|0;break b}e=P()|0;break b}e=P()|0;break b}e=P()|0;break b}e=P()|0;break b}e=P()|0}yb(h);S(e|0);p()}b=x[a+8>>2];Xo(k,D(x[b+20>>2],1e4),D(x[b+24>>2],1e4));if(y[a+480224|0]>=3){v[q|0]=0}if(y[l|0]>=6){v[l|0]=0}wc(r,256);wc(n,65536);wc(o,65536)}ib=f+224|0}function oma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0;e=ib-1360|0;ib=e;yc(b);g=ib-16|0;ib=g;j=e+784|0;XV(g+8|0,j);i=x[g+12>>2];kc(g,x[b>>2],x[b+8>>2],x[g+8>>2],x[g+12>>2]);l=x[g+4>>2];if((l|0)==(i|0)){Yb(b,x[g+12>>2])}ib=g+16|0;g=(i|0)==(l|0);if(!g){WV(j)}a:{if(!g){break a}if(!ZV(e+784|0)){break a}if(!Ob(x[b>>2],x[b+8>>2],Ec(YV(z[e+818>>1],z[e+820>>1]),kb))){break a}if(!c){d=1;break a}r=sc(e+776|0);b:{while(1){if((d|0)!=32){g=(d<<5)+a|0;i=g+480280|0;lf(i);j=(e+784|0)+(d<<4)|0;w[g+480284>>1]=((y[j+78|0]<<8&65280)>>>0)/255;m=e+512|0;Bk(m,1,j- -64|0);l=e+112|0;Fc(l,m);Il(g+480289|0,l);wb(l);c:{d:{switch(y[j+79|0]){case 0:k=f+1|0;break c;case 1:x[i>>2]=1024;k=d+1|0;break c;case 2:break d;default:break b}}x[i>>2]=1024;g=e+112|0;Pc(g,r,d);uo(g)}f=f+1|0;d=d+1|0;continue}break}zd(a,33554432);w[a+480188>>1]=k&255;d=e+112|0;f=xc(d,6776);Gb(a+1298344|0,f);xb(f);d=xc(d,11050);Gb(a+1298356|0,d);xb(d);x[a+1298404>>2]=4;e:{if(y[e+863|0]){break e}d=1;f=1;while(1){if((d|0)==16){while(1){if((f|0)==16){break e}d=((f<<5)+a|0)+480280|0;x[d>>2]=x[d>>2]&-1025;f=f+1|0;continue}}g=d<<4;d=d+1|0;if(y[(e+g|0)+863|0]==1){continue}break}}d=e+512|0;Se(d,1,e+784|0);f=e+112|0;Fc(f,d);Ac(a+1298308|0,f);wb(f);x[a+480208>>2]=x[a+480208>>2]&-17|z[e+822>>1]<<4&16;x[a+480196>>2]=y[e+832|0];x[a+480204>>2]=D(y[e+833|0],1e4);x[a+480200>>2]=y[e+834|0]<<2;x[a+480228>>2]=y[e+835|0];f=z[e+820>>1];w[a+480190>>1]=0;w[a+480192>>1]=f;yv(b,d);er(Tb(x[a+484360>>2],y[a+484376|0]),d,z[e+816>>1],65535,255);o=c&1;if(o){Fg(a+484344|0,z[e+818>>1])}m=a+484344|0;t=a+480188|0;f:{while(1){g:{if(z[e+818>>1]<=h>>>0){l=c&2;r=e+108|0;m=a+480192|0;g=1;c=0;h:while(1){if(z[m>>1]<=(c&65535)>>>0){d=32;break b}c=c+1|0;f=hv(a,c&65535,0);i=!f;d=ib-16|0;ib=d;k=e+112|0;cc(d+8|0,k,384);h=x[d+12>>2];kc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);j=x[d+4>>2];if((j|0)==(h|0)){Yb(b,x[d+12>>2])}ib=d+16|0;d=(h|0)==(j|0);if(!d){Rb(k,0,384)}if(!d|i){continue}k=g&65535;h=ib-32|0;ib=h;i=e+112|0;Se(h,1,i);d=h+16|0;Fc(d,h);Cc(f+492|0,d);wb(d);i:{if(!(y[i+378|0]|y[i+379|0]<<8)){break i}j=f+236|0;d=0;while(1){x[h+16>>2]=120;x[h>>2]=116;if(A[Hb(h+16|0,h)>>2]<=d>>>0){break i}u=bc(j,d+12|0),B=k+y[(d+i|0)+32|0]|0,w[u>>1]=B;d=d+1|0;continue}}d=y[i+376|0]|y[i+377|0]<<8;v[f+33|0]=1;x[f>>2]=d;FB(i,f+48|0,0);FB(i,f+68|0,1);FB(i,f+88|0,2);d=y[f+100|0];if(d&1){v[f+100|0]=d|16}if(!(x[f>>2]|v[f+60|0]&1)){x[f>>2]=32767}ib=h+32|0;d=0;while(1){f=z[e+490>>1];if(f>>>0<=d>>>0){g=f+g|0;continue h}bX(b,e+48|0);j:{k:{if(Qb(r,15521,4)){break k}f=d+g|0;k=f&65535;if(k>>>0>3999){break k}w[a+480190>>1]=f;i=ib-32|0;ib=i;j=D(k,104)+a|0;f=j+484380|0;md(f,0);di(i,1,e+48|0);h=i+16|0;Fc(h,i);Fe(f+43|0,h);wb(h);q=y[e+64|0]|y[e+65|0]<<8|(y[e+66|0]<<16|y[e+67|0]<<24);x[f>>2]=q;n=y[e+68|0]|y[e+69|0]<<8|(y[e+70|0]<<16|y[e+71|0]<<24);x[f+4>>2]=n;o=y[e+72|0]|y[e+73|0]<<8|(y[e+74|0]<<16|y[e+75|0]<<24);x[f+8>>2]=o;x[f+24>>2]=y[e+76|0]|y[e+77|0]<<8|(y[e+78|0]<<16|y[e+79|0]<<24);w[f+30>>1]=y[e+80|0]<<2;w[f+28>>1]=y[e+81|0];h=y[e+96|0];if(h&1){w[f+34>>1]=z[f+34>>1]|2;h=y[e+96|0]}if(h&2){w[f+34>>1]=z[f+34>>1]|4;h=y[e+96|0]}if(h&4){x[f+8>>2]=o>>>1;x[f+4>>2]=n>>>1;x[f>>2]=q>>>1;w[f+34>>1]=z[f+34>>1]|1;h=y[e+96|0]}if(h&8){w[f+34>>1]=z[f+34>>1]|32}ib=i+32|0;h=ib-16|0;ib=h;Iv(h+8|0,j+484423|0);i=e+24|0;kr(i,x[h+8>>2],x[h+12>>2]);ib=h+16|0;Cc(((k<<5)+a|0)+946304|0,i);wb(i);h=x[e+64>>2];if(!h){break k}ae(e,b,h);h=hc(e+24|0,e);yb(e);if(l){i=Zc(e,w[j+484414>>1]&1?16:8,1,0,0);x[27524]=0;W(223,i|0,f|0,h|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break j}}yb(h)}d=d+1|0;continue}break}break}a=P()|0;yb(h);break f}f=_g(b);q=_g(b);d=e+48|0;ae(d,b,f-4|0);j=hc(e+112|0,d);yb(d);l:{m:{if(!o){break m}x[27524]=0;d=W(230,m|0,h&65535,q|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break l}if(!d){break m}k=0;i=Bg(e+24|0);while(1){if(k>>>0>=q>>>0){break m}x[27524]=0;l=T(210,j|0)|0;d=x[27524];x[27524]=0;n:{if((d|0)!=1){if(l){break n}k=k+1|0;continue}break g}f=i;n=l&31;if(n>>>0<z[t>>1]){d=Xb(x[m>>2],h);f=hd(x[d>>2],x[x[d+48>>2]+12>>2],k,n)}if(l&32){x[27524]=0;R(264,e+48|0,j|0);d=x[27524];x[27524]=0;if((d|0)==1){break g}g=y[e+48|0];v[f|0]=g;u=f,B=y[Lc(e+48|0)|0],v[u+1|0]=B;o:{p:{if((g|0)==160){d=255;break p}if((g|0)==255){d=0;break p}d=0;g=(D(g>>>4|0,12)+(g&15)|0)+13|0;if(VV(g)){break o}}g=d}v[f|0]=g}d=l&192;q:{if(!d){break q}if((d|0)==192){x[27524]=0;R(353,e+48|0,j|0);d=x[27524];x[27524]=0;if((d|0)!=1){d=e+48|0;g=Lc(d);l=Ze(d);d=Si(d);GB(e,y[e+48|0],y[g|0]);g=Lc(e);s=e+504|0;GB(s,y[l|0],y[d|0]);Fo(e+496|0,f,y[e|0],y[g|0],y[e+504|0],y[Lc(s)|0]);break q}break g}x[27524]=0;R(264,e+48|0,j|0);d=x[27524];x[27524]=0;r:{s:{if((d|0)!=1){GB(e,y[e+48|0],y[Lc(e+48|0)|0]);g=y[Lc(e)|0];d=y[e|0];if((d|0)!=13){break s}v[f+2|0]=1;d=f+4|0;break r}break g}v[f+3|0]=d;d=f+5|0}v[d|0]=g}Pc(e+48|0,r,n);if(!zb(x[x[e+48>>2]>>2],x[e+52>>2])){continue}if(!VX(y[f+3|0],y[f+5|0])){continue}v[f+3|0]=0;continue}}yb(j);h=h+1|0;continue}}break}a=P()|0;yb(j)}S(a|0);p()}d=d>>>0>31}ib=e+1360|0;return d|0}function aka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,A=0;e=ib-1824|0;ib=e;yc(b);d=ib-16|0;ib=d;i=e+1224|0;oU(d+8|0,i);h=x[d+12>>2];kc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);k=x[d+4>>2];if((k|0)==(h|0)){Yb(b,x[d+12>>2])}ib=d+16|0;d=(h|0)==(k|0);if(!d){nU(i)}a:{if(!d){break a}if(!pU(e+1224|0)){break a}if(!TA(b,16,0)){break a}x[e+1216>>2]=x[e+1240>>2];d=x[e+1228>>2];x[e+1200>>2]=x[e+1224>>2];x[e+1204>>2]=d;d=e+1232|0;f=x[d+4>>2];x[e+1208>>2]=x[d>>2];x[e+1212>>2]=f;zd(a,1);Lb(Lb(fg(a+1074312|0,83),84,1),85,1);w[a+480188>>1]=4;x[e+1196>>2]=0;w[a+480190>>1]=15;bd(b,20);l=a+480188|0;f=1;i=1;while(1){b:{if((f|0)==16){d=e+1064|0;xU(b,d);h=a+484360|0;k=a+484376|0;Uq(Tb(x[h>>2],y[k|0]),d|2,128);f=0;k=wU(b,Tb(x[h>>2],y[k|0]),y[e+1064|0],g,l,0,1);if(!(y[e+1065|0]|k>>>0>1|y[e+1064|0])){break a}if(jf(b)+65536>>>0<(k<<10)+g>>>0){break a}if(c){break b}f=1;break a}h=D(f,104)+a|0;k=h+484380|0;d=((f<<5)+a|0)+946304|0;UA(b,e+24|0,k,d,1);n=x[k>>2];c:{if(!y[Jb(d,0)|0]){break c}d:{if(Qb(d,16750,3)){if(Qb(d,16754,3)){break d}}if(y[Jb(d,5)|0]==58){break c}}i=0}d=Fb(z[e+52>>1]);if(d>>>0>=2){m=d<<1;d=Fb(z[e+50>>1]);x[h+484388>>2]=m+d;x[h+484384>>2]=d;Jk(k)}e:{if(Fb(z[e+46>>1])>>>0<=4999){if(Fb(z[e+50>>1])>>>0<1e4){break e}}x[e+1064>>2]=5;u=e,A=x[Ve(e+1196|0,e+1064|0)>>2],x[u+1196>>2]=A}g=g+n|0;f=f+1|0;continue}break}f=y[e+1065|0];if(!f){v[e+1065|0]=120;f=120}f:{if(!Qb(e+1200|0,14927,6)){v[e+1065|0]=120;x[a+480204>>2]=125e4;break f}x[a+480204>>2]=125e4;if((f|0)==120){break f}u=a,A=Xe(1773447.5/(+(240-f|0)*122)*1e4),x[u+480204>>2]=A;if(x[e+1196>>2]>=2){x[e+24>>2]=i?4:5;u=e,A=x[Ve(e+1196|0,e+24|0)>>2],x[u+1196>>2]=A;break f}x[e+24>>2]=i?1:2;u=e,A=x[Ve(e+1196|0,e+24|0)>>2],x[u+1196>>2]=A}x[a+480228>>2]=64;x[a+480260>>2]=452;x[a+480264>>2]=3424;x[a+480208>>2]=x[a+480208>>2]|2097152;g=e+1048|0;Hj(g,3,e+1200|0);d=e+24|0;Fc(d,g);Ac(a+1298308|0,d);wb(d);uh(a,0);r=x[b+8>>2];s=a+484376|0;while(1){g:{h:{if((q&65535)>>>0<k>>>0){d=Tb(x[a+484360>>2],y[s|0]);d=Mb(NA(Cb(x[d>>2]),Cb(x[d+4>>2]),q),Cb(x[d+4>>2]));mU(b,e+24|0);if(d){j=RA(e+24|0,0)+j|0;if(j>>>0>512){break h}}n=0;d=0;h=0;i:while(1){if((h|0)==64){break g}f=0;t=Kd(e+24|0,h);while(1){g=d;if((f|0)==4){h=h+1|0;continue i}else{p=Bb(t,f);m=y[Jb(p,2)|0]&15;l=y[Jb(p,3)|0];d=0;j:{if(!(g&255)){break j}if(Qb(p,26900,4)){break j}d=g+1|0;if((d&255)>>>0<33){break j}x[e+1196>>2]=6}k:{l:{m:{switch(m-1|0){case 0:case 1:g=x[e+1196>>2];if((g|0)==1&l>>>0>=32){break l}m=(m|0)!=1;if(!(m|!l|l>>>0>2)){x[e+1048>>2]=2;u=e,A=x[Ve(e+1196|0,e+1048|0)>>2],x[u+1196>>2]=A;break k}if(m|(l|0)!=55&(l|0)!=71){break k}if((g|0)<=2){break l}break k;case 10:x[e+1196>>2]=6;break k;case 11:case 12:case 13:x[e+1048>>2]=2;u=e,A=x[Ve(e+1196|0,e+1048|0)>>2],x[u+1196>>2]=A;if((m|0)!=13){break k}n=((h|l)!=0)+n|0;d=1;break k;case 14:break m;default:break k}}x[e+1048>>2]=3;u=e,A=x[Ve(e+1196|0,e+1048|0)>>2],x[u+1196>>2]=A;break k}x[e+1196>>2]=i}f=f+1|0;continue}}}}if(!(x[e+1196>>2]!=6|k+32>>>0>=o>>>0)){x[e+1196>>2]=5}bd(b,r);m=c&1;if(m){Fg(a+484344|0,k)}n=a+484344|0;o=0;while(1)if((k|0)==(o|0)){f=21631;d=x[e+1196>>2];if(d>>>0<7){f=x[(d<<2)+26912>>2]}d=e+24|0;g=xc(d,8252);Gb(a+1298344|0,g);xb(g);d=xc(d,10694);Gb(a+1298356|0,d);xb(d);Vl(a+1298368|0,f);x[a+1298404>>2]=28;if(!(c&2)){break h}f=1;while(1){if((f|0)==16){break h}c=D(f,104)+a|0;d=c+484384|0;Yb(b,x[d>>2]);g=x[d>>2];x[d>>2]=0;d=c+484380|0;x[d>>2]=x[d>>2]-g;c=c+484388|0;x[c>>2]=x[c>>2]-g;c=e+24|0;Zc(c,8,1,1,0);Eg(c,d,b);f=f+1|0;continue}}else{mU(b,e+24|0);n:{if(!m){break n}if(!vh(n,o&65535,64)){break n}h=0;x[e+1048>>2]=0;o:while(1){if((h|0)==64){break n}f=0;d=Xb(x[n>>2],o);p=hd(x[d>>2],x[x[d+48>>2]+12>>2],h,0);r=Kd(e+24|0,h);while(1)if((f|0)==4){h=h+1|0;continue o}else{d=Bb(r,f);d=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);x[e+4>>2]=d;x[e+8>>2]=d;g=e+16|0;d=p+D(f,6)|0;Su(g,e+4|0,d);l=(e+1048|0)+f|0;j=y[e+16|0];g=Lc(g);i=y[g|0];p:{q:{if(!((j&255)!=14?i:0)){v[l|0]=0;if((j|i)&255){break q}break p}i=y[l|0];if(!i){break q}r:{if(i>>>0>=16){v[d+2|0]=3;i=i>>>4|0;break r}v[d+2|0]=4}v[d+4|0]=i;j=y[e+16|0]}s:{t:{u:{v:{w:{switch((j&255)-12|0){case 1:j=x[e+1196>>2];if((j|0)!=6){v[e+16|0]=10;break u}v[g|0]=0;break v;case 0:v[g|0]=y[g|0]&127;break v;case 2:j=y[g|0];if(j>>>0<=1){i=14;if(x[e+1196>>2]>3){break t}}v[e+16|0]=10;v[l|0]=y[g|0];break v;case 3:break w;default:break v}}v[g|0]=y[g|0]&15}j=x[e+1196>>2]}if((j|0)<2){break s}j=y[g|0];i=y[e+16|0]}Xf(d,i,j&255);break p}j=y[g|0];v[d+5|0]=j;x:{switch(y[e+16|0]){case 0:if(y[g|0]<=2){v[d+3|0]=0;break p}v[d+3|0]=1;break p;case 1:v[d+3|0]=1;break p;case 2:g=j&15;if(g){v[d+3|0]=2;v[d+5|0]=g;break p}if(j>>>0<16){break p}v[d+3|0]=3;v[d+5|0]=(j&240)>>>4;break p;default:break x}}v[d+3|0]=0}f=f+1|0;continue}}}o=o+1|0;continue}}f=(q&65535)>>>0>=k>>>0;break a}if((n-1&255)>>>0<2){x[e+1196>>2]=6}q=q+1|0;o=(n&255)+o|0;continue}}ib=e+1824|0;return f|0}function Oia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;d=ib-352|0;ib=d;bd(b,60);f=15;a:{if(!Lh(b,14138)){bd(b,124);f=31;if(!Lh(b,15376)){break a}}zd(a,536870912);w[a+480190>>1]=f;yc(b);b:{while(1){if(z[a+480190>>1]>g>>>0){e=Go(b);x[(d+224|0)+(g<<2)>>2]=e;g=g+1|0;if(e>>>0<=131072){continue}break b}break}x[a+480260>>2]=56;x[a+480264>>2]=13696;x[a+480196>>2]=6;g=0;w[a+480192>>1]=0;w[a+480188>>1]=4;x[a+480228>>2]=64;uh(a,1);Yb(b,4);e=Mj(b);if(e>>>0<178){break a}q=a,r=Xe(1776930/+(e>>>0)*1e4),x[q+480204>>2]=r;Yb(b,14);f=0;n=1;c:while(1){m=n&65535;if(m>>>0<=z[a+480190>>1]){sU(b,d+56|0);g=x[((m<<2)+d|0)+220>>2];l=ib-16|0;ib=l;h=(D(m,104)+a|0)+484380|0;md(h,1);x[h>>2]=g;v[h+37|0]=y[d+80|0]<<4;v[l+15|0]=y[d+81|0];v[l+14|0]=64;q=h,r=y[Ub(l+15|0,l+14|0)|0]<<2,w[q+30>>1]=r;d:{if(!g){break d}e=Fb(y[d+84|0]|y[d+85|0]<<8);j=Fb(y[d+82|0]|y[d+83|0]<<8);x[h+4>>2]=j;e=(e<<1)+j|0;x[h+8>>2]=e;if(g>>>0<=j>>>0){j=g-1|0;x[h+4>>2]=j}if(e>>>0>g>>>0){x[h+8>>2]=g;e=g}if(!(!(e>>>0<4|e>>>0<j>>>0)&e-j>>>0>3)){x[h+4>>2]=0;x[h+8>>2]=0;break d}if(e>>>0<=j>>>0){break d}w[h+34>>1]=z[h+34>>1]|2}ib=l+16|0;g=0;while(1)if((g|0)==22){if(f>>>0>127){break b}e=d+192|0;Ll(e,3,d+56|0);g=d+208|0;Fc(g,e);Cc(((m<<5)+a|0)+946304|0,g);n=n+1|0;wb(g);continue c}else{e=(d+56|0)+g|0;if((y[e|0]-1&255)>>>0<=30){v[e|0]=32;f=f+1|0}g=g+1|0;continue}}break}l=1;e:{f:{g:{f=a+946336|0;g=Kc(d+56|0,14005);if(!mT(f,g)){x[27524]=0;e=Q(55,d+208|0,14016)|0;h=x[27524];x[27524]=0;if((h|0)==1){break g}l=mT(f,e);wb(e)}wb(g);g=0;e=d+56|0;f=rU(b,e);if(!f){PA(e)}if(!f){break a}e=y[d+56|0];if(!pT(e)){break a}if(!c){break e}w[d+54>>1]=0;while(1)if((e|0)==(g|0)){g=a+484360|0;f=a+484376|0;i=Tb(x[g>>2],y[f|0]);h=y[d+57|0];_e(i,e>>>0>h>>>0?h:0);Uq(Tb(x[g>>2],y[f|0]),d+56|2,y[d+56|0]);if(z[a+480190>>1]==31){Yb(b,4)}x[d+48>>2]=0;x[d+44>>2]=0;x[d+40>>2]=0;v[d+39|0]=0;m=c&1;if(m){Fg(a+484344|0,z[d+54>>1])}n=a+484344|0;h=0;while(1){h:{i:{j:{if(z[d+54>>1]<=h>>>0){if(!(c&2)){break j}g=1;while(1){f=z[a+480190>>1];c=g&65535;if(f>>>0<c>>>0){break i}c=(D(c,104)+a|0)+484380|0;if(x[c>>2]){Eg(Zc(d+192|0,8,1,0,0),c,b)}g=g+1|0;continue}}k:{if(m){j=0;if(vh(n,h&65535,64)){break k}}Yb(b,1024);break h}l:while(1){if((j|0)==64){break h}g=0;e=Xb(x[n>>2],h);o=hd(x[e>>2],x[x[e+48>>2]+12>>2],j,0);while(1)if((g|0)==4){j=j+1|0;continue l}else{f=d+192|0;Um(f,b);e=D(g,6)+o|0;m:{n:{o:{p:{if(y[Jb(f,0)|0]!=255){break p}v[(d+48|0)+g|0]=0;v[(d+40|0)+g|0]=0;f=Jb(d+192|0,1);i=y[f|0];if((i|0)==252&l){v[f|0]=254;break n}switch(i-252|0){case 1:break m;case 2:break n;case 0:break o;default:break p}}f=x[d+192>>2];x[d+32>>2]=f;x[d+12>>2]=f;f=d+16|0;Su(f,d+12|0,e);i=Lc(f);f=y[e|0];q:{if(!f){break q}v[(d+40|0)+g|0]=0;v[(d+48|0)+g|0]=f;if(f>>>0>48){break q}v[d+31|0]=8;q=d,r=y[mf(d+39|0,d+31|0)|0],v[q+39|0]=r}f=y[i|0];r:{if(!(f|y[d+16|0])){break r}v[e+5|0]=f;s:{t:{switch(y[d+16|0]-1|0){case 0:v[e+3|0]=1;break r;case 1:if(f>>>0>=16){v[e+3|0]=3;v[e+5|0]=(f&240)>>>4;break r}if(f){v[e+3|0]=2;v[e+5|0]=f;break r}v[e+3|0]=0;break r;case 2:if(y[(d+40|0)+g|0]){v[e+3|0]=0;break r}v[e+3|0]=19;v[e+5|0]=0;break r;case 3:if(y[(d+40|0)+g|0]){v[e+3|0]=0;break r}v[e+3|0]=19;v[e+5|0]=1;break r;case 4:if(!y[e+1|0]){break s}v[d+31|0]=63;v[d+30|0]=y[e+5|0]+(z[(D(y[e+1|0],104)+a|0)+484410>>1]>>>2|0);f=y[Ub(d+31|0,d+30|0)|0];v[e+3|0]=13;v[e+5|0]=f;if(!y[(d+40|0)+g|0]){break r}v[e+4|0]=y[e+5|0];v[e+2|0]=1;v[e+3|0]=0;break r;case 5:i=y[e+1|0];if(i){v[e+3|0]=13;i=z[(D(i,104)+a|0)+484410>>1]>>>2|0;f=f>>>0<=i>>>0?i-f|0:0;v[e+5|0]=f;if(!y[(d+40|0)+g|0]){break r}v[e+4|0]=f;v[e+2|0]=1}v[e+3|0]=0;break r;case 6:i=f&15;v[(d+40|0)+g|0]=i;k=y[(d+48|0)+g|0];f=k-((f&240)>>>4|0)|0;v[(d+44|0)+g|0]=f;f=lT(i,f&255,k);v[e+3|0]=3;v[e+5|0]=f;break r;case 7:i=f&15;v[(d+40|0)+g|0]=i;k=(f&240)>>>4|0;f=y[(d+48|0)+g|0];k=k+f|0;v[(d+44|0)+g|0]=k;f=lT(i,f,k&255);v[e+3|0]=2;v[e+5|0]=f;break r;case 8:break t;default:break s}}v[d+31|0]=8;q=d,r=y[mf(d+39|0,d+31|0)|0],v[q+39|0]=r}v[e+3|0]=0}if(y[e+3|0]){break m}i=y[(d+40|0)+g|0];if(!i){break m}k=(d+44|0)+g|0;f=y[k|0];if(f){v[(d+48|0)+g|0]=f;v[e|0]=f;v[e+5|0]=i;v[k|0]=0}v[e+3|0]=4;break m}v[e+3|0]=14;v[d+39|0]=9;break m}v[e+3|0]=13}g=g+1|0;continue}}}f=z[a+480190>>1]}u:{v:{if((f&65535)==15){b=d+16|0;_f(b,4421);x[27524]=0;U(309,d+192|0,b|0,d+39|0);b=x[27524];x[27524]=0;if((b|0)!=1){break v}f=P()|0;$b(d+16|0);break f}x[27524]=0;Q(1,d+192|0,12286)|0;b=x[27524];x[27524]=0;if((b|0)==1){break u}}b=d+192|0;Gb(a+1298344|0,b);xb(b);if((f&65535)==15){$b(d+16|0)}Vl(a+1298356|0,z[a+480190>>1]==15?5285:15115);x[a+1298404>>2]=28;break e}f=P()|0;break f}h=h+1|0;continue}}else{w[d+192>>1]=y[(d+g|0)+58|0]+1;q=d,r=z[pe(d+54|0,d+192|0)>>1],w[q+54>>1]=r;g=g+1|0;continue}}f=P()|0;wb(g)}S(f|0);p()}g=1;break a}g=0}ib=d+352|0;return g|0}function _I(a,b,c,d,e,f){var g=0,h=E(0),i=0,j=0,k=E(0),l=E(0),m=E(0),n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,x=0,y=0,z=E(0),A=E(0),C=0,F=0,G=0,H=E(0),I=E(0),J=E(0),K=E(0),L=E(0),M=E(0),N=E(0),O=E(0),P=0,Q=0;F=(d|0)>0?d:0;while(1){if((s|0)!=(F|0)){G=D(s,2304)+b|0;u=0;q=(c|0)>0?c:0;n=ib-128|0;x=n+96|0;y=n- -64|0;C=n+32|0;while(1){if((q|0)!=(u|0)){o=G+(u<<2)|0;v=0;i=n;p=i;j=0;while(1){if((j|0)!=8){k=B[D(15-j|0,72)+o>>2];g=D(j,72)+o|0;h=B[g+1152>>2];l=E(k+h);m=B[g>>2];z=B[D(31-j|0,72)+o>>2];A=E(m+z);B[p>>2]=l+A;g=D(j,12);k=E(E(k-h)*B[g+86528>>2]);h=E(E(m-z)*B[g+86532>>2]);B[p+64>>2]=k+h;m=E(A-l);l=B[g+86536>>2];B[p+32>>2]=m*l;B[p+96>>2]=l*E(h-k);p=p+4|0;j=j+1|0;continue}break}while(1){if((v|0)!=4){l=B[i+8>>2];m=B[i+20>>2];h=E(l+m);z=B[i+4>>2];A=B[i+24>>2];H=E(z+A);k=E(h+H);I=B[i+12>>2];J=B[i+16>>2];K=E(I+J);L=B[i>>2];M=B[i+28>>2];N=E(L+M);O=E(K+N);B[i>>2]=k+O;B[i+16>>2]=E(O-k)*E(.7071067690849304);k=E(N-K);h=E(E(k+E(H-h))*E(.7071067690849304));B[i+24>>2]=E(k-h)*E(1.3065630197525024);B[i+8>>2]=E(k+h)*E(.5411961078643799);k=E(L-M);h=E(l-m);l=E(z-A);m=E(E(h+l)*E(.7071067690849304));z=E(k+m);A=E(E(I-J)+h);h=E(l+k);l=E(A-E(h*E(.1989123672246933)));h=E(E(l*E(.3826834261417389))+h);B[i+28>>2]=E(z-h)*E(2.562915563583374);B[i+4>>2]=E(z+h)*E(.509795606136322);k=E(k-m);h=E(l-E(h*E(.1989123672246933)));B[i+20>>2]=E(k+h)*E(.8999761939048767);B[i+12>>2]=E(k-h)*E(.601344883441925);i=i+32|0;v=v+1|0;continue}break}i=0;while(1){if((i|0)!=7){p=i<<2;B[o>>2]=B[p+n>>2];k=B[p+x>>2];i=i+1|0;j=i<<2;h=B[j+x>>2];B[o+72>>2]=E(B[p+y>>2]+k)+h;B[o+144>>2]=B[p+C>>2]+B[j+C>>2];B[o+216>>2]=h+E(k+B[j+y>>2]);o=o+288|0;continue}break}B[o>>2]=B[n+28>>2];k=B[n+124>>2];B[o+72>>2]=B[n+92>>2]+k;h=B[n+60>>2];B[o+216>>2]=k;B[o+144>>2]=h;u=u+1|0;continue}break}s=s+1|0;continue}break}C=rc(f,a,3840);G=d<<5;s=0;while(1){if((c|0)>(s|0)){i=ib-32|0;ib=i;o=C+(s<<8)|0;u=(s<<2)+b|0;B[o+4080>>2]=B[u+1152>>2];f=d-1|0;v=u+D(f,2304)|0;B[o+4084>>2]=B[v+1152>>2];B[o+4088>>2]=B[u>>2];B[o+4092>>2]=B[v>>2];B[o+4336>>2]=B[u+1156>>2];B[o+4340>>2]=B[v+1156>>2];B[o+4344>>2]=B[u+4>>2];B[o+4348>>2]=B[v+4>>2];x=(D(s,G)<<1)+e|0;y=x+(f<<1)|0;Es(y,d,o+244|0);f=d<<6;Es(f+y|0,d,o+500|0);Es(x,d,o+240|0);Es(f+x|0,d,o+496|0);F=o+3840|0;p=14;n=86624;while(1){if((p|0)>=0){g=p<<4;j=g+F|0;f=D(31-p|0,72);B[j>>2]=B[f+u>>2];B[j+4>>2]=B[f+v>>2];f=f|4;B[j+8>>2]=B[f+u>>2];B[j+12>>2]=B[f+v>>2];f=D(p,72);q=f+76|0;B[j+256>>2]=B[q+u>>2];B[j+260>>2]=B[q+v>>2];f=f+72|0;B[j-248>>2]=B[f+u>>2];B[j-244>>2]=B[f+v>>2];q=p<<2;t=g+o|0;k=B[n+4>>2];h=B[n>>2];f=0;while(1){if((f|0)!=4){g=f<<2;l=B[g+j>>2];m=B[g+t>>2];B[g+(i+16|0)>>2]=E(l*h)-E(k*m);B[i+g>>2]=E(l*k)+E(h*m);f=f+1|0;continue}break}j=F+(q<<2)|0;q=j-3584|0;t=j-256|0;k=B[n+12>>2];h=B[n+8>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=B[g+t>>2];m=B[g+q>>2];B[r>>2]=B[r>>2]+E(E(l*k)+E(h*m));g=g+(i+16|0)|0;B[g>>2]=E(E(m*k)-E(h*l))+B[g>>2];f=f+1|0;continue}break}q=j-3328|0;t=j-512|0;k=B[n+20>>2];h=B[n+16>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=B[g+t>>2];m=B[g+q>>2];B[r>>2]=B[r>>2]+E(E(l*k)+E(h*m));g=g+(i+16|0)|0;B[g>>2]=E(E(l*h)-E(k*m))+B[g>>2];f=f+1|0;continue}break}q=j-3072|0;t=j-768|0;k=B[n+28>>2];h=B[n+24>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=B[g+t>>2];m=B[g+q>>2];B[r>>2]=B[r>>2]+E(E(l*k)+E(h*m));g=g+(i+16|0)|0;B[g>>2]=E(E(m*k)-E(h*l))+B[g>>2];f=f+1|0;continue}break}q=j-2816|0;t=j-1024|0;k=B[n+36>>2];h=B[n+32>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=B[g+t>>2];m=B[g+q>>2];B[r>>2]=B[r>>2]+E(E(l*k)+E(h*m));g=g+(i+16|0)|0;B[g>>2]=E(E(l*h)-E(k*m))+B[g>>2];f=f+1|0;continue}break}q=j-2560|0;t=j-1280|0;k=B[n+44>>2];h=B[n+40>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=B[g+t>>2];m=B[g+q>>2];B[r>>2]=B[r>>2]+E(E(l*k)+E(h*m));g=g+(i+16|0)|0;B[g>>2]=E(E(m*k)-E(h*l))+B[g>>2];f=f+1|0;continue}break}q=j-2304|0;t=j-1536|0;k=B[n+52>>2];h=B[n+48>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=B[g+t>>2];m=B[g+q>>2];B[r>>2]=B[r>>2]+E(E(l*k)+E(h*m));g=g+(i+16|0)|0;B[g>>2]=E(E(l*h)-E(k*m))+B[g>>2];f=f+1|0;continue}break}g=j-2048|0;q=j-1792|0;k=B[n+60>>2];h=B[n+56>>2];f=0;while(1){if((f|0)!=4){j=f<<2;t=j+i|0;l=B[j+q>>2];m=B[g+j>>2];B[t>>2]=B[t>>2]+E(E(l*k)+E(h*m));j=j+(i+16|0)|0;B[j>>2]=E(E(m*k)-E(h*l))+B[j>>2];f=f+1|0;continue}break}f=D(15-p|0,d)<<1;P=f+y|0,Q=nj(B[i+20>>2]),w[P>>1]=Q;j=D(p+17|0,d)<<1;P=j+y|0,Q=nj(B[i+4>>2]),w[P>>1]=Q;P=f+x|0,Q=nj(B[i+16>>2]),w[P>>1]=Q;P=j+x|0,Q=nj(B[i>>2]),w[P>>1]=Q;f=D(47-p|0,d)<<1;P=f+y|0,Q=nj(B[i+28>>2]),w[P>>1]=Q;j=D(p+49|0,d)<<1;P=j+y|0,Q=nj(B[i+12>>2]),w[P>>1]=Q;P=f+x|0,Q=nj(B[i+24>>2]),w[P>>1]=Q;P=j+x|0,Q=nj(B[i+8>>2]),w[P>>1]=Q;p=p-1|0;n=n- -64|0;continue}break}ib=i+32|0;s=s+2|0;continue}break}b=c<<6;a:{if((d|0)==1){s=0;while(1){if(s>>>0>959){break a}B[(s<<2)+a>>2]=B[C+(b+s<<2)>>2];s=s+2|0;continue}}rc(a,C+(b<<2)|0,3840)}}function Fja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0;f=ib-256|0;ib=f;yc(b);a:{if(!AX(b,f+184|0)){break a}if(!bU(f+184|0)){break a}if(!Ob(x[b>>2],x[b+8>>2],Ec(aU(f+184|0),kb))){break a}b:{if(!c){break b}zd(a,16);e=f+24|0;Hj(e,2,f+184|4);d=f+48|0;Fc(d,e);Ac(a+1298308|0,d);wb(d);m=a+480190|0;w[m>>1]=y[f+214|0];w[a+480188>>1]=y[f+217|0];h=xc(d,8313);Gb(a+1298344|0,h);xb(h);h=xc(d,10067);Gb(a+1298356|0,h);xb(h);_f(e,4214);h=y[f+187|0];x[f>>2]=h>>>4;x[27524]=0;x[f+176>>2]=h&15;X(306,d|0,e|0,f|0,f+176|0);d=x[27524];x[27524]=0;c:{d:{if((d|0)!=1){d=f+48|0;Gb(a+1298368|0,d);xb(d);$b(f+24|0);x[a+1298404>>2]=4;g=1;while(1){l=g&65535;if(l>>>0>z[m>>1]){g=0;d=a+480188|0;while(1)if(z[d>>1]<=g>>>0){e=f+48|0;d=ib-16|0;ib=d;l=b;e:{if(!Ob(x[b>>2],x[b+8>>2],128)){b=0;while(1){if((b|0)!=128){Jh(b+e|0);b=b+1|0;continue}break}break e}sV(d+8|0,e);sd(d,l,x[d+8>>2],x[d+12>>2])}ib=d+16|0;Bv(Tb(x[a+484360>>2],y[a+484376|0]),e,y[f+211|0]+1|0);b=y[f+216|0];ae(f,l,D(z[f+208>>1],192));m=hc(f+24|0,f);yb(f);f:{r=c&1;if(!r){break f}x[27524]=0;R(229,a+484344|0,y[f+210|0]+1|0);d=x[27524];x[27524]=0;if((d|0)!=1){break f}break d}o=b?b:64;q=a+484344|0;s=a+480188|0;b=0;while(1){g:{h:{i:{if(y[f+210|0]<k>>>0){if(!(b&u)){break h}B=f,C=Cb(x[a+484344>>2]),x[B>>2]=C;i=Cb(x[a+484348>>2]);j=z[a+480188>>1];break i}j:{if(r){x[27524]=0;d=W(230,q|0,k&65535,o|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break d}n=0;if(d){break j}}x[27524]=0;Q(192,l|0,64)|0;d=x[27524];x[27524]=0;if((d|0)!=1){break g}break d}while(1){e=n&65535;if(e>>>0>31){break g}x[27524]=0;d=T(198,l|0)|0;h=x[27524];x[27524]=0;if((h|0)==1){break d}k:{if(!d|d>>>0>z[f+208>>1]|e>>>0>=z[s>>1]){break k}x[27524]=0;Q(159,m|0,D(d,192)-192|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break d}d=0;h=Xb(x[q>>2],k);g=hd(x[h>>2],x[x[h+48>>2]+12>>2],0,e);while(1){if((d|0)==(o|0)){break k}i=b;x[27524]=0;R(538,f|0,m|0);b=x[27524];x[27524]=0;if((b|0)!=1){j=Lc(f);e=Ze(f);b=y[f|0];if(b>>>0>=4){v[g|0]=(b>>>2|0)+37;b=y[f|0]}v[g+1|0]=b<<4&48|y[j|0]>>>4;b=y[e|0];h=0;e=0;l:{m:{n:{o:{p:{q:{r:{j=y[j|0]&15;switch(j-8|0){case 2:break o;case 0:break p;case 6:break r;default:break q}}j=14;t=((b&240)+16&240)>>>4|0;if(t>>>0>8){break n}if(1<<t&435){break p}break n}h=j;e=b}j=h;b=e;if((h|e)&255){break n}break m}b=(b&240?-16:15)&b;j=10}Xf(g,j,b&255);b=1;s:{switch(y[g+3|0]-16|0){case 0:break l;case 1:break s;default:break m}}u=1}b=i}d=d+1|0;g=D(z[s>>1],6)+g|0;continue}break}break d}n=n+1|0;continue}}while(1){t:{b=x[f>>2];if(Mb(b,i)){k=x[b+48>>2];n=x[b+12>>2];o=x[b>>2];e=0;u:while(1){if((e|0)==(n|0)){break t}g=0;q=qf(o,x[k+12>>2],e);d=0;h=0;while(1)if((g|0)==(j|0)){e=e+1|0;if(!(d&h&1)){continue u}break h}else{b=1;v:{switch(y[(q+D(g,6)|0)+3|0]-16|0){case 1:h=1;default:b=d;break;case 0:break v}}g=g+1|0;d=b;continue}}}B=f,C=Cb(x[a+484344>>2]),x[B+176>>2]=C;d=Cb(x[a+484348>>2]);h=a+480188|0;w:while(1){b=x[f+176>>2];if(!Mb(b,d)){break h}e=0;while(1)if(A[b+12>>2]<=e>>>0){ou(f+176|0);continue w}else{i=qf(x[b>>2],x[x[b+48>>2]+12>>2],e);j=z[h>>1];g=0;x:{while(1){if((g|0)==(j|0)){break x}k=D(g,6);g=g+1|0;k=y[(i+k|0)+3|0];if((k&254)!=16){continue}break}i=(k|0)==16;ue(b,Te(Me(f,i?17:16,i?125:6),e))}e=e+1|0;continue}}}ou(f);continue}}y:{b=z[f+212>>1];if(!b){break y}x[27524]=0;ea(317,a+1298332|0,l|0,b|0,39,1);b=x[27524];x[27524]=0;if((b|0)!=1){break y}break d}z:{if(!(c&2)){break z}g=1;b=a+480190|0;while(1){c=g&65535;if(c>>>0>z[b>>1]){break z}c=D(c,104)+a|0;d=Zc(f,w[c+484414>>1]&1?16:8,1,0,1);x[27524]=0;W(223,d|0,c+484380|0,l|0)|0;c=x[27524];x[27524]=0;if((c|0)!=1){g=g+1|0;continue}break}break d}x[a+480260>>2]=64;x[a+480264>>2]=32767;yb(m);break b}k=k+1|0;continue}}else{e=(g<<5)+a|0;lf(e+480280|0);w[e+480284>>1]=(y[(f+g|0)+218|0]<<4|8)&248;g=g+1|0;continue}}else{e=f+48|0;gD(b,e);i=ib-16|0;ib=i;d=(D(l,104)+a|0)+484380|0;md(d,0);w[i+14>>1]=y[e+35|0]<<2;w[i+12>>1]=256;B=d,C=z[Tc(i+14|0,i+12|0)>>1],w[B+30>>1]=C;h=y[e+22|0]|y[e+23|0]<<8|(y[e+24|0]<<16|y[e+25|0]<<24);A:{if(h>>>0<3){break A}x[d>>2]=h;x[d+4>>2]=y[e+26|0]|y[e+27|0]<<8|(y[e+28|0]<<16|y[e+29|0]<<24);x[i+8>>2]=y[e+30|0]|y[e+31|0]<<8|(y[e+32|0]<<16|y[e+33|0]<<24);x[i+4>>2]=1;B=d,C=x[Yc(i+8|0,i+4|0)>>2]-1|0,x[B+8>>2]=C;wc(d+8|0,h);h=x[d+8>>2];j=x[d+4>>2];B:{if(h>>>0<=j+4>>>0){x[d+4>>2]=0;x[d+8>>2]=0;h=0;j=0;break B}if(h>>>0<3){break B}w[d+34>>1]=z[d+34>>1]|2}v[d+37|0]=y[e+34|0];B=d,C=pv(0,v[e+34|0]<<4),x[B+24>>2]=C;if(!(v[e+36|0]&1)){break A}x[d+8>>2]=h>>>1;x[d+4>>2]=j>>>1;w[d+34>>1]=z[d+34>>1]|1;x[d>>2]=x[d>>2]>>>1}ib=i+16|0;Ll(f,2,e);d=f+24|0;Fc(d,f);Cc(((l<<5)+a|0)+946304|0,d);g=g+1|0;wb(d);continue}}}g=P()|0;$b(f+24|0);break c}g=P()|0;yb(m)}S(g|0);p()}g=1}ib=f+256|0;return g|0}function Sma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;g=ib-288|0;ib=g;yc(b);e=ib-16|0;ib=e;h=g+80|0;xW(e+8|0,h);f=x[e+12>>2];kc(e,x[b>>2],x[b+8>>2],x[e+8>>2],x[e+12>>2]);i=x[e+4>>2];if((i|0)==(f|0)){Yb(b,x[e+12>>2])}ib=e+16|0;e=(f|0)==(i|0);if(!e){wW(h)}a:{if(!e){break a}if(!zW(g+80|0)){break a}if(!Ob(x[b>>2],x[b+8>>2],Ec(yW(g+80|0),kb))){break a}b:{if(!c){break b}zd(a,16777216);gg(a);x[a+480208>>2]=x[a+480208>>2]|16777216;d=g+56|0;Hq(d,32);f=g- -64|0;h=x[f+4>>2];e=a+1074320|0;x[e>>2]=x[f>>2];x[e+4>>2]=h;e=x[g+60>>2];x[a+1074312>>2]=x[g+56>>2];x[a+1074316>>2]=e;Lb(a+1074312|0,114,1);t=a+480188|0,u=Fb(z[g+280>>1]),w[t>>1]=u;uh(a,1);e=xc(d,8489);Gb(a+1298368|0,e);xb(e);e=g+32|0;_f(e,3927);x[27524]=0;U(366,d|0,e|0,y[g+83|0]);d=x[27524];x[27524]=0;c:{if((d|0)!=1){d=g+56|0;Gb(a+1298344|0,d);xb(d);e=g+32|0;$b(e);f=xc(d,10698);Gb(a+1298356|0,f);xb(f);x[a+1298404>>2]=26;Se(e,3,g+80|4);Fc(d,e);Ac(a+1298308|0,d);wb(d);f=160;while(1){d:{d=f;if(!d){d=0;break d}f=d-1|0;if(y[(g+f|0)+116|0]==32){continue}}break}vW(a+1298332|0,g+116|0,d,4);o=a+480190|0;d=Fb(z[g+276>>1]);w[o>>1]=d;l=1;while(1){e:{f:{g:{h:{i:{e=d&65535;d=l&65535;if(e>>>0<d>>>0){f=a+484360|0;e=a+484376|0;_e(Tb(x[f>>2],y[e|0]),Fb(z[g+284>>1]));d=g+32|0;ae(d,b,512);j=hc(g+56|0,d);yb(d);d=y[e|0];f=x[f>>2];h=z[g+282>>1];x[27524]=0;U(278,Tb(f,d)|0,j|0,Fb(h)|0);d=x[27524];x[27524]=0;if((d|0)!=1){break i}d=P()|0;break h}h=D(d,104)+a|0;i=h+484380|0;md(i,1);xo(i);yX(b,((d<<5)+a|0)+946304|0,y[g+83|0]==1?32:28);n=1;d=y[g+83|0];if(d>>>0>=3){Yb(b,14);d=NB(b);if((d|0)>=0){e=h+484414|0;w[e>>1]=z[e>>1]|32;t=h+484408|0,u=Ec((((d&65535)<<8)+2047>>>0)/4095|0,0),w[t>>1]=u}d=y[g+83|0]}if((d&255)>>>0>=2){n=Mj(b);t=h+484404|0,u=Mj(b),x[t>>2]=u}d=g+56|0;f=ib-16|0;ib=f;j:{if(!Ob(x[b>>2],x[b+8>>2],12)){x[f>>2]=0;e=d;j=3;while(1){if(j){k=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);v[e|0]=k;v[e+1|0]=k>>>8;v[e+2|0]=k>>>16;v[e+3|0]=k>>>24;j=j-1|0;e=e+4|0;continue}break}break j}Oq(f+8|0,d);sd(f,b,x[f+8>>2],x[f+12>>2])}ib=f+16|0;e=gc(d);d=Db(d);k=ac(x[g+56>>2]);x[i>>2]=k;m=h+484384|0;j=ac(y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24));x[m>>2]=j;q=h+484388|0;r=ac(y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24))+j|0;x[q>>2]=r;f=h+484414|0;if(j){e=z[f>>1];break f}e=z[f>>1];if(ac(y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24))>>>0>=3){break f}d=e&-3;break e}d=Cb(x[Tb(x[a+484360>>2],y[e|0])>>2]);f=Cb(x[Tb(x[a+484360>>2],y[e|0])+4>>2]);e=ib-16|0;ib=e;k:{if(!Mb(d,f)){break k}x[e+8>>2]=d;while(1){h=x[Ye(e+8|0)>>2];if(!Mb(h,f)){break k}d=Lk(z[d>>1],z[h>>1])?h:d;continue}}ib=e+16|0;d=z[d>>1];x[27524]=0;n=a+484344|0;q=d+1&65535;R(229,n|0,q|0);d=x[27524];x[27524]=0;if((d|0)!=1){d=y[g+83|0];x[g+24>>2]=x[a+480204>>2];x[g+20>>2]=x[a+480196>>2];o=d>>>0<4?4:5;r=c&1;k=a+480188|0;h=0;while(1){if((h|0)==(q|0)){if(!(c&2)){break g}d=1;c=a+480190|0;while(1){e=d&65535;if(e>>>0>z[c>>1]){break g}e=D(e,104)+a|0;f=Zc(g+8|0,w[e+484414>>1]&1?16:8,1,1,0);x[27524]=0;W(223,f|0,e+484380|0,b|0)|0;e=x[27524];x[27524]=0;if((e|0)!=1){d=d+1|0;continue}break}d=P()|0;break h}l:{if(!r){break l}d=z[g+278>>1];e=x[b+8>>2];f=z[k>>1];i=x[b>>2];x[27524]=0;d=W(160,i|0,e|0,D(f,D(Fb(d),o))|0)|0;e=x[27524];x[27524]=0;m:{n:{if((e|0)==1){break n}if(!d){break l}d=z[g+278>>1];x[27524]=0;d=W(230,n|0,h&65535,Fb(d)|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break n}if(!d){break l}d=z[k>>1];v[g+19|0]=0;e=fe(g+8|0,0,g+19|0);x[27524]=0;i=W(367,g+32|0,d|0,e|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break m}e=0;o:while(1){if(Fb(z[g+278>>1])>>>0<=e>>>0){jd(i);break l}d=0;f=Xb(x[n>>2],h);s=qf(x[f>>2],x[x[f+48>>2]+12>>2],e);while(1){if(z[k>>1]<=d>>>0){e=e+1|0;continue o}v[g+12|0]=0;x[g+8>>2]=0;x[27524]=0;U(368,b|0,g+8|0,o|0);f=x[27524];x[27524]=0;p:{if((f|0)==1){break p}l=D(d,6)+s|0;f=y[g+8|0];if((f-24&255)>>>0<=59){f=f+13|0;v[l|0]=f;t=bc(x[i>>2],d),u=f,v[t|0]=u}m=y[g+9|0];q:{if(!m){f=bc(x[i>>2],d);break q}v[l+1|0]=m;f=bc(x[i>>2],d);v[f+1|0]=m}m=y[f+1|0];f=y[f|0];x[27524]=0;Aa(369,a|0,l|0,y[g+10|0],y[g+11|0],0-y[g+83|0]|0,f|0,m|0,g+24|0,g+20|0);f=x[27524];x[27524]=0;if((f|0)==1){break p}if(y[g+12|0]){v[l+2|0]=1;v[l+4|0]=y[g+12|0]+1>>>2}d=d+1|0;continue}break}break}d=P()|0;jd(i);break h}d=P()|0;break h}d=P()|0;break h}h=h+1|0;continue}}d=P()|0}yb(j);break c}yb(j);break b}d=e|2}w[f>>1]=d;if((n|0)==2){w[f>>1]=d|1;x[i>>2]=k>>>1;x[m>>2]=j>>>1;x[q>>2]=r>>>1}t=h+484410|0,u=Mj(b),w[t>>1]=u;d=NB(b);if(d){Cl(i,+(d|0)/96)}v[h+484417|0]=d<<4;l=l+1|0;d=z[o>>1];continue}}d=P()|0;$b(g+32|0)}S(d|0);p()}d=1}ib=g+288|0;return d|0}function aia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0;i=ib-208|0;ib=i;yc(b);a:{if(!RB(b,i+160|0)){break a}if(!qS(i+160|0)){break a}b:{if(!c){break b}if(!Ob(x[b>>2],x[b+8>>2],Ec(pS(y[i+207|0]),kb))){break a}zd(a,128);d=i+144|0;Se(d,2,i+175|0);h=i+72|0;Fc(h,d);Ac(a+1298308|0,h);wb(h);e=xc(h,8401);Gb(a+1298344|0,e);xb(e);e=xc(h,6059);Gb(a+1298356|0,e);xb(e);e=xc(d,17517);x[27524]=0;U(730,h|0,e|0,x[(y[i+174|0]<<2)+26876>>2]);h=x[27524];x[27524]=0;c:{if((h|0)!=1){h=i+72|0;Gb(a+1298368|0,h);xb(h);xb(e);x[a+480208>>2]=12;x[a+1298404>>2]=4;iC(a+1298332|0,b,y[i+207|0]<<5,32,0);l=a+480190|0;d=Re(b);w[l>>1]=d;h=1;while(1){j=h&65535;if(j>>>0>(d&65535)>>>0){wo(Tb(x[a+484360>>2],y[a+484376|0]),b,256,255,254);h=0;d=Re(b);if(d>>>0>=127){break a}g=a+480188|0;w[g>>1]=d+1;e=Re(b);while(1)if(z[g>>1]<=h>>>0){o=a+484344|0;r=e+1|0;Fg(o,r);d=0;while(1){d:{g=d&65535;if(g>>>0>e>>>0){s=a+480188|0;e:while(1){u=t&65535;h=z[s>>1];if(u>>>0>=h>>>0){e=ko(i+8|0);v[e+16|0]=0;w[e+14>>1]=0;w[e+12>>1]=h;x[27524]=0;R(732,e|0,h|0);h=x[27524];x[27524]=0;if((h|0)==1){a=P()|0;$e(e);S(a|0);p()}x[27524]=0;U(731,i+32|0,o|0,e|0);d=x[27524];x[27524]=0;h=1;if((d|0)==1){break d}$e(i+32|0);$e(e);if(!(c&2)){break a}c=a+480190|0;while(1){d=h&65535;if(d>>>0>z[c>>1]){break b}d=D(d,104)+a|0;Eg(Zc(i+72|0,w[d+484414>>1]&1?16:8,1,0,0),d+484380|0,b);h=h+1|0;continue}}n=0;e=Bg(i+72|0);f:while(1){g:{if((n|0)!=(r|0)){if(Ob(x[b>>2],x[b+8>>2],5)){break g}}t=t+1|0;continue e}d=0;h=Xb(x[o>>2],n);h=hd(x[h>>2],x[x[h+48>>2]+12>>2],0,u);while(1){h:{i:{if(d>>>0>63){break i}l=y[i+174|0];g=ib-32|0;ib=g;q=1;f=Re(b);if((f|0)==252){q=Re(b);f=Re(b)}v[e|0]=(f-1&255)>>>0<60?f+36|0:0;f=g+24|0;Um(f,b);k=Lc(f);j=Ze(f);f=Si(f);v[e+1|0]=y[g+24|0];m=g+16|0;nS(m,y[k|0]&15,y[j|0],l);j=Lc(m);m=g+8|0;nS(m,y[k|0]>>>4|0,y[f|0],l);l=Lc(m);f=y[g+16|0];m=(f|0)!=10;k=y[g+8|0];j:{if(!(m|(k|0)!=10)){j=y[j|0];f=y[l|0];v[e+3|0]=10;j=j|f<<8;v[e+5|0]=j>>>6;if(j>>>0<16384){break j}v[e+2|0]=15;v[e+4|0]=f>>>6;break j}k:{l:{m:{n:{o:{if(!m){k=y[j|0];m=k<<2;A=j,B=Nl(m),v[A|0]=B;if(k>>>0<64){break o}f=y[g+8|0];if(Ri(f)>>>0>=qA(10)>>>0){break n}v[e+5|0]=m;v[e+2|0]=15;v[e+3|0]=10;v[e+4|0]=k>>>6;break j}if((k|0)==10){f=y[l|0];k=f<<2;A=l,B=Nl(k),v[A|0]=B;if(f>>>0<64){break o}if(Ri(y[g+16|0])>>>0>=qA(10)>>>0){break o}v[e+5|0]=k;v[e+2|0]=15;v[e+3|0]=10;v[e+4|0]=f>>>6;break j}if((f|0)!=(k|0)){break o}v[g+8|0]=0;break m}f=y[g+8|0]}if((f|0)==13){break l}if(f){break k}f=y[g+16|0]}if((f|0)==13){break k}}Qi(g+16|0,g+8|0);Qi(j,l)}mv(g+8|0,l,g+16|0,j);Fo(g,e,y[g+16|0],y[j|0],y[g+8|0],y[l|0])}ib=g+32|0;f=d+q|0;d=f>>>0>64?64-d|0:q;if(!d){break i}while(1){if(!d){break h}g=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);v[h|0]=g;v[h+1|0]=g>>>8;v[h+2|0]=g>>>16;v[h+3|0]=g>>>24;g=y[e+4|0]|y[e+5|0]<<8;v[h+4|0]=g;v[h+5|0]=g>>>8;d=d-1|0;h=D(z[s>>1],6)+h|0;continue}}n=n+1|0;continue f}d=f>>>0>=64?64:f;continue}}}}d=d+1|0;h=0;if(vh(o,g,64)){continue}break a}break}d=P()|0;$e(e);break c}else{d=(h<<5)+a|0;lf(d+480280|0);d=d+480284|0;p:{if(y[i+174|0]>=51){f=(Re(b)<<4|8)&248;break p}f=h&1?192:64}w[d>>1]=f;h=h+1|0;continue}}else{q:{if(y[i+174|0]>=52){d=i+72|0;if(!gX(b,d)){lC(d)}break q}e=ib-32|0;ib=e;x[e+28>>2]=64;x[e+8>>2]=66;f=x[b>>2];g=x[b+8>>2];d=x[Hb(e+28|0,e+8|0)>>2];if(!Ob(f,g,d)){d=jf(b)}f=e+8|0;n=i+72|0;Zu(f,n);g=dc(e+16|0,x[e+8>>2],d);kc(e,x[b>>2],x[b+8>>2],x[g>>2],x[g+4>>2]);Zu(f,n);Rb(x[e+8>>2]+d|0,0,66-d|0);Yb(b,x[e+28>>2]);ib=e+32|0;w[i+136>>1]=z[i+134>>1];w[i+134>>1]=8363}g=ib-32|0;ib=g;e=(D(j,104)+a|0)+484380|0;md(e,0);xo(e);d=i+72|0;Bk(g,2,d+32|0);f=g+16|0;Fc(f,g);Fe(e+43|0,f);wb(f);f=y[d+56|0]|y[d+57|0]<<8|(y[d+58|0]<<16|y[d+59|0]<<24);n=y[d+52|0]|y[d+53|0]<<8|(y[d+54|0]<<16|y[d+55|0]<<24);r:{if(f>>>0<=n>>>0){break r}x[e>>2]=f-n;x[e+12>>2]=y[d+44|0]|y[d+45|0]<<8|(y[d+46|0]<<16|y[d+47|0]<<24);x[g+16>>2]=y[d+48|0]|y[d+49|0]<<8|(y[d+50|0]<<16|y[d+51|0]<<24);A=e,B=x[Hb(g+16|0,e)>>2],x[A+16>>2]=B;w[e+30>>1]=y[d+60|0];x[e+24>>2]=y[d+62|0]|y[d+63|0]<<8;f=y[d+64|0]|y[d+65|0]<<8;if(f){Cl(e,+(f<<16>>16)/393216)}f=y[d+61|0];if(f&8){w[e+34>>1]=z[e+34>>1]|8;f=y[d+61|0]}if(f&16){w[e+34>>1]=z[e+34>>1]|16;f=y[d+61|0]}if(!(f&4)){break r}w[e+34>>1]=z[e+34>>1]|1;x[e+12>>2]=x[e+12>>2]>>>1;x[e+16>>2]=x[e+16>>2]>>>1}ib=g+32|0;e=i+56|0;Se(e,2,d);d=i+144|0;Fc(d,e);Cc(((j<<5)+a|0)+946304|0,d);h=h+1|0;wb(d);d=z[l>>1];continue}}}d=P()|0;xb(e)}S(d|0);p()}h=1}ib=i+208|0;return h|0}function Jd(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;k=ib-96|0;ib=k;t=h;u=i&65535;m=(e^i)&-2147483648;l=e&65535;p=l;v=l;K=i>>>16&32767;L=e>>>16&32767;a:{b:{if(K-32767>>>0>4294934529&L-32767>>>0>=4294934530){break b}l=e&2147483647;j=d;if(!(!d&(l|0)==2147418112?!(b|c):l>>>0<2147418112)){o=d;m=e|32768;break a}e=i&2147483647;if(!(!h&(e|0)==2147418112?!(f|g):e>>>0<2147418112)){o=h;m=i|32768;b=f;c=g;break a}if(!(b|j|(l^2147418112|c))){if(!(f|h|(e|g))){m=2147450880;b=0;c=0;break a}m=m|2147418112;b=0;c=0;break a}if(!(f|h|(e^2147418112|g))){d=b|j;e=c|l;b=0;c=0;if(!(d|e)){m=2147450880;break a}m=m|2147418112;break a}if(!(b|j|(c|l))){b=0;c=0;break a}if(!(f|h|(e|g))){b=0;c=0;break a}if((l|0)==65535|l>>>0<65535){j=b;h=!(d|p);i=h<<6;l=G(h?b:d)+32|0;b=G(h?c:p);b=i+((b|0)==32?l:b)|0;Sf(k+80|0,j,c,d,p,b-15|0);s=16-b|0;d=x[k+88>>2];v=x[k+92>>2];c=x[k+84>>2];b=x[k+80>>2]}if(e>>>0>65535){break b}e=!(t|u);h=e<<6;i=G(e?f:t)+32|0;e=G(e?g:u);e=h+((e|0)==32?i:e)|0;Sf(k- -64|0,f,g,t,u,e-15|0);s=(s-e|0)+16|0;t=x[k+72>>2];u=x[k+76>>2];f=x[k+64>>2];g=x[k+68>>2]}e=f;j=g<<15|e>>>17;h=e<<15;e=j;p=h&-32768;q=c;A=qoa(p,0,c,0);c=kb;y=c;B=e;i=0;j=qoa(e,0,b,i);e=j+A|0;h=kb+c|0;h=e>>>0<j>>>0?h+1|0:h;c=e;j=e;n=qoa(b,i,p,i);l=0+n|0;e=kb+e|0;e=l>>>0<n>>>0?e+1|0:e;z=l;n=l;l=e;C=(j|0)==(e|0)&r>>>0>n>>>0|e>>>0<j>>>0;r=d;M=qoa(p,i,d,0);H=kb;e=qoa(q,i,B,i);d=e+M|0;j=kb+H|0;n=d;d=d>>>0<e>>>0?j+1|0:j;e=t;j=u<<15|e>>>17;D=e<<15|g>>>17;g=qoa(D,0,b,i);e=g+n|0;f=kb+d|0;I=e;f=e>>>0<g>>>0?f+1|0:f;u=f;e=f;f=(h|0)==(y|0)&c>>>0<A>>>0|h>>>0<y>>>0;c=h+I|0;f=e+f|0;A=c;f=c>>>0<h>>>0?f+1|0:f;t=f;c=f;E=v|65536;v=w;N=qoa(p,i,E,w);J=kb;g=qoa(r,o,B,i);f=g+N|0;e=kb+J|0;O=f;e=f>>>0<g>>>0?e+1|0:e;w=e;F=j|-2147483648;y=0;g=qoa(F,y,b,i);b=g+f|0;f=kb+e|0;f=b>>>0<g>>>0?f+1|0:f;P=b;e=qoa(D,o,q,i);b=b+e|0;p=f;j=f+kb|0;Q=b;g=b>>>0<e>>>0?j+1|0:j;f=0;b=f+A|0;e=c+Q|0;e=b>>>0<f>>>0?e+1|0:e;R=b;c=b;b=b+C|0;C=e;f=b>>>0<c>>>0?e+1|0:e;c=f;s=((L+K|0)+s|0)-16383|0;j=qoa(F,y,q,i);h=kb;i=qoa(E,v,B,i);e=i+j|0;f=kb+h|0;f=e>>>0<i>>>0?f+1|0:f;i=(f|0)==(h|0)&e>>>0<j>>>0|f>>>0<h>>>0;h=e;q=i;i=qoa(D,o,r,o);e=i+e|0;j=kb+f|0;j=e>>>0<i>>>0?j+1|0:j;i=(f|0)==(j|0)&e>>>0<h>>>0|f>>>0>j>>>0;f=q+i|0;h=0;h=f>>>0<i>>>0?1:h;q=qoa(F,y,E,v);i=q+f|0;f=kb+h|0;f=i>>>0<q>>>0?f+1|0:f;q=e;h=j;B=i;e=(d|0)==(u|0)&n>>>0>I>>>0|d>>>0>u>>>0;d=e+((d|0)==(H|0)&n>>>0<M>>>0|d>>>0<H>>>0)|0;j=0;j=d>>>0<e>>>0?1:j;i=d;d=q+d|0;e=h+j|0;e=d>>>0<i>>>0?e+1|0:e;n=d;i=e;e=(e|0)==(h|0)&d>>>0<q>>>0|e>>>0<h>>>0;d=B+e|0;h=d>>>0<e>>>0?f+1|0:f;q=d;j=qoa(D,o,E,v);e=kb;r=qoa(F,y,r,o);d=r+j|0;f=kb+e|0;f=d>>>0<r>>>0?f+1|0:f;r=d;d=f;f=(e|0)==(f|0)&j>>>0>r>>>0|e>>>0>f>>>0;v=d+q|0;e=f+h|0;e=v>>>0<d>>>0?e+1|0:e;h=0;d=h+n|0;f=i+r|0;f=d>>>0<h>>>0?f+1|0:f;h=f;j=(i|0)==(f|0)&d>>>0<n>>>0|f>>>0<i>>>0;i=j+v|0;n=i;i=i>>>0<j>>>0?e+1|0:e;r=d;e=d;d=h;j=(p|0)==(w|0)&O>>>0>P>>>0|p>>>0<w>>>0;f=j+((w|0)==(J|0)&O>>>0<N>>>0|w>>>0<J>>>0)|0;h=0;j=f+((g|0)==(p|0)&P>>>0>Q>>>0|g>>>0<p>>>0)|0;f=g+e|0;e=d+j|0;e=f>>>0<g>>>0?e+1|0:e;g=f;h=(d|0)==(e|0)&f>>>0<r>>>0|d>>>0>e>>>0;d=h+n|0;f=i;f=d>>>0<h>>>0?f+1|0:f;h=e;n=d;i=(t|0)==(C|0)&A>>>0>R>>>0|t>>>0>C>>>0;d=i+((t|0)==(u|0)&A>>>0<I>>>0|t>>>0<u>>>0)|0;j=0;j=d>>>0<i>>>0?1:j;i=d;d=d+g|0;e=e+j|0;e=d>>>0<i>>>0?e+1|0:e;h=(e|0)==(h|0)&d>>>0<g>>>0|e>>>0<h>>>0;g=n+h|0;f=g>>>0<h>>>0?f+1|0:f;h=g;i=f;c:{if(f&65536){s=s+1|0;break c}w=l>>>31|0;f=i<<1|h>>>31;h=g<<1|e>>>31;i=f;f=e<<1|d>>>31;d=d<<1|c>>>31;e=f;g=z;f=l<<1|g>>>31;z=g<<1;l=f;f=c<<1|b>>>31;b=b<<1|w;c=f}if((s|0)>=32767){m=m|2147418112;b=0;c=0;break a}d:{if((s|0)<=0){f=1-s|0;if(f>>>0>=128){b=0;c=0;break a}g=s+127|0;Sf(k+48|0,z,l,b,c,g);Sf(k+32|0,d,e,h,i,g);xm(k+16|0,z,l,b,c,f);xm(k,d,e,h,i,f);z=x[k+32>>2]|x[k+16>>2]|(x[k+48>>2]|x[k+56>>2]|(x[k+52>>2]|x[k+60>>2]))!=0;l=x[k+36>>2]|x[k+20>>2];b=x[k+40>>2]|x[k+24>>2];c=x[k+44>>2]|x[k+28>>2];d=x[k>>2];e=x[k+4>>2];f=x[k+8>>2];g=x[k+12>>2];break d}f=h;g=i&65535|s<<16}o=f|o;m=g|m;if(!(!b&(c|0)==-2147483648?!(l|z):(c|0)>0|(c|0)>=0)){b=d+1|0;j=b?e:e+1|0;c=j;f=(e|0)==(j|0)&b>>>0<d>>>0|e>>>0>j>>>0;d=f+o|0;e=m;o=d;m=d>>>0<f>>>0?e+1|0:e;break a}if(b|z|(c^-2147483648|l)){b=d;c=e;break a}j=m;c=d&1;b=c+d|0;f=b>>>0<c>>>0?e+1|0:e;c=f;e=(e|0)==(f|0)&b>>>0<d>>>0|e>>>0>f>>>0;d=e+o|0;o=d;m=d>>>0<e>>>0?j+1|0:j}x[a>>2]=b;x[a+4>>2]=c;x[a+8>>2]=o;x[a+12>>2]=m;ib=k+96|0}function lia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;d=ib-144|0;ib=d;yc(c);a:{b:{c:{d:{if(!yo(c,d+128|0)){break d}if(Qb(d+128|0,13813,4)){break d}g=d+136|0;e:{if(!Qb(g,13466,4)){break e}if(!Qb(g,13524,4)){break e}if(Qb(g,14248,4)){break d}}e=ib-32|0;ib=e;l=Nb(d+112|0);f:{g:{h:{i:{j:{while(1){k=x[c+8>>2];h=x[c>>2];x[27524]=0;k=W(160,h|0,k|0,8)|0;h=x[27524];x[27524]=0;if((h|0)==1){break h}if(!k){break i}x[27524]=0;R(797,e|0,c|0);k=x[27524];x[27524]=0;if((k|0)!=1){x[27524]=0;R(798,l|0,e|0);k=x[27524];x[27524]=0;if((k|0)==1){break j}yd(e);continue}break}a=P()|0;break g}a=P()|0;yd(e);break g}ib=e+32|0;break f}a=P()|0}Zd(l);S(a|0);p()}x[27524]=0;k=T(178,d+88|0)|0;c=x[27524];x[27524]=0;k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{if((c|0)!=1){l=Zc(d+80|0,8,1,1,0);if(Qb(g,14248,4)){break t}x[27524]=0;U(717,d+56|0,d+112|0,1296581714);c=x[27524];x[27524]=0;if((c|0)==1){break q}x[27524]=0;U(717,d+32|0,d+112|0,1296318804);c=x[27524];x[27524]=0;if((c|0)==1){break c}c=d+32|0;e=fd(k,c);yb(c);c=0;x[27524]=0;g=T(718,d+56|0)|0;i=x[27524];x[27524]=0;f=1;if((i|0)==1){break c}i=0;if(!g){break u}e=x[e>>2];x[27524]=0;e=T(182,e|0)|0;i=x[27524];x[27524]=0;if((i|0)==1){break c}i=0;if(!e){break u}x[27524]=0;i=T(283,d+56|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break c}x[27524]=0;g=T(275,d+56|0)|0;c=x[27524];x[27524]=0;w:{if((c|0)==1){break w}x[27524]=0;Q(192,d+56|0,2)|0;c=x[27524];x[27524]=0;if((c|0)==1){break w}x[27524]=0;c=T(283,d+56|0)|0;e=x[27524];x[27524]=0;if((e|0)!=1){break v}}break c}f=P()|0;break a}x[27524]=0;R(633,d+32|0,d+56|0);e=x[27524];x[27524]=0;if((e|0)==1){break c}e=oW(d+32|0);j=Fb(z[d+32>>1]);if(!j){break u}c=(c>>>0)/(j>>>0)|0;f=d+32|0;j=gc(f);h=Ze(f);f=1;j=Fb(y[j|0]|y[j+1|0]<<8);if((j|0)!=(Fb(y[h|0]|y[h+1|0]<<8)+1|0)){break u}if((j|0)==2){Qo(l,2)}x:{if((g|0)!=16){if((g|0)!=8){break u}y:{switch(Fb(y[e|0]|y[e+1|0]<<8)|0){case 0:jg(l,1);break x;case 2:jg(l,17);break x;case 3:break y;default:break u}}jg(l,16);break x}if(Fb(y[e|0]|y[e+1|0]<<8)){break u}ne(l,16)}f=0}yb(d+56|0);j=0;if(!f){break s}f=0;break k}x[27524]=0;U(717,d+56|0,d+112|0,1447576658);c=x[27524];x[27524]=0;z:{A:{if((c|0)!=1){x[27524]=0;U(717,d+32|0,d+112|0,1128808782);c=x[27524];x[27524]=0;if((c|0)==1){break A}x[27524]=0;U(717,d+8|0,d+112|0,1112491097);c=x[27524];x[27524]=0;if((c|0)==1){break m}c=d+8|0;h=fd(k,c);yb(c);c=x[h>>2];x[27524]=0;m=T(182,c|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break z}c=0;e=0;B:{if(!m){break B}x[27524]=0;m=T(182,x[d+56>>2])|0;c=x[27524];x[27524]=0;if((c|0)==1){break z}c=0;e=0;if(!m){break B}x[27524]=0;m=Q(719,d+56|0,d+8|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break z}c=0;e=0;if(!m){break B}c=Qb(g,13466,4);x[27524]=0;e=T(283,d+32|0)|0;i=x[27524];x[27524]=0;if((i|0)==1){break m}if(c){q=l,r=x[Zc(d,16,1,0,0)>>2],x[q>>2]=r}if((e|0)==6){Qo(l,3)}i=x[h>>2];x[27524]=0;g=x[d+24>>2];h=z[d+20>>1];n=x[d+12>>2];m=x[d+8>>2];i=T(164,i|0)|0;j=x[27524];x[27524]=0;o=1;if((j|0)==1){break m}e=D((e|0)==6?2:1,c?2:1);i=(i>>>0)/(e>>>0)|0;j=ac(g);c=Fb(h);n=(ac(n)>>>0)/(e>>>0)|0;e=(ac(m)>>>0)/(e>>>0)|0}yb(d+32|0);yb(d+56|0);if(o){break r}break k}f=P()|0;break b}f=P()|0;break l}break m}e=0}Kt(a,b);x[27524]=0;f=D(b,104)+a|0;g=f+484380|0;R(281,g|0,0);h=x[27524];x[27524]=0;if((h|0)==1){break p}x[g>>2]=i;h=e+n|0;x[f+484388>>2]=h;x[f+484384>>2]=e;if(!(h>>>0<=e+4>>>0|h>>>0>i>>>0)){e=(D(b,104)+a|0)+484414|0;w[e>>1]=z[e>>1]|2}e=D(b,104)+a|0;x[e+484404>>2]=c?c:22050;c=j>>>8|0;w[e+484410>>1]=(j&16776960)>>>0>65536?256:c&65535?c:256;jA(g,x[a+480180>>2]);x[27524]=0;U(717,d+56|0,d+112|0,1312902469);c=x[27524];x[27524]=0;if((c|0)==1){break o}x[27524]=0;c=T(182,x[d+56>>2])|0;e=x[27524];x[27524]=0;if((e|0)==1){break n}C:{D:{if(c){x[27524]=0;c=T(164,x[d+56>>2])|0;e=x[27524];x[27524]=0;if((e|0)==1){break n}x[27524]=0;U(329,d+56|0,((b<<5)+a|0)+946304|0,c|0);b=x[27524];x[27524]=0;if((b|0)!=1){break D}break n}x[27524]=0;c=Q(55,d+32|0,21631)|0;e=x[27524];x[27524]=0;if((e|0)==1){break C}Cc(((b<<5)+a|0)+946304|0,c);wb(c)}x[27524]=0;W(223,l|0,g|0,k|0)|0;b=x[27524];x[27524]=0;f=1;if((b|0)==1){break n}yj(g,a);yb(d+56|0);break k}break n}f=P()|0;break b}f=P()|0;break b}f=P()|0;break b}f=P()|0;yb(d+56|0);break b}f=P()|0;yb(d+32|0)}yb(d+56|0);break b}yb(k);Zd(d+112|0)}ib=d+144|0;return f|0}f=P()|0;yb(d+56|0)}yb(k)}Zd(d+112|0);S(f|0);p()}function BP(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;h=ib-16|0;ib=h;a:{if(!Wc(d&255)){break a}m=a+1074376|0;j=(m+D(b,872)|0)+616|0;b:{g=z[a+480192>>1];if(!(!(x[a+480180>>2]&17825824)|!g|e)){break b}if(uj(x[j+656>>2])){break b}c=D(b,872)+a|0;d=c+1075068|0;if(!x[d>>2]){break a}c=x[c+1075080>>2];if(c&1024){break a}e=D(b,872)+a|0;g=e+1075012|0;e=e+1075016|0;if(!(x[g>>2]|x[e>>2])){break a}c:{if(!(c&512)){break c}c=x[a+1298300>>2];if(!Ed(c)){break c}vj(c,b,0);break a}c=oz(a,b);if((c|0)==65535){break a}i=D(c,872);c=a+1074992|0;a=i+c|0;aq(a,j);v[a+831|0]=0;v[a+805|0]=0;w[a+786>>1]=b+1;x[a+88>>2]=x[a+88>>2]&-918529;mo(a+788|0);x[a+696>>2]=0;x[a+88>>2]=x[a+88>>2]|2101248;x[d>>2]=0;x[j>>2]=0;x[j+4>>2]=0;a=c+D(b,872)|0;x[a+92>>2]=0;x[a+96>>2]=0;x[g>>2]=0;x[e>>2]=0;break a}e=D(b,872)+a|0;l=x[e+1075096>>2];c=c>>>0<=g>>>0?c:0;g=x[(c?((c<<2)+a|0)+900380|0:e+1075648|0)>>2];d:{if(!g){break d}k=d-1|0;c=z[bc(g+236|0,k)>>1];f=a+1074312|0;Ab(h+8|0,f,104);e:{if(zb(x[x[h+8>>2]>>2],x[h+12>>2])){Ab(h,f,34);if(zb(x[x[h>>2]>>2],x[h+4>>2])){break e}}d=y[Jb(g+108|0,k)|0]}if((c-1&65535)>>>0<=3998){l=(D(c,104)+a|0)+484380|0;break d}Ab(h+8|0,f,43);if(!zb(x[x[h+8>>2]>>2],x[h+12>>2])){break d}if(!zj(y[g+31|0])){break a}}if(y[e+1075081|0]&4){break a}o=b>>>0<=256?256:b;k=a+1074312|0;p=b+1|0;q=a+480188|0;c=b;f:{while(1){if((c|0)==(o|0)){g:{e=0;c=0;if(!uj(x[j+656>>2])){break f}c=0;if(!Wc(y[(D(b,872)+a|0)+1075789|0])){break f}d=Ql(a,m,b,2,1)-1|0;c=0;if((d&255)>>>0>249){break f}e=x[Nd(a+906300|0,d)>>2];if(e){break g}e=0;c=0;break f}}else{h:{if((b|0)!=(c|0)&z[q>>1]>c>>>0){break h}e=D(c,872)+a|0;if(z[e+1075778>>1]!=(p|0)&(b|0)!=(c|0)){break h}n=e+1075648|0;f=x[n>>2];if(!f){break h}i:{j:{k:{l:{m:{n:{o:{switch(y[f+17|0]-1|0){case 0:if(!d){break h}i=y[e+1075789|0]==(d|0)&(f|0)==(g|0);if(!g){break n}if(i){break k}break h;case 1:if(!l|x[e+1075096>>2]!=(l|0)){break h}if((f|0)==(g|0)){break i}Ab(h+8|0,k,104);if(!zb(x[x[h+8>>2]>>2],x[h+12>>2])){break i}break h;case 3:break m;case 2:break o;default:break h}}if(g){break l}i=(f|0)==(g|0)}if(i){break i}break h}if(!g){break h}i=y[g+34|0];if(!i){break h}if((i|0)==y[f+34|0]){break j}break h}if((f|0)!=(g|0)){break h}}if(!y[g+34|0]){break i}}if(!y[e+1075789|0]|y[f+18|0]>2){break i}f=e+1075793|0;i=y[f|0];if(!i){break i}wm(a,c&65535,i|256,0);v[f|0]=0}f=e+1074992|0;p:{q:{switch(y[x[n>>2]+18|0]){case 0:Yn(a,f);x[e+1075680>>2]=0;if(!(y[e+1075081|0]&2)){break p}f=x[a+1298300>>2];if(!Ed(f)){break p}vj(f,c&65535,1);break p;case 1:Yn(a,f);if(!(y[e+1075081|0]&2)){break p}f=x[a+1298300>>2];if(!Ed(f)){break p}pk(f,c&65535);break p;case 2:break q;default:break p}}i=e+1075080|0;f=x[i>>2];x[i>>2]=f|4096;if(!(f&512)){break p}if(!Ed(x[a+1298300>>2])){break p}Ab(h+8|0,k,105);if(zb(x[x[h+8>>2]>>2],x[h+12>>2])){break p}pk(x[a+1298300>>2],c&65535)}if(x[e+1075680>>2]){break h}x[e+1075688>>2]=0;e=e+1075080|0;x[e>>2]=x[e>>2]|2101248}c=c+1|0;continue}break}d=y[(D(b,872)+a|0)+1075793|0];c=0;if(!d){break f}c=lb[x[x[e>>2]+104>>2]](e,d,b)|0}if(!(Gi(x[j+8>>2],x[j+12>>2])|c)){break a}r:{if(!(c&(e|0)!=0)){break r}c=y[(D(b,872)+a|0)+1075790|0];if(c>>>0>3|(c|0)==1){break r}wm(a,b,255,0);w[(D(b,872)+a|0)+1075792>>1]=0}c=oz(a,b);if((c|0)==65535){break a}f=D(c,872);e=f+a|0;d=e+1075080|0;g=e+1074992|0;s:{if(!(y[e+1075081|0]&2)){break s}e=x[a+1298300>>2];if(!Ed(e)){break s}vj(e,c,1)}l=aq(g,j);e=x[d>>2];g=e&-917505;x[d>>2]=g;i=a+1074992|0;f=i+f|0;v[f+831|0]=0;m=z[a+480188>>1];v[f+805|0]=0;w[f+786>>1]=b>>>0<m>>>0?b+1|0:0;t:{u:{switch(y[(i+D(b,872)|0)+798|0]){case 2:Yn(a,l);if(!(y[d+1|0]&2)){break t}e=x[a+1298300>>2];if(!Ed(e)){break t}pk(e,b);Ab(h+8|0,k,105);if(!zb(x[x[h+8>>2]>>2],x[h+12>>2])){break t}$z(x[a+1298300>>2],b,c);break t;case 0:x[(D(c,872)+a|0)+1075688>>2]=0;x[d>>2]=g|4096;if(!(e&512)){break t}e=x[a+1298300>>2];if(!Ed(e)){break t}vj(e,b,1);break t;case 3:x[d>>2]=g|4096;if(!(e&512)){break t}if(!Ed(x[a+1298300>>2])){break t}Ab(h+8|0,k,105);e=x[a+1298300>>2];if(zb(x[x[h+8>>2]>>2],x[h+12>>2])){$z(e,b,c);break t}pk(e,b);break t;case 1:break u;default:break t}}if(!(e&512)){break t}e=x[a+1298300>>2];if(!Ed(e)){break t}$z(e,b,c)}c=D(c,872)+a|0;if(!x[c+1075680>>2]){x[c+1075688>>2]=0;x[d>>2]=x[d>>2]|2101248}a=D(b,872)+a|0;x[a+1075068>>2]=0;x[j>>2]=0;x[j+4>>2]=0;a=a+1075084|0;x[a>>2]=0;x[a+4>>2]=0}ib=h+16|0}function xja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;g=ib-144|0;ib=g;yc(b);a:{b:{c:{d:{e:{if(!WT(b,14134)){break e}k=Nb(g+128|0);j=Nb(g+112|0);x[27524]=0;x[g+104>>2]=0;x[g+108>>2]=0;R(250,a|0,32768);d=x[27524];x[27524]=0;if((d|0)==1){break b}x[27524]=0;d=Q(1,g+88|0,8117)|0;i=x[27524];x[27524]=0;if((i|0)==1){break c}Gb(a+1298344|0,d);xb(d);x[27524]=0;d=Q(1,g+72|0,6063)|0;i=x[27524];x[27524]=0;if((i|0)==1){break d}Gb(a+1298356|0,d);xb(d);x[a+1298404>>2]=28;m=a+484376|0;i=a+480280|0;while(1){d=x[b+8>>2];f=x[b>>2];x[27524]=0;d=W(160,f|0,d|0,8)|0;f=x[27524];x[27524]=0;f:{g:{h:{if((f|0)!=1){i:{j:{k:{l:{m:{n:{if(!d){break n}x[27524]=0;d=Q(632,b|0,g- -64|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break m}if(!d){break n}d=x[g+68>>2];x[27524]=0;U(194,g+16|0,b|0,ac(d)|0);d=x[27524];x[27524]=0;if((d|0)==1){break l}d=g+16|0;f=hc(g+40|0,d);yb(d);d=x[f>>2];x[27524]=0;d=T(182,d|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break j}if(d){break k}yb(f)}if(z[a+480188>>1]){break i}i=0;break g}a=P()|0;break a}a=P()|0;break a}o:{p:{q:{r:{s:{t:{u:{d=ac(x[g+64>>2]);if((d|0)!=1397769541){if((d|0)==1346458708){break t}if((d|0)==1346522948){break s}if((d|0)==1347175758){break u}if((d|0)!=1396788560){if((d|0)==1396854596){break r}if((d|0)==1397507406){break f}if((d|0)!=1129140036){break p}if(z[a+480188>>1]){break f}d=x[f>>2];x[27524]=0;d=T(164,d|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break j}if(d>>>0<8){break f}d=0;x[27524]=0;R(633,g+16|0,f|0);e=x[27524];x[27524]=0;if((e|0)==1){break j}while(1)if((d|0)==4){if(c){break f}i=1;break o}else{e=z[a+480188>>1];h=bc(g+16|0,d);v:{if(!Fb(y[h|0]|y[h+1|0]<<8)){h=(d&3)-1|0;break v}h=g+104|0;o=Jb(h,e),q=1,v[o|0]=q;o=Jb(h,z[a+480188>>1]+1|0),q=255,v[o|0]=q;lf(i+(z[a+480188>>1]<<5)|0);h=z[a+480188>>1];e=h+1|0;w[a+480188>>1]=e;l=i+(h<<5)|0;h=(d&3)-1|0;w[l+4>>1]=h>>>0<2?192:64}lf(i+((e&65535)<<5)|0);e=z[a+480188>>1];w[a+480188>>1]=e+1;w[(i+(e<<5)|0)+4>>1]=h>>>0<2?192:64;d=d+1|0;continue}}if(z[a+480190>>1]){break f}x[27524]=0;R(634,f|0,a|0);d=x[27524];x[27524]=0;if((d|0)!=1){break f}break j}d=x[f>>2];x[27524]=0;d=T(164,d|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break j}if(d>>>0<2){break f}x[27524]=0;d=T(275,f|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break j}o=a,q=Bd(d,1,255),x[o+480196>>2]=q;break f}d=x[f>>2];x[27524]=0;d=T(164,d|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break j}if(d>>>0<2){break f}x[27524]=0;n=T(275,f|0)|0;d=x[27524];x[27524]=0;if((d|0)!=1){break f}break j}d=y[m|0];e=x[a+484360>>2];h=x[f>>2];x[27524]=0;h=T(164,h|0)|0;l=x[27524];x[27524]=0;if((l|0)==1){break j}x[27524]=0;ea(344,Tb(e,d)|0,f|0,h|0,255,254);d=x[27524];x[27524]=0;if((d|0)==1){break j}break f}d=k;if(Kf(x[d>>2],x[d+4>>2])>>>0>=256){break f}break q}if(Kf(x[j>>2],x[j+4>>2])>>>0>3998){break f}d=x[f>>2];x[27524]=0;e=T(164,d|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break j}d=j;if(!e){break f}}x[27524]=0;R(635,d|0,f|0);d=x[27524];x[27524]=0;if((d|0)!=1){break f}break j}if(!(d&-2139062144)){break f}i=0}yb(f);break g}a=P()|0;yb(f);break a}x[a+480200>>2]=256;x[a+480204>>2]=125e4;x[a+480260>>2]=452;x[a+480264>>2]=3424;x[a+480228>>2]=48;x[a+480232>>2]=48;b=y[a+484376|0];d=x[a+484360>>2];x[27524]=0;R(328,Tb(d,b)|0,n&65535);b=x[27524];x[27524]=0;if((b|0)==1){break b}w:{if(!(c&1)){break w}b=x[k+4>>2];i=x[k>>2];d=0;x[27524]=0;R(229,a+484344|0,Kf(i,b)&65535);b=x[27524];x[27524]=0;if((b|0)==1){break b}while(1){f=x[k>>2];b=d&65535;if(Kf(f,x[k+4>>2])>>>0<=b>>>0){break w}x[27524]=0;i=x[g+108>>2];e=x[g+104>>2];x[g+8>>2]=e;x[g+12>>2]=i;x[g>>2]=e;x[g+4>>2]=i;X(636,Yg(f,b)|0,b|0,a|0,g|0);b=x[27524];x[27524]=0;if((b|0)!=1){d=d+1|0;continue}break}a=P()|0;break a}f=c&2;i=1;d=1;b=0;while(1){if(z[a+480190>>1]<=d>>>0){break g}if(!f|Kf(x[j>>2],x[j+4>>2])>>>0<=b>>>0){break g}c=(D(d,104)+a|0)+484380|0;Ro(c);x:{if(x[c>>2]){e=x[Yg(x[j>>2],b)>>2];x[27524]=0;e=T(164,e|0)|0;h=x[27524];x[27524]=0;if((h|0)==1){break h}wc(c,e);e=Zc(g+40|0,8,1,1,0);h=x[j>>2];x[27524]=0;W(223,e|0,c|0,Yg(h,b)|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break x}b=b+1|0}d=d+1|0;continue}break}a=P()|0;break a}a=P()|0;break a}a=P()|0;break a}Sc(j);Sc(k);break e}yb(f);continue}}ib=g+144|0;return i|0}a=P()|0;break a}a=P()|0;break a}a=P()|0}Sc(j);Sc(k);S(a|0);p()}function AY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=ib-112|0;ib=f;yc(b);a:{if(!dr(b,11670)){break a}if(!sv(b,f+96|0)){break a}if(!QC(y[f+97|0])){break a}if(!Ob(x[b>>2],x[b+8>>2],Ec(PC(f+96|0),kb))){break a}if(!Yb(b,y[f+105|0]|y[f+106|0]<<8)){break a}b:{if(!c){break b}zd(a,4096);x[a+480208>>2]=12;w[a+480188>>1]=(y[f+98|0]&31)+1;e=a+480190|0;w[e>>1]=y[f+99|0];uh(a,1);d=f+24|0;i=xc(d,8424);Gb(a+1298344|0,i);xb(i);i=xc(d,7053);Gb(a+1298356|0,i);xb(i);i=ib-16|0;ib=i;g=xc(i,4250);$c(f,g);xb(g);ib=i+16|0;x[27524]=0;X(233,d|0,f|0,y[f+97|0],f+96|0);d=x[27524];x[27524]=0;c:{if((d|0)!=1){d=f+24|0;Gb(a+1298368|0,d);xb(d);$b(f);x[a+1298404>>2]=4;d=y[f+99|0];i=f+80|0;x[i>>2]=0;x[i+4>>2]=0;vk(i+8|0,0);if(d){jr(i,d);DD(i,d,0)}d=1;d:{while(1){g=d&65535;if(g>>>0>z[e>>1]){x[27524]=0;Q(234,b|0,a+1298308|0)|0;g=x[27524];x[27524]=0;d=1;e:{if((g|0)==1){break e}g=a+480190|0;while(1){e=d&65535;if(e>>>0>z[g>>1]){d=0;g=a+480188|0;f:{while(1){if(z[g>>1]<=d>>>0){d=0;x[27524]=0;g=a+484344|0;R(229,g|0,z[f+100>>1]);e=x[27524];x[27524]=0;if((e|0)==1){break e}break f}e=(d<<5)+a|0;lf(e+480280|0);x[27524]=0;R(235,b|0,e+480289|0);e=x[27524];x[27524]=0;if((e|0)!=1){d=d+1|0;continue}break}b=P()|0;break d}g:{h:{i:{j:{while(1){if(z[f+100>>1]<=d>>>0){x[27524]=0;e=T(198,b|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break h}if(!e){break i}d=x[b+8>>2];g=x[b>>2];x[27524]=0;d=W(160,g|0,d|0,e|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break h}if(d){break j}break i}x[27524]=0;e=Q(236,b|0,f+24|0)|0;h=x[27524];x[27524]=0;k:{if((h|0)==1){break k}x[27524]=0;h=W(230,g|0,d&65535,64)|0;j=x[27524];x[27524]=0;if((j|0)==1){break k}if((e&h)==1){e=x[g>>2];x[27524]=0;R(237,Xb(e,d)|0,f+24|0);e=x[27524];x[27524]=0;if((e|0)==1){break k}}d=d+1|0;continue}break}b=P()|0;break d}g=Nb(f+24|0);x[27524]=0;U(238,b|0,g|0,e|0);d=x[27524];x[27524]=0;l:{if((d|0)!=1){d=Kb(f);x[27524]=0;R(46,d|0,e|0);e=x[27524];x[27524]=0;m:{if((e|0)==1){break m}k=f,l=Cb(x[g>>2]),x[k+48>>2]=l;h=Cb(x[g+4>>2]);while(1){n:{e=x[f+48>>2];if(!Mb(e,h)){x[27524]=0;X(239,f+48|0,4,20,d|0);e=x[27524];x[27524]=0;if((e|0)==1){break n}h=f+48|0;e=Ac(d,h);wb(h);h=Jc(e);j=Eb(e);x[27524]=0;ea(240,a+1298332|0,h|0,j|0,76,0);h=x[27524];x[27524]=0;if((h|0)==1){break m}wb(e);ec(g);break i}o:{e=v[e|0];if((e|0)<0){k=f,l=Eh(d),x[k+64>>2]=l;j=x[pj(f+72|0,f- -64|0)>>2];x[27524]=0;X(241,d|0,j|0,e&127,32);e=x[27524];x[27524]=0;if((e|0)!=1){break o}break m}x[27524]=0;R(47,d|0,e|0);e=x[27524];x[27524]=0;if((e|0)!=1){break o}break m}Ie(f+48|0);continue}break}}b=P()|0;wb(d);break l}b=P()|0}ec(g);break d}d=y[a+484376|0];g=x[a+484360>>2];x[27524]=0;U(242,Tb(g,d)|0,b|0,z[f+102>>1]);d=x[27524];x[27524]=0;if((d|0)==1){break h}e=c&1;h=a+484348|0;d=0;while(1){p:{q:{if(z[f+100>>1]>d>>>0){g=x[b+8>>2];j=x[b>>2];x[27524]=0;g=W(160,j|0,g|0,4)|0;j=x[27524];x[27524]=0;if((j|0)==1){break p}if(g){break q}}if(!(c&2)){break g}g=a+480190|0;d=1;while(1){c=d&65535;if(c>>>0>z[g>>1]){break g}e=D(c,104)+a|0;h=z[e+484414>>1];Ab(f+24|0,x[i>>2],c-1|0);c=Zc(f,h&1?16:8,1,0,zb(x[x[f+24>>2]>>2],x[f+28>>2])?6:0);x[27524]=0;W(223,c|0,e+484380|0,b|0)|0;c=x[27524];x[27524]=0;if((c|0)!=1){d=d+1|0;continue}break}b=P()|0;break d}x[27524]=0;g=T(161,b|0)|0;j=x[27524];x[27524]=0;r:{s:{if((j|0)!=1){x[27524]=0;U(194,f|0,b|0,g|0);g=x[27524];x[27524]=0;if((g|0)==1){break s}g=hc(f+24|0,f);yb(f);if(!e){break r}j=x[a+484344>>2];if(!Ce(j,x[h>>2],d&65535)){break r}x[27524]=0;U(243,Xb(j,d)|0,0,g|0);j=x[27524];x[27524]=0;if((j|0)!=1){break r}b=P()|0;yb(g);break d}b=P()|0;break d}b=P()|0;break d}yb(g);d=d+1|0;continue}break}b=P()|0;break d}b=P()|0;break d}$e(i);break b}x[27524]=0;Q(244,b|0,((e<<5)+a|0)+946304|0)|0;e=x[27524];x[27524]=0;if((e|0)!=1){d=d+1|0;continue}break}b=P()|0;break d}b=P()|0;break d}x[27524]=0;R(245,b|0,f+24|0);h=x[27524];x[27524]=0;t:{if((h|0)==1){break t}x[27524]=0;R(246,f+24|0,(D(g,104)+a|0)+484380|0);h=x[27524];x[27524]=0;if((h|0)==1){break t}h=y[f+40|0];Ab(f,x[i>>2],g-1|0);bf(f,(h&3)!=0);d=d+1|0;continue}break}b=P()|0}$e(i);break c}b=P()|0;$b(f)}S(b|0);p()}d=1}ib=f+112|0;return d|0}function sda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=E(0),j=0,k=0,l=0;e=ib-336|0;ib=e;d=-1;a:{b:{c:{if(!jh(x[(x[x[b>>2]-12>>2]+b|0)+16>>2])){b=bm(e+224|0,b);x[27524]=0;d=Q(453,e+208|0,13965)|0;f=x[27524];x[27524]=0;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((f|0)!=1){x[27524]=0;x[e+192>>2]=83886084;x[e+196>>2]=0;U(454,b|0,d|0,e+192|0);f=x[27524];x[27524]=0;if((f|0)==1){break A}Zb(d);v[e+207|0]=0;x[27524]=0;d=Q(453,e+192|0,14743)|0;f=x[27524];x[27524]=0;if((f|0)==1){break z}x[27524]=0;U(455,b|0,e+207|0,d|0);f=x[27524];x[27524]=0;if((f|0)==1){break y}Zb(d);x[27524]=0;f=y[e+207|0];d=Q(453,e+176|0,15783)|0;g=x[27524];x[27524]=0;if((g|0)==1){break x}x[27524]=0;f=f?0:c;X(886,b|0,a+40|0,d|0,f|0);c=x[27524];x[27524]=0;if((c|0)==1){break w}Zb(d);w[e+174>>1]=65535;x[27524]=0;c=Q(453,e+160|0,15460)|0;d=x[27524];x[27524]=0;if((d|0)==1){break v}x[27524]=0;W(483,b|0,e+174|0,c|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break u}Zb(c);w[e+158>>1]=0;x[27524]=0;c=Q(453,e+144|0,15359)|0;d=x[27524];x[27524]=0;if((d|0)==1){break t}x[27524]=0;W(483,b|0,e+158|0,c|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break s}Zb(c);w[a>>1]=z[e+158>>1];x[27524]=0;c=Q(453,e+128|0,15046)|0;d=x[27524];x[27524]=0;if((d|0)==1){break r}x[27524]=0;X(887,b|0,a+52|0,c|0,f|0);d=x[27524];x[27524]=0;if((d|0)==1){break q}Zb(c);x[27524]=0;c=Q(453,e+112|0,14983)|0;d=x[27524];x[27524]=0;if((d|0)==1){break p}x[27524]=0;U(878,b|0,a+36|0,c|0);d=x[27524];x[27524]=0;if((d|0)==1){break o}Zb(c);x[27524]=0;c=Q(453,e+96|0,15467)|0;d=x[27524];x[27524]=0;if((d|0)==1){break n}x[27524]=0;h=a+4|0;U(888,b|0,h|0,c|0);d=x[27524];x[27524]=0;if((d|0)==1){break m}Zb(c);x[27524]=0;c=Q(453,e+80|0,15361)|0;d=x[27524];x[27524]=0;if((d|0)==1){break l}x[27524]=0;f=a+28|0;U(889,b|0,f|0,c|0);d=x[27524];x[27524]=0;if((d|0)==1){break k}Zb(c);x[27524]=0;c=Q(453,e- -64|0,15208)|0;d=x[27524];x[27524]=0;if((d|0)==1){break j}x[27524]=0;U(889,b|0,a+30|0,c|0);d=x[27524];x[27524]=0;if((d|0)==1){break i}Zb(c);x[27524]=0;c=Q(453,e+48|0,15012)|0;d=x[27524];x[27524]=0;if((d|0)==1){break h}x[27524]=0;U(890,b|0,a+32|0,c|0);d=x[27524];x[27524]=0;if((d|0)==1){break g}Zb(c);w[e+46>>1]=0;x[27524]=0;c=Q(453,e+32|0,14962)|0;d=x[27524];x[27524]=0;if((d|0)==1){break c}x[27524]=0;W(483,b|0,e+46|0,c|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break f}Zb(c);i=QN(B[a+32>>2]);B[a+32>>2]=i;d=-1;if(!um(i)){break d}k=e,l=Cb(x[a+4>>2]),x[k+24>>2]=l;c=Cb(x[a+8>>2]);while(1){g=x[e+24>>2];if(!Mb(g,c)){break e}if(!um(B[g>>2])){break d}Pe(e+24|0);continue}}a=P()|0;break a}a=P()|0;Zb(d);break a}a=P()|0;break a}a=P()|0;Zb(d);break a}a=P()|0;break a}a=P()|0;Zb(d);break a}a=P()|0;break a}a=P()|0;Zb(c);break a}a=P()|0;break a}a=P()|0;Zb(c);break a}a=P()|0;break a}a=P()|0;Zb(c);break a}a=P()|0;break a}a=P()|0;Zb(c);break a}a=P()|0;break a}a=P()|0;Zb(c);break a}a=P()|0;break a}a=P()|0;Zb(c);break a}a=P()|0;break a}a=P()|0;Zb(c);break a}a=P()|0;break a}a=P()|0;Zb(c);break a}a=P()|0;Zb(c);break a}if(Rk(y[b|0])){break d}c=z[f>>1];if((c-301&65535)>>>0<64935){break d}g=z[a>>1];if(g>>>0>3|(g|0)==2){break d}j=w[a+30>>1];if((j|0)<0){break d}k=e,l=Mi(x[a+36>>2]),x[k+24>>2]=l;x[e+16>>2]=0;k=a,l=x[Oj(e+24|0,e+16|0,43856)>>2],x[k+36>>2]=l;if(tc(x[a+4>>2],x[a+8>>2])>>>0>32767){break d}B:{C:{switch(g-1|0){case 2:f=w[e+46>>1];if((f|0)<=0){break d}w[e+14>>1]=j;B[e+24>>2]=B[a+32>>2];x[27524]=0;w[e+16>>1]=c;w[e+18>>1]=(c+f|0)-1;a=fa(891,a|0,e+14|0,e+24|0,e+16|0)|0;c=x[27524];x[27524]=0;if((c|0)!=1){if(a){break B}break d}a=P()|0;break a;case 0:g=w[e+46>>1];if((g|0)<=0){break d}B[e+24>>2]=B[a+32>>2];x[27524]=0;w[e+16>>1]=c;w[e+18>>1]=(c+g|0)-1;a=ja(892,a|0,h|0,e+24|0,e+16|0,f|0)|0;c=x[27524];x[27524]=0;if((c|0)!=1){if(a){break B}break d}a=P()|0;break a;default:break C}}x[27524]=0;Y(893,a|0);a=x[27524];x[27524]=0;if((a|0)==1){break b}}d=1}rh(b)}ib=e+336|0;return d|0}a=P()|0;break a}a=P()|0}rh(b);S(a|0);p()}function zI(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0;i=ib-560|0;ib=i;g=c;c=(c-3|0)/24|0;s=(c|0)>0?c:0;k=g+D(s,-24)|0;o=x[(e<<2)+89024>>2];j=d-1|0;if((o+j|0)>=0){g=d+o|0;c=s-j|0;while(1){C[(i+320|0)+(h<<3)>>3]=(c|0)<0?0:+x[(c<<2)+89040>>2];c=c+1|0;h=h+1|0;if((g|0)!=(h|0)){continue}break}}q=k-24|0;g=0;t=(o|0)>0?o:0;h=(d|0)<=0;while(1){a:{if(h){f=0;break a}n=g+j|0;c=0;f=0;while(1){f=C[(c<<3)+a>>3]*C[(i+320|0)+(n-c<<3)>>3]+f;c=c+1|0;if((d|0)!=(c|0)){continue}break}}C[(g<<3)+i>>3]=f;c=(g|0)==(t|0);g=g+1|0;if(!c){continue}break}z=47-k|0;u=48-k|0;A=k-25|0;g=o;b:{while(1){f=C[(g<<3)+i>>3];c=0;h=g;l=(g|0)<=0;if(!l){while(1){n=(i+480|0)+(c<<2)|0;m=f*5.960464477539063e-8;c:{if(F(m)<2147483648){j=~~m;break c}j=-2147483648}m=+(j|0);f=m*-16777216+f;d:{if(F(f)<2147483648){j=~~f;break d}j=-2147483648}x[n>>2]=j;h=h-1|0;f=C[(h<<3)+i>>3]+m;c=c+1|0;if((g|0)!=(c|0)){continue}break}}f=$j(f,q);f=f+J(f*.125)*-8;e:{if(F(f)<2147483648){n=~~f;break e}n=-2147483648}f=f-+(n|0);f:{g:{h:{v=(q|0)<=0;i:{if(!v){h=(g<<2)+i|0;j=x[h+476>>2];c=j>>u;r=h;h=j-(c<<u)|0;x[r+476>>2]=h;n=c+n|0;j=h>>z;break i}if(q){break h}j=x[((g<<2)+i|0)+476>>2]>>23}if((j|0)<=0){break f}break g}j=2;if(f>=.5){break g}j=0;break f}c=0;h=0;if(!l){while(1){r=(i+480|0)+(c<<2)|0;w=x[r>>2];l=16777215;j:{k:{if(h){break k}l=16777216;if(w){break k}h=0;break j}x[r>>2]=l-w;h=1}c=c+1|0;if((g|0)!=(c|0)){continue}break}}l:{if(v){break l}c=8388607;m:{switch(A|0){case 1:c=4194303;break;case 0:break m;default:break l}}l=(g<<2)+i|0;x[l+476>>2]=x[l+476>>2]&c}n=n+1|0;if((j|0)!=2){break f}f=1-f;j=2;if(!h){break f}f=f-$j(1,q)}if(f==0){c=1;l=0;h=g;n:{if((g|0)<=(o|0)){break n}while(1){h=h-1|0;l=x[(i+480|0)+(h<<2)>>2]|l;if((h|0)>(o|0)){continue}break}if(!l){break n}k=q;while(1){k=k-24|0;g=g-1|0;if(!x[(i+480|0)+(g<<2)>>2]){continue}break}break b}while(1){h=c;c=c+1|0;if(!x[(i+480|0)+(o-h<<2)>>2]){continue}break}h=g+h|0;while(1){j=d+g|0;g=g+1|0;C[(i+320|0)+(j<<3)>>3]=x[(s+g<<2)+89040>>2];c=0;f=0;if((d|0)>0){while(1){f=C[(c<<3)+a>>3]*C[(i+320|0)+(j-c<<3)>>3]+f;c=c+1|0;if((d|0)!=(c|0)){continue}break}}C[(g<<3)+i>>3]=f;if((g|0)<(h|0)){continue}break}g=h;continue}break}f=$j(f,24-k|0);o:{if(f>=16777216){d=(i+480|0)+(g<<2)|0;m=f*5.960464477539063e-8;p:{if(F(m)<2147483648){c=~~m;break p}c=-2147483648}f=+(c|0)*-16777216+f;q:{if(F(f)<2147483648){a=~~f;break q}a=-2147483648}x[d>>2]=a;g=g+1|0;break o}if(F(f)<2147483648){c=~~f}else{c=-2147483648}k=q}x[(i+480|0)+(g<<2)>>2]=c}f=$j(1,k);if((g|0)>=0){d=g;while(1){a=d;C[(a<<3)+i>>3]=f*+x[(i+480|0)+(a<<2)>>2];d=a-1|0;f=f*5.960464477539063e-8;if(a){continue}break}a=0;h=g;while(1){d=a>>>0>t>>>0?t:a;c=0;f=0;while(1){f=C[(c<<3)+91808>>3]*C[(c+h<<3)+i>>3]+f;k=(c|0)!=(d|0);c=c+1|0;if(k){continue}break}C[(i+160|0)+(g-h<<3)>>3]=f;h=h-1|0;c=(a|0)!=(g|0);a=a+1|0;if(c){continue}break}}r:{s:{t:{switch(e|0){case 3:u:{if((g|0)<=0){break u}d=(i+160|0)+(g<<3)|0;f=C[d>>3];c=g;while(1){m=f;e=i+160|0;a=c-1|0;h=e+(a<<3)|0;y=C[h>>3];f=y+f;C[e+(c<<3)>>3]=m+(y-f);C[h>>3]=f;e=c>>>0>1;c=a;if(e){continue}break}if((g|0)<2){break u}f=C[d>>3];c=g;while(1){m=f;d=i+160|0;a=c-1|0;e=d+(a<<3)|0;p=C[e>>3];f=p+f;C[d+(c<<3)>>3]=m+(p-f);C[e>>3]=f;d=c>>>0>2;c=a;if(d){continue}break}p=0;while(1){p=p+C[(i+160|0)+(g<<3)>>3];a=(g|0)>2;g=g-1|0;if(a){continue}break}}f=C[i+160>>3];if(j){break s}C[b>>3]=f;f=C[i+168>>3];C[b+16>>3]=p;C[b+8>>3]=f;break r;case 0:f=0;if((g|0)>=0){while(1){a=g;g=g-1|0;f=f+C[(i+160|0)+(a<<3)>>3];if(a){continue}break}}C[b>>3]=j?-f:f;break r;case 1:case 2:break t;default:break r}}f=0;if((g|0)>=0){d=g;while(1){a=d;d=a-1|0;f=f+C[(i+160|0)+(a<<3)>>3];if(a){continue}break}}C[b>>3]=j?-f:f;f=C[i+160>>3]-f;c=1;if((g|0)>0){while(1){f=f+C[(i+160|0)+(c<<3)>>3];a=(c|0)!=(g|0);c=c+1|0;if(a){continue}break}}C[b+8>>3]=j?-f:f;break r}C[b>>3]=-f;f=C[i+168>>3];C[b+16>>3]=-p;C[b+8>>3]=-f}ib=i+560|0;return n&7}function Zx(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;l=ib-48|0;ib=l;x[l+44>>2]=0;a:{if(!(d|g|h)){j=3;if(!i){break a}}k=g?l+44|0:0;b:{if(!k){break b}j=x[k>>2];if(!j){break b}Ib(j);x[k>>2]=0}x[27524]=0;Z(109);j=x[27524];x[27524]=0;c:{d:{if((j|0)==1){m=Va(108196,49024,49080,50060,108384,108488,108436,108328,108316,108632,108600,108568,108556,108780,0)|0;e:{f:{n=jb;if((n|0)==(da(108196)|0)){j=_(m|0)|0;x[27524]=0;R(1059,k|0,j|0);k=x[27524];x[27524]=0;j=277;if((k|0)==1){break f}break c}if((da(49024)|0)==(n|0)){j=_(m|0)|0;x[27524]=0;R(1059,k|0,j|0);k=x[27524];x[27524]=0;j=358;if((k|0)!=1){break c}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){break d}break e}if((da(49080)|0)==(n|0)){j=_(m|0)|0;x[27524]=0;R(1059,k|0,j|0);k=x[27524];x[27524]=0;j=359;if((k|0)!=1){break c}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){break d}break e}if((da(50060)|0)==(n|0)){j=_(m|0)|0;x[27524]=0;R(1059,k|0,j|0);k=x[27524];x[27524]=0;j=357;if((k|0)!=1){break c}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){break d}break e}if((da(108384)|0)==(n|0)){j=_(m|0)|0;x[27524]=0;R(1059,k|0,j|0);k=x[27524];x[27524]=0;j=300;if((k|0)!=1){break c}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){break d}break e}if((da(108488)|0)==(n|0)){j=_(m|0)|0;x[27524]=0;R(1059,k|0,j|0);k=x[27524];x[27524]=0;j=299;if((k|0)!=1){break c}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){break d}break e}if((da(108436)|0)==(n|0)){j=_(m|0)|0;x[27524]=0;R(1059,k|0,j|0);k=x[27524];x[27524]=0;j=298;if((k|0)!=1){break c}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){break d}break e}if((da(108328)|0)==(n|0)){j=_(m|0)|0;x[27524]=0;R(1059,k|0,j|0);k=x[27524];x[27524]=0;j=297;if((k|0)!=1){break c}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){break d}break e}if((da(108316)|0)==(n|0)){j=_(m|0)|0;x[27524]=0;R(1059,k|0,j|0);k=x[27524];x[27524]=0;j=296;if((k|0)!=1){break c}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){break d}break e}if((da(108632)|0)==(n|0)){j=_(m|0)|0;x[27524]=0;R(1059,k|0,j|0);k=x[27524];x[27524]=0;j=289;if((k|0)!=1){break c}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){break d}break e}if((da(108600)|0)==(n|0)){j=_(m|0)|0;x[27524]=0;R(1059,k|0,j|0);k=x[27524];x[27524]=0;j=288;if((k|0)!=1){break c}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){break d}break e}if((da(108568)|0)==(n|0)){j=_(m|0)|0;x[27524]=0;R(1059,k|0,j|0);k=x[27524];x[27524]=0;j=287;if((k|0)!=1){break c}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){break d}break e}if((da(108556)|0)==(n|0)){j=_(m|0)|0;x[27524]=0;R(1059,k|0,j|0);k=x[27524];x[27524]=0;j=286;if((k|0)!=1){break c}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){break d}break e}o=da(108780)|0;j=257;m=_(m|0)|0;if((n|0)!=(o|0)){break c}x[27524]=0;R(1059,k|0,m|0);k=x[27524];x[27524]=0;j=267;if((k|0)!=1){break c}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)==1){break e}break d}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){break d}}V(0)|0;Sb()}p()}S(a|0);p()}$();k=j;m=!g;if(d){j=lb[d|0](k,e)|0}else{j=3}if(!(m|!(j&2))){x[g+16>>2]=k;m=g;g=x[l+44>>2];q=m,r=mg(g?g:21631),x[q+20>>2]=r}if(h){x[h>>2]=k}if(!i){break a}g=x[l+44>>2];q=i,r=mg(g?g:21631),x[q>>2]=r}g=x[l+44>>2];if(g){Ib(g);x[l+44>>2]=0}g:{if(!(j&1)){break g}x[27524]=0;R(1057,l+32|0,a|0);g=x[27524];x[27524]=0;h:{i:{if((g|0)!=1){j:{if(f){g=x[f+24>>2];x[27524]=0;R(1058,g|0,l+32|0);g=x[27524];x[27524]=0;if((g|0)!=1){break j}break i}g=Jc(l+32|0);if(b){x[27524]=0;R(b|0,g|0,c|0);g=x[27524];x[27524]=0;if((g|0)==1){break i}break j}_s(g,l)}wb(l+32|0);break g}g=V(0)|0;break h}g=V(0)|0;wb(l+32|0)}_(g|0)|0;x[l+28>>2]=f;x[l+24>>2]=e;x[l+20>>2]=d;x[l+16>>2]=c;x[l+12>>2]=b;x[l+8>>2]=a?a:21631;x[l+4>>2]=254;x[l>>2]=9122;uM(17847,l);Zs(109136);$()}ib=l+48|0}function Yma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;e=ib-352|0;ib=e;yc(b);f=ib-16|0;ib=f;FW(f+8|0,e+128|0);h=x[f+12>>2];kc(f,x[b>>2],x[b+8>>2],x[f+8>>2],x[f+12>>2]);i=x[f+4>>2];if((i|0)==(h|0)){Yb(b,x[f+12>>2])}ib=f+16|0;a:{b:{c:{d:{e:{f:{g:{if((h|0)!=(i|0)){break g}if(!HW(e+128|0)){break g}if(!Ob(x[b>>2],x[b+8>>2],Ec(GW(y[e+344|0],y[e+345|0]),kb))){break g}if(!c){d=1;break g}zd(a,2);gg(a);x[a+480188>>2]=524296;t=a,u=Xe(455e3),x[t+480204>>2]=u;Lb(a+1074312|0,110,1);x[a+480208>>2]=x[a+480208>>2]|16777216;f=e+96|0;Se(f,2,e+159|0);d=e+112|0;Fc(d,f);Ac(a+1298308|0,d);wb(d);d=0;h:{i:{while(1){if((d|0)==8){j:{d=Tb(x[a+484360>>2],y[a+484376|0]);o=y[e+344|0];n=o+1|0;wo(d,b,n,65535,65535);f=Nb(e+112|0);x[27524]=0;U(238,b|0,f|0,n|0);d=x[27524];x[27524]=0;if((d|0)==1){break j}t=e,u=Cb(x[f>>2]),x[t+96>>2]=u;d=Cb(x[f+4>>2]);while(1){h=x[e+96>>2];q=Mb(h,d);if(q){if((y[h|0]-9&255)>>>0<248){break h}Ie(e+96|0);continue}break}t=a,u=y[Jb(x[f>>2],0)|0],x[t+480196>>2]=u;d=y[e+343|0];i=y[e+345|0];h=Nb(e+96|0);x[27524]=0;m=i+1|0;U(238,b|0,h|0,m|0);i=x[27524];x[27524]=0;k:{if((i|0)==1){break k}x[27524]=0;i=a+484344|0;R(229,i|0,m|0);g=x[27524];x[27524]=0;if((g|0)==1){break k}r=d+1|0;if(!(c&1)){break i}c=0;while(1){if((c|0)==(m|0)){break i}d=y[Jb(x[h>>2],c)|0];x[27524]=0;d=W(230,i|0,d|0,r|0)|0;g=x[27524];x[27524]=0;l:{if((g|0)!=1){if(!d){break i}g=0;k=Xb(x[i>>2],y[Jb(x[h>>2],c)|0]);m:while(1){s=g&65535;if(s>>>0>7){break l}g=g+1|0;d=0;while(1){if(A[k+12>>2]<=d>>>0){continue m}x[27524]=0;j=T(210,b|0)|0;l=x[27524];x[27524]=0;n:{o:{if((l|0)!=1){j=j<<24>>24;if((j|0)>=0){break o}d=(j&127)+d|0;break n}d=P()|0;break b}l=hd(x[k>>2],x[x[k+48>>2]+12>>2],d,s);if((j|0)==1){v[l|0]=254;break n}if((j-1&255)>>>0>96){break n}v[l+1|0]=g;v[l|0]=j+12}d=d+1|0;continue}}}d=P()|0;break b}c=c+1|0;continue}}d=P()|0;break b}}else{i=e+112|0;f=(e+128|0)+D(d,19)|0;QB(i,f+63|0);h=e+96|0;Fc(h,i);Il(((d<<5)+a|0)+480289|0,h);wb(h);d=d+1|0;g=D(d,104)+a|0;j=g+484380|0;md(j,2);v[e+107|0]=0;h=y[f+78|0]|y[f+79|0]<<8|(y[f+80|0]<<16|y[f+81|0]<<24);v[e+103|0]=h;v[e+104|0]=h>>>8;v[e+105|0]=h>>>16;v[e+106|0]=h>>>24;h=y[f+75|0]|y[f+76|0]<<8|(y[f+77|0]<<16|y[f+78|0]<<24);f=y[f+71|0]|y[f+72|0]<<8|(y[f+73|0]<<16|y[f+74|0]<<24);x[e+8>>2]=x[e+104>>2];x[e+96>>2]=f;x[e+100>>2]=h;f=x[e+100>>2];x[e>>2]=x[e+96>>2];x[e+4>>2]=f;Rm(j,1,e);x[g+484404>>2]=8215;f=e+80|0;Fc(f,i);Cc(((d<<5)+a|0)+946304|0,f);wb(f);continue}break}d=P()|0;break a}j=o+1|0;c=a+484376|0;d=0;p:{q:{while(1){if((d|0)==(j|0)){x[27524]=0;b=Q(1,e+80|0,8564)|0;c=x[27524];x[27524]=0;if((c|0)!=1){break p}d=P()|0;break b}b=y[c|0];g=x[a+484360>>2];x[27524]=0;k=d&65535;b=Q(315,Tb(g,b)|0,k|0)|0;g=x[27524];x[27524]=0;if((g|0)!=1){r:{s:{if(b){b=Tb(x[a+484360>>2],y[c|0]);break s}x[27524]=0;g=Q(363,i|0,r|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break q}if((g|0)==65535){break r}b=Tb(x[a+484360>>2],y[c|0]);t=bc(x[b>>2],d),u=g,w[t>>1]=u}b=PB(Cb(x[Xb(x[i>>2],z[bc(x[b>>2],d)>>1])+4>>2]),1);g=y[b+5|0];l=y[Jb(x[f>>2],(d+1>>>0)%(n>>>0)|0)|0];if((g|0)==(l|0)){break r}t:{if(y[b+3|0]!=16){break t}g=y[c|0];m=x[a+484360>>2];x[27524]=0;g=Q(364,Tb(m,g)|0,k|0)|0;k=x[27524];x[27524]=0;if((k|0)==1){break c}if((g|0)==65535){break t}b=PB(Cb(x[Xb(x[i>>2],g)+4>>2]),1)}v[b+5|0]=l;v[b+3|0]=16}d=d+1|0;continue}break}d=P()|0;break b}d=P()|0;break b}Gb(a+1298344|0,b);xb(b);x[27524]=0;b=Q(1,e- -64|0,6052)|0;c=x[27524];x[27524]=0;if((c|0)==1){break f}Gb(a+1298356|0,b);xb(b);b=e+16|0;Hj(b,2,e+139|0);x[27524]=0;R(226,e+32|0,b|0);b=x[27524];x[27524]=0;if((b|0)==1){break e}x[27524]=0;U(11,e+48|0,4,e+32|0);b=x[27524];x[27524]=0;if((b|0)==1){break d}b=e+48|0;Gb(a+1298368|0,b);xb(b);wb(e+32|0);x[a+1298404>>2]=4;ec(h)}ec(f);d=q^1}ib=e+352|0;return d|0}d=P()|0;break b}d=P()|0;break b}d=P()|0;wb(e+32|0);break b}d=P()|0}ec(h)}ec(f);S(d|0);p()}function F1(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;h=ib+-64|0;ib=h;x[h+56>>2]=b;x[e>>2]=0;ed(h,d);x[27524]=0;i=T(1164,h|0)|0;j=x[27524];x[27524]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((j|0)!=1){_b(h);switch(g-65|0){case 54:break j;case 19:break k;case 18:break l;case 17:break m;case 49:break n;case 47:break o;case 45:case 51:break p;case 12:break q;case 44:break r;case 41:break s;case 8:break t;case 7:break u;case 5:break v;case 3:break w;case 35:case 36:break x;case 34:break y;case 1:case 33:case 39:break z;case 0:case 32:break A;case 2:case 4:case 6:case 9:case 10:case 11:case 13:case 14:case 15:case 16:case 20:case 21:case 22:case 25:case 26:case 27:case 28:case 29:case 30:case 31:case 37:case 38:case 40:case 42:case 43:case 46:case 48:case 50:case 52:case 53:break d;case 24:break f;case 56:break g;case 23:break h;case 55:break i;default:break e}}a=P()|0;_b(h);S(a|0);p()}SG(a,f+24|0,h+56|0,c,e,i);break b}RG(a,f+16|0,h+56|0,c,e,i);break b}g=a;i=b;a=lb[x[x[a+8>>2]+12>>2]](a+8|0)|0;b=vc(a);k=h,l=ek(g,i,c,d,e,f,b,b+(Eb(a)<<2)|0),x[k+56>>2]=l;break b}a=bj(h+56|0,c,e,i,2);b=x[e>>2];B:{if(!(b&4|a-1>>>0>30)){x[f+12>>2]=a;break B}x[e>>2]=b|4}break b}g=x[24579];x[h+24>>2]=x[24578];x[h+28>>2]=g;g=x[24577];x[h+16>>2]=x[24576];x[h+20>>2]=g;g=x[24575];x[h+8>>2]=x[24574];x[h+12>>2]=g;g=x[24573];x[h>>2]=x[24572];x[h+4>>2]=g;k=h,l=ek(a,b,c,d,e,f,h,h+32|0),x[k+56>>2]=l;break b}g=x[24587];x[h+24>>2]=x[24586];x[h+28>>2]=g;g=x[24585];x[h+16>>2]=x[24584];x[h+20>>2]=g;g=x[24583];x[h+8>>2]=x[24582];x[h+12>>2]=g;g=x[24581];x[h>>2]=x[24580];x[h+4>>2]=g;k=h,l=ek(a,b,c,d,e,f,h,h+32|0),x[k+56>>2]=l;break b}a=bj(h+56|0,c,e,i,2);b=x[e>>2];C:{if(!(b&4|(a|0)>23)){x[f+8>>2]=a;break C}x[e>>2]=b|4}break b}a=bj(h+56|0,c,e,i,2);b=x[e>>2];D:{if(!(b&4|a-1>>>0>11)){x[f+8>>2]=a;break D}x[e>>2]=b|4}break b}a=bj(h+56|0,c,e,i,3);b=x[e>>2];E:{if(!(b&4|(a|0)>365)){x[f+28>>2]=a;break E}x[e>>2]=b|4}break b}a=bj(h+56|0,c,e,i,2);b=x[e>>2];F:{if(!(b&4|(a|0)>12)){x[f+16>>2]=a-1;break F}x[e>>2]=b|4}break b}a=bj(h+56|0,c,e,i,2);b=x[e>>2];G:{if(!(b&4|(a|0)>59)){x[f+4>>2]=a;break G}x[e>>2]=b|4}break b}a=h+56|0;b=ib-16|0;ib=b;x[b+8>>2]=c;while(1){H:{if(!ss(a,b+8|0)){break H}if(!$k(i,1,al(x[a>>2]))){break H}Gn(a);continue}break}if(gk(a,b+8|0)){x[e>>2]=x[e>>2]|2}ib=b+16|0;break b}b=h+56|0;a=lb[x[x[a+8>>2]+8>>2]](a+8|0)|0;I:{if((Eb(a)|0)==(0-Eb(a+12|0)|0)){x[e>>2]=x[e>>2]|4;break I}c=gs(b,c,a,a+24|0,i,e,0);b=x[f+8>>2];if(!((c|0)!=(a|0)|(b|0)!=12)){x[f+8>>2]=0;break I}if(!((c-a|0)!=12|(b|0)>11)){x[f+8>>2]=b+12}}break b}g=rc(h,98352,44);k=g,l=ek(a,b,c,d,e,f,g,g+44|0),x[k+56>>2]=l;break b}x[h+16>>2]=x[24604];g=x[24603];x[h+8>>2]=x[24602];x[h+12>>2]=g;g=x[24601];x[h>>2]=x[24600];x[h+4>>2]=g;k=h,l=ek(a,b,c,d,e,f,h,h+20|0),x[k+56>>2]=l;break b}a=bj(h+56|0,c,e,i,2);b=x[e>>2];J:{if(!(b&4|(a|0)>60)){x[f>>2]=a;break J}x[e>>2]=b|4}break b}g=x[24615];x[h+24>>2]=x[24614];x[h+28>>2]=g;g=x[24613];x[h+16>>2]=x[24612];x[h+20>>2]=g;g=x[24611];x[h+8>>2]=x[24610];x[h+12>>2]=g;g=x[24609];x[h>>2]=x[24608];x[h+4>>2]=g;k=h,l=ek(a,b,c,d,e,f,h,h+32|0),x[k+56>>2]=l;break b}a=bj(h+56|0,c,e,i,1);b=x[e>>2];K:{if(!(b&4|(a|0)>6)){x[f+24>>2]=a;break K}x[e>>2]=b|4}break b}a=lb[x[x[a>>2]+20>>2]](a,b,c,d,e,f)|0;break a}g=a;i=b;a=lb[x[x[a+8>>2]+24>>2]](a+8|0)|0;b=vc(a);k=h,l=ek(g,i,c,d,e,f,b,b+(Eb(a)<<2)|0),x[k+56>>2]=l;break b}QG(f+20|0,h+56|0,c,e,i);break b}a=bj(h+56|0,c,e,i,4);if(!(y[e|0]&4)){x[f+20>>2]=a-1900}break b}if((g|0)==37){break c}}x[e>>2]=x[e>>2]|4;break b}a=ib-16|0;ib=a;x[a+8>>2]=c;b=6;c=h+56|0;L:{M:{if(gk(c,a+8|0)){break M}b=4;if((zn(i,al(x[c>>2]))|0)!=37){break M}b=2;if(!gk(Gn(c),a+8|0)){break L}}x[e>>2]=x[e>>2]|b}ib=a+16|0}a=x[h+56>>2]}ib=h- -64|0;return a|0}function by(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=ib-272|0;ib=f;g=x[b+4>>2];a:{if(!g){break a}h=x[b>>2];i=y[gl(h,g)|0];if((i|0)==33){e=1}else{if((i|0)!=63){break a}e=0}ol(f+96|0,h,g,g-1|0);g=x[f+100>>2];x[b>>2]=x[f+96>>2];x[b+4>>2]=g}g=f+96|0;Yd(g);h=x[f+96>>2];Yd(f+248|0);i=fl(h,x[f+252>>2],b);Yd(g);g=x[b+4>>2];h=x[b>>2];b:{c:{d:{e:{if((i|0)==x[f+100>>2]){a=qc(f+264|0,21631);i=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=i;if(Nc(h,g,f+8|0)){e=ba(8)|0;x[27524]=0;c=Qh(f+248|0,c,d);a=x[27524];x[27524]=0;f:{g:{h:{if((a|0)!=1){x[27524]=0;U(973,f+96|0,17610,c|0);a=x[27524];x[27524]=0;if((a|0)==1){break h}lc(e,f+96|0);a=0;x[27524]=0;U(123,e|0,50060,962);b=x[27524];x[27524]=0;if((b|0)!=1){break b}b=P()|0;wb(f+96|0);break g}b=P()|0;break f}b=P()|0;a=1}wb(c);if(!a){break c}}ca(e|0);break c}if(!e){break e}e=ba(8)|0;a=x[b+4>>2];b=x[b>>2];x[27524]=0;g=Qh(f+216|0,b,a);a=x[27524];x[27524]=0;i:{j:{k:{l:{m:{n:{o:{p:{q:{if((a|0)!=1){x[27524]=0;U(973,f+232|0,17646,g|0);a=x[27524];x[27524]=0;if((a|0)==1){break q}x[27524]=0;R(975,f+248|0,f+232|0);b=x[27524];x[27524]=0;a=1;if((b|0)==1){break p}x[27524]=0;c=Qh(f+200|0,c,d);a=x[27524];x[27524]=0;if((a|0)==1){break o}x[27524]=0;U(977,f+96|0,f+248|0,c|0);b=x[27524];x[27524]=0;a=1;if((b|0)==1){break n}lc(e,f+96|0);x[27524]=0;U(123,e|0,50060,962);a=x[27524];x[27524]=0;if((a|0)!=1){break b}b=P()|0;wb(f+96|0);a=0;break m}b=P()|0;break i}b=P()|0;a=1;break j}b=P()|0;break k}b=P()|0;a=1;break l}b=P()|0}wb(c)}wb(f+248|0)}wb(f+232|0)}wb(g);if(!a){break c}}ca(e|0);break c}b=qc(f+192|0,21631);e=x[b+4>>2];x[f+88>>2]=x[b>>2];x[f+92>>2]=e;if(Nc(h,g,f+88|0)){e=ba(8)|0;x[27524]=0;c=Qh(f+248|0,c,d);a=x[27524];x[27524]=0;r:{s:{t:{if((a|0)!=1){x[27524]=0;U(973,f+96|0,17610,c|0);a=x[27524];x[27524]=0;if((a|0)==1){break t}lc(e,f+96|0);a=0;x[27524]=0;U(123,e|0,50060,962);b=x[27524];x[27524]=0;if((b|0)!=1){break b}b=P()|0;wb(f+96|0);break s}b=P()|0;break r}b=P()|0;a=1}wb(c);if(!a){break c}}ca(e|0);break c}b=qc(f+184|0,12317);e=x[b+4>>2];x[f+80>>2]=x[b>>2];x[f+84>>2]=e;if(Nc(h,g,f+80|0)){b=qc(f+176|0,5604);e=x[b+4>>2];x[f+32>>2]=x[b>>2];x[f+36>>2]=e;b=c;e=d;if(Nc(b,e,f+32|0)){x[a+52>>2]=0;break e}g=qc(f+168|0,11181);h=x[g+4>>2];x[f+24>>2]=x[g>>2];x[f+28>>2]=h;if(Nc(b,e,f+24|0)){x[a+52>>2]=1;break e}g=qc(f+160|0,9154);h=x[g+4>>2];x[f+16>>2]=x[g>>2];x[f+20>>2]=h;if(Nc(b,e,f+16|0)){x[a+52>>2]=2;break e}e=ba(8)|0;x[27524]=0;c=Qh(f+248|0,c,d);a=x[27524];x[27524]=0;u:{v:{w:{if((a|0)!=1){x[27524]=0;U(973,f+96|0,14621,c|0);a=x[27524];x[27524]=0;if((a|0)==1){break w}lc(e,f+96|0);a=0;x[27524]=0;U(123,e|0,50060,962);b=x[27524];x[27524]=0;if((b|0)!=1){break b}b=P()|0;wb(f+96|0);break v}b=P()|0;break u}b=P()|0;a=1}wb(c);if(!a){break c}}ca(e|0);break c}b=qc(f+152|0,11418);e=x[b+4>>2];x[f+72>>2]=x[b>>2];x[f+76>>2]=e;if(!Nc(h,g,f+72|0)){break e}b=qc(f+144|0,15573);e=x[b+4>>2];x[f+64>>2]=x[b>>2];x[f+68>>2]=e;b=0;x:{e=c;c=d;if(Nc(e,c,f- -64|0)){break x}b=qc(f+136|0,15578);d=x[b+4>>2];x[f+56>>2]=x[b>>2];x[f+60>>2]=d;b=1;if(Nc(e,c,f+56|0)){break x}b=qc(f+128|0,12591);d=x[b+4>>2];x[f+48>>2]=x[b>>2];x[f+52>>2]=d;b=2;if(Nc(e,c,f+48|0)){break x}b=qc(f+120|0,9218);d=x[b+4>>2];x[f+40>>2]=x[b>>2];x[f+44>>2]=d;b=3;if(Nc(e,c,f+40|0)){break x}a=ba(8)|0;x[27524]=0;c=Q(55,f+96|0,11454)|0;b=x[27524];x[27524]=0;if((b|0)==1){break d}lc(a,c);x[27524]=0;U(123,a|0,50060,962);a=x[27524];x[27524]=0;if((a|0)!=1){break b}b=P()|0;wb(c);break c}x[a+56>>2]=b;a=x[a+24>>2];if(!x[a+24668>>2]){break e}c=a+24664|0;d=x[c+4>>2];x[f+112>>2]=x[c>>2];x[f+116>>2]=d;c=a+24656|0;d=x[c+4>>2];x[f+104>>2]=x[c>>2];x[f+108>>2]=d;c=x[a+24652>>2];x[f+96>>2]=x[a+24648>>2];x[f+100>>2]=c;j=f,k=TJ(b),x[j+116>>2]=k;if(!Sx(f+96|0,a+24648|0)){break e}Vy(a,f+96|0)}ib=f+272|0;return}b=P()|0;ca(a|0)}S(b|0)}p()}function Xia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0;e=ib-752|0;ib=e;yc(b);d=ib-16|0;ib=d;g=e+144|0;zT(d+8|0,g);f=x[d+12>>2];kc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);k=x[d+4>>2];if((k|0)==(f|0)){Yb(b,x[d+12>>2])}ib=d+16|0;d=(f|0)==(k|0);if(!d){yT(g)}a:{if(!d){break a}if(!BT(e+144|0)){break a}if(!Ob(x[b>>2],x[b+8>>2],Ec(AT(z[e+178>>1]),kb))){break a}if(!c){n=1;break a}zd(a,262144);f=e+104|0;Pi(f,2,e+144|0);d=e+24|0;Fc(d,f);Ac(a+1298308|0,d);wb(d);g=xc(d,8265);Gb(a+1298344|0,g);xb(g);d=xc(d,10063);Gb(a+1298356|0,d);xb(d);d=ib-16|0;ib=d;h=f;f=xc(d,4196);$c(h,f);xb(f);ib=d+16|0;v[e+8|0]=y[e+174|0];x[27524]=0;v[e+127|0]=y[e+173|0];R(669,e+128|0,e+127|0);d=x[27524];x[27524]=0;b:{c:{d:{if((d|0)!=1){x[27524]=0;X(254,e+24|0,e+104|0,e+8|0,e+128|0);d=x[27524];x[27524]=0;if((d|0)!=1){d=e+24|0;Gb(a+1298368|0,d);xb(d);xb(e+128|0);f=e+104|0;$b(f);x[a+480208>>2]=12;x[a+1298404>>2]=4;g=a+480188|0;w[g>>1]=z[e+182>>1];w[e+24>>1]=z[e+178>>1];w[e+104>>1]=3999;B=a,C=z[Tc(d,f)>>1],w[B+480190>>1]=C;KW(Tb(x[a+484360>>2],y[a+484376|0]),e+240|0,z[e+176>>1]);d=0;while(1)if(z[g>>1]<=d>>>0){d=e+24|0;ae(d,b,D(z[e+178>>1],80));g=c&2;k=hc(e+104|0,d);yb(d);l=e+72|0;d=0;e:{f:{while(1){if(z[a+480190>>1]<=d>>>0){n=1;if(c&1){break f}break b}x[27524]=0;R(670,k|0,e+24|0);f=x[27524];x[27524]=0;if((f|0)==1){break e}f=e+8|0;Pi(f,2,l);x[27524]=0;R(226,e+128|0,f|0);f=x[27524];x[27524]=0;if((f|0)==1){break e}d=d+1|0;f=e+128|0;Cc(((d<<5)+a|0)+946304|0,f);wb(f);x[27524]=0;h=f;f=(D(d,104)+a|0)+484380|0;U(671,h|0,e+24|0,f|0);h=x[27524];x[27524]=0;g:{if((h|0)==1){break g}if(!g|!x[f>>2]){continue}x[27524]=0;h=Q(159,b|0,z[e+42>>1]|z[e+44>>1]<<16)|0;j=x[27524];x[27524]=0;if((j|0)==1){break g}if(!h){continue}x[27524]=0;W(223,e+128|0,f|0,b|0)|0;f=x[27524];x[27524]=0;if((f|0)!=1){continue}}break}break e}x[27524]=0;m=a+484344|0;R(229,m|0,z[e+180>>1]);c=x[27524];x[27524]=0;if((c|0)==1){break e}c=e+24|0;s=c|4;t=c|2;o=c|3;u=c|5;A=c|1;q=a+480188|0;a=0;while(1){if(z[e+180>>1]<=a>>>0){break b}x[27524]=0;c=W(230,m|0,a&65535,64)|0;d=x[27524];x[27524]=0;if((d|0)==1){break e}h:{if(!c){break h}c=(a<<1)+e|0;c=y[c+496|0]|y[c+497|0]<<8;if(!c){break h}x[27524]=0;c=Q(159,b|0,c<<4)|0;d=x[27524];x[27524]=0;if((d|0)==1){break e}if(!c){break h}c=0;d=Xb(x[m>>2],a);l=hd(x[d>>2],x[x[d+48>>2]+12>>2],0,0);while(1){if(c>>>0>63){break h}d=x[b+8>>2];f=x[b>>2];x[27524]=0;d=W(160,f|0,d|0,1)|0;f=x[27524];x[27524]=0;i:{if((f|0)!=1){if(!d){break h}x[27524]=0;d=T(210,b|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break e}h=d<<24>>24;if(h){break i}c=c+1|0;l=D(z[q>>1],6)+l|0;continue}break e}w[e+28>>1]=0;x[e+24>>2]=0;f=h&31;d=D(f,6)+l|0;g=Bg(e+24|0);f=f>>>0<z[q>>1];j=f?d:g;i=h&255;j:{if(!(i&32)){break j}x[27524]=0;R(264,e+128|0,b|0);g=x[27524];x[27524]=0;if((g|0)==1){break e}g=y[e+128|0];v[j|0]=g;B=f?d+1|0:A,C=y[Lc(e+128|0)|0],v[B|0]=C;k:{if(g){if((g|0)==254){break k}if(g>>>0<121){break j}}g=0}v[j|0]=g}l:{if(!(i&64)){break l}x[27524]=0;R(264,e+128|0,b|0);g=x[27524];x[27524]=0;if((g|0)==1){break e}g=f?d+5|0:u;r=Lc(e+128|0);v[g|0]=y[r|0];i=y[e+128|0];m:{if(i>>>0<=15){Xf(j,i,y[r|0]);break m}v[(f?d+3|0:o)|0]=i>>>0<=23?y[i+27015|0]:0}j=f?d+3|0:o;i=y[j|0];if((i|0)!=23){if((i|0)!=9){break l}v[j|0]=20;v[e+8|0]=y[g|0]>>>3;v[e+127|0]=1;B=g,C=y[mf(e+8|0,e+127|0)|0]-1&15|128,v[B|0]=C;break l}v[e+8|0]=64;B=g,C=y[Ub(g,e+8|0)|0]<<1,v[B|0]=C}if((h|0)>=0){continue}v[(f?d+2|0:t)|0]=1;x[27524]=0;g=T(210,b|0)|0;h=x[27524];x[27524]=0;if((h|0)==1){break e}v[(f?d+4|0:s)|0]=g;continue}}a=a+1|0;continue}}b=P()|0;yb(k);break c}else{f=(d<<5)+a|0;lf(f+480280|0);w[f+480284>>1]=(y[(e+d|0)+208|0]<<4|4)&244;d=d+1|0;continue}}b=P()|0;xb(e+128|0);break d}b=P()|0}$b(e+104|0)}S(b|0);p()}yb(k)}ib=e+752|0;return n|0}function Ama(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0;g=ib-48|0;ib=g;a:{b:{if(!c){break b}f=Mh(a,b);a=Cb(x[d>>2]);x[g+40>>2]=a;d=Cb(x[d+4>>2]);while(1){if(!Mb(a,d)){break b}yc(a);c:{if((Mj(a)|0)==(c|0)){Yb(a,20);d=Mj(a);k=zg(g+24|0);c=Bl(g+16|0,0,b?32:64);x[27524]=0;R(397,f|0,c|0);c=x[27524];x[27524]=0;if((c|0)==1){break c}o=(b|0)==2?4096:(b|0)==1?2048:16384;c=24;d=d+24|0;q=1;l=1;d:{while(1){h=o;while(1){e=x[a+8>>2];i=x[a>>2];x[27524]=0;e=W(160,i|0,e|0,1)|0;i=x[27524];x[27524]=0;e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if((i|0)!=1){if(!e){break d}e=x[f+4>>2];i=x[f>>2];m=x[a+8>>2];x[27524]=0;x[g+16>>2]=m;m=Q(398,k|0,g+16|0)|0;r=x[27524];x[27524]=0;if((r|0)==1){break a}u=m,A=$d(i,e),x[u>>2]=A;x[27524]=0;e=T(210,a|0)|0;i=x[27524];x[27524]=0;if((i|0)==1){break a}q:{switch(e-128|0){case 5:case 6:case 9:case 10:break h;case 2:break i;case 1:break j;case 0:break k;case 3:case 4:case 7:case 8:break e;default:break q}}r:{switch(e|0){case 0:break g;case 5:break l;case 4:break m;case 3:break n;case 2:break o;case 1:break p;default:break r}}s:{switch(e-160|0){case 5:case 6:break h;case 2:break i;case 1:break j;case 0:break k;case 3:case 4:break e;default:break s}}switch(e-192|0){case 2:break i;case 1:break j;case 0:break k;default:break e}}break a}if(y[f+12|0]&4){break e}x[27524]=0;e=T(275,a|0)|0;i=x[27524];x[27524]=0;t:{if((i|0)==1){break t}x[27524]=0;x[g+16>>2]=e;e=Q(398,k|0,g+16|0)|0;i=x[27524];x[27524]=0;if((i|0)==1){break t}v[f+15|0]=x[e>>2];u=f,A=$d(x[f>>2],x[f+4>>2])-1|0,v[u+16|0]=A;v[f+12|0]=y[f+12|0]|4;break e}break a}x[27524]=0;e=T(275,a|0)|0;i=x[27524];x[27524]=0;if((i|0)==1){break a}w[g+16>>1]=e;w[g+14>>1]=1;e=z[pe(g+16|0,g+14|0)>>1];h=D(e,D(s<<16>>16,l))+h|0;u:{if(e>>>0<2){break u}u=g,A=Fl((e+z[Fj(x[f+4>>2])>>1]|0)-1|0),w[u+16>>1]=A;e=Mu(b,h);x[27524]=0;v[g+14|0]=e;U(399,f|0,g+16|0,g+14|0);e=x[27524];x[27524]=0;if((e|0)!=1){break u}break a}u=g,A=Fl(z[Fj(x[f+4>>2])>>1]+1|0),w[u+16>>1]=A;e=Mu(b,h);x[27524]=0;v[g+14|0]=e;U(399,f|0,g+16|0,g+14|0);e=x[27524];x[27524]=0;if((e|0)!=1){break e}break a}x[27524]=0;j=T(210,a|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break a}t=x[a+8>>2];break e}x[27524]=0;e=T(275,a|0)|0;i=x[27524];x[27524]=0;if((i|0)==1){break a}e=c+e|0;x[g+16>>2]=e;if(!(!(j&255)|e>>>0<t>>>0)){j=j-1|0;if(!(j&255)){break f}x[27524]=0;Q(159,a|0,e|0)|0;e=x[27524];x[27524]=0;if((e|0)!=1){break e}break a}if(!(j&255)){break f}x[27524]=0;e=Q(400,k|0,g+16|0)|0;i=x[27524];x[27524]=0;if((i|0)==1){break a}v[f+13|0]=x[e>>2];u=f,A=$d(x[f>>2],x[f+4>>2])-1|0,v[u+14|0]=A;v[f+12|0]=y[f+12|0]|2;break e}q=0;n=1;break e}x[27524]=0;h=T(275,a|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break a}e=Mu(b,h);u=Fj(x[f+4>>2]),A=e,v[u+2|0]=A;break e}x[27524]=0;s=T(401,a|0)|0;e=x[27524];x[27524]=0;if((e|0)!=1){break e}break a}x[27524]=0;e=T(210,a|0)|0;l=x[27524];x[27524]=0;if((l|0)!=1){v[g+16|0]=e;v[g+14|0]=1;l=y[mf(g+16|0,g+14|0)|0];break e}break a}x[27524]=0;Q(192,a|0,1)|0;e=x[27524];x[27524]=0;if((e|0)==1){break a}break e}n=1;if(c>>>0<d>>>0){break e}break d}j=0}if(!n|c>>>0>=d>>>0){continue}break}x[27524]=0;c=Q(159,a|0,d|0)|0;h=x[27524];x[27524]=0;if((h|0)==1){break a}if(!c){break d}c=x[a+8>>2];h=x[a>>2];x[27524]=0;c=W(160,h|0,c|0,2)|0;h=x[27524];x[27524]=0;if((h|0)==1){break a}if(!c){break d}h=y[f+12|0];v:{if(!(!(h&4)&q)){c=x[f+4>>2];break v}c=x[f+4>>2];e=x[f>>2];v[f+12|0]=h|4;h=$d(e,c)-1|0;v[f+15|0]=h;v[f+16|0]=h}u=g,A=Fl(z[Fj(c)>>1]+1|0),w[u+16>>1]=A;c=Mu(b,o);x[27524]=0;v[g+14|0]=c;U(399,f|0,g+16|0,g+14|0);c=x[27524];x[27524]=0;if((c|0)!=1){n=1;v[f+17|0]=y[f+16|0]+1;c=d;continue}break}break a}v[f+12|0]=y[f+12|0]|1;gW(k);break b}a=x[Uf(g+40|0)>>2];continue}break}break a}ib=g+48|0;return}a=P()|0;gW(k);S(a|0);p()}function mda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=E(0),n=0,o=0,q=0;d=ib-128|0;ib=d;g=-1;a:{b:{c:{d:{if(!fh(x[x[b>>2]-12>>2]+b|0)){break d}e=d+112|0;Pd(e,b);f=x[e+8>>2];k=x[e+12>>2];e=d+104|0;Zj(e);b=ri(b,e,8);if(Qb(e,16718,8)){a=Nf(d+88|0,f,k);c=x[a+12>>2];x[d+16>>2]=x[a+8>>2];x[d+20>>2]=c;c=x[a+4>>2];x[d+8>>2]=x[a>>2];x[d+12>>2]=c;eh(b,d+8|0);break d}w[d+86>>1]=0;dg(b,d+86|0);k=w[d+86>>1];if((k-4&65535)>>>0<65534){break d}f=d+78|0;Zj(f);e=ri(b,f,8);if(Qb(f,14295,8)){break d}w[d+76>>1]=0;dg(e,d+76|0);f=w[d+76>>1];if((f-5&65535)>>>0<65534){break d}e:{f:{g:{h:{i:{j:{if(f>>>0<=3){b=Kb(d+112|0);x[27524]=0;h=W(487,e|0,b|0,65535)|0;l=x[27524];x[27524]=0;if((l|0)==1){break b}if(!h){break i}x[27524]=0;U(11,d- -64|0,c|0,b|0);h=x[27524];x[27524]=0;if((h|0)!=1){break j}break b}b=Kb(d+112|0);x[27524]=0;h=Q(489,e|0,b|0)|0;l=x[27524];x[27524]=0;if((l|0)==1){break c}if(!h){break h}x[27524]=0;U(11,d- -64|0,c|0,b|0);h=x[27524];x[27524]=0;if((h|0)==1){break c}}h=d- -64|0;Gb(a+40|0,h);xb(h);wb(b);w[d+62>>1]=0;dg(e,d+62|0);w[d+60>>1]=0;dg(e,d+60|0);w[a>>1]=z[d+60>>1];w[d+58>>1]=0;k:{if((f|0)<=3){x[d+112>>2]=0;wk(e,d+112|0);b=x[d+112>>2];if(b>>>0>65535){break d}b=Fl(b);w[d+58>>1]=b;break k}dg(e,d+58|0);b=z[d+58>>1]}h=a+52|0;l=b&65535;n=(f|0)>3;b=0;l:{m:{while(1){if(l>>>0<=(b&65535)>>>0){break l}f=Kb(d+112|0);x[27524]=0;w[d+40>>1]=0;R(897,e|0,d+40|0);i=x[27524];x[27524]=0;if((i|0)==1){break g}n:{if(!n){x[27524]=0;i=W(487,e|0,f|0,65535)|0;j=x[27524];x[27524]=0;if((j|0)==1){break g}if(i){break n}break e}x[27524]=0;i=Q(489,e|0,f|0)|0;j=x[27524];x[27524]=0;if((j|0)==1){break g}if(!i){break e}}x[27524]=0;U(11,d- -64|0,c|0,f|0);i=x[27524];x[27524]=0;if((i|0)!=1){x[27524]=0;i=Q(894,h|0,d+40|0)|0;j=x[27524];x[27524]=0;if((j|0)==1){break m}j=i;i=d- -64|0;Gb(j,i);xb(i);wb(f);b=b+1|0;continue}break}g=P()|0;break f}g=P()|0;xb(d- -64|0);break f}c=d- -64|0;Zj(c);b=ri(e,c,8);if(Qb(c,14239,8)){break d}c=z[a>>1];if(c>>>0>3|(c|0)==2){break d}c=a+4|0;o:{if((k|0)<=2){if(ON(b,c)){break o}break d}if(!NN(b,c)){break d}}o=d,q=Cb(x[a+4>>2]),x[o+112>>2]=q;c=Cb(x[a+8>>2]);while(1){e=x[d+112>>2];if(Mb(e,c)){if(!um(B[e>>2])){break d}Pe(d+112|0);continue}break}c=a+16|0;p:{if((k|0)<=2){if(ON(b,c)){break p}break d}if(!NN(b,c)){break d}}o=d,q=Cb(x[a+16>>2]),x[o+112>>2]=q;c=Cb(x[a+20>>2]);while(1){e=x[d+112>>2];if(Mb(e,c)){if(!um(B[e>>2])){break d}Pe(d+112|0);continue}break}o=a,q=tc(x[a+16>>2],x[a+20>>2]),x[o+36>>2]=q;w[d+56>>1]=0;dg(b,d+56|0);c=z[d+56>>1];w[a+28>>1]=c;if((c-201&65535)>>>0<65135){break d}w[d+54>>1]=0;dg(b,d+54|0);c=w[d+54>>1];w[a+30>>1]=c;if((c|0)<0){break d}x[d+48>>2]=0;Pp(b,d+48|0);m=QN(B[d+48>>2]);B[a+32>>2]=m;if(!um(m)){break d}c=d+40|0;Zj(c);ri(b,c,8);if(Qb(c,16709,8)){break d}b=tc(x[a+4>>2],x[a+8>>2]);if(b>>>0>32767){break d}c=w[a+30>>1];e=z[a>>1];if(!(e?!(B[a+32>>2]<=E(0))&(c|0)>0:1)){break d}q:{switch(e-1|0){case 0:case 2:if(b>>>0<c>>>0){break d}break;default:break q}}b=0;c=x[a+36>>2];if(c){b=c-1|0;x[a+36>>2]=b}o=d,q=Mi(b),x[o+112>>2]=q;x[d+32>>2]=0;o=a,q=x[Oj(d+112|0,d+32|0,43856)>>2],x[o+36>>2]=q;Qp(a);g=1;if(z[a>>1]!=3){break d}c=w[a+30>>1];if((c-w[a+28>>1]|0)>(XN(tc(x[a+4>>2],x[a+8>>2]))|0)){break d}g=a+32|0;e=Nb(d+112|0);b=0;while(1){r:{if(c<<16>>16<=(b|0)){b=z[a+28>>1];w[d+32>>1]=b;o=d,q=(tc(x[a+4>>2],x[a+8>>2])+b|0)-1|0,w[o+34>>1]=q;x[27524]=0;w[d+30>>1]=0;ja(892,a|0,e|0,g|0,d+32|0,d+30|0)|0;a=x[27524];x[27524]=0;g=1;if((a|0)==1){break r}uc(e);break d}c=w[a+28>>1];f=x[a+4>>2];x[27524]=0;R(898,e|0,Bb(f,b-c|0)|0);c=x[27524];x[27524]=0;if((c|0)!=1){b=b+1|0;c=z[a+30>>1];continue}}break}g=P()|0;uc(e);break a}wb(b);break d}wb(b);break d}g=P()|0}wb(f);break a}wb(f)}ib=d+128|0;return g|0}g=P()|0;wb(b);break a}g=P()|0;wb(b)}S(g|0);p()}function moa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;e=ib-3056|0;ib=e;yc(b);f=ib-16|0;ib=f;h=e+1096|0;bY(f+8|0,h);i=x[f+12>>2];j=b;kc(f,x[b>>2],x[b+8>>2],x[f+8>>2],x[f+12>>2]);b=x[f+4>>2];if((b|0)==(i|0)){Yb(j,x[f+12>>2])}ib=f+16|0;b=(b|0)==(i|0);if(!b){aY(h)}a:{if(!b){break a}if(!cY(e+1096|0)){break a}b:{if(!c){break b}if(!Ob(x[j>>2],x[j+8>>2],Ec(1024,0))){break a}$X(j,e+576|0);$X(j,e- -64|0);while(1){if((g|0)!=128){b=g<<2;f=x[b+(e+576|0)>>2];if(f>>>0>16777215){break a}b=x[b+(e- -64|0)>>2];if(b-4097>>>0<4294963202){break a}g=g+1|0;if(Br(x[j>>2],(b+f|0)+2978|0)){continue}break a}break}zd(a,2);gg(a);b=e+40|0;d=xc(b,13838);Gb(a+1298344|0,d);xb(d);d=xc(b,14760);Gb(a+1298356|0,d);xb(d);b=xc(b,15483);Gb(a+1298368|0,b);xb(b);x[a+1298404>>2]=4;b=y[e+1096|0];x[a+480204>>2]=143e4;x[a+480196>>2]=b;_e(Tb(x[a+484360>>2],y[a+484376|0]),y[e+1097|0]);x[a+480188>>2]=4194317;Lb(a+1074312|0,95,1);x[a+480208>>2]=x[a+480208>>2]|16777216;d=0;g=0;while(1){if((g|0)==4){c:{while(1){d:{if((d|0)==32){g=0;break d}b=d+1|0;g=D(b,104)+a|0;i=g+484380|0;md(i,2);h=e+16|0;di(h,1,(D(d,13)+e|0)+1098|0);f=e+40|0;Fc(f,h);Cc(((b<<5)+a|0)+946304|0,f);wb(f);d=(e+1096|0)+(d<<4)|0;f=y[d+422|0]|y[d+423|0]<<8|(y[d+424|0]<<16|y[d+425|0]<<24);x[i>>2]=f;h=f;f=y[d+430|0]|y[d+431|0]<<8|(y[d+432|0]<<16|y[d+433|0]<<24);if(h>>>0>=f>>>0){d=y[d+426|0]|y[d+427|0]<<8|(y[d+428|0]<<16|y[d+429|0]<<24);w[g+484414>>1]=2;x[g+484388>>2]=f;x[g+484384>>2]=d}x[g+484404>>2]=8287;d=b;continue}break}while(1){if((g|0)!=32){d=g+33|0;f=(D(d,104)+a|0)+484380|0;md(f,2);i=e+16|0;di(i,1,(D(g,13)+e|0)+2026|0);b=e+40|0;Fc(b,i);Cc(((d<<5)+a|0)+946304|0,b);wb(b);x[e+48>>2]=0;x[e+40>>2]=0;x[e+44>>2]=0;d=(e+1096|0)+D(g,11)|0;o=Jb(b,0),q=y[d+1347|0],v[o|0]=q;o=Jb(b,1),q=y[d+1352|0],v[o|0]=q;o=Jb(b,2),q=y[d+1348|0],v[o|0]=q;o=Jb(b,3),q=y[d+1353|0],v[o|0]=q;o=Jb(b,4),q=y[d+1349|0],v[o|0]=q;o=Jb(b,5),q=y[d+1354|0],v[o|0]=q;o=Jb(b,6),q=y[d+1350|0],v[o|0]=q;o=Jb(b,7),q=y[d+1355|0],v[o|0]=q;o=Jb(b,8),q=y[d+1351|0],v[o|0]=q;o=Jb(b,9),q=y[d+1356|0],v[o|0]=q;o=Jb(b,10),q=y[d+1346|0],v[o|0]=q;x[e+8>>2]=x[e+48>>2];b=x[e+44>>2];x[e>>2]=x[e+40>>2];x[e+4>>2]=b;Rm(f,1,e);g=g+1|0;continue}break}er(Tb(x[a+484360>>2],y[a+484376|0]),e+2794|0,256,255,65535);l=a+484344|0;Fg(l,128);m=c&1;f=0;while(1){e:{f:{if((f|0)!=128){b=f<<2;bd(j,x[b+(e+576|0)>>2]+2978|0);d=e+16|0;ae(d,j,x[b+(e- -64|0)>>2]);b=hc(e+40|0,d);yb(d);if(!m){break e}x[27524]=0;d=W(230,l|0,f&65535,64)|0;g=x[27524];x[27524]=0;if((g|0)==1){break c}if(!d){break e}g=0;i=Xb(x[l>>2],f);while(1){if(g>>>0>63){break e}d=x[b>>2];x[27524]=0;d=W(160,d|0,x[e+48>>2],1)|0;h=x[27524];x[27524]=0;g:{if((h|0)!=1){if(!d){break e}x[27524]=0;d=T(210,b|0)|0;h=x[27524];x[27524]=0;if((h|0)==1){break c}if(d>>>0>12){break g}h=hd(x[i>>2],x[x[i+48>>2]+12>>2],g,d);x[27524]=0;R(264,e+16|0,b|0);k=x[27524];x[27524]=0;if((k|0)==1){break c}k=y[e+16|0];d=d>>>0>3;v[h|0]=((k&15)+(d?13:37)|0)+D(k>>>4&7,12);k=Lc(e+16|0);v[h+1|0]=((y[k|0]>>>4|0)+(d?33:1)|0)+(y[e+16|0]>>>3&16);_X(h,y[k|0],d);continue}break c}h=d-32|0;if((h&255)>>>0<=12){h=hd(x[i>>2],x[x[i+48>>2]+12>>2],g,h&65535);x[27524]=0;k=T(210,b|0)|0;n=x[27524];x[27524]=0;if((n|0)==1){break c}_X(h,k,d>>>0>35);continue}if((d|0)!=64){if((d|0)!=96){break f}if(!g){break e}o=hd(x[i>>2],x[x[i+48>>2]+12>>2],g-1|0,0),q=14,v[o+3|0]=q;break e}x[27524]=0;d=T(210,b|0)|0;h=x[27524];x[27524]=0;if((h|0)==1){break c}g=d+g|0;continue}}d=1;if(!(c&2)){break a}while(1){if((d|0)==33){break b}Eg(Zc(e+40|0,8,1,0,1),(D(d,104)+a|0)+484380|0,j);d=d+1|0;continue}}yb(b);d=0;break a}yb(b);f=f+1|0;continue}}}else{w[((g<<5)+a|0)+480284>>1]=g&1?192:64;g=g+1|0;continue}break}a=P()|0;yb(b);S(a|0);p()}d=1}ib=e+3056|0;return d|0}function HO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;k=ib-16|0;ib=k;a:{b:{c:{if(!Wc(c)|!d|x[b+480180>>2]!=16777216|z[b+480192>>1]<d>>>0){break c}d=x[((d<<2)+b|0)+900380>>2];if(!d){break c}e=x[d+44>>2];if(!e){break c}w[k+14>>1]=c-61;c=ib+-64|0;ib=c;d:{e:{d=w[e+28>>1];h=k+14|0;b=w[h>>1];if((d|0)<=(b|0)){if((b|0)<=(tc(x[e+4>>2],x[e+8>>2])+d<<16)-65536>>16){break e}}Kb(a);break d}f:{d=z[e+30>>1];if(!d){b=e+52|0;d=Ay(b,h);if(!Rg(d,Gf(b))){break f}Nk(a,ud(d)+4|0);break d}b=zy(b,d<<16>>16);w[c+62>>1]=b;d=Kb(a);g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{a=e+52|0;f=Ay(a,c+62|0);t:{if(Rg(f,Gf(a))){x[27524]=0;R(139,d|0,ud(f)+4|0);a=x[27524];x[27524]=0;if((a|0)==1){break t}a=w[e+30>>1];b=w[h>>1];x[27524]=0;l=c,m=yy(b,a)+5|0,x[l+32>>2]=m;R(136,c+48|0,c+32|0);a=x[27524];x[27524]=0;u:{if((a|0)!=1){x[27524]=0;Q(99,d|0,c+48|0)|0;a=x[27524];x[27524]=0;if((a|0)==1){break u}xb(c+48|0);break d}a=P()|0;break g}a=P()|0;xb(c+48|0);break g}if(w[e+30>>1]>26){break q}x[27524]=0;b=W(531,c+32|0,1,(b<<24)+1090519040>>24)|0;a=x[27524];x[27524]=0;if((a|0)==1){break s}x[27524]=0;U(11,c+48|0,0,b|0);a=x[27524];x[27524]=0;if((a|0)==1){break r}a=c+48|0;f=Gb(d,a);xb(a);wb(b);x[27524]=0;Q(137,f|0,14644)|0;a=x[27524];x[27524]=0;if((a|0)!=1){break p}}a=P()|0;break g}a=P()|0;break g}a=P()|0;wb(b);break g}x[27524]=0;a=b<<16>>16;x[c+28>>2]=(a|0)%16;R(846,c+32|0,c+28|0);f=x[27524];x[27524]=0;if((f|0)==1){break o}x[27524]=0;x[c+12>>2]=((a|0)/16<<16>>16)%16;R(846,c+16|0,c+12|0);a=x[27524];x[27524]=0;if((a|0)==1){break n}x[27524]=0;U(2,c+48|0,c+32|0,c+16|0);a=x[27524];x[27524]=0;if((a|0)==1){break m}a=c+48|0;f=Gb(d,a);xb(a);xb(c+16|0);xb(c+32|0);if(b<<16>>16<256){break p}x[27524]=0;U(8,c|0,0,f|0);a=x[27524];x[27524]=0;if((a|0)==1){break k}b=c+32|0;g=ke(c);j=Eh(c);i=ke(c);a=ib-32|0;ib=a;x[a+16>>2]=j;x[a+24>>2]=g;x[a+8>>2]=i;while(1){if(Fi(a+24|0,a+16|0)){g=a+24|0;j=Xp(v[x[g>>2]]);i=a+8|0;v[x[i>>2]]=j;Ie(g);Ie(i);continue}break}ib=a+32|0;$c(b,c);x[27524]=0;U(11,c+48|0,0,b|0);a=x[27524];x[27524]=0;if((a|0)==1){break j}a=c+48|0;Gb(f,a);xb(a);wb(c+32|0);wb(c)}a=w[e+30>>1];b=w[h>>1];x[27524]=0;l=c,m=yy(b,a)+5|0,x[l+16>>2]=m;R(136,c+48|0,c+16|0);a=x[27524];x[27524]=0;if((a|0)==1){break i}x[27524]=0;Q(99,d|0,c+48|0)|0;a=x[27524];x[27524]=0;if((a|0)==1){break h}xb(c+48|0);break d}a=P()|0;break g}a=P()|0;break l}a=P()|0;xb(c+16|0)}xb(c+32|0);break g}a=P()|0;break g}a=P()|0;wb(c+32|0);wb(c);break g}a=P()|0;break g}a=P()|0;xb(c+48|0)}break a}d=ib-16|0;ib=d;f=ib-32|0;ib=f;e=wf(f+16|0,1,0);v:{w:{x:{while(1){j=f+8|0;b=vc(e);i=Eb(e)+b|0;g=w[h>>1];if(!((b|0)==(i|0)|(g|0)>=0)){v[b|0]=45;g=0-(g&65535)&65535;b=b+1|0}Yx(j,b,i,g&65535);if(!x[f+12>>2]){break x}b=Og(Eb(e));x[27524]=0;R(59,e|0,b|0);b=x[27524];x[27524]=0;if((b|0)!=1){continue}break}break w}b=x[f+8>>2];h=vc(e);x[27524]=0;R(60,e|0,b-h|0);b=x[27524];x[27524]=0;y:{if((b|0)!=1){x[27524]=0;R(72,d|0,e|0);b=x[27524];x[27524]=0;if((b|0)!=1){break y}break w}break w}wb(e);ib=f+32|0;break v}a=P()|0;wb(e);S(a|0);p()}x[27524]=0;R(71,a|0,d|0);a=x[27524];x[27524]=0;z:{if((a|0)!=1){xb(d);ib=d+16|0;break z}a=P()|0;break a}}ib=c- -64|0;break b}e=x[b>>2];b=ib-32|0;ib=b;A:{if(Wp(c)){x[b+16>>2]=x[8032];d=x[8031];x[b+8>>2]=x[8030];x[b+12>>2]=d;d=x[8029];x[b>>2]=x[8028];x[b+4>>2]=d;xc(a,(b+(c<<2)|0)-1004|0);break A}if(Wc(c)){d=Kb(b);x[27524]=0;c=c-1|0;f=(c|0)/12|0;c=Q(847,d|0,e+(D(f,-12)+c<<16>>16<<2)|0)|0;e=x[27524];x[27524]=0;B:{if((e|0)==1){break B}x[27524]=0;c=Q(848,c|0,f+48&255)|0;e=x[27524];x[27524]=0;if((e|0)==1){break B}x[27524]=0;Q(3,a|0,c|0)|0;a=x[27524];x[27524]=0;if((a|0)==1){break B}xb(c);break A}a=P()|0;break a}if(!c){xc(a,16742);break A}xc(a,14615)}ib=b+32|0}ib=k+16|0;return}xb(d);S(a|0);p()}function Xja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=ib-208|0;ib=d;yc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if(!yo(b,d+192|0)){break l}if(!kU(d+192|0)){break l}g=Oh(d+168|0);h=Kb(d+152|0);Vu(d+88|0);x[27524]=0;f=Q(601,b|0,d+80|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break h}m:{if(!f){break m}m=d,n=ac(ac(x[d+84>>2])-4|0),x[m+84>>2]=n;while(1){f=ac(ac(x[d+84>>2])-8|0);x[d+84>>2]=f;n:{if(c){break n}if((ac(x[d+80>>2])|0)!=1347699796){break n}j=1;break m}x[27524]=0;U(194,d+56|0,b|0,ac(f)|0);f=x[27524];x[27524]=0;if((f|0)==1){break d}e=d+56|0;f=hc(d,e);yb(e);e=x[f>>2];x[27524]=0;i=T(182,e|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break b}o:{if(!i){break o}p:{e=ac(x[d+80>>2]);if((e|0)!=1129139796){if((e|0)!=1229866575){if((e|0)==1347699796){break p}if((e|0)!=1447383635){break o}x[27524]=0;Q(192,f|0,4)|0;e=x[27524];x[27524]=0;if((e|0)==1){break b}x[27524]=0;e=T(602,f|0)|0;k=x[27524];x[27524]=0;if((k|0)==1){break b}if(!e){break o}e=ac(x[d+84>>2]);if(e>>>0<7){break o}x[27524]=0;U(603,f|0,h|0,e-6|0);e=x[27524];x[27524]=0;if((e|0)==1){break b}break o}x[27524]=0;l=Q(604,f|0,d+88|0)|0;e=x[27524];x[27524]=0;if((e|0)!=1){break o}break b}Pv(g,f);break o}x[27524]=0;j=W(605,a|0,f|0,c|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break b}}yb(f);if(i){x[27524]=0;f=Q(601,b|0,d+80|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break i}if(f){continue}}break}if(yh(x[h+4>>2],y[h+11|0])){x[27524]=0;b=Q(1,d+56|0,14879)|0;c=x[27524];x[27524]=0;if((c|0)==1){break g}Gb(h,b);xb(b)}q:{if(!(j&l&1)){break q}b=z[d+130>>1];x[27524]=0;b=Fb(b)&256;W(268,a+1074312|0,5,!b|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break f}c=Fb(z[d+126>>1]);if(c){w[d>>1]=64;w[d+40>>1]=c;m=a,n=z[Tc(d,d+40|0)>>1],x[m+480228>>2]=n}c=!b;b=Fb(z[d+128>>1]);if(!(c|!b)){x[a+480204>>2]=D(b,1e4)}if(y[d+88|0]){b=d+40|0;Se(b,2,d+88|0);x[27524]=0;R(226,d|0,b|0);b=x[27524];x[27524]=0;if((b|0)==1){break e}Ac(a+1298308|0,d);wb(d)}c=z[d+134>>1];if(!uq(c,1,12)){break q}f=z[d+132>>1];if(!uq(f,1,31)){break q}e=z[d+138>>1];if(!uq(e,0,23)){break q}i=z[d+140>>1];if(!uq(i,0,59)){break q}k=z[d+142>>1];if(!uq(k,0,59)){break q}x[a+1298408>>2]=0;b=Bo(d);m=b,n=Fb(z[d+136>>1])+1900|0,x[m>>2]=n;m=b,n=Fb(c),x[m+4>>2]=n;m=b,n=Fb(f),x[m+8>>2]=n;m=b,n=Fb(e),x[m+12>>2]=n;m=b,n=Fb(i),x[m+16>>2]=n;m=b,n=Fb(k),x[m+24>>2]=n;x[b+28>>2]=0;x[27524]=0;R(438,a+1298412|0,b|0);b=x[27524];x[27524]=0;if((b|0)!=1){break q}a=P()|0;break a}if(j&1){b=x[g>>2];x[27524]=0;b=T(182,b|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break h}if(b){b=Kb(d);x[27524]=0;U(272,g|0,b|0,32);c=x[27524];x[27524]=0;if((c|0)==1){break c}if(Jq(b,13731)){x[27524]=0;U(11,d+40|0,28,b|0);c=x[27524];x[27524]=0;if((c|0)==1){break c}c=d+40|0;Gb(a+1298320|0,c);xb(c)}c=x[g+8>>2];f=x[g>>2];x[27524]=0;c=Q(606,f|0,c|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break c}if(!c){x[27524]=0;c=T(206,g|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break c}x[27524]=0;ea(317,a+1298332|0,g|0,c|0,40,0);c=x[27524];x[27524]=0;if((c|0)==1){break c}}wb(b)}x[27524]=0;b=Q(1,d+40|0,17505)|0;c=x[27524];x[27524]=0;if((c|0)==1){break k}x[27524]=0;U(481,d|0,b|0,h|0);c=x[27524];x[27524]=0;if((c|0)==1){break j}Gb(a+1298368|0,d);xb(d);xb(b)}x[a+480208>>2]=x[a+480208>>2]|2097152;x[27524]=0;a=W(268,a+1074312|0,84,1)|0;b=x[27524];x[27524]=0;if((b|0)==1){break h}x[27524]=0;a=W(268,a|0,83,1)|0;b=x[27524];x[27524]=0;if((b|0)==1){break h}x[27524]=0;Q(269,a|0,85)|0;a=x[27524];x[27524]=0;if((a|0)==1){break h}}xb(h);yb(g)}ib=d+208|0;return j&1}a=P()|0;break a}a=P()|0;xb(b);break a}a=P()|0;break a}a=P()|0;break a}a=P()|0;break a}a=P()|0;break a}a=P()|0;break a}a=P()|0;break a}a=P()|0;wb(b);break a}a=P()|0;yb(f)}xb(h);yb(g);S(a|0);p()}function ck(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;k=1;o(+b);g=j(1)|0;c=j(0)|0;a:{b:{m=g&2147483647;f=c;c:{if(!(m|c)){break c}o(+a);c=j(1)|0;t=j(0)|0;if(!t&(c|0)==1072693248){break c}q=c&2147483647;if(!(!(q>>>0>2146435072|(q|0)==2146435072&(t|0)!=0|m>>>0>2146435072)&(!f|(m|0)!=2146435072))){return a+b}d:{e:{f:{g:{h:{r=0;i:{if((c|0)>0|(c|0)>=0){break i}r=2;if(m>>>0>1128267775){break i}r=0;if(m>>>0<1072693248){break i}e=m>>>20|0;if(m>>>0<1094713344){break h}i=1075-e|0;e=f>>>i|0;r=0;if((f|0)!=e<<i){break i}r=2-(e&1)|0}i=r;if(f){break f}if((m|0)!=2146435072){break g}if(!(q-1072693248|t)){break c}if(q>>>0<1072693248){break e}return(g|0)>0|(g|0)>=0?b:0}if(f){break f}f=1043-e|0;e=m>>>f|0;if((m|0)!=e<<f){break g}i=2-(e&1)|0}if((m|0)==1072693248){if((g|0)>0|(g|0)>=0){return a}return 1/a}if((g|0)==1073741824){return a*a}if((g|0)!=1071644672|(c|0)<0){break f}return M(a)}d=F(a);if(t){break d}j:{if((c|0)<0){if((c|0)==-2147483648|(c|0)==-1074790400|(c|0)==-1048576){break j}break d}if(!c|(c|0)==2146435072){break j}if((c|0)!=1072693248){break d}}k=(g|0)<0?1/d:d;if((c|0)>0|(c|0)>=0){break c}if(!(q-1072693248|i)){a=k-k;return a/a}return(i|0)==1?-k:k}return(g|0)>0|(g|0)>=0?0:-b}k:{if((c|0)>0|(c|0)>=0){break k}l:{switch(i|0){case 0:a=a-a;return a/a;case 1:break l;default:break k}}k=-1}m:{if(m>>>0>=1105199105){if(m>>>0>=1139802113){if(q>>>0<=1072693247){return(g|0)<0?O:0}return(g|0)>0?O:0}if(q>>>0<=1072693246){return(g|0)<0?k*1e300*1e300:k*1e-300*1e-300}if(q>>>0>=1072693249){return(g|0)>0?k*1e300*1e300:k*1e-300*1e-300}a=d+-1;d=a*1.9259629911266175e-8+a*a*(.5-a*(a*-.25+.3333333333333333))*-1.4426950408889634;h=d;d=a*1.4426950216293335;o(+(h+d));c=j(1)|0;j(0)|0;l(0,0);l(1,c|0);a=+n();d=h-(a-d);break m}a=d*9007199254740992;f=q>>>0<1048576;d=f?a:d;o(+a);c=j(1)|0;j(0)|0;i=f?c:q;e=i&1048575;c=e|1072693248;i=(i>>20)+(f?-1076:-1023)|0;f=0;n:{if(e>>>0<235663){break n}if(e>>>0<767610){f=1;break n}c=e|1071644672;i=i+1|0}e=f<<3;w=C[e+3536>>3];o(+d);j(1)|0;q=0;l(0,j(0)|q);l(1,c|0);p=+n();s=C[e+3520>>3];h=p-s;u=1/(s+p);d=h*u;o(+d);m=j(1)|0;j(0)|0;l(0,0);l(1,m|0);a=+n();x=a;l(0,q|0);l(1,((f<<18)+(c>>>1|0)|0)+537395200|0);v=a*a;y=h;h=+n();p=u*(y-a*h-a*(p-(h-s)));h=p*(d+a);a=d*d;s=h+a*a*(a*(a*(a*(a*(a*.20697501780033842+.23066074577556175)+.272728123808534)+.33333332981837743)+.4285714285785502)+.5999999999999946);o(+(v+3+s));c=j(1)|0;j(0)|0;l(0,0);l(1,c|0);a=+n();h=x*a;d=p*a+d*(s-(a+-3-v));o(+(h+d));c=j(1)|0;j(0)|0;l(0,0);l(1,c|0);a=+n();d=w+(a*-7.028461650952758e-9+(d-(a-h))*.9617966939259756);h=d;p=C[e+3552>>3];d=a*.9617967009544373;s=+(i|0);o(+(p+(h+d)+s));c=j(1)|0;j(0)|0;l(0,0);l(1,c|0);a=+n();d=h-(a-s-p-d)}l(0,0);l(1,g|0);p=+n();d=(b-p)*a+d*b;b=a*p;a=d+b;o(+a);g=j(1)|0;c=j(0)|0;o:{e=g;if((e|0)>=1083179008){if(c|e-1083179008){break b}if(!(d+8008566259537294e-32>a-b)){break o}break b}if((e&2147482624)>>>0<1083231232){break o}if(c|e+1064252416){break a}if(!(d<=a-b)){break o}break a}f=0;i=e&2147483647;if(i>>>0>=1071644673){c=e+(1048576>>>(i>>>20|0)-1022|0)|0;e=c>>>20&2047;f=(c&1048575|1048576)>>>1043-e|0;f=(g|0)<0?0-f|0:f;l(0,0);l(1,c&-1048576>>e-1023);b=b-+n();o(+(d+b));g=j(1)|0;j(0)|0}l(0,0);l(1,g|0);a=+n();p=a*.6931471824645996;d=(d-(a-b))*.6931471805599453+a*-1.904654299957768e-9;a=p+d;b=a*a;b=a-b*(b*(b*(b*(b*4.1381367970572385e-8+-16533902205465252e-22)+6613756321437934e-20)+-.0027777777777015593)+.16666666666666602);h=a*b/(b+-2);b=a;a=d-(a-p);a=b-(h-(b*a+a))+1;o(+a);c=j(1)|0;g=j(0)|0;c=(f<<20)+c|0;p:{if((c|0)<=1048575){a=$j(a,f);break p}l(0,g|0);l(1,c|0);a=+n()}k=k*a}return k}return k*1e300*1e300}return k*1e-300*1e-300}function nma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;h=ib-736|0;ib=h;a:{b:{if(d>>>0<=511){a=ib-16|0;ib=a;e=h+56|0;cc(a+8|0,e,554);d=x[a+12>>2];kc(a,x[b>>2],x[b+8>>2],x[a+8>>2],x[a+12>>2]);f=x[a+4>>2];if((f|0)==(d|0)){Yb(b,x[a+12>>2])}ib=a+16|0;a=(d|0)==(f|0);if(!a){Rb(e,0,554)}if(!a){break b}d=ib-32|0;ib=d;c:{a=h+56|0;if(Qb(a,13995,4)){break c}lr(d,a+32|0);b=d+16|0;Fc(b,d);Cc(c+492|0,b);wb(b);di(d,1,a+4|0);Fc(b,d);Cc(c+524|0,b);wb(b);b=y[a+24|0]|y[a+25|0]<<8;x[c+4>>2]=64;x[c+8>>2]=128;x[c>>2]=b<<6;v[c+16|0]=y[a+26|0];v[c+17|0]=y[a+27|0];f=c+108|0;g=c+236|0;b=0;while(1)if((b|0)==120){b=y[c+60|0]&-2|v[a+17|0]&1;v[c+60|0]=b;b=b&-3|y[a+17|0]&2;v[c+60|0]=b;v[c+60|0]=b&251|y[a+17|0]&4;g=c+61|0;v[g|0]=y[a+18|0];i=c+62|0;v[i|0]=y[a+19|0];j=c+63|0;v[j|0]=y[a+20|0];k=c- -64|0;v[k|0]=y[a+21|0];f=c+48|0;Zg(f,25);e=x[c+48>>2];b=0;while(1){d:{if((b|0)!=25){l=Bb(e,b);m=b<<1;n=y[(a+m|0)+504|0];w[l>>1]=n;if((n|0)!=255){break d}Zg(f,b);e=x[f>>2]}b=mf(g,i);a=$d(e,x[c+52>>2]);if(a>>>0<=y[b|0]){v[c+60|0]=y[c+60|0]&253}if(a>>>0>y[mf(j,k)|0]){break c}v[c+60|0]=y[c+60|0]&251;break c}v[l+2|0]=y[(a+(m|1)|0)+504|0];b=b+1|0;continue}}else{i=a+(b<<1)|0;e=y[i- -64|0];o=bc(g,b),q=y[i+65|0],w[o>>1]=q;o=Jb(f,b),q=(e>>>0<120?e:b)+1|0,v[o|0]=q;b=b+1|0;continue}}ib=d+32|0;break b}i=x[b+8>>2];d=ib-32|0;ib=d;x[d+28>>2]=674;x[d+8>>2]=674;e=x[b>>2];g=x[b+8>>2];f=x[Hb(d+28|0,d+8|0)>>2];if(!Ob(e,g,f)){f=jf(b)}j=d+8|0;e=h+56|0;UV(j,e);g=dc(d+16|0,x[d+8>>2],f);kc(d,x[b>>2],x[b+8>>2],x[g>>2],x[g+4>>2]);UV(j,e);Rb(x[d+8>>2]+f|0,0,674-f|0);Yb(b,x[d+28>>2]);ib=d+32|0;f=x[a+480180>>2];a=0;d=ib-32|0;ib=d;if(!Qb(e,13995,4)){lr(d,e+32|0);a=d+16|0;Fc(a,d);Cc(c+492|0,a);wb(a);di(d,1,e+4|0);Fc(a,d);Cc(c+524|0,a);wb(a);x[c>>2]=(y[e+20|0]|y[e+21|0]<<8)<<5;x[c+4>>2]=y[e+24|0]>>>1;wc(c+4|0,64);g=y[e+25|0]&127;x[c+8>>2]=g>>>0>64?128:g<<2;v[c+15|0]=y[c+15|0]&254|((y[e+25|0]^-1)&128)>>>7;v[d+16|0]=y[e+26|0];v[d|0]=100;o=c,q=y[Ub(a,d)|0],v[o+20|0]=q;v[d+16|0]=y[e+27|0];v[d|0]=64;o=c,q=y[Ub(a,d)|0],v[o+19|0]=q;v[c+16|0]=y[e+17|0];v[c+17|0]=y[e+18|0];v[c+18|0]=y[e+19|0];v[c+26|0]=y[e+22|0];v[c+27|0]=y[e+23|0];a=y[e+58|0];Tj(c,a&127,a>>>7|0);a=y[e+59|0];Sj(c,a&127,a>>>7|0);e:{f:{g:{h:{i:{j:{a=y[e+28|0]|y[e+29|0]<<8;switch(a-529|0){case 1:case 2:break h;case 0:case 3:break i;default:break j}}if((a|0)==544){break i}if((a|0)!=514){break h}}a=y[e+61|0];if((a|0)==255){break g}if(a>>>0<=128){v[c+30|0]=a}a=y[e+62|0]|y[e+63|0]<<8;if(a>>>0<129){break f}break e}a=v[e+61|0];if((a|0)<0){break g}v[c+30|0]=a+1}a=y[e+62|0];a=a<<24>>24>=0?a+1|0:0;g=v[e+63|0];if((g|0)<0){break f}a=((g&255)<<7)+a|0}w[c+28>>1]=a}a=v[e+60|0];v[c+31|0]=a;if((a|0)<0){v[c+31|0]=0;v[c+34|0]=a^128}a=0;f=f&16777216?240:25;Lv(e+304|0,c+48|0,0,f);Lv(e+386|0,c+68|0,32,f);Lv(e+468|0,c+88|0,32,f);v[c+100|0]=y[c+100|0]&239|y[e+468|0]>>>3&16;g=c+108|0;j=c+236|0;while(1){if((a|0)!=120){k=e+(a<<1)|0;f=y[k- -64|0];o=bc(j,a),q=y[k+65|0],w[o>>1]=q;o=Jb(g,a),q=(f>>>0<120?f:a)+1|0,v[o|0]=q;a=a+1|0;continue}break}a=554}ib=d+32|0;d=0;k:{if(!a){break k}d=e+550|0;l:{if(Qb(d,13471,4)){if(Qb(d,13823,4)){break l}}d=c+236|0;a=0;while(1){if((a|0)!=120){f=bc(d,a);w[f>>1]=z[f>>1]|y[(a+e|0)+554|0]<<8;a=a+1|0;continue}break}a=674}d=a}bd(b,d+i|0);if(!Lh(b,14e3)){break b}d=h+8|0;ae(d,b,Jg(b));a=hc(h+32|0,d);yb(d);b=x[a>>2];x[27524]=0;T(164,b|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break a}x[27524]=0;b=Q(406,a|0,13746)|0;d=x[27524];x[27524]=0;if((d|0)==1){break a}if(b){x[27524]=0;b=T(210,a|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break a}v[c+34|0]=b>>>0<=250?b:0}yb(a)}ib=h+736|0;return}b=P()|0;yb(a);S(b|0);p()}function L1(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;h=ib-32|0;ib=h;x[h+24>>2]=b;x[e>>2]=0;i=h+8|0;ed(i,d);x[27524]=0;i=T(19,i|0)|0;j=x[27524];x[27524]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((j|0)!=1){_b(h+8|0);switch(g-65|0){case 54:break j;case 19:break k;case 18:break l;case 17:break m;case 49:break n;case 47:break o;case 45:case 51:break p;case 12:break q;case 44:break r;case 41:break s;case 8:break t;case 7:break u;case 5:break v;case 3:break w;case 35:case 36:break x;case 34:break y;case 1:case 33:case 39:break z;case 0:case 32:break A;case 2:case 4:case 6:case 9:case 10:case 11:case 13:case 14:case 15:case 16:case 20:case 21:case 22:case 25:case 26:case 27:case 28:case 29:case 30:case 31:case 37:case 38:case 40:case 42:case 43:case 46:case 48:case 50:case 52:case 53:break d;case 24:break f;case 56:break g;case 23:break h;case 55:break i;default:break e}}a=P()|0;_b(h+8|0);S(a|0);p()}VG(a,f+24|0,h+24|0,c,e,i);break b}UG(a,f+16|0,h+24|0,c,e,i);break b}g=a;i=b;a=lb[x[x[a+8>>2]+12>>2]](a+8|0)|0;b=Jc(a);k=h,l=fk(g,i,c,d,e,f,b,Eb(a)+b|0),x[k+24>>2]=l;break b}a=cj(h+24|0,c,e,i,2);b=x[e>>2];B:{if(!(b&4|a-1>>>0>30)){x[f+12>>2]=a;break B}x[e>>2]=b|4}break b}x[h+8>>2]=623865125;x[h+12>>2]=2032480100;k=h,l=fk(a,b,c,d,e,f,h+8|0,h+16|0),x[k+24>>2]=l;break b}x[h+8>>2]=623728933;x[h+12>>2]=1680158061;k=h,l=fk(a,b,c,d,e,f,h+8|0,h+16|0),x[k+24>>2]=l;break b}a=cj(h+24|0,c,e,i,2);b=x[e>>2];C:{if(!(b&4|(a|0)>23)){x[f+8>>2]=a;break C}x[e>>2]=b|4}break b}a=cj(h+24|0,c,e,i,2);b=x[e>>2];D:{if(!(b&4|a-1>>>0>11)){x[f+8>>2]=a;break D}x[e>>2]=b|4}break b}a=cj(h+24|0,c,e,i,3);b=x[e>>2];E:{if(!(b&4|(a|0)>365)){x[f+28>>2]=a;break E}x[e>>2]=b|4}break b}a=cj(h+24|0,c,e,i,2);b=x[e>>2];F:{if(!(b&4|(a|0)>12)){x[f+16>>2]=a-1;break F}x[e>>2]=b|4}break b}a=cj(h+24|0,c,e,i,2);b=x[e>>2];G:{if(!(b&4|(a|0)>59)){x[f+4>>2]=a;break G}x[e>>2]=b|4}break b}a=h+24|0;b=ib-16|0;ib=b;x[b+8>>2]=c;while(1){H:{if(!yp(a,b+8|0)){break H}c=bl(x[a>>2]);if(!Bh(x[i+8>>2],1,c)){break H}im(a);continue}break}if(jj(a,b+8|0)){x[e>>2]=x[e>>2]|2}ib=b+16|0;break b}b=h+24|0;a=lb[x[x[a+8>>2]+8>>2]](a+8|0)|0;I:{if((Eb(a)|0)==(0-Eb(a+12|0)|0)){x[e>>2]=x[e>>2]|4;break I}c=is(b,c,a,a+24|0,i,e,0);b=x[f+8>>2];if(!((c|0)!=(a|0)|(b|0)!=12)){x[f+8>>2]=0;break I}if(!((c-a|0)!=12|(b|0)>11)){x[f+8>>2]=b+12}}break b}g=y[98264]|y[98265]<<8|(y[98266]<<16|y[98267]<<24);v[h+15|0]=g;v[h+16|0]=g>>>8;v[h+17|0]=g>>>16;v[h+18|0]=g>>>24;g=y[98261]|y[98262]<<8|(y[98263]<<16|y[98264]<<24);x[h+8>>2]=y[98257]|y[98258]<<8|(y[98259]<<16|y[98260]<<24);x[h+12>>2]=g;k=h,l=fk(a,b,c,d,e,f,h+8|0,h+19|0),x[k+24>>2]=l;break b}v[h+12|0]=y[98272];x[h+8>>2]=y[98268]|y[98269]<<8|(y[98270]<<16|y[98271]<<24);k=h,l=fk(a,b,c,d,e,f,h+8|0,h+13|0),x[k+24>>2]=l;break b}a=cj(h+24|0,c,e,i,2);b=x[e>>2];J:{if(!(b&4|(a|0)>60)){x[f>>2]=a;break J}x[e>>2]=b|4}break b}x[h+8>>2]=624576549;x[h+12>>2]=1394948685;k=h,l=fk(a,b,c,d,e,f,h+8|0,h+16|0),x[k+24>>2]=l;break b}a=cj(h+24|0,c,e,i,1);b=x[e>>2];K:{if(!(b&4|(a|0)>6)){x[f+24>>2]=a;break K}x[e>>2]=b|4}break b}a=lb[x[x[a>>2]+20>>2]](a,b,c,d,e,f)|0;break a}g=a;i=b;a=lb[x[x[a+8>>2]+24>>2]](a+8|0)|0;b=Jc(a);k=h,l=fk(g,i,c,d,e,f,b,Eb(a)+b|0),x[k+24>>2]=l;break b}TG(f+20|0,h+24|0,c,e,i);break b}a=cj(h+24|0,c,e,i,4);if(!(y[e|0]&4)){x[f+20>>2]=a-1900}break b}if((g|0)==37){break c}}x[e>>2]=x[e>>2]|4;break b}a=ib-16|0;ib=a;x[a+8>>2]=c;b=6;c=h+24|0;L:{M:{if(jj(c,a+8|0)){break M}b=4;if((An(i,bl(x[c>>2]))|0)!=37){break M}b=2;if(!jj(im(c),a+8|0)){break L}}x[e>>2]=x[e>>2]|b}ib=a+16|0}a=x[h+24>>2]}ib=h+32|0;return a|0}function jM(){var a=0,b=0,c=0,d=0,e=0,f=0;if(y[483552]){return x[120887]}b=Wd(485192);x[b>>2]=98472;c=b+8|0;x[c>>2]=0;x[c+4>>2]=0;e=sc(c+8|0),f=0,v[e+128|0]=f;if(zh(1073741823)>>>0<=29){_c();p()}a=zG(Nw(c),30);x[c>>2]=a;x[c+4>>2]=a;e=Db(c),f=a+120|0,x[e>>2]=f;Tt(c,30);x[27524]=0;d=Q(55,b+152|0,14293)|0;a=x[27524];x[27524]=0;a:{b:{c:{if((a|0)!=1){Ic(c);Wd(484864);x[121216]=101060;x[27524]=0;Y(1205,b|0);a=x[27524];x[27524]=0;if((a|0)==1){break c}Wd(484872);x[121218]=101092;x[27524]=0;Y(1206,b|0);a=x[27524];x[27524]=0;if((a|0)==1){break c}a=Wd(484880);v[a+12|0]=0;x[a+8>>2]=0;x[a>>2]=98492;x[a+8>>2]=98544;x[27524]=0;Y(1207,b|0);a=x[27524];x[27524]=0;if((a|0)==1){break c}Wd(484896);x[121224]=100008;x[27524]=0;Y(1208,b|0);a=x[27524];x[27524]=0;if((a|0)==1){break c}Wd(484904);x[121226]=100156;x[27524]=0;Y(1209,b|0);a=x[27524];x[27524]=0;if((a|0)==1){break c}x[27524]=0;Z(1210);a=x[27524];x[27524]=0;if((a|0)==1){break c}x[27524]=0;Y(1211,b|0);a=x[27524];x[27524]=0;if((a|0)==1){break c}Wd(484928);x[121232]=100304;x[27524]=0;Y(1212,b|0);a=x[27524];x[27524]=0;if((a|0)==1){break c}Wd(484936);x[121234]=100536;x[27524]=0;Y(1213,b|0);a=x[27524];x[27524]=0;if((a|0)==1){break c}Wd(484944);x[121236]=100420;x[27524]=0;Y(1214,b|0);a=x[27524];x[27524]=0;if((a|0)==1){break c}Wd(484952);x[121238]=100652;x[27524]=0;Y(1215,b|0);a=x[27524];x[27524]=0;if((a|0)==1){break c}a=Wd(484960);w[a+8>>1]=11310;x[a>>2]=99624;Kb(a+12|0);x[27524]=0;Y(1216,b|0);a=x[27524];x[27524]=0;if((a|0)==1){break c}a=Wd(484984);x[a+8>>2]=46;x[a+12>>2]=44;x[a>>2]=99664;Kb(a+16|0);x[27524]=0;Y(1217,b|0);a=x[27524];x[27524]=0;if((a|0)==1){break c}Wd(485016);x[121254]=101124;x[27524]=0;Y(1218,b|0);a=x[27524];x[27524]=0;if((a|0)==1){break c}Wd(485024);x[121256]=101368;x[27524]=0;Y(1219,b|0);a=x[27524];x[27524]=0;if((a|0)==1){break c}Wd(485032);x[121258]=101580;x[27524]=0;Y(1220,b|0);a=x[27524];x[27524]=0;if((a|0)==1){break c}Wd(485040);x[121260]=101812;x[27524]=0;Y(1221,b|0);a=x[27524];x[27524]=0;if((a|0)==1){break c}Wd(485048);x[121262]=102796;x[27524]=0;Y(1222,b|0);a=x[27524];x[27524]=0;if((a|0)==1){break c}Wd(485056);x[121264]=102944;x[27524]=0;Y(1223,b|0);a=x[27524];x[27524]=0;if((a|0)==1){break c}Wd(485064);x[121266]=103060;x[27524]=0;Y(1224,b|0);a=x[27524];x[27524]=0;if((a|0)==1){break c}Wd(485072);x[121268]=103176;x[27524]=0;Y(1225,b|0);a=x[27524];x[27524]=0;if((a|0)==1){break c}Wd(485080);x[121270]=103292;x[27524]=0;Y(1226,b|0);a=x[27524];x[27524]=0;if((a|0)==1){break c}Wd(485088);x[121272]=103456;x[27524]=0;Y(1227,b|0);a=x[27524];x[27524]=0;if((a|0)==1){break c}Wd(485096);x[121274]=103620;x[27524]=0;Y(1228,b|0);a=x[27524];x[27524]=0;if((a|0)==1){break c}Wd(485104);x[121276]=103784;x[27524]=0;Y(1229,b|0);a=x[27524];x[27524]=0;if((a|0)==1){break c}Wd(485112);x[121280]=105040;x[121280]=102060;x[121278]=102012;x[27524]=0;Y(1230,b|0);a=x[27524];x[27524]=0;if((a|0)==1){break c}Wd(485128);x[121284]=105076;x[121284]=102324;x[121282]=102276;x[27524]=0;Y(1231,b|0);a=x[27524];x[27524]=0;if((a|0)==1){break c}x[27524]=0;Z(1232);a=x[27524];x[27524]=0;if((a|0)==1){break c}x[27524]=0;Y(1233,b|0);a=x[27524];x[27524]=0;if((a|0)==1){break c}x[27524]=0;Z(1234);a=x[27524];x[27524]=0;if((a|0)==1){break c}x[27524]=0;Y(1235,b|0);a=x[27524];x[27524]=0;if((a|0)==1){break c}Wd(485176);x[121294]=103948;x[27524]=0;Y(1236,b|0);a=x[27524];x[27524]=0;if((a|0)==1){break c}Wd(485184);x[121296]=104068;x[27524]=0;Y(1237,b|0);b=x[27524];x[27524]=0;if((b|0)==1){break c}break a}b=P()|0;break b}b=P()|0;wb(d)}CG(c);S(b|0);p()}x[120886]=485192;v[483552]=1;x[120887]=483544;return 483544}function vP(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=ib-16|0;ib=f;g=a+1074376|0;h=D(b,872);e=(g+h|0)+616|0;d=c&15;a:{b:{switch((c&240)-16>>>4|0){case 0:a=(a+h|0)+1075080|0;x[a>>2]=x[a>>2]&-1048577|((d|0)!=0)<<20;break a;case 1:if(!(y[a+480209|0]&16)){break a}if(Aj(x[e+656>>2])){a=D(b,872)+a|0;w[a+1075764>>1]=d-8;a=a+1075843|0;v[a|0]=y[a|0]|64;break a}if(x[a+480180>>2]!=64){b=D(b,872)+a|0;w[b+1075764>>1]=d<<28>>24;c=z[(d<<1)+33296>>1];x[b+1075696>>2]=c;e=b+1075692|0;if(!x[e>>2]){break a}l=e,m=nh(a,y[b+1075789|0],d<<28>>24,c),x[l>>2]=m;break a}a=D(b,872)+a|0;b=x[a+1075096>>2];if(!b){break a}x[a+1075696>>2]=x[b+24>>2]+D(d,80);break a;case 2:if(x[a+480180>>2]==2){v[(D(b,872)+a|0)+1075814|0]=c&3;break a}Ab(f+8|0,a+1074312|0,21);if(zb(x[x[f+8>>2]>>2],x[f+12>>2])){v[(D(b,872)+a|0)+1075814|0]=d>>>0<4?d:0;break a}v[(D(b,872)+a|0)+1075814|0]=c&7;break a;case 3:if(x[a+480180>>2]==2){v[(D(b,872)+a|0)+1075817|0]=c&3;break a}Ab(f+8|0,a+1074312|0,21);if(zb(x[x[f+8>>2]>>2],x[f+12>>2])){v[(D(b,872)+a|0)+1075817|0]=d>>>0<4?d:0;break a}v[(D(b,872)+a|0)+1075817|0]=c&7;break a;case 4:Ab(f+8|0,a+1074312|0,21);if(zb(x[x[f+8>>2]>>2],x[f+12>>2])){a=D(b,872)+a|0;v[a+1075813|0]=0;v[a+1075820|0]=d>>>0<4?d:0;break a}v[(D(b,872)+a|0)+1075820|0]=c&7;break a;case 5:if(x[a+1074392>>2]|!(y[a+480209|0]&16)){break a}a=a+1074400|0;x[a>>2]=x[a>>2]+d;break a;case 6:if(!(y[a+480209|0]&16)){break a}if(d>>>0<=2){d=z[a+480188>>1];h=d>>>0<=256?256:d;i=a+906300|0;j=b+1|0;k=(c&15)-1|0;while(1){if((d|0)==(h|0)){break a}c=D(d,872)+a|0;c:{if(z[c+1075778>>1]!=(j|0)){break c}d:{e:{switch(k|0){case 0:Yn(a,c+1074992|0);if(!(y[c+1075081|0]&2)){break d}e=x[a+1298300>>2];if(!Ed(e)){break d}pk(e,d&65535);break d;case 1:g=c+1075080|0;e=x[g>>2];x[g>>2]=e|4096;if(!(e&512)){break d}e=x[a+1298300>>2];if(!Ed(e)){break d}pk(e,d&65535);break d;default:break e}}x[c+1075688>>2]=0;g=c+1075080|0;e=x[g>>2];x[g>>2]=e|4096;if(!(e&512)){break d}e=x[a+1298300>>2];if(!Ed(e)){break d}vj(e,d&65535,1)}e=x[c+1075648>>2];if(!e){break c}g=y[e+34|0];if(!g){break c}g=x[Nd(i,g-1|0)>>2];if(!g){break c}lb[x[x[g>>2]+96>>2]](g,e,y[c+1075789|0]|256,0,b)}d=d+1|0;continue}}VR(e,d,x[a+480180>>2]);break a;case 7:if(!(y[a+480209|0]&16)){break a}zm(a,e,d,4);break a;case 8:b=e;c=x[a+480208>>2];f:{if(!(c&4096)){break f}g:{switch(d&15){case 0:x[b+88>>2]=x[b+88>>2]&-257;break f;case 1:x[b+692>>2]=128;x[b+88>>2]=x[b+88>>2]|256;break f;case 8:x[b+88>>2]=x[b+88>>2]&-25165825|16777216;break f;case 9:x[b+88>>2]=x[b+88>>2]&-25165825|8388608;break f;case 10:x[a+480208>>2]=c&-16385;break f;case 11:x[a+480208>>2]=c|16384;break f;case 12:x[a+480208>>2]=c&-8193;break f;case 13:x[a+480208>>2]=c|8192;break f;case 14:x[b+88>>2]=x[b+88>>2]&-129;break f;case 15:break g;default:break f}}h:{if(x[b>>2]|x[b+4>>2]){break h}a=x[b+76>>2];if(!a){break h}if(!(l=Wc(y[b+788|0]),m=1,n=y[b+88|0]&2,n?l:m)){break h}x[b>>2]=-1;x[b+4>>2]=a-1}x[b+88>>2]=x[b+88>>2]|128}break a;case 9:if(!(y[a+480209|0]&16)){break a}c=D(b,872)+a|0;v[c+1075828|0]=d;Ab(f+8|0,a+1074312|0,35);if(zb(x[x[f+8>>2]>>2],x[f+12>>2])){break a}if(!Wc(y[c+1075780|0])){break a}b=x[(D(b,872)+a|0)+1075068>>2];a=d<<16;if(b>>>0<=a>>>0){break a}x[e+4>>2]=a;break a;case 10:if(!(y[a+480209|0]&16)){break a}Ez(a,g,e,d);break a;case 11:i:{if(d){break i}d=1;c=x[a+480180>>2];if(c&16777248){break i}d=0;if((c|0)==2){break a}}Ab(f+8|0,a+1074312|0,30);nz(a,b,d,zb(x[x[f+8>>2]>>2],x[f+12>>2])|x[a+480180>>2]==2);break a;case 14:break b;default:break a}}if(x[a+480180>>2]==2){break a}v[(D(b,872)+a|0)+1075836|0]=d}ib=f+16|0}function Nha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=ib-192|0;ib=e;a:{b:{if(Ob(x[c>>2],x[c+8>>2],8)){Yb(c,4);while(1){if(Cu(x[c>>2],x[c+8>>2])){break b}m=ib-288|0;ib=m;f=lR(m);h=ib-384|0;ib=h;i=rc(f,lR(h+96|0),282);f=0;c:{d:{e:{f:{g:{if(Lh(c,13637)){Gg(c,4);l=te(h+72|0,c);x[27524]=0;j=Q(765,l|0,i|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break g}h:{if(!j){break h}j=x[l+8>>2];g=x[l>>2];k=y[i+26|0];x[27524]=0;j=W(160,g|0,j|0,k|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break g}if(!j){break h}j=0;i:{while(1){if(y[i+26|0]<=f>>>0){g=x[l+8>>2];k=x[l>>2];f=0;x[27524]=0;j=j&65535;g=W(160,k|0,g|0,j|0)|0;k=x[27524];x[27524]=0;if((k|0)==1){break e}if(!g){break h}x[27524]=0;Q(192,l|0,j|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break e}Gg(l,mR(i));f=sc(h- -64|0);g=h+96|0;Xz(g);x[27524]=0;R(766,l|0,g|0);g=x[27524];x[27524]=0;if((g|0)!=1){w[h+118>>1]=0;w[h+120>>1]=0;f=Yz(f,h+96|0,h+123|0);g=y[i+26|0];x[27524]=0;Q(192,l|0,g|0)|0;g=x[27524];x[27524]=0;if((g|0)!=1){break i}}f=P()|0;break d}x[27524]=0;g=T(202,l|0)|0;k=x[27524];x[27524]=0;if((k|0)!=1){v[(f+i|0)+27|0]=g;f=f+1|0;j=g+j|0;continue}break}f=P()|0;break d}k=f;f=i+27|0;k=Yz(k,f,f+y[i+26|0]|0);x[27524]=0;U(194,h+16|0,l|0,j|0);f=x[27524];x[27524]=0;if((f|0)==1){break f}g=h+16|0;j=hc(h+40|0,g);yb(g);f=0;x[27524]=0;R(564,g|0,j|0);g=x[27524];x[27524]=0;if((g|0)==1){f=P()|0;yb(j);break d}g=h+16|0;LC(h+8|0,g);n=k;k=x[h+8>>2];k=Yz(n,k,Jb(k,x[h+12>>2]));Rc(g);yb(j);if(x[k>>2]!=(y[i+22|0]|y[i+23|0]<<8|(y[i+24|0]<<16|y[i+25|0]<<24))){break h}f=mR(i);x[27524]=0;Q(192,c|0,f|0)|0;i=x[27524];x[27524]=0;f=1;if((i|0)==1){break e}}yb(l)}ib=h+384|0;break c}f=P()|0;break d}f=P()|0;break d}f=P()|0}yb(l);S(f|0);p()}ib=m+288|0;if(f){continue}break}}yc(c);Eg(b,a,c);a=1;break a}v[d|0]=1;yc(c);f=Jg(c);d=e+144|0;ae(d,c,jf(c));h=hc(e+168|0,d);yb(d);c=z[a+34>>1]&-66|y[b|0]>15;b=y[b+1|0]!=1;c=c|b<<6;w[a+34>>1]=c;x[a>>2]=f>>>(c&1)>>>b;x[e+140>>2]=0;x[e+136>>2]=0;x[27524]=0;R(564,d|0,h|0);b=x[27524];x[27524]=0;j:{k:{l:{m:{if((b|0)!=1){c=Le(e+144|0);d=x[e+144>>2];i=_A(c,Mi(d),e+140|0,e+136|0);x[27524]=0;b=x[e+140>>2];Q(192,h|0,b|0)|0;f=x[27524];x[27524]=0;if((f|0)!=1){if(!i){break j}Xg(a);l=b+c|0;b=d-b|0;d=x[e+136>>2];c=0;while(1){n:{if(d){if(!b|(d|0)!=1){break k}d=x[a>>2];if(d>>>0>c>>>0){break n}break k}d=x[a>>2];if(d>>>0<=c>>>0){break k}}if(!_d(d,x[a+20>>2])){break k}x[e+132>>2]=0;x[e+128>>2]=0;j=NU(i,l,Mi(b),e+132|0,e+124|0,e+128|0);x[27524]=0;Q(192,h|0,j|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break m}gi(e+128|0,Mi(x[a>>2]-c|0));d=x[e+128>>2];o:{if((d|0)<=0){break o}f=x[e+132>>2];k=z[a+34>>1];if((Md(k)|0)!=(f|0)){break o}m=D(c,f);g=x[a+20>>2];if(k&1){x[e+120>>2]=d;x[e+104>>2]=d;x[e+56>>2]=d;x[e+40>>2]=d;x[e+100>>2]=f;x[e+96>>2]=x[e+124>>2];x[e+116>>2]=f;x[e+112>>2]=g+(m<<1);x[27524]=0;f=x[e+100>>2];x[e+32>>2]=x[e+96>>2];x[e+36>>2]=f;f=x[e+116>>2];x[e+48>>2]=x[e+112>>2];x[e+52>>2]=f;R(565,e+48|0,e+32|0);f=x[27524];x[27524]=0;if((f|0)!=1){break o}break m}x[e+88>>2]=d;x[e+72>>2]=d;x[e+24>>2]=d;x[e+8>>2]=d;x[e+68>>2]=f;x[e+64>>2]=x[e+124>>2];x[e+84>>2]=f;x[e+80>>2]=g+m;x[27524]=0;f=x[e+68>>2];x[e>>2]=x[e+64>>2];x[e+4>>2]=f;f=x[e+84>>2];x[e+16>>2]=x[e+80>>2];x[e+20>>2]=f;R(566,e+16|0,e|0);f=x[27524];x[27524]=0;if((f|0)==1){break m}}b=b-j|0;l=j+l|0;c=c+d|0;d=MU(i);continue}}break m}c=P()|0;break l}c=P()|0;Rc(e+144|0)}yb(h);S(c|0);p()}LU(i)}Rc(e+144|0);yb(h);a=(i|0)!=0}ib=e+192|0;return a|0}function _ma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;e=ib-976|0;ib=e;yc(b);d=ib-16|0;ib=d;h=e+872|0;NW(d+8|0,h);f=x[d+12>>2];kc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);g=x[d+4>>2];if((g|0)==(f|0)){Yb(b,x[d+12>>2])}ib=d+16|0;d=(f|0)==(g|0);if(!d){MW(h)}a:{if(!d){break a}if(!PW(e+872|0)){break a}if(!Ob(x[b>>2],x[b+8>>2],Ec(OW(y[e+919|0]|y[e+920|0]<<8),kb))){break a}if(!c){l=1;break a}zd(a,512);x[a+480228>>2]=32;w[a+480188>>1]=16;x[a+480196>>2]=y[e+947|0];x[a+480208>>2]=16;x[a+480200>>2]=256;x[a+480204>>2]=8e5;Lb(a+1074312|0,7,1);d=e+96|0;f=xc(d,8172);Gb(a+1298344|0,f);xb(f);f=xc(d,8860);Gb(a+1298356|0,f);xb(f);x[a+1298404>>2]=4;f=e+16|0;LW(f,e+872|4);Fc(d,f);Ac(a+1298308|0,d);wb(d);d=0;while(1){if((d|0)==16){b:{d=z[e+968>>1];if(d){iC(a+1298332|0,b,d,132,0)}d=ib-16|0;ib=d;h=e+96|0;cc(d+8|0,h,771);f=x[d+12>>2];kc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);g=x[d+4>>2];if((g|0)==(f|0)){Yb(b,x[d+12>>2])}ib=d+16|0;l=(f|0)==(g|0);if(!l){Rb(h,0,771)}if(!l){break a}d=a+484360|0;f=a+484376|0;KW(Tb(x[d>>2],y[f|0]),e+96|0,y[e+353|0]);_e(Tb(x[d>>2],y[f|0]),y[e+354|0]);bd(b,y[e+919|0]|y[e+920|0]<<8);o=a+484344|0;q=c&1;h=0;while(1){c:{if((h|0)==256){if(!(c&2)){break a}UX(b,e- -64|0);d=0;while(1){if((d|0)==64){break a}if(!(y[e- -64+(d>>>3)|0]>>>(d&7)&1)){d=d+1|0;continue}if(!RB(b,e+16|0)){break a}d=d+1|0;w[a+480190>>1]=d;Se(e,1,e+16|0);h=e+72|0;Fc(h,e);Cc(((z[a+480190>>1]<<5)+a|0)+946304|0,h);wb(h);c=(D(d,104)+a|0)+484380|0;md(c,0);i=y[e+48|0]|y[e+49|0]<<8|(y[e+50|0]<<16|y[e+51|0]<<24);x[c>>2]=i;f=y[e+54|0]|y[e+55|0]<<8|(y[e+56|0]<<16|y[e+57|0]<<24);x[c+4>>2]=f;g=y[e+58|0]|y[e+59|0]<<8|(y[e+60|0]<<16|y[e+61|0]<<24);x[c+24>>2]=16726;x[c+8>>2]=g;w[c+30>>1]=y[e+53|0]<<4;if(v[e+62|0]&1){g=g>>>1|0;x[c+8>>2]=g;f=f>>>1|0;x[c+4>>2]=f;x[c>>2]=i>>>1}if(!(!(y[e+63|0]&8)|f>>>0>=g>>>0)){w[c+34>>1]=z[c+34>>1]|2}Zc(h,v[e+62|0]&1?16:8,1,0,0);Eg(h,c,b);continue}}d:{d=(h<<1)+e|0;g=y[d+355|0]|y[d+356|0]<<8;if(g){f=e+72|0;ae(f,b,g);i=hc(e+16|0,f);yb(f);n=((y[d+355|0]|y[d+356|0]<<8)-2|0)/64|0;e:{if(!q){break e}x[27524]=0;d=W(230,o|0,h&65535,n|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break d}if(!d){break e}x[27524]=0;d=T(210,i|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break b}x[27524]=0;Q(192,i|0,1)|0;f=x[27524];x[27524]=0;if((f|0)==1){break b}r=d?d>>>0>=n-2>>>0?-1:d+1|0:-1;f=0;f:while(1){g:{d=Xb(x[o>>2],h);if((f|0)==(n|0)){break g}m=0;s=qf(x[d>>2],x[x[d+48>>2]+12>>2],f);while(1){if((m|0)==16){f=f+1|0;continue f}x[27524]=0;R(353,e+72|0,i|0);d=x[27524];x[27524]=0;if((d|0)==1){break c}d=D(m,6)+s|0;j=e+72|0;g=Ze(j);j=Si(j);k=y[e+72|0];if((k-1&255)>>>0<=71){v[d|0]=k+36;t=d,u=y[Lc(e+72|0)|0]+1|0,v[t+1|0]=u}if((y[g|0]-1&255)>>>0<=15){v[d+2|0]=1;v[d+4|0]=((y[g|0]<<6)+-64>>>0)/15}k=y[j|0];g=k&15;v[d+5|0]=g;h:{i:{switch((y[j|0]>>>4|0)-1|0){case 0:case 1:v[d+5|0]=k|240;break h;case 2:v[d+5|0]=g<<2;break h;case 3:v[d+5|0]=(6/(g+1>>>0)|0)+1;break h;case 5:case 6:v[d+5|0]=g<<3;break h;case 9:v[d+4|0]=(g<<2)+4;v[d+2|0]=1;break h;case 10:v[d+5|0]=g|128;break h;case 11:break i;default:break h}}v[d+5|0]=(6/(g+1>>>0)|0)+1|13}v[d+3|0]=y[(y[j|0]>>>4|0)+26384|0];m=m+1|0;continue}}break}ue(d,Kh(Te(Me(e+72|0,14,0),r)))}yb(i)}h=h+1|0;continue}}break}}}else{f=(d<<5)+a|0;h=f+480280|0;lf(h);g=h;h=(e+872|0)+d|0;x[g>>2]=!y[h+50|0]<<10;w[f+480284>>1]=(y[h+76|0]<<4|8)&248;d=d+1|0;continue}break}a=P()|0;yb(i);S(a|0);p()}ib=e+976|0;return l|0}function Qea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,A=0,B=0,C=0,F=0,G=0,H=0,I=0,J=0;i=ib-32|0;ib=i;s=x[a+4>>2];e=We(x[a+8>>2],b);u=x[e>>2];a:{if(u+1>>>0<2){break a}j=(D(b,872)+s|0)+616|0;if(!(Gi(x[j+8>>2],x[j+12>>2])|y[e+4|0])){break a}h=D(b,872)+s|0;if(!x[h+720>>2]){break a}g=x[h+704>>2]&2;e=x[(g?h+700|0:h+692|0)>>2];k=x[h+700>>2];f=x[h+696>>2];Ab(i+8|0,x[a>>2]+1074312|0,31);w=zb(x[x[i+8>>2]>>2],x[i+12>>2]);m=rf(x[h+624>>2],x[h+628>>2],c);q=m;l=y[h+704|0]&128;m=l?0-m|0:m;n=kb;l=l?0-(n+((q|0)!=0)|0)|0:n;q=e;B=g?A:0;e=f;r=g?e:0;n=k-e|0;F=n<<1;G=h+1316|0;o=h+1467|0;C=h+1362|0;A=(y[C|0]&17)!=1;b:{c:{while(1){if((p|0)!=(u|0)){d:{if(d>>>0>p>>>0){f=(y[C|0]&17)==1;break d}x[x[a+4>>2]+16>>2]=p-d;v[o|0]=y[o|0]&254|(d|0)==(p|0);f=x[a>>2];k=x[a+4>>2];e=Xb(x[f+484344>>2],z[k+70>>1]);e=hd(x[e>>2],x[x[e+48>>2]+12>>2],x[k+48>>2],b);g=y[e+3|0];e:{f:{switch(y[e+2|0]-11|0){case 0:k=i+8|0;Fz(k,f,g,y[e+4|0],0);k=Ze(k);Dt(x[a>>2],x[a+4>>2],b,z[i+8>>1]);f=1;if(!y[k|0]){break e}break d;case 1:t=y[e+4|0];Ab(i+8|0,f+1074312|0,12);Az(f,k,b,t<<2&252,zb(x[x[i+8>>2]>>2],x[i+12>>2]));break e;case 2:break f;default:break e}}t=y[e+4|0];Ab(i+8|0,f+1074312|0,12);zz(f,k,b,t<<2&252,zb(x[x[i+8>>2]>>2],x[i+12>>2]))}f=1;g:{h:{i:{j:{k:{switch(g-2|0){default:if(g-38>>>0<4){break h}if((g|0)==19){break j}if((g|0)!=28){break g}e=y[e+5|0];f=e&240;if((f|0)==32){break i}if((f|0)!=16){break g}yz(x[a>>2],j,e&15);break g;case 2:Dt(x[a>>2],x[a+4>>2],b,y[e+5|0]);break g;case 4:Dt(x[a>>2],x[a+4>>2],b,0);break g;case 0:e=y[e+5|0];g=x[a>>2];if(!e&(v[g+480180|0]&1)){break d}Az(g,x[a+4>>2],b,e,0);break g;case 1:break k;case 3:break d}}e=y[e+5|0];g=x[a>>2];if(!e&(v[g+480180|0]&1)){break d}zz(g,x[a+4>>2],b,e,0);break g}f=y[e+5|0];e=f&15;if(!(e|x[x[a>>2]+480180>>2]&1048580)){break g}f=f&240;if((f|0)!=32){if((f|0)!=16){break g}xz(x[a>>2],j,e);break g}wz(x[a>>2],j,e);break g}vz(x[a>>2],j,e&15);break g}VP(x[a>>2],j,y[e+5|0],(g|0)==38|(g|0)==40,(g&254)==40)}f=1}x[i+28>>2]=x[G>>2];if(w){Ct(x[a>>2],j)}if(!A){UP(x[a>>2],j,i+28|0);f=1}if(!w){Ct(x[a>>2],j)}x[i+24>>2]=0;TP(j,i+24|0);l:{if(y[h+705|0]&2){break l}m:{if(!f){if(!y[We(x[a+8>>2],b)+4|0]){break m}}if(y[o|0]&96){WR(j,E(1),0,x[a>>2]);e=y[o|0];v[o|0]=(e&64?-65:-33)&e}Hz(i+8|0,x[a>>2],j,x[i+28>>2],0);e=x[i+12>>2];x[h+624>>2]=x[i+8>>2];x[h+628>>2]=e;I=We(x[a+8>>2],b),J=0,v[I+4|0]=J;e=rf(x[h+624>>2],x[h+628>>2],c);f=y[h+704|0]&128;m=f?0-e|0:e;g=kb;l=f?0-(g+((e|0)!=0)|0)|0:g}Pb(j,m,l);k=x[j>>2];e=x[j+4>>2];if((k>>>0<H>>>0&(e|0)<=(q|0)|(e|0)<(q|0))&((e|0)>=(r|0)&k>>>0>=B>>>0|(e|0)>(r|0)|((l|0)>0|(l|0)>=0))){break l}g=x[h+704>>2];if(!(g&2)){break c}if(g&4){f=x[h+696>>2];if(k>>>0<B>>>0&(e|0)<=(r|0)|(e|0)<(r|0)){I=j,J=$g(0,f<<1,k,e),x[I>>2]=J;e=kb;x[j+4>>2]=e;x[h+704>>2]=g^128;g=m;m=0-g|0;l=0-(((g|0)!=0)+l|0)|0}Ab(i+8|0,x[a>>2]+1074312|0,33);e=(e-f>>>0)%(F-zb(x[x[i+8>>2]>>2],x[i+12>>2])>>>0)|0;n:{if(e>>>0<n>>>0){f=e+x[h+696>>2]|0;break n}f=x[h+700>>2]+(n-e|0)|0}x[j+4>>2]=f;f=x[h+704>>2];if((f&128)>>>7^e>>>0<n>>>0){break l}x[h+704>>2]=f^128;e=m;m=0-e|0;l=0-(((e|0)!=0)+l|0)|0;break l}f=e;g=x[h+700>>2];if(e>>>0>=g+n>>>0){f=g+((f-g>>>0)%(n>>>0)|0)|0}while(1){e=f;f=e-n|0;if(e>>>0>=g>>>0){continue}break}x[j>>2]=k;x[j+4>>2]=e}p=p+1|0;continue}break}x[x[a+4>>2]+16>>2]=0;break b}x[x[a+4>>2]+16>>2]=0;YR(j);x[(D(b,872)+s|0)+1324>>2]=0}I=We(x[a+8>>2],b),J=0,x[I>>2]=J}ib=i+32|0}function QY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=ib-576|0;ib=e;yc(b);d=ib-16|0;ib=d;f=e+72|0;rD(d+8|0,f);g=x[d+12>>2];kc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);j=x[d+4>>2];if((j|0)==(g|0)){Yb(b,x[d+12>>2])}ib=d+16|0;d=(g|0)==(j|0);if(!d){qD(f)}a:{if(!d){break a}if(!tD(e+72|0)){break a}b:{if(!c){break b}if(!Ob(x[b>>2],x[b+8>>2],Ec(sD(y[e+182|0],y[e+183|0]),kb))){break a}zd(a,64);x[a+480204>>2]=78e4;x[a+480260>>2]=112;x[a+480264>>2]=13696;x[a+480196>>2]=4;w[a+480188>>1]=8;Lb(a+1074312|0,7,1);d=e+40|0;g=xc(d,14657);Gb(a+1298344|0,g);xb(g);d=xc(d,14690);Gb(a+1298356|0,d);xb(d);Vl(a+1298368|0,Qb(e+72|0,11062,2)?14685:14657);x[a+1298404>>2]=4;f=y[e+182|0];w[a+480190>>1]=f;g=1;while(1){j=g&65535;if(j>>>0<=f>>>0){f=ib-16|0;ib=f;d=e+40|0;cc(f+8|0,d,25);l=x[f+12>>2];kc(f,x[b>>2],x[b+8>>2],x[f+8>>2],x[f+12>>2]);i=x[f+4>>2];if((i|0)==(l|0)){Yb(b,x[f+12>>2])}ib=f+16|0;if((i|0)!=(l|0)){v[d|0]=0;v[d+1|0]=0;v[d+2|0]=0;v[d+3|0]=0;v[d+4|0]=0;v[d+5|0]=0;v[d+6|0]=0;v[d+7|0]=0;v[d+24|0]=0;v[d+16|0]=0;v[d+17|0]=0;v[d+18|0]=0;v[d+19|0]=0;v[d+20|0]=0;v[d+21|0]=0;v[d+22|0]=0;v[d+23|0]=0;v[d+8|0]=0;v[d+9|0]=0;v[d+10|0]=0;v[d+11|0]=0;v[d+12|0]=0;v[d+13|0]=0;v[d+14|0]=0;v[d+15|0]=0}if((y[e+53|0]|y[e+54|0]<<8|(y[e+55|0]<<16|y[e+56|0]<<24))>>>0>67108863){break a}f=(D(j,104)+a|0)+484380|0;md(f,0);x[f+24>>2]=8363;l=e+40|0;d=l;i=y[d+13|0]|y[d+14|0]<<8|(y[d+15|0]<<16|y[d+16|0]<<24);x[f>>2]=i;k=y[d+17|0]|y[d+18|0]<<8|(y[d+19|0]<<16|y[d+20|0]<<24);x[f+4>>2]=k;d=y[d+21|0]|y[d+22|0]<<8|(y[d+23|0]<<16|y[d+24|0]<<24);d=d>>>0>i>>>0?k?d:0:d;x[f+8>>2]=d;if(d){w[f+34>>1]=2;Jk(f)}f=e+8|0;di(f,2,l);d=e+24|0;Fc(d,f);Cc(((j<<5)+a|0)+946304|0,d);g=g+1|0;wb(d);f=z[a+480190>>1];continue}break}g=e+24|0;h=e+72|2;ig(g,3,h,36);d=e+40|0;Fc(d,g);Ac(a+1298308|0,d);wb(d);g=0;pD(a+1298332|0,h,108,36,0);d=a+484360|0;h=a+484376|0;Bv(Tb(x[d>>2],y[h|0]),e+185|0,128);d=Tb(x[d>>2],y[h|0]);h=y[e+184|0];if(z[bc(x[d>>2],h)>>1]<y[e+183|0]){_e(d,h)}while(1)if((g|0)==8){j=a+484344|0;Fg(j,y[e+183|0]);n=c&1;f=0;while(1)if(y[e+183|0]<=f>>>0){h=1;if(!(c&2)){break a}c=Zc(e+40|0,8,1,0,1);g=1;while(1){d=g&65535;if(d>>>0>z[a+480190>>1]){break b}Eg(c,(D(d,104)+a|0)+484380|0,b);g=g+1|0;continue}}else{c:{d:{if(n){if(vh(j,f&65535,64)){break d}}Yb(b,1536);break c}x[e+24>>2]=-1;x[e+28>>2]=-1;l=0;e:while(1){if((l|0)==64){d=(e+72|0)+f|0;g=y[d+369|0];if(g>>>0<63){ue(Xb(x[j>>2],f),Kh(Te(Me(e+40|0,14,0),g)))}ue(Xb(x[j>>2],f),Kh(Me(e+40|0,16,y[d+241|0])));break c}g=0;d=Xb(x[j>>2],f);h=qf(x[d>>2],x[x[d+48>>2]+12>>2],l);while(1){if((g|0)==8){l=l+1|0;continue e}d=e+40|0;fr(d,b);i=Lc(d);k=Ze(d);i=y[i|0];d=y[e+40|0];if(d>>>0<=253){v[h|0]=(d>>>2|0)+37;v[h+1|0]=(d<<4&48|i>>>4)+1;v[(e+24|0)+g|0]=255;d=y[e+40|0]}if((d&255)!=255){v[h+2|0]=1;v[h+4|0]=(((i&15)<<6|8)>>>0)/15}d=y[k|0];if((d|0)!=255){v[(e+24|0)+g|0]=d}i=(e+24|0)+g|0;f:{g:{if(!(d&15)&(d|0)!=48){break g}k=y[i|0];if((k|0)==255){break f}m=k<<24>>24;d=m&15;v[h+5|0]=d;h:{if((m|0)<0){break h}k=k>>>4|0;v[h+3|0]=y[k+26168|0];i:{switch(k-3|0){case 0:v[h+5|0]=d|32;break g;case 1:v[h+5|0]=d|m<<4;break f;case 2:break g;case 3:break i;default:break f}}j:{switch(d|0){case 0:v[h+5|0]=79;break f;case 1:break j;default:break h}}v[h+5|0]=244;break f}v[h+3|0]=0;break f}v[i|0]=255}h=h+6|0;g=g+1|0;continue}}}f=f+1|0;continue}}else{d=(g<<5)+a|0;lf(d+480280|0);w[d+480284>>1]=g&1?208:48;g=g+1|0;continue}}h=1}ib=e+576|0;return h|0}function yna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;e=ib-336|0;ib=e;yc(b);a:{if(!yo(b,e+320|0)){break a}if(!eX(e+320|0)){break a}if(!Qb(e+320|0,14162,4)){Yb(b,4)}if(!ii(b,e+312|0)){break a}if(Qb(e+312|0,14138,4)){break a}if(!c){l=1;break a}yC(b,e+120|0,x[e+316>>2]);if(z[e+156>>1]>128|z[e+162>>1]>16|(z[e+160>>1]>256|z[e+154>>1]>128)){break a}zd(a,8192);d=e+32|0;f=xc(d,6542);Gb(a+1298344|0,f);xb(f);f=xc(d,10079);Gb(a+1298356|0,f);xb(f);x[a+1298404>>2]=4;f=e+96|0;Pi(f,2,e+120|0);Fc(d,f);Ac(a+1298308|0,d);wb(d);w[e+32>>1]=z[e+162>>1];w[e+96>>1]=1;h=z[pe(d,f)>>1];w[a+480188>>1]=h;x[a+480196>>2]=y[e+166|0];x[a+480204>>2]=D(y[e+167|0],1e4);v[e+32|0]=y[e+164|0];v[e+96|0]=64;d=y[Ub(d,f)|0];x[a+480200>>2]=d<<2;if(!d){x[a+480200>>2]=256}d=y[e+165|0];b:{if((d|0)==128){x[e+32>>2]=256/(h>>>0);x[e+96>>2]=128;d=x[Hb(e+32|0,e+96|0)>>2];break b}d=d&127}x[a+480228>>2]=d;d=0;while(1){if((d|0)==16){d=a+484376|0;Bv(Tb(x[a+484360>>2],y[d|0]),e+184|0,z[e+156>>1]);f=z[e+154>>1];if(f>>>0<z[e+156>>1]){_e(Tb(x[a+484360>>2],y[d|0]),f)}o=c&2;m=a+484344|0;l=1;q=c&1;r=e+68|0;k=a+480190|0;s=a+480188|0;while(1){if(!ii(b,e+312|0)){break a}d=e+32|0;ae(d,b,x[e+316>>2]);c=hc(e+96|0,d);yb(d);c:{d:{if(!(Qb(e+312|0,13534,4)|!q)){x[27524]=0;i=n&65535;d=W(230,m|0,i|0,64)|0;f=x[27524];x[27524]=0;if((f|0)==1){break d}if(!d){break c}x[27524]=0;Q(192,c|0,2)|0;d=x[27524];x[27524]=0;if((d|0)==1){break d}Jj(e+32|0);h=0;e:{while(1){d=x[c>>2];x[27524]=0;d=W(160,d|0,x[e+104>>2],1)|0;f=x[27524];x[27524]=0;f:{if((f|0)!=1){if(!(d&h>>>0<64)){break e}x[27524]=0;d=T(210,c|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break d}g=d<<24>>24;if(g){break f}h=h+1|0;continue}break d}f=e+32|0;d=g&15;if(d>>>0<z[s>>1]){f=Xb(x[m>>2],i);f=hd(x[f>>2],x[x[f+48>>2]+12>>2],h,d)}g:{if((g|0)>=0){break g}x[27524]=0;d=T(210,c|0)|0;j=x[27524];x[27524]=0;if((j|0)==1){break d}if(!d){break g}v[f|0]=d>>>0<109?d+12|0:d}d=g&255;if(d&64){x[27524]=0;g=T(210,c|0)|0;j=x[27524];x[27524]=0;if((j|0)==1){break d}v[f+1|0]=g}if(d&32){v[f+2|0]=1;x[27524]=0;g=T(210,c|0)|0;j=x[27524];x[27524]=0;if((j|0)==1){break d}v[e+16|0]=g;v[e|0]=64;t=f,u=y[Ub(e+16|0,e)|0],v[t+4|0]=u}if(!(d&16)){continue}x[27524]=0;R(264,e+16|0,c|0);d=x[27524];x[27524]=0;if((d|0)!=1){g=Lc(e+16|0);h:{i:{j:{k:{l:{d=y[e+16|0];switch(d-17|0){case 2:break k;case 0:case 1:break l;default:break j}}d=d&15;break i}v[e+16|0]=33;v[g|0]=145;d=y[e+16|0];break h}if(d>>>0<17){break h}d=(d&240)==32?9:-1}v[e+16|0]=d}Xf(f,d&255,y[g|0]);continue}break}break d}n=n+1|0;break c}if(Qb(e+312|0,13539,4)){break c}d=z[k>>1];if(!bi(d)){break c}d=d+1|0;w[k>>1]=d;x[27524]=0;R(323,c|0,e+32|0);f=x[27524];x[27524]=0;m:{if((f|0)==1){break m}x[27524]=0;g=(D(d&65535,104)+a|0)+484380|0;R(324,e+32|0,g|0);d=x[27524];x[27524]=0;if((d|0)==1){break m}Pi(e,2,r);x[27524]=0;R(226,e+16|0,e|0);d=x[27524];x[27524]=0;if((d|0)==1){break m}d=e+16|0;Cc(((z[k>>1]<<5)+a|0)+946304|0,d);wb(d);if(!o){break c}d=y[e+45|0]|y[e+46|0]<<8;f=2;i=e+16|0;h=Zc(i,8,1,0,1);n:{if(!(d&64)){f=0;if(!(d&2)){break n}}jg(h,f)}if(d&4){ne(h,16)}x[27524]=0;W(223,i|0,g|0,c|0)|0;d=x[27524];x[27524]=0;if((d|0)!=1){break c}}}a=P()|0;yb(c);S(a|0);p()}yb(c);continue}}f=(d<<5)+a|0;lf(f+480280|0);h=y[(d+e|0)+168|0];if(h>>>0<=128){w[f+480284>>1]=h<<1}d=d+1|0;continue}}ib=e+336|0;return l|0}function eo(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0;f=ib-96|0;ib=f;r=Uz(x[a+24>>2],y[a+32|0]);t=xj(r);c=t;e=x[a>>2];d=wd(e,x[a+4>>2]);a:{if(c>>>0>d>>>0){i=ib-32|0;ib=i;c=c-d|0;d=x[Db(a)>>2];e=x[a+4>>2];b:{if(c>>>0<=(d-e|0)/12>>>0){e=ib-16|0;ib=e;c=hu(e,a,c);d=x[c+4>>2];h=x[c+8>>2];while(1){if((d|0)==(h|0)){ic(c);ib=e+16|0}else{LQ(d);d=d+12|0;x[c+4>>2]=d;continue}break}break b}d=Db(a);d=Pk(i+8|0,on(a,wd(x[a>>2],e)+c|0),wd(x[a>>2],x[a+4>>2]),d);h=ib-16|0;ib=h;e=TS(h,d+8|0,c);c=x[e>>2];while(1){if(x[e+4>>2]!=(c|0)){LQ(c);c=x[e>>2]+12|0;x[e>>2]=c;continue}break}Vd(e);ib=h+16|0;h=x[a>>2];c=x[a+4>>2];e=d+4|0;while(1){if((c|0)!=(h|0)){c=c-12|0;EA(x[e>>2]-12|0,c);x[e>>2]=x[e>>2]-12;continue}break}oc(a,e);oc(a+4|0,d+8|0);oc(Db(a),zc(d));x[d>>2]=x[d+4>>2];c=x[d+4>>2];while(1){e=x[d+8>>2];if((e|0)!=(c|0)){e=e-12|0;x[d+8>>2]=e;$e(e);continue}break}c=x[d>>2];if(c){ep(d);Ib(c)}}ib=i+32|0;break a}if(d>>>0>c>>>0){RQ(a,e+D(c,12)|0)}}if(b){c=a+12|0;gq(c,Td(c));A=Db(c),B=0,x[A>>2]=B;d=c;c=gc(c);x[d>>2]=c;x[c>>2]=0;x[a+28>>2]=0}i=Nb(f+80|0);c=x[a+24>>2];c=Mt(x[c+484344>>2],x[c+484348>>2]);x[27524]=0;h=W(610,f- -64|0,c|0,30236)|0;c=x[27524];x[27524]=0;c:{if((c|0)!=1){e=a+12|0;d:{while(1){if((k|0)==(t|0)){jd(h);ec(i);ib=f+96|0;return}c=x[a+24>>2];m=z[bc(x[r>>2],k)>>1];d=XQ(c,m);x[f+60>>2]=d;c=Cd(x[a>>2],k);e:{f:{if(b){x[27524]=0;v[f+40|0]=0;U(772,c|0,d|0,f+40|0);d=x[27524];x[27524]=0;if((d|0)!=1){break f}d=P()|0;break d}x[27524]=0;R(732,c|0,d|0);d=x[27524];x[27524]=0;if((d|0)==1){break e}}x[27524]=0;d=Q(315,r|0,k&65535)|0;g=x[27524];x[27524]=0;if((g|0)==1){break e}g:{if(!d){break g}x[f+40>>2]=b?0:x[c+4>>2];s=x[Hb(f+40|0,f+60|0)>>2];o=Gf(e);c=z[bc(x[h>>2],m)>>1];if((c|0)!=65535){d=VQ(e,z[Bm(f+40|0,c,s)>>1],x[f+44>>2]);h:{if(Rg(d,Gf(e))){c=VQ(e,z[Bm(f+40|0,z[bc(x[h>>2],m)>>1],x[f+60>>2])>>1],x[f+44>>2]);break h}c=Gf(e)}x[f+56>>2]=d;while(1){i:{if(!Rg(d,c)){break g}g=Nb(f+40|0);d=mn(ud(d)+8|0);x[27524]=0;R(773,g|0,d|0);d=x[27524];x[27524]=0;if((d|0)!=1){d=vk(f+24|0,o);j=Bm(f+16|0,k,x[ud(x[f+56>>2])+4>>2]);d=x[d>>2];x[27524]=0;d=fa(774,e|0,d|0,j|0,g|0)|0;j=x[27524];x[27524]=0;if((j|0)==1){break i}x[f+32>>2]=d;o=x[Ug(f+32|0)>>2];we(g);d=x[Ug(f+56|0)>>2];continue}}break}d=P()|0;we(g);break d}q=Xb(x[x[a+24>>2]+484344>>2],m);c=Cg(x[x[q+48>>2]+12>>2]);x[27524]=0;v[f+40|0]=0;U(755,i|0,c|0,f+40|0);c=x[27524];x[27524]=0;if((c|0)!=1){n=x[f+60>>2];j:while(1){k:{if((n|0)==(s|0)){if(s){break g}A=bc(x[h>>2],m),B=k,w[A>>1]=B;break g}g=1;j=0;c=x[x[q+48>>2]+12>>2];n=n-1|0;d=qf(x[q>>2],c,n);while(1){if(g>>>0<16&Cg(c)>>>0>j>>>0){u=Jb(x[i>>2],j);c=y[u|0];l:{m:{n:{switch(y[d+3|0]-19|0){case 1:l=y[d+5|0];if((l&240)==176){break m}break l;case 0:break n;default:break l}}l=y[d+5|0];if((l&240)!=96){break l}}v[u|0]=l&15;l=y[Jb(x[i>>2],j)|0];c=l?l:c}c=c&255;g=D(c?c+1|0:1,g);d=d+6|0;j=j+1|0;c=x[x[q+48>>2]+12>>2];continue}else{o:{if(g>>>0<=1){continue j}c=Nb(f+40|0);x[27524]=0;R(773,c|0,g|0);d=x[27524];x[27524]=0;if((d|0)==1){break o}d=vk(f+8|0,o);g=Bm(f+16|0,k,n);d=x[d>>2];x[27524]=0;o=fa(774,e|0,d|0,g|0,c|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break k}we(c);continue j}}break}}break}d=P()|0;we(c);break d}d=P()|0;break d}k=k+1|0;continue}break}d=P()|0}jd(h);break c}d=P()|0}ec(i);S(d|0);p()}function kz(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,B=0,C=0,E=0;f=ib-16|0;ib=f;k=D(b,872)+a|0;m=k+1075800|0;i=y[m|0];l=a+1074312|0;Ab(f+8|0,l,23);h=c&15;a:{b:{c:{d:{e:{f:{g:{h:{i:{if(zb(x[x[f+8>>2]>>2],x[f+12>>2])){if(!(x[a+1074392>>2]|!y[(D(b,872)+a|0)+1075780|0])){v[m|0]=h;break i}e=y[m|0];if(e){g=e-1|0;v[m|0]=g;e=0;if(g&255){break c}}v[m|0]=h;e=1;break c}Ab(f+8|0,l,52);g=c&256;if(!(!g|!zb(x[x[f+8>>2]>>2],x[f+12>>2]))){g=x[a+480208>>2]&4096;if(!g){break e}e=D(b,872)+a|0;if(y[e+1075781|0]){i=VV(y[e+1075780|0])?1:i}if(y[(D(b,872)+a|0)+1075784|0]?y[e+1075782|0]==1:0){break b}e=0;if(h>>>0>i>>>0){break c}if(!g){break d}if(Wc(y[(D(b,872)+a|0)+1075780|0])){break c}break d}j=x[a+480180>>2];if(j&16777250){e=!(i?(i>>>0)%((h?h:1)>>>0)|0:1);i=i+1|0;break c}if((j|0)==16){break g}if((j|0)!=1){break f}e=A[a+1074392>>2]%A[a+1074416>>2]|0;if(!e){if(Wc(y[(D(b,872)+a|0)+1075780|0])){break a}}if(h){break h}}e=0;break c}e=!((e>>>0)%(h>>>0)|0);break c}e=x[a+1074392>>2]==(h|0)&(h|0)!=0;break c}j:{if(!g){break j}e=D(b,872)+a|0;if(y[e+1075782|0]!=1){break j}h=(y[e+1075785|0]>15)+h|0}k:{if(x[a+480208>>2]&4096?g:1){h=h?h:1;e=0;e=!x[a+1074416>>2]|g?e:!(A[a+1074392>>2]%(h>>>0)|0);i=i+1|0;break k}e=0;i=j&1048580?0:i}if(!(!(y[(D(b,872)+a|0)+1075780|0]|!g?x[a+1074392>>2]:1)|(i&255)>>>0<h>>>0)){e=1}Ab(f+8|0,l,52);if(!zb(x[x[f+8>>2]>>2],x[f+12>>2])|c){break c}e=!x[a+1074392>>2];break c}if(h>>>0>i>>>0){break c}}i=0;e=1}h=k+1074992|0;n=(D(b,872)+a|0)+1075068|0;l:{if(x[n>>2]){break l}Ab(f+8|0,l,38);if(!zb(x[x[f+8>>2]>>2],x[f+12>>2])){break l}if(!uj(x[h+656>>2])){break a}}Ab(f+8|0,l,106);if(B=0,C=zb(x[x[f+8>>2]>>2],x[f+12>>2]),E=x[(D(b,872)+a|0)+1075688>>2],E?B:C){break a}if(e){j=D(b,872)+a|0;q=j+1075680|0;g=x[q>>2];x[f+4>>2]=g;e=c>>>4&15;m:{if(!e){e=x[j+1075080>>2];break m}Ab(f+8|0,l,52);n:{if(B=zb(x[x[f+8>>2]>>2],x[f+12>>2]),C=0,E=y[(D(b,872)+a|0)+1075782|0]==1,E?B:C){break n}if(!(16191>>>e&1)){x[f+4>>2]=(D(g,v[e+33712|0])|0)/16;break n}x[f+4>>2]=g+(v[e+33728|0]<<2)}re(f+4|0,0,256);g=(D(b,872)+a|0)+1075080|0;e=x[g>>2]|2097152;x[g>>2]=e}k=D(b,872)+a|0;r=k+1075692|0;s=x[r>>2];g=y[k+1075794|0];j=0;if(e&512){Ab(f+8|0,l,108);j=zb(x[x[f+8>>2]>>2],x[f+12>>2])}if(!((j^-1)&x[a+480180>>2]==2|(!x[n>>2]|(g-1&255)>>>0>119))){BP(a,b,0,g,1)}k=k+1075080|0;o:{if(!(x[a+480180>>2]&1048580)){break o}t=(c|0)<256;if((c|0)>255){break o}e=y[(D(b,872)+a|0)+1075781|0];if(!e){break o}t=1;cq(a,h,e,0,0,1)}o=D(b,872)+a|0;p=o+1075652|0;u=x[p>>2];w=x[k>>2];x[p>>2]=0;Ab(f+8|0,l,23);e=1;p:{if(zb(x[x[f+8>>2]>>2],x[f+12>>2])){break p}e=0;if(x[a+480180>>2]!=2){break p}e=(j^1)&x[n>>2]!=0}Gt(a,h,g,e,t,0,b);if(!y[o+1075781|0]){x[p>>2]=u}if(!(!(w&4096)|x[a+480180>>2]!=4)){x[k>>2]=x[k>>2]|4096}j=o+1075780|0;x[q>>2]=x[f+4>>2];if(z[a+480192>>1]){v[j|0]=g;zP(a,b)}g=x[a+480180>>2];if(!(!(g&16777248)|(y[j|0]|!s))){x[r>>2]=s}if(e){x[h>>2]=0;x[h+4>>2]=0}e=g&16777250;q:{if(d-11>>>0<4294967286){break q}g=x[(D(b,872)+a|0)+1075096>>2];if(!g){break q}r:{if((d|0)==1){b=x[(D(b,872)+a|0)+1075656>>2];break r}j=(D(b,872)+a|0)+1075656|0;b=x[Bb(g+68|0,d-2|0)>>2];x[j>>2]=b}bo(a,h,b)}i=e?i:0}a=f+8|0;Ab(a,l,52);b=x[x[f+8>>2]>>2];d=x[f+12>>2];Ab(a,l,23);if(zb(x[x[f+8>>2]>>2],x[f+12>>2])){break a}i=(zb(b,d)&c>>>8)+i|0}v[m|0]=i}ib=f+16|0}function Mia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;e=ib-192|0;ib=e;yc(b);a:{if(!RB(b,e+144|0)){break a}if(!jT(e+144|0)){break a}if(!Ob(x[b>>2],x[b+8>>2],Ec(iT(y[e+175|0],y[e+177|0]),kb))){break a}b:{if(!c){break b}zd(a,256);g=e+32|0;Hj(g,2,e+144|0);d=e- -64|0;Fc(d,g);Ac(a+1298308|0,d);wb(d);f=xc(d,15322);Gb(a+1298344|0,f);xb(f);d=xc(d,10058);Gb(a+1298356|0,d);xb(d);_f(g,4274);x[27524]=0;R(253,e+128|0,e+175|0);d=x[27524];x[27524]=0;c:{d:{if((d|0)!=1){x[27524]=0;X(678,e- -64|0,e+32|0,e+174|0,e+128|0);d=x[27524];x[27524]=0;if((d|0)!=1){d=e- -64|0;Gb(a+1298368|0,d);xb(d);xb(e+128|0);$b(e+32|0);x[a+1298404>>2]=4;d=Lb(a+1074312|0,107,1);x[a+480260>>2]=64;x[a+480264>>2]=32767;x[a+480188>>2]=2031620;Lb(d,107,1);f=y[e+176|0];d=y[e+175|0];if(d>>>0<=20){g=((f&255)>>>0)/10|0;f=g<<4|D(g,-10)+f}g=(f&255?f:96)&255;f=CA(g);x[a+480196>>2]=g>>>4;x[a+480204>>2]=f;f=0;if(d>>>0>=11){v[e+64|0]=64;o=a,q=y[Ub(e+178|0,e- -64|0)|0]<<2,x[o+480200>>2]=q}while(1)if((f|0)==4){f=1;while(1){if((f|0)!=32){pu(b,e+32|0);d=y[e+44|0];if(d?(d|0)!=46:0){break c}h=ib-32|0;ib=h;d=(D(f,104)+a|0)+484380|0;md(d,0);k=e+32|0;g=k;Bk(h,2,g);i=h+16|0;Fc(i,h);Fe(d+43|0,i);wb(i);x[d+24>>2]=y[g+24|0]|y[g+25|0]<<8;v[h+16|0]=y[g+22|0];v[h|0]=64;o=d,q=y[Ub(i,h)|0]<<2,w[o+30>>1]=q;i=y[g+16|0]|y[g+17|0]<<8;x[d>>2]=i;j=y[g+18|0]|y[g+19|0]<<8;x[d+4>>2]=j;g=y[g+20|0]|y[g+21|0]<<8;x[d+8>>2]=g;e:{if(i>>>0<=1){x[d>>2]=0;break e}if((g|0)==65535|i>>>0<=j>>>0|g>>>0<=j>>>0){break e}w[d+34>>1]=2;o=d,q=x[Hb(d+8|0,d)>>2],x[o+8>>2]=q}ib=h+32|0;g=e+16|0;Bk(g,2,k);d=e+128|0;Fc(d,g);Cc(((f<<5)+a|0)+946304|0,d);wb(d);w[((f<<1)+e|0)+62>>1]=z[e+46>>1];f=f+1|0;continue}break}d=a+484360|0;g=a+484376|0;wo(Tb(x[d>>2],y[g|0]),b,y[e+175|0]?128:64,65535,65535);f=0;if(!gT(Tb(x[d>>2],y[g|0]))){break a}m=c&1;if(m){Fg(a+484344|0,y[e+177|0])}i=a+484344|0;while(1)if(y[e+177|0]<=l>>>0){f=1;if(!(c&2)){break a}c=Zc(e+32|0,8,1,0,0);while(1){if((f|0)==32){break b}d=D(f,104)+a|0;g=d+484380|0;f:{if(!x[g>>2]|!z[d+484410>>1]){break f}d=z[((f<<1)+e|0)+62>>1];if(d>>>0<4){break f}if(!bd(b,d<<4)){break f}Eg(c,g,b)}f=f+1|0;continue}}else{f=0;g:{h:{if(m){if(vh(i,l&65535,64)){break h}}while(1){if((f|0)==256){break g}if((Re(b)+2&255)>>>0<=252){Yb(b,3)}f=f+1|0;continue}}o=e,q=Cb(x[Xb(x[i>>2],l)>>2]),x[o+128>>2]=q;w[e+14>>1]=65535;x[e+16>>2]=63;h=0;i:while(1){f=0;if((h|0)==64){d=z[e+14>>1];if((d|0)==65535){break g}ue(Xb(x[i>>2],l),Pm(Te(Me(e+32|0,12,d&255),x[e+16>>2])));break g}while(1){j:{k:{l:{if((f&65535)>>>0<=3){d=0;j=0;k=0;n=0;m:{n:{o:{p:{g=Re(b);switch(g-251|0){case 1:break j;case 0:break n;case 2:break p;default:break o}}v[x[e+128>>2]]=254;break j}d=e+32|0;fr(d,b);j=y[Jb(d,0)|0];k=y[Jb(d,1)|0];n=y[Jb(d,2)|0];d=254;if((g|0)==254){break m}if(g>>>0>=96){break l}d=g}d=(D(d>>>4|0,12)+(d&15)|0)+37|0}g=d;d=x[e+128>>2];v[d|0]=g;break k}h=h+1|0;continue i}d=x[e+128>>2]}v[d+1|0]=(j&248)>>>3;g=k>>>1&120|j&7;if(g>>>0<=64){v[d+4|0]=g;v[d+2|0]=1}v[d+5|0]=n;fT(d,k&15,h,y[e+175|0],e+14|0,e+16|0)}f=f+1|0;MA(e+128|0);continue}}}l=l+1|0;continue}}else{d=(f<<5)+a|0;lf(d+480280|0);w[d+480284>>1]=f&1?64:192;f=f+1|0;continue}}f=P()|0;xb(e+128|0);break d}f=P()|0}$b(e+32|0);S(f|0);p()}f=0;break a}f=1}ib=e+192|0;return f|0}function rP(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;j=ib-48|0;ib=j;l=ib-16|0;ib=l;x[l>>2]=b;x[l+4>>2]=c;f=ib-16|0;ib=f;e=ib-16|0;ib=e;d=x[Wb(e+8|0,roa(x[l>>2],x[l+4>>2],500654080,20))>>2];ib=e+16|0;e=x[l+4>>2];g=ib-16|0;ib=g;x[g+8>>2]=x[l>>2];x[g+12>>2]=e;i=x[g+8>>2];k=x[g+12>>2];h=mP(g,d);e=x[h>>2];ib=g+16|0;g=e>>>0>i>>>0;e=x[h+4>>2];if(g&(e|0)>=(k|0)|(e|0)>(k|0)){e=x[Wb(f+8|0,1)>>2];h=ib-16|0;ib=h;d=x[Wb(h+8|0,d-e|0)>>2];ib=h+16|0}ib=f+16|0;m=x[Wb(l+8|0,d)>>2];ib=l+16|0;f=ib-16|0;ib=f;g=ib-32|0;ib=g;d=m+719468|0;e=(((m|0)>-719469?d:m+573372|0)|0)/146097|0;i=D(e,-146097)+d|0;d=((i>>>0)/36524|0)+i-(((i>>>0)/146096|0)+((i>>>0)/1460|0))|0;h=(d>>>0)/365|0;i=((i-((d>>>0)/1460|0)|0)+((d>>>0)/36500|0)|0)+D(h,-365)|0;d=D(i,5)+2|0;k=(d>>>0)/153|0;d=k+(d>>>0<1530?3:-9)|0;h=zv(g+24|0,(h+D(e,400)|0)+(d>>>0<3)|0);e=pp(g+16|0,d);d=pp(g+8|0,(i-((D(k,153)+2>>>0)/5|0)|0)+1|0);kP(f+8|0,z[h>>1],e,d);ib=g+32|0;d=x[f+8>>2];w[j+40>>1]=d;w[j+42>>1]=d>>>16;ib=f+16|0;d=ib-32|0;ib=d;x[d+8>>2]=b;x[d+12>>2]=c;b=x[d+8>>2];e=x[d+12>>2];c=mP(d,m);h=x[c>>2];c=e-(x[c+4>>2]+(b>>>0<h>>>0)|0)|0;x[d+16>>2]=b-h;x[d+20>>2]=c;b=Oe(d+24|0,d+16|0);c=x[b+4>>2];b=x[b>>2];ib=d+32|0;g=ib-32|0;ib=g;x[g+24>>2]=b;x[g+28>>2]=c;k=g+16|0;n=j,o=oP(g+24|0,jz(k,0)),v[n+8|0]=o;i=ib-16|0;ib=i;x[i+8>>2]=b;x[i+12>>2]=c;d=ib-16|0;ib=d;x[d>>2]=0;x[d+4>>2]=0;e=Oe(d+8|0,d);h=x[e+4>>2];e=x[e>>2];ib=d+16|0;x[i>>2]=e;x[i+4>>2]=h;if(!(oP(i+8|0,i)^1)){d=ib-16|0;ib=d;x[d>>2]=0-b;x[d+4>>2]=0-(((b|0)!=0)+c|0);c=Oe(d+8|0,d);b=x[c>>2];ib=d+16|0;c=x[c+4>>2]}ib=i+16|0;x[g+16>>2]=b;x[g+20>>2]=c;d=ib-16|0;ib=d;e=x[Wb(d+8|0,roa(x[k>>2],x[k+4>>2],-694967296,0))>>2];ib=d+16|0;x[j+12>>2]=e;f=ib-32|0;ib=f;x[f+8>>2]=b;x[f+12>>2]=c;d=x[f+8>>2];i=x[f+12>>2];c=ib-16|0;ib=c;b=ib-16|0;ib=b;n=b,o=qoa(e,e>>31,-694967296,0),x[n>>2]=o;x[b+4>>2]=kb;e=Oe(b+8|0,b);h=x[e+4>>2];e=x[e>>2];ib=b+16|0;x[c+8>>2]=e;x[c+12>>2]=h;b=x[c+12>>2];x[f>>2]=x[c+8>>2];x[f+4>>2]=b;ib=c+16|0;b=d;d=x[f>>2];c=i-(x[f+4>>2]+(b>>>0<d>>>0)|0)|0;x[f+16>>2]=b-d;x[f+20>>2]=c;b=Oe(f+24|0,f+16|0);d=x[b+4>>2];c=x[b>>2];ib=f+32|0;x[g+16>>2]=c;x[g+20>>2]=d;b=ib-16|0;ib=b;e=x[Wb(b+8|0,roa(x[k>>2],x[k+4>>2],6e7,0))>>2];ib=b+16|0;x[j+16>>2]=e;f=ib-32|0;ib=f;x[f+8>>2]=c;x[f+12>>2]=d;d=x[f+8>>2];i=x[f+12>>2];c=ib-16|0;ib=c;b=ib-16|0;ib=b;n=b,o=qoa(e,e>>31,6e7,0),x[n>>2]=o;x[b+4>>2]=kb;e=Oe(b+8|0,b);h=x[e+4>>2];e=x[e>>2];ib=b+16|0;x[c+8>>2]=e;x[c+12>>2]=h;b=x[c+12>>2];x[f>>2]=x[c+8>>2];x[f+4>>2]=b;ib=c+16|0;b=d;d=x[f>>2];c=i-(x[f+4>>2]+(b>>>0<d>>>0)|0)|0;x[f+16>>2]=b-d;x[f+20>>2]=c;b=Oe(f+24|0,f+16|0);e=x[b+4>>2];d=x[b>>2];ib=f+32|0;x[g+16>>2]=d;x[g+20>>2]=e;c=nP(k);x[j+24>>2]=c;b=kb;x[j+28>>2]=b;x[g+8>>2]=c;x[g+12>>2]=b;h=ib-32|0;ib=h;x[h+8>>2]=d;x[h+12>>2]=e;b=x[h+8>>2];d=x[h+12>>2];c=tt(h,g+8|0);e=x[c>>2];c=d-(x[c+4>>2]+(b>>>0<e>>>0)|0)|0;x[h+16>>2]=b-e;x[h+20>>2]=c;b=Oe(h+24|0,h+16|0);c=x[b+4>>2];b=x[b>>2];ib=h+32|0;x[g+16>>2]=b;x[g+20>>2]=c;n=j,o=OT(k),x[n+32>>2]=o;x[j+36>>2]=kb;ib=g+32|0;b=qP(a);n=b,o=pP(z[j+40>>1]),x[n>>2]=o;n=b,o=Ke(y[j+42|0]),x[n+4>>2]=o;n=b,o=Ke(y[j+43|0]),x[n+8>>2]=o;x[b+12>>2]=x[j+12>>2];x[b+16>>2]=x[j+16>>2];a=x[j+28>>2];x[j>>2]=x[j+24>>2];x[j+4>>2]=a;a=x[j+4>>2];x[b+24>>2]=x[j>>2];x[b+28>>2]=a;ib=j+48|0}function bF(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=ib-32|0;ib=e;i=x[b+28>>2];x[e+24>>2]=x[b+24>>2];x[e+28>>2]=i;i=x[b+20>>2];x[e+16>>2]=x[b+16>>2];x[e+20>>2]=i;i=x[b+12>>2];x[e+8>>2]=x[b+8>>2];x[e+12>>2]=i;i=x[b+4>>2];x[e>>2]=x[b>>2];x[e+4>>2]=i;b=ib-176|0;ib=b;i=Kb(b+160|0);k=Kb(b+144|0);x[27524]=0;d=Q(1,b+128|0,c|0)|0;c=x[27524];x[27524]=0;a:{b:{c:{if((c|0)!=1){c=Gb(k,d);xb(d);if(!x[e>>2]){break b}x[27524]=0;R(98,b+112|0,e|0);d=x[27524];x[27524]=0;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{if((d|0)!=1){x[27524]=0;g=Q(99,i|0,b+112|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break q}xb(b+112|0);x[27524]=0;d=Q(1,b+96|0,16776)|0;f=x[27524];x[27524]=0;if((f|0)==1){break p}x[27524]=0;R(100,b+80|0,e+4|0);f=x[27524];x[27524]=0;if((f|0)==1){break o}x[27524]=0;U(2,b+112|0,d|0,b+80|0);f=x[27524];x[27524]=0;if((f|0)==1){break n}x[27524]=0;g=Q(99,g|0,b+112|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break m}xb(b+112|0);f=b+80|0;xb(f);xb(d);x[27524]=0;d=Q(1,f|0,16776)|0;f=x[27524];x[27524]=0;if((f|0)==1){break j}x[27524]=0;R(100,b- -64|0,e+8|0);f=x[27524];x[27524]=0;if((f|0)==1){break i}x[27524]=0;U(2,b+112|0,d|0,b- -64|0);f=x[27524];x[27524]=0;if((f|0)==1){break h}x[27524]=0;j=Q(99,g|0,b+112|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break g}xb(b+112|0);xb(b- -64|0);xb(d);g=x[e+24>>2];f=x[e+28>>2];if(x[e+12>>2]|(x[e+16>>2]|!(g|f))){break d}break b}a=P()|0;break c}a=P()|0;xb(b+112|0);break c}a=P()|0;break c}a=P()|0;break k}a=P()|0;break l}a=P()|0;xb(b+112|0)}xb(b+80|0)}xb(d);break c}a=P()|0;break c}a=P()|0;break e}a=P()|0;break f}a=P()|0;xb(b+112|0)}xb(b- -64|0)}xb(d);break c}x[27524]=0;d=Q(1,b+112|0,13635)|0;h=x[27524];x[27524]=0;r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{if((h|0)!=1){x[27524]=0;j=Q(99,j|0,d|0)|0;h=x[27524];x[27524]=0;if((h|0)==1){break J}xb(d);x[27524]=0;R(101,b+32|0,e+12|0);d=x[27524];x[27524]=0;if((d|0)==1){break I}x[27524]=0;d=Q(1,b+16|0,14644)|0;h=x[27524];x[27524]=0;if((h|0)==1){break H}x[27524]=0;U(2,b+48|0,b+32|0,d|0);h=x[27524];x[27524]=0;if((h|0)==1){break G}x[27524]=0;R(101,b|0,e+16|0);h=x[27524];x[27524]=0;if((h|0)==1){break F}x[27524]=0;U(2,b- -64|0,b+48|0,b|0);h=x[27524];x[27524]=0;if((h|0)==1){break E}x[27524]=0;j=Q(99,j|0,b- -64|0)|0;h=x[27524];x[27524]=0;if((h|0)==1){break D}xb(b- -64|0);xb(b);xb(b+48|0);xb(d);xb(b+32|0);if(f|g){break y}x[27524]=0;U(102,a|0,j|0,c|0);a=x[27524];x[27524]=0;if((a|0)==1){break x}break a}a=P()|0;break c}a=P()|0;xb(d);break c}a=P()|0;break c}a=P()|0;break z}a=P()|0;break A}a=P()|0;break B}a=P()|0;break C}a=P()|0;xb(b- -64|0)}xb(b)}xb(b+48|0)}xb(d)}xb(b+32|0);break c}x[27524]=0;d=Q(1,b+48|0,14644)|0;g=x[27524];x[27524]=0;if((g|0)==1){break w}x[27524]=0;R(103,b+32|0,e+24|0);g=x[27524];x[27524]=0;if((g|0)==1){break v}x[27524]=0;U(2,b- -64|0,d|0,b+32|0);g=x[27524];x[27524]=0;if((g|0)==1){break u}x[27524]=0;g=Q(99,j|0,b- -64|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break t}xb(b- -64|0);xb(b+32|0);xb(d);x[27524]=0;Q(99,g|0,c|0)|0;d=x[27524];x[27524]=0;if((d|0)!=1){break b}}a=P()|0;break c}a=P()|0;break c}a=P()|0;break r}a=P()|0;break s}a=P()|0;xb(b- -64|0)}xb(b+32|0)}xb(d);break c}a=P()|0}xb(k);xb(i);S(a|0);p()}$c(a,i)}xb(c);xb(i);ib=b+176|0;ib=e+32|0}function RM(a){var b=0,c=E(0),d=E(0),e=E(0),f=E(0),g=E(0),h=0,i=0,j=0,k=0,l=E(0),m=E(0),n=0,o=E(0),p=0,q=E(0),r=E(0),s=E(0),t=0,u=E(0);j=ib-16|0;ib=j;b=a+4208|0;i=rk(E(B[Bb(b,12)>>2]*E(3)));x[a+4264>>2]=i;d=E(x[x[a+16>>2]+24620>>2]>>>((i^-1)>>>1&1)>>>0);B[a+4268>>2]=d;t=a,u=E(E(B[Bb(b,9)>>2]*E(100))*E(.0061803399585187435)),B[t+4272>>2]=u;t=j,u=ze(E(10),E(E(QM(a)+E(E(B[Bb(b,5)>>2]*E(11e3))+E(-1e4)))/E(2e3))),B[t+12>>2]=u;x[j+8>>2]=1065353216;t=a,u=E(B[rm(j+12|0,j+8|0)>>2]*E(.7609999775886536)),B[t+4280>>2]=u;c=ze(E(10),E(E(E(E(B[Bb(b,1)>>2]*E(1e4))+E(-1e4))/E(100))/E(10)));if(c!=E(1)){d=Mp(E(E(PM(a)*E(6.2831854820251465))/d));f=E(c+c);e=E(c*c);c=Jz(E(E(E(E(d*f)+E(-2))+E(M(E(E(E(E(d*E(E(d*e)*E(4)))+E(c*E(8)))-E(e*E(4)))-E(E(d*c)*E(8))))))/E(f+E(-2))),E(0),E(1))}else{c=E(0)}B[a+4276>>2]=c;i=ib-16|0;ib=i;c=B[a+4268>>2];b=a+4208|0;d=E(B[Bb(b,6)>>2]*E(.30000001192092896));t=i,u=E(B[Bb(b,8)>>2]*E(.10000000149011612)),B[t+12>>2]=u;x[i+8>>2]=1000593162;f=B[oy(i+12|0,i+8|0)>>2];e=E(c*E(E(d+f)+E(.007000000216066837)));a:{if(E(F(e))<E(2147483648)){b=~~e;break a}b=-2147483648}x[a+4352>>2]=b;b=1;while(1){if((b|0)==12){t=i,u=E(E(E(E(B[Bb(a+4208|0,10)>>2]*E(100))/E(100))+E(.10000000149011612))*E(.9090999960899353)),B[t+12>>2]=u;x[i+8>>2]=1065353216;d=B[rm(i+12|0,i+8|0)>>2];f=E(c*E(E(d*E(75))/E(1e3)));d=E(c*E(E(d*E(67))/E(1e3)));b=0;while(1){if((b|0)==6){h=a+4348|0;d=E(c*E(.0035299998708069324));b:{if(E(F(d))<E(2147483648)){b=~~d;break b}b=-2147483648}x[h>>2]=b;h=a+4344|0;d=E(c*E(.0032500000670552254));c:{if(E(F(d))<E(2147483648)){b=~~d;break c}b=-2147483648}x[h>>2]=b;h=a+4340|0;c=E(c*E(.009999999776482582));d:{if(E(F(c))<E(2147483648)){b=~~c;break d}b=-2147483648}x[h>>2]=b}else{h=(b<<2)+a|0;p=h+4316|0;n=b+n|0;e=ze(E(.9300000071525574),E(n|0));g=E(f*e);e:{if(E(F(g))<E(2147483648)){k=~~g;break e}k=-2147483648}x[p>>2]=k;k=h+4292|0;e=E(d*e);f:{if(E(F(e))<E(2147483648)){h=~~e;break f}h=-2147483648}x[k>>2]=h;b=b+1|0;continue}break}b=0;while(1){if((b|0)!=15){TM((D(b,24)+a|0)+4504|0,x[((b<<2)+a|0)+4292>>2]);b=b+1|0;continue}break}ib=i+16|0}else{k=((D(b&1,24)+a|0)+(b<<1&-4)|0)+4352|0;e=E(c*E(E(f*B[(b<<2)+46976>>2])+d));g:{if(E(F(e))<E(2147483648)){h=~~e;break g}h=-2147483648}x[k>>2]=h;b=b+1|0;continue}break}b=ib-16|0;ib=b;d=Dh(a,5);e=Dh(a,11);c=E(d*Dh(a,4));d=E(E(c*E(.03999999910593033))+E(E(d*E(.02250000089406967))+E(0)));f=E(e*Dh(a,10));e=E(E(f*E(.03999999910593033))+E(E(e*E(.02250000089406967))+E(0)));if(v[a+4264|0]&1){g=Dh(a,3);l=Dh(a,9);g=E(c*g);c=E(g*Dh(a,2));d=E(E(c*E(.1444000005722046))+E(E(g*E(.12250000238418579))+d));g=E(f*l);f=E(g*Dh(a,8));e=E(E(f*E(.1444000005722046))+E(E(g*E(.12250000238418579))+e))}Dh(a,12);g=B[a+4496>>2];l=Dh(a,1);m=Dh(a,7);q=Dh(a,0);r=Dh(a,6);t=b,u=ze(E(10),E(E(QM(a)+E(E(B[Bb(a+4208|0,7)>>2]*E(12e3))+E(-1e4)))/E(2e3))),B[t+12>>2]=u;x[b+8>>2]=1065353216;o=B[rm(b+12|0,b+8|0)>>2];s=c;c=E(g*g);g=E(l*E(s*c));l=E(q*g);c=E(m*E(f*c));f=E(r*c);m=E(E(E(l+f)*E(-.5))+E(1));B[a+4284>>2]=o*E(M(E(m/E(E(l*E(.1444000005722046))+E(E(c*E(.1444000005722046))+d)))));B[a+4288>>2]=o*E(M(E(m/E(E(f*E(.1444000005722046))+E(E(g*E(.1444000005722046))+e)))));ib=b+16|0;v[a+5046|0]=0;ib=j+16|0}function rw(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=ib-96|0;ib=c;i=a+32|0;Pc(c+56|0,i,11);a:{b:{c:{if(zb(x[x[c+56>>2]>>2],x[c+60>>2])|x[a+8>>2]){d=x[a+36>>2];b=x[a+76>>2]+x[a+20>>2]|0;f=x[a+16>>2];e=f+x[a+72>>2]|0;b=Nf(c+80|0,e,e>>>0<f>>>0?b+1|0:b);e=x[b+12>>2];x[c+24>>2]=x[b+8>>2];x[c+28>>2]=e;e=x[b+4>>2];x[c+16>>2]=x[b>>2];x[c+20>>2]=e;eh(d,c+16|0);b=x[a+36>>2];if(jh(x[(x[x[b>>2]-12>>2]+b|0)+16>>2])){Ah(a,2,256);break a}b=x[a+104>>2];e=a+52|0;f=x[e>>2];d=Xi(f,x[e+4>>2]);d:{if(b>>>0>d>>>0){h=ib-32|0;ib=h;f=b-d|0;d=x[Db(e)>>2];g=x[e+4>>2];e:{if(f>>>0<=(d-g|0)/24>>>0){d=ib-16|0;ib=d;b=RE(d,e,f);e=x[b+4>>2];f=x[b+8>>2];while(1){if((e|0)==(f|0)){ic(b);ib=d+16|0}else{QE(e);e=e+24|0;x[b+4>>2]=e;continue}break}break e}b=Db(e);d=UE(h+8|0,VE(e,Xi(x[e>>2],g)+f|0),Xi(x[e>>2],x[e+4>>2]),b);b=ib-16|0;ib=b;x[b>>2]=x[d+8>>2];g=x[d+8>>2];x[b+8>>2]=d+8;x[b+4>>2]=g+D(f,24);f=x[b>>2];while(1){if(x[b+4>>2]!=(f|0)){QE(f);f=x[b>>2]+24|0;x[b>>2]=f;continue}break}Vd(b);ib=b+16|0;TE(e,d);SE(d)}ib=h+32|0;break d}if(b>>>0<d>>>0){Od(e,f+D(b,24)|0)}}h=a+40|0;wn(h,x[a+104>>2]<<2);e=0;while(1){if(A[a+104>>2]>e>>>0){d=x[a+36>>2];if(jh(x[(x[x[d>>2]-12>>2]+d|0)+16>>2])){Ah(a,2,1024);break a}b=z[a+24>>1];w[c+32>>1]=b;if((b|0)==65535){tw(d,c+32|0);b=z[c+32>>1]}d=cd(x[a+40>>2],x[a+44>>2]);f=b&65535;f:{if(!f){b=0;break f}if(f>>>0>(d^-1)>>>0){break f}Yi(h,d+f|0);ri(x[a+36>>2],Jb(x[a+40>>2],d),f)}f=sf(x[a+52>>2],e);x[f>>2]=d;w[f+20>>1]=b;Pc(c+56|0,i,6);if(zb(x[x[c+56>>2]>>2],x[c+60>>2])){Qk(x[a+36>>2],c+56|0);d=x[c+56>>2];b=x[c+60>>2];if(!sw(d,b)){break c}f=sf(x[a+52>>2],e);x[f+8>>2]=d;x[f+12>>2]=b}d=x[a+8>>2];g:{if(d){b=sf(x[a+52>>2],e);x[b+16>>2]=d;break g}Pc(c+56|0,i,7);if(!zb(x[x[c+56>>2]>>2],x[c+60>>2])){b=sf(x[a+52>>2],e);break g}Qk(x[a+36>>2],c+56|0);d=x[c+56>>2];if(!sw(d,x[c+60>>2])){break b}b=sf(x[a+52>>2],e);x[b+16>>2]=d}h:{if(x[b+16>>2]==-1){break h}Pc(c+56|0,i,6);if(zb(x[x[c+56>>2]>>2],x[c+60>>2])){break h}i:{if(!e){f=0;b=0;d=sf(x[a+52>>2],0);break i}g=x[a+52>>2];b=sf(g,e-1|0);f=x[b+16>>2];d=x[b+8>>2]+f|0;b=x[b+12>>2];b=d>>>0<f>>>0?b+1|0:b;f=d;d=sf(g,e)}x[d+8>>2]=f;x[d+12>>2]=b}Pc(c+56|0,i,8);if(zb(x[x[c+56>>2]>>2],x[c+60>>2])){w[c+78>>1]=0;tw(x[a+36>>2],c+78|0);Pc(c+56|0,i,9);em(x[a+36>>2],z[c+78>>1]<<zb(x[x[c+56>>2]>>2],x[c+60>>2]))}e=e+1|0;continue}break}Pd(c+56|0,x[a+36>>2]);b=x[c+68>>2];x[a+80>>2]=x[c+64>>2];x[a+84>>2]=b}e=c+56|0;Pc(e,i,4);bf(e,1);f=x[a+84>>2];h=x[a+96>>2];g=x[a+16>>2];d=h+g|0;j=x[a+100>>2];b=j+x[a+20>>2]|0;b=d>>>0<g>>>0?b+1|0:b;g=d;d=(h|0)==x[a+72>>2]&(j|0)==x[a+76>>2];h=d?x[a+80>>2]:g;x[a+88>>2]=h;b=d?f:b;x[a+92>>2]=b;d=x[a+36>>2];b=Nf(c+40|0,h,b);f=x[b+12>>2];x[c+8>>2]=x[b+8>>2];x[c+12>>2]=f;f=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=f;eh(d,c);Pc(e,i,6);if(zb(x[x[c+56>>2]>>2],x[c+60>>2])){break a}Pc(c+32|0,i,7);if(!(zb(x[x[c+32>>2]>>2],x[c+36>>2])|x[a+8>>2])){break a}b=x[a+88>>2];e=x[a+16>>2];i=b-e|0;d=x[a+92>>2]-(x[a+20>>2]+(b>>>0<e>>>0)|0)|0;f=x[a+52>>2];h=x[a+104>>2];a=0;while(1){if((a|0)==(h|0)){break a}b=sf(f,a);g=b;j=x[b+8>>2];e=j+i|0;b=x[b+12>>2]+d|0;x[g+8>>2]=e;x[g+12>>2]=e>>>0<j>>>0?b+1|0:b;a=a+1|0;continue}}Ah(a,2,2048);break a}Ah(a,2,2048)}ib=c+96|0}function jfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=ib-112|0;ib=e;g=a+140|0;Gj(e+88|0,g,1296125513);x[27524]=0;f=T(182,x[e+88>>2])|0;h=x[27524];x[27524]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if((h|0)!=1){if(f){f=Kb(e+32|0);x[27524]=0;h=T(164,x[e+88>>2])|0;i=x[27524];x[27524]=0;if((i|0)==1){break p}x[27524]=0;U(782,e+88|0,f|0,h|0);h=x[27524];x[27524]=0;if((h|0)==1){break p}h=z[a+174>>1];x[27524]=0;U(783,e+72|0,h|0,f|0);h=x[27524];x[27524]=0;if((h|0)==1){break o}x[27524]=0;U(8,e+8|0,c|0,e+72|0);c=x[27524];x[27524]=0;if((c|0)==1){break n}c=e+8|0;Cc(d,c);wb(c);xb(e+72|0);wb(f)}if(y[a+176|0]){x[27524]=0;R(784,e+32|0,d|0);c=x[27524];x[27524]=0;if((c|0)==1){break e}c=e+32|0;Fe(b+43|0,c);wb(c)}x[27524]=0;U(777,e+32|0,g|0,1413894985);c=x[27524];x[27524]=0;if((c|0)==1){break l}x[27524]=0;f=T(785,e+32|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break k}g=e+32|0;yb(g);c=a+40|0;yc(c);x[27524]=0;g=Q(786,c|0,g|0)|0;h=x[27524];x[27524]=0;if((h|0)==1){break j}if(g){q:{if(A[e+60>>2]<2){break q}x[27524]=0;g=Q(787,c|0,e+8|0)|0;h=x[27524];x[27524]=0;if((h|0)==1){break i}if(!g){break q}oO(e+8|0,b+12|0,b+16|0,x[b>>2],b+34|0,8,16,f)}x[27524]=0;c=Q(787,c|0,e+8|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break i}if(c){oO(e+8|0,b+4|0,b+8|0,x[b>>2],b+34|0,2,4,f)}c=x[e+44>>2];v[b+42|0]=c&128?0:c+1|0;Jk(b)}r:{if(y[b+42|0]){break r}c=x[a+60>>2];x[27524]=0;c=Q(657,c|0,7)|0;f=x[27524];x[27524]=0;if((f|0)==1){break j}if(!c){break r}c=a+60|0;yc(c);x[27524]=0;c=Q(788,c|0,e+8|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break d}if(!c){break r}c=v[e+8|0];v[b+42|0]=(c|0)>=0?c+1|0:0}c=x[a+120>>2];x[27524]=0;c=T(182,c|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break j}if(!c){break f}x[27524]=0;h=a+120|0;c=T(161,h|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break c}x[e+72>>2]=c;wc(e+72|0,9);f=b+68|0;g=x[e+72>>2];c=0;while(1){if((c|0)==(g|0)){break g}x[27524]=0;R(789,h|0,e+8|0);i=x[27524];x[27524]=0;if((i|0)==1){break h}j=Bb(f,c),k=x[e+12>>2],x[j>>2]=k;c=c+1|0;continue}}a=P()|0;break a}a=P()|0;break m}a=P()|0;break m}a=P()|0;xb(e+72|0)}wb(f);break a}a=P()|0;break a}a=P()|0;yb(e+32|0);break a}a=P()|0;break a}a=P()|0;break a}a=P()|0;break a}AA(f+(g<<2)|0,PV(f),42704)}c=a+80|0;yc(c);x[27524]=0;f=Q(790,c|0,e+8|0)|0;g=x[27524];x[27524]=0;s:{if((g|0)==1){break s}if(!f){break b}if(y[e+8|0]&32){w[b+34>>1]=z[b+34>>1]|32}w[e+72>>1]=z[e+12>>1];w[e+6>>1]=256;j=b,k=z[Tc(e+72|0,e+6|0)>>1],w[j+28>>1]=k;w[e+72>>1]=z[e+14>>1];w[e+6>>1]=256;j=b,k=z[Tc(e+72|0,e+6|0)>>1],w[j+30>>1]=k;w[e+72>>1]=z[e+16>>1];w[e+6>>1]=64;j=b,k=z[Tc(e+72|0,e+6|0)>>1],w[j+32>>1]=k;v[b+38|0]=y[e+20|0];v[b+39|0]=y[e+21|0];v[b+40|0]=y[e+22|0];v[b+41|0]=y[e+23|0];f=x[a+88>>2];a=x[a+80>>2];x[27524]=0;a=W(160,a|0,f|0,32)|0;f=x[27524];x[27524]=0;if((f|0)==1){break s}if(!a){break b}x[27524]=0;R(791,c|0,d|0);a=x[27524];x[27524]=0;if((a|0)==1){break s}x[27524]=0;a=T(206,c|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break s}x[27524]=0;U(792,c|0,b+43|0,a|0);a=x[27524];x[27524]=0;if((a|0)!=1){break b}}a=P()|0;break a}a=P()|0;break a}a=P()|0;break a}a=P()|0;break a}yb(e+88|0);ib=e+112|0;return}yb(e+88|0);S(a|0);p()}function eP(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,z=0;if(b){h=a+327720|0;c=ib-400|0;ib=c;hR(c+384|0,8);x[27524]=0;oa(767,c+368|0,9);i=x[27524];x[27524]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if((i|0)!=1){x[27524]=0;i=Q(768,c+352|0,14)|0;e=x[27524];x[27524]=0;if((e|0)==1){break l}x[27524]=0;R(769,c+384|0,i|0);e=x[27524];x[27524]=0;if((e|0)==1){break k}x[27524]=0;R(769,c+368|0,i|0);e=x[27524];x[27524]=0;if((e|0)==1){break k}gR(c+280|0,4900);gR(c+208|0,32e3);$Q(c+136|0,8377175819504598e-21,16754351639009197e-21,8377175819504598e-21,-1.991112714669597,.9911462233728751);x[27524]=0;e=Q(770,c+104|0,c+384|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break j}Pt(c+120|0,c+280|0,e);we(e);x[27524]=0;e=Q(770,c+72|0,c+368|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break i}Pt(c+88|0,c+208|0,e);we(e);x[27524]=0;e=Q(770,c+40|0,c+120|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break h}Pt(c+56|0,c+136|0,e);we(e);x[27524]=0;e=Q(770,c+8|0,c+88|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break g}g=c+24|0;Pt(g,c+136|0,e);we(e);e=c+120|0;iq(e);l=c+56|0;iq(l);m=c+88|0;iq(m);iq(g);q=c+368|0;iq(q);hq(x[c+120>>2],x[c+124>>2],fo(h,0));hq(x[c+56>>2],x[c+60>>2],fo(h,1));hq(x[c+88>>2],x[c+92>>2],fo(h,2));hq(x[c+24>>2],x[c+28>>2],fo(h,3));hq(x[c+368>>2],x[c+372>>2],fo(h,4));we(g);we(l);we(m);we(e);Gm(i);we(q);we(c+384|0);ib=c+400|0;break a}a=P()|0;break b}a=P()|0;break c}a=P()|0;break d}a=P()|0;break d}a=P()|0;break e}a=P()|0;break f}a=P()|0;we(c+56|0)}we(c+88|0)}we(c+120|0)}Gm(i)}we(c+368|0)}we(c+384|0);S(a|0);p()}Ky(a+131112|0,9.6377,.97);Ky(a+196648|0,8.5,.5);Ky(a+262184|0,7,.425)}c=a+368680|0;if(!(u=0,v=rO(c,a),z=b,z?u:v)){e=a+24|0;s=C[a+8>>3];g=y[a+16|0];h=ib+-64|0;ib=h;m:while(1){if((n|0)!=8193){t=+(n-4096|0)*.0001220703125;b=0;o=0;while(1)if((b|0)==8){j=1/o;l=n<<3;b=0;while(1)if((b|0)==8){n=n+1|0;continue m}else{m=e+(b+l<<1)|0;d=J(C[h+(b<<3)>>3]*32768*j+.5);d=d<-32768?-32768:H(d,32768);n:{if(F(d)<2147483648){i=~~d;break n}i=-2147483648}w[m>>1]=i;b=b+1|0;continue}}else{j=s;f=1;d=+(b|0)-t;r=d+-3.5;if(!(F(r)<1e-8)){o:{p:{switch(g|0){case 0:f=gf(d*.8975979010256552)*-.5+.5;break o;case 1:f=gf(d*.8975979010256552)*-.46+.54;break o;case 2:f=gf(d*1.7951958020513104)*.08+(gf(d*.8975979010256552)*-.5+.42);break o;case 3:f=gf(d*1.7951958020513104)*.05677+(gf(d*.8975979010256552)*-.49364+.44959);break o;case 4:f=gf(d*1.7951958020513104)*.07922+(gf(d*.8975979010256552)*-.49755+.42323);break o;case 5:f=gf(d*1.7951958020513104);k=gf(d*.8975979010256552);f=gf(d*2.6927937030769655)*-.01168+(f*.14128+(k*-.48829+.35875));break o;case 6:f=gf(d*1.7951958020513104);k=gf(d*.8975979010256552);f=gf(d*2.6927937030769655)*-.00183+(f*.09392+(k*-.49703+.40217));break o;case 7:break p;default:break o}}f=gf(d*1.7951958020513104);k=gf(d*.8975979010256552);f=gf(d*2.6927937030769655)*-.00122+(f*.09831+(k*-.49804+.40243))}d=r*3.141592653589793;j=Ki(d*j)/d}j=f*j;C[h+(b<<3)>>3]=j;o=o+j;b=b+1|0;continue}}break}ib=h- -64|0;b=x[a+20>>2];x[c+16>>2]=x[a+16>>2];x[c+20>>2]=b;b=x[a+12>>2];x[c+8>>2]=x[a+8>>2];x[c+12>>2]=b;b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b}}function ey(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=ib-256|0;ib=e;v[e+255|0]=c;f=x[b+4>>2];a:{if(!f){break a}g=x[b>>2];h=y[gl(g,f)|0];if((h|0)==33){d=1}else{if((h|0)!=63){break a}d=0}ol(e+80|0,g,f,f-1|0);f=x[e+84>>2];x[b>>2]=x[e+80>>2];x[b+4>>2]=f}f=e+80|0;Yd(f);g=x[e+80>>2];Yd(e+224|0);h=fl(g,x[e+228>>2],b);Yd(f);f=x[b+4>>2];g=x[b>>2];b:{c:{d:{e:{f:{g:{h:{if((h|0)==x[e+84>>2]){a=qc(e+240|0,21631);c=x[a+4>>2];x[e>>2]=x[a>>2];x[e+4>>2]=c;if(Nc(g,f,e)){d=ba(8)|0;x[27524]=0;R(966,e+224|0,e+255|0);a=x[27524];x[27524]=0;if((a|0)==1){break g}x[27524]=0;U(973,e+80|0,17610,e+224|0);a=x[27524];x[27524]=0;if((a|0)==1){break f}lc(d,e+80|0);a=0;x[27524]=0;U(123,d|0,50060,962);b=x[27524];x[27524]=0;if((b|0)!=1){break b}b=P()|0;wb(e+80|0);break e}if(!d){break h}d=ba(8)|0;a=x[b+4>>2];b=x[b>>2];x[27524]=0;a=Qh(e+192|0,b,a);b=x[27524];x[27524]=0;i:{j:{k:{l:{m:{n:{o:{p:{if((b|0)!=1){x[27524]=0;U(973,e+208|0,17646,a|0);b=x[27524];x[27524]=0;if((b|0)==1){break p}x[27524]=0;R(975,e+224|0,e+208|0);b=x[27524];x[27524]=0;c=1;if((b|0)==1){break o}x[27524]=0;R(966,e+176|0,e+255|0);b=x[27524];x[27524]=0;if((b|0)==1){break n}x[27524]=0;U(977,e+80|0,e+224|0,e+176|0);b=x[27524];x[27524]=0;if((b|0)==1){break m}lc(d,e+80|0);x[27524]=0;U(123,d|0,50060,962);b=x[27524];x[27524]=0;if((b|0)!=1){break b}b=P()|0;wb(e+80|0);c=0;break l}b=P()|0;break d}b=P()|0;c=1;break i}b=P()|0;break j}b=P()|0;break k}b=P()|0}wb(e+176|0)}wb(e+224|0)}wb(e+208|0)}wb(a);if(c){break d}break c}b=qc(e+168|0,21631);d=x[b+4>>2];x[e+72>>2]=x[b>>2];x[e+76>>2]=d;if(Nc(g,f,e+72|0)){d=ba(8)|0;x[27524]=0;R(966,e+224|0,e+255|0);a=x[27524];x[27524]=0;q:{r:{if((a|0)!=1){x[27524]=0;U(973,e+80|0,17610,e+224|0);a=x[27524];x[27524]=0;if((a|0)==1){break r}lc(d,e+80|0);a=0;x[27524]=0;U(123,d|0,50060,962);b=x[27524];x[27524]=0;if((b|0)!=1){break b}b=P()|0;wb(e+80|0);break q}b=P()|0;break d}b=P()|0;a=1}wb(e+224|0);if(a){break d}break c}b=qc(e+160|0,7410);d=x[b+4>>2];x[e+64>>2]=x[b>>2];x[e+68>>2]=d;s:{if(!Nc(g,f,e- -64|0)){b=qc(e+152|0,7392);d=x[b+4>>2];x[e+56>>2]=x[b>>2];x[e+60>>2]=d;if(!Nc(g,f,e+56|0)){break s}}v[a+60|0]=c;break h}b=qc(e+144|0,6937);d=x[b+4>>2];x[e+48>>2]=x[b>>2];x[e+52>>2]=d;t:{if(!Nc(g,f,e+48|0)){b=qc(e+136|0,6918);d=x[b+4>>2];x[e+40>>2]=x[b>>2];x[e+44>>2]=d;if(!Nc(g,f,e+40|0)){break t}}v[a+61|0]=c;break h}b=qc(e+128|0,7021);d=x[b+4>>2];x[e+32>>2]=x[b>>2];x[e+36>>2]=d;if(Nc(g,f,e+32|0)){v[a+62|0]=c;break h}b=qc(e+120|0,6067);d=x[b+4>>2];x[e+24>>2]=x[b>>2];x[e+28>>2]=d;if(Nc(g,f,e+24|0)){v[a+63|0]=c;break h}b=qc(e+112|0,7459);d=x[b+4>>2];x[e+16>>2]=x[b>>2];x[e+20>>2]=d;if(Nc(g,f,e+16|0)){v[a+64|0]=c;break h}b=qc(e+104|0,13340);d=x[b+4>>2];x[e+8>>2]=x[b>>2];x[e+12>>2]=d;if(!Nc(g,f,e+8|0)){break h}b=x[a+24>>2];d=b+24664|0;f=x[d+4>>2];x[e+96>>2]=x[d>>2];x[e+100>>2]=f;d=b+24656|0;f=x[d+4>>2];x[e+88>>2]=x[d>>2];x[e+92>>2]=f;d=x[b+24652>>2];x[e+80>>2]=x[b+24648>>2];x[e+84>>2]=d;if(c){a=TJ(x[a+56>>2])}else{a=0}x[e+100>>2]=a;if(!Sx(e+80|0,b+24648|0)){break h}Vy(b,e+80|0)}ib=e+256|0;return}b=P()|0;break d}b=P()|0;a=1}wb(e+224|0);if(!a){break c}}ca(d|0)}S(b|0)}p()}function zla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;f=ib-240|0;ib=f;Pd(f+224|0,b);g=ib-48|0;ib=g;x[g+44>>2]=0;wk(b,g+44|0);a:{b:{c:{if(x[g+44>>2]!=(Vm(14102)|0)){break c}x[g+40>>2]=0;e=ib-32|0;ib=e;x[e+24>>2]=0;pw(e+8|0,e+24|0);Bn(e+16|0,b,x[e+8>>2],x[e+12>>2]);cm(g+40|0,x[e+24>>2]);ib=e+32|0;e=-1;i=x[g+40>>2];if(i-3>>>0<4294967294){break c}d:{e:{f:{if(i>>>0<=1){i=Kb(g+24|0);x[27524]=0;h=W(487,b|0,i|0,256)|0;j=x[27524];x[27524]=0;if((j|0)==1){break b}if(!h){break e}x[27524]=0;U(11,g+8|0,d|0,i|0);h=x[27524];x[27524]=0;if((h|0)!=1){break f}break b}i=Kb(g+24|0);x[27524]=0;h=Q(489,b|0,i|0)|0;j=x[27524];x[27524]=0;if((j|0)==1){break b}if(!h){break d}x[27524]=0;U(11,g+8|0,d|0,i|0);h=x[27524];x[27524]=0;if((h|0)==1){break b}}h=g+8|0;Gb(c,h);xb(h);wb(i);dg(b,h);i=0;x[g+24>>2]=0;wk(b,g+24|0);h=x[g+24>>2];if(h>>>0>50){break c}g:{while(1){if((h|0)==(i|0)){break g}i=i+1|0;if(MN(a,b,d)){continue}break}break c}x[g+24>>2]=0;wk(b,g+24|0);e=x[g+24>>2]==(Vm(14148)|0)?1:-1;break c}wb(i);break c}wb(i)}ib=g+48|0;break a}a=P()|0;wb(i);S(a|0);p()}h:{if(e){break h}$f(x[x[b>>2]-12>>2]+b|0,0);e=x[f+236>>2];x[f+16>>2]=x[f+232>>2];x[f+20>>2]=e;e=x[f+228>>2];x[f+8>>2]=x[f+224>>2];x[f+12>>2]=e;b=bm(f+112|0,eh(b,f+8|0));x[27524]=0;e=Q(453,f+96|0,14287)|0;g=x[27524];x[27524]=0;i:{if((g|0)!=1){x[27524]=0;x[f+80>>2]=3;x[f+84>>2]=0;U(454,b|0,e|0,f+80|0);g=x[27524];x[27524]=0;if((g|0)!=1){Zb(e);v[f+95|0]=0;x[27524]=0;e=Q(453,f+80|0,14743)|0;g=x[27524];x[27524]=0;if((g|0)!=1){x[27524]=0;U(455,b|0,f+95|0,e|0);g=x[27524];x[27524]=0;if((g|0)!=1){Zb(e);x[27524]=0;g=y[f+95|0];e=T(468,b|0)|0;i=x[27524];x[27524]=0;if((i|0)!=1){x[27524]=0;i=T(469,b|0)|0;h=x[27524];x[27524]=0;if((h|0)!=1){g=g?0:d;x[f+72>>2]=e;j:{k:{l:{m:{while(1){if(!Mb(e,i)){a=Rk(y[b|0]);rh(b);e=a?-1:1;break h}x[27524]=0;d=Q(453,f+56|0,15783)|0;e=x[27524];x[27524]=0;if((e|0)==1){break l}e=x[b+44>>2];h=x[b+40>>2];x[27524]=0;e=fa(470,h|0,e|0,x[f+72>>2],d|0)|0;h=x[27524];x[27524]=0;if((h|0)==1){break k}Zb(d);n:{o:{if(e){x[27524]=0;X(471,b|0,f+72|0,c|0,g|0);d=x[27524];x[27524]=0;if((d|0)!=1){break o}break j}x[27524]=0;d=Q(453,f+40|0,15460)|0;e=x[27524];x[27524]=0;p:{q:{if((e|0)!=1){e=x[b+44>>2];h=x[b+40>>2];x[27524]=0;e=fa(470,h|0,e|0,x[f+72>>2],d|0)|0;h=x[27524];x[27524]=0;if((h|0)==1){break q}Zb(d);if(!e){break p}x[27524]=0;U(472,b|0,f+72|0,f+70|0);d=x[27524];x[27524]=0;if((d|0)==1){break j}break o}a=P()|0;break i}a=P()|0;Zb(d);break i}x[27524]=0;d=Q(453,f+24|0,15359)|0;e=x[27524];x[27524]=0;if((e|0)==1){break n}e=x[b+44>>2];h=x[b+40>>2];x[27524]=0;e=fa(470,h|0,e|0,x[f+72>>2],d|0)|0;h=x[27524];x[27524]=0;if((h|0)==1){break m}Zb(d);if(!e){break o}x[27524]=0;X(473,b|0,f+72|0,a|0,g|0);d=x[27524];x[27524]=0;if((d|0)==1){break j}}xy(f+72|0);e=x[f+72>>2];continue}break}a=P()|0;break i}a=P()|0;Zb(d);break i}a=P()|0;break i}a=P()|0;Zb(d);break i}a=P()|0;break i}a=P()|0;break i}a=P()|0;break i}a=P()|0;Zb(e);break i}a=P()|0;break i}a=P()|0;Zb(e);break i}a=P()|0}rh(b);S(a|0);p()}ib=f+240|0;return e|0}function Ib(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{if(!a){break a}d=a-8|0;b=x[a-4>>2];a=b&-8;f=d+a|0;b:{if(b&1){break b}if(!(b&3)){break a}b=x[d>>2];d=d-b|0;if(d>>>0<A[27404]){break a}a=a+b|0;if(x[27405]!=(d|0)){if(b>>>0<=255){e=x[d+8>>2];b=b>>>3|0;c=x[d+12>>2];if((c|0)==(e|0)){i=109600,j=x[27400]&toa(-2,b),x[i>>2]=j;break b}x[e+12>>2]=c;x[c+8>>2]=e;break b}h=x[d+24>>2];b=x[d+12>>2];c:{if((d|0)!=(b|0)){c=x[d+8>>2];x[c+12>>2]=b;x[b+8>>2]=c;break c}d:{e=d+20|0;c=x[e>>2];if(c){break d}e=d+16|0;c=x[e>>2];if(c){break d}b=0;break c}while(1){g=e;b=c;e=b+20|0;c=x[e>>2];if(c){continue}e=b+16|0;c=x[b+16>>2];if(c){continue}break}x[g>>2]=0}if(!h){break b}e=x[d+28>>2];c=(e<<2)+109904|0;e:{if(x[c>>2]==(d|0)){x[c>>2]=b;if(b){break e}i=109604,j=x[27401]&toa(-2,e),x[i>>2]=j;break b}x[h+(x[h+16>>2]==(d|0)?16:20)>>2]=b;if(!b){break b}}x[b+24>>2]=h;c=x[d+16>>2];if(c){x[b+16>>2]=c;x[c+24>>2]=b}c=x[d+20>>2];if(!c){break b}x[b+20>>2]=c;x[c+24>>2]=b;break b}b=x[f+4>>2];if((b&3)!=3){break b}x[27402]=a;x[f+4>>2]=b&-2;x[d+4>>2]=a|1;x[a+d>>2]=a;return}if(d>>>0>=f>>>0){break a}b=x[f+4>>2];if(!(b&1)){break a}f:{if(!(b&2)){if(x[27406]==(f|0)){x[27406]=d;a=x[27403]+a|0;x[27403]=a;x[d+4>>2]=a|1;if(x[27405]!=(d|0)){break a}x[27402]=0;x[27405]=0;return}if(x[27405]==(f|0)){x[27405]=d;a=x[27402]+a|0;x[27402]=a;x[d+4>>2]=a|1;x[a+d>>2]=a;return}a=(b&-8)+a|0;g:{if(b>>>0<=255){e=x[f+8>>2];b=b>>>3|0;c=x[f+12>>2];if((c|0)==(e|0)){i=109600,j=x[27400]&toa(-2,b),x[i>>2]=j;break g}x[e+12>>2]=c;x[c+8>>2]=e;break g}h=x[f+24>>2];b=x[f+12>>2];h:{if((f|0)!=(b|0)){c=x[f+8>>2];x[c+12>>2]=b;x[b+8>>2]=c;break h}i:{e=f+20|0;c=x[e>>2];if(c){break i}e=f+16|0;c=x[e>>2];if(c){break i}b=0;break h}while(1){g=e;b=c;e=b+20|0;c=x[e>>2];if(c){continue}e=b+16|0;c=x[b+16>>2];if(c){continue}break}x[g>>2]=0}if(!h){break g}e=x[f+28>>2];c=(e<<2)+109904|0;j:{if(x[c>>2]==(f|0)){x[c>>2]=b;if(b){break j}i=109604,j=x[27401]&toa(-2,e),x[i>>2]=j;break g}x[h+(x[h+16>>2]==(f|0)?16:20)>>2]=b;if(!b){break g}}x[b+24>>2]=h;c=x[f+16>>2];if(c){x[b+16>>2]=c;x[c+24>>2]=b}c=x[f+20>>2];if(!c){break g}x[b+20>>2]=c;x[c+24>>2]=b}x[d+4>>2]=a|1;x[a+d>>2]=a;if(x[27405]!=(d|0)){break f}x[27402]=a;return}x[f+4>>2]=b&-2;x[d+4>>2]=a|1;x[a+d>>2]=a}if(a>>>0<=255){b=(a&-8)+109640|0;c=x[27400];a=1<<(a>>>3);k:{if(!(c&a)){x[27400]=a|c;a=b;break k}a=x[b+8>>2]}x[b+8>>2]=d;x[a+12>>2]=d;x[d+12>>2]=b;x[d+8>>2]=a;return}e=31;if(a>>>0<=16777215){b=a>>>8|0;g=b+1048320>>>16&8;b=b<<g;e=b+520192>>>16&4;b=b<<e;c=b+245760>>>16&2;b=(b<<c>>>15|0)-(c|(e|g))|0;e=(b<<1|a>>>b+21&1)+28|0}x[d+28>>2]=e;x[d+16>>2]=0;x[d+20>>2]=0;g=(e<<2)+109904|0;l:{m:{c=x[27401];b=1<<e;n:{if(!(c&b)){x[27401]=b|c;x[g>>2]=d;x[d+24>>2]=g;break n}e=a<<((e|0)!=31?25-(e>>>1|0)|0:0);b=x[g>>2];while(1){c=b;if((x[b+4>>2]&-8)==(a|0)){break m}b=e>>>29|0;e=e<<1;g=c+(b&4)|0;b=x[g+16>>2];if(b){continue}break}x[g+16>>2]=d;x[d+24>>2]=c}x[d+12>>2]=d;x[d+8>>2]=d;break l}a=x[c+8>>2];x[a+12>>2]=d;x[c+8>>2]=d;x[d+24>>2]=0;x[d+12>>2]=c;x[d+8>>2]=a}a=x[27408]-1|0;x[27408]=a?a:-1}}function dy(a,b,c,d){a=a|0;b=b|0;c=+c;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=ib-176|0;ib=e;C[e+168>>3]=c;f=x[b+4>>2];a:{if(!f){break a}g=x[b>>2];h=y[gl(g,f)|0];if((h|0)==33){d=1}else{if((h|0)!=63){break a}d=0}ol(e+144|0,g,f,f-1|0);f=x[e+148>>2];x[b>>2]=x[e+144>>2];x[b+4>>2]=f}f=e+144|0;Yd(f);g=x[e+144>>2];Yd(e+128|0);h=fl(g,x[e+132>>2],b);Yd(f);f=x[b+4>>2];g=x[b>>2];b:{c:{d:{e:{if((h|0)==x[e+148>>2]){a=qc(e+160|0,21631);h=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=h;if(Nc(g,f,e+8|0)){d=ba(8)|0;x[27524]=0;R(970,e+128|0,e+168|0);a=x[27524];x[27524]=0;f:{g:{h:{if((a|0)!=1){x[27524]=0;U(973,e+144|0,17610,e+128|0);a=x[27524];x[27524]=0;if((a|0)==1){break h}lc(d,e+144|0);a=0;x[27524]=0;U(123,d|0,50060,962);b=x[27524];x[27524]=0;if((b|0)!=1){break b}b=P()|0;wb(e+144|0);break g}b=P()|0;break f}b=P()|0;a=1}wb(e+128|0);if(!a){break c}}ca(d|0);break c}if(!d){break e}d=ba(8)|0;a=x[b+4>>2];b=x[b>>2];x[27524]=0;f=Qh(e+96|0,b,a);a=x[27524];x[27524]=0;i:{j:{k:{l:{m:{n:{o:{p:{q:{if((a|0)!=1){x[27524]=0;U(973,e+112|0,17646,f|0);a=x[27524];x[27524]=0;if((a|0)==1){break q}x[27524]=0;R(975,e+128|0,e+112|0);b=x[27524];x[27524]=0;a=1;if((b|0)==1){break p}x[27524]=0;R(970,e+80|0,e+168|0);a=x[27524];x[27524]=0;if((a|0)==1){break o}x[27524]=0;U(977,e+144|0,e+128|0,e+80|0);b=x[27524];x[27524]=0;a=1;if((b|0)==1){break n}lc(d,e+144|0);x[27524]=0;U(123,d|0,50060,962);a=x[27524];x[27524]=0;if((a|0)!=1){break b}b=P()|0;wb(e+144|0);a=0;break m}b=P()|0;break i}b=P()|0;a=1;break j}b=P()|0;break k}b=P()|0;a=1;break l}b=P()|0}wb(e+80|0)}wb(e+128|0)}wb(e+112|0)}wb(f);if(!a){break c}}ca(d|0);break c}b=qc(e+72|0,21631);d=x[b+4>>2];x[e+40>>2]=x[b>>2];x[e+44>>2]=d;if(Nc(g,f,e+40|0)){d=ba(8)|0;x[27524]=0;R(970,e+128|0,e+168|0);a=x[27524];x[27524]=0;r:{s:{t:{if((a|0)!=1){x[27524]=0;U(973,e+144|0,17610,e+128|0);a=x[27524];x[27524]=0;if((a|0)==1){break t}lc(d,e+144|0);a=0;x[27524]=0;U(123,d|0,50060,962);b=x[27524];x[27524]=0;if((b|0)!=1){break b}b=P()|0;wb(e+144|0);break s}b=P()|0;break r}b=P()|0;a=1}wb(e+128|0);if(!a){break c}}ca(d|0);break c}b=qc(e- -64|0,7707);d=x[b+4>>2];x[e+32>>2]=x[b>>2];x[e+36>>2]=d;if(Nc(g,f,e+32|0)){if(!Qd(y[a+28|0])){break e}if(c<=0|c>4){a=ba(8)|0;x[27524]=0;d=Q(55,e+144|0,7802)|0;b=x[27524];x[27524]=0;if((b|0)==1){break d}lc(a,d);x[27524]=0;U(123,a|0,50060,962);a=x[27524];x[27524]=0;if((a|0)!=1){break b}b=P()|0;wb(d);break c}a=x[a+24>>2];i=a,j=Xe(65536/c),x[i+480244>>2]=j;Yp(a);break e}b=qc(e+56|0,7759);d=x[b+4>>2];x[e+24>>2]=x[b>>2];x[e+28>>2]=d;if(Nc(g,f,e+24|0)){if(!Qd(y[a+28|0])){break e}if(c<=0|c>4){a=ba(8)|0;x[27524]=0;d=Q(55,e+144|0,7823)|0;b=x[27524];x[27524]=0;if((b|0)!=1){lc(a,d);x[27524]=0;U(123,a|0,50060,962);a=x[27524];x[27524]=0;if((a|0)!=1){break b}b=P()|0;wb(d);break c}b=P()|0;ca(a|0);break c}a=x[a+24>>2];i=a,j=Xe(c*65536),x[i+480240>>2]=j;Yp(a);break e}b=qc(e+48|0,7777);d=x[b+4>>2];x[e+16>>2]=x[b>>2];x[e+20>>2]=d;if(!Nc(g,f,e+16|0)){break e}i=x[a+24>>2],j=Al(c*65536),x[i+480236>>2]=j}ib=e+176|0;return}b=P()|0;ca(a|0)}S(b|0)}p()}function Ng(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;k=ib-112|0;ib=k;l=i&2147483647;j=e&2147483647;m=j;a:{b:{o=!(b|c);if(!(d|j?j-2147418112>>>0<2147549184:o)){n=l-2147418112|0;if(!h&(n|0)==-2147418112?f|g:(n|0)==-2147418112&(h|0)!=0|n>>>0>2147549184){break b}}if(!(!d&(m|0)==2147418112?o:m>>>0<2147418112)){h=d;i=e|32768;f=b;g=c;break a}if(!(!h&(l|0)==2147418112?!(f|g):l>>>0<2147418112)){i=i|32768;break a}if(!(b|d|(m^2147418112|c))){j=d;d=!(b^f|d^h|(c^g|e^i^-2147483648));h=d?0:j;i=d?2147450880:e;f=d?0:b;g=d?0:c;break a}if(!(f|h|(l^2147418112|g))){break a}if(!(b|d|(c|m))){if(f|h|(g|l)){break a}f=b&f;g=c&g;h=d&h;i=e&i;break a}if(f|h|(g|l)){break b}f=b;g=c;h=d;i=e;break a}j=(l|0)==(m|0);j=j&(d|0)==(h|0)?(c|0)==(g|0)&b>>>0<f>>>0|c>>>0<g>>>0:j&d>>>0<h>>>0|l>>>0>m>>>0;p=j?f:b;m=j?g:c;l=j?i:e;s=l;q=j?h:d;o=l&65535;e=j?e:i;r=e;h=j?d:h;l=e>>>16&32767;n=s>>>16&32767;if(!n){d=!(o|q);e=d<<6;i=G(d?p:q)+32|0;d=G(d?m:o);d=e+((d|0)==32?i:d)|0;Sf(k+96|0,p,m,q,o,d-15|0);q=x[k+104>>2];o=x[k+108>>2];p=x[k+96>>2];n=16-d|0;m=x[k+100>>2]}f=j?b:f;g=j?c:g;i=r&65535;if(!l){b=!(h|i);c=b<<6;d=G(b?f:h)+32|0;b=G(b?g:i);b=c+((b|0)==32?d:b)|0;Sf(k+80|0,f,g,h,i,b-15|0);l=16-b|0;h=x[k+88>>2];i=x[k+92>>2];g=x[k+84>>2];f=x[k+80>>2]}c=h;b=i<<3|c>>>29;d=c<<3;c=b;b=g>>>29|d;c=c|524288;d=q;j=o<<3|d>>>29;h=d<<3|m>>>29;i=j;r=r^s;d=f;e=g<<3|d>>>29;d=d<<3;c:{if((l|0)==(n|0)){break c}f=n-l|0;if(f>>>0>127){b=0;c=0;e=0;d=1;break c}Sf(k- -64|0,d,e,b,c,128-f|0);xm(k+48|0,d,e,b,c,f);b=x[k+56>>2];c=x[k+60>>2];e=x[k+52>>2];d=x[k+48>>2]|(x[k+64>>2]|x[k+72>>2]|(x[k+68>>2]|x[k+76>>2]))!=0}l=d;o=e;j=h;q=i|524288;d=p;e=m<<3|d>>>29;m=d<<3;p=e;d:{if((r|0)<0){f=0;g=0;h=0;i=0;if(!(l^m|b^j|(o^p|c^q))){break a}d=m-l|0;e=p-((l>>>0>m>>>0)+o|0)|0;c=q-((b>>>0>j>>>0)+c|0)|0;f=j-b|0;b=(o|0)==(p|0)&l>>>0>m>>>0|o>>>0>p>>>0;i=c-(f>>>0<b>>>0)|0;h=f-b|0;if(i>>>0>524287){break d}b=!(h|i);c=b<<6;f=G(b?d:h)+32|0;b=G(b?e:i);b=c+((b|0)==32?f:b)|0;b=b-12|0;Sf(k+32|0,d,e,h,i,b);n=n-b|0;h=x[k+40>>2];i=x[k+44>>2];d=x[k+32>>2];e=x[k+36>>2];break d}e=o+p|0;d=l+m|0;e=d>>>0<m>>>0?e+1|0:e;f=b;b=j;f=f+b|0;j=c+q|0;j=b>>>0>f>>>0?j+1|0:j;c=f;b=c+((e|0)==(o|0)&d>>>0<l>>>0|e>>>0<o>>>0)|0;h=b;i=b>>>0<c>>>0?j+1|0:j;if(!(i&1048576)){break d}c=h;j=c<<31;d=l&1|((e&1)<<31|d>>>1);e=j|e>>>1;n=n+1|0;h=(i&1)<<31|c>>>1;i=i>>>1|0}c=0;m=s&-2147483648;if((n|0)>=32767){h=c;i=m|2147418112;f=0;g=0;break a}l=0;e:{if((n|0)>0){l=n;break e}Sf(k+16|0,d,e,h,i,n+127|0);xm(k,d,e,h,i,1-n|0);d=x[k>>2]|(x[k+16>>2]|x[k+24>>2]|(x[k+20>>2]|x[k+28>>2]))!=0;e=x[k+4>>2];h=x[k+8>>2];i=x[k+12>>2]}j=h<<29;o=(e&7)<<29|d>>>3;f=o;n=d&7;d=f+(n>>>0>4)|0;b=e>>>3|j;e=d>>>0<f>>>0?b+1|0:b;f=d;c=c|((i&7)<<29|h>>>3);g=e;b=c+((b|0)==(e|0)&d>>>0<o>>>0|b>>>0>e>>>0)|0;i=m|(i>>>3&65535|l<<16);i=b>>>0<c>>>0?i+1|0:i;h=b;f:{if((n|0)==4){c=0;j=g+c|0;d=f&1;b=f+d|0;j=b>>>0<f>>>0?j+1|0:j;f=b;g=j;c=(c|0)==(j|0)&b>>>0<d>>>0|c>>>0>j>>>0;b=c+h|0;i=b>>>0<c>>>0?i+1|0:i;h=b;break f}if(!n){break a}}}x[a>>2]=f;x[a+4>>2]=g;x[a+8>>2]=h;x[a+12>>2]=i;ib=k+112|0}function dJ(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;g=ib-48|0;ib=g;a:{b:{if(Fs(c)){h=x[b+484344>>2];if(Ce(h,x[b+484348>>2],c&65535)){break b}}c=a;a=Kb(g+32|0);b=Kb(g+16|0);vi(c,a,b);wb(b);wb(a);break a}c=Xb(h,c);if(!(x[c+12>>2]>(d|0)&(d|0)>=0)){c=a;a=Kb(g+32|0);b=Kb(g+16|0);vi(c,a,b);wb(b);wb(a);break a}if(!(z[b+480188>>1]>e>>>0&(e|0)>=0)){c=a;a=Kb(g+32|0);b=Kb(g+16|0);vi(c,a,b);wb(b);wb(a);break a}if(f>>>0>=6){c=a;a=Kb(g+32|0);b=Kb(g+16|0);vi(c,a,b);wb(b);wb(a);break a}c=hd(x[c>>2],x[x[c+48>>2]+12>>2],d,e&65535);c:{d:{e:{f:{switch(f|0){case 0:g:{h:{i:{j:{k:{d=y[c|0];if(!Wc(d)){if(!Wp(d)){break k}}e=g+16|0;HO(e,b,d,y[c+1|0]);x[27524]=0;R(1021,g+32|0,e|0);b=x[27524];x[27524]=0;d=1;if((b|0)!=1){break j}c=P()|0;break g}d=0;x[27524]=0;Q(55,g+32|0,16742)|0;b=x[27524];x[27524]=0;if((b|0)==1){break i}}b=9906;c=y[c|0];if(!Wc(c)){b=Wp(c)?10216:16742}x[27524]=0;b=Q(55,g|0,b|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break h}c=a;a=g+32|0;vi(c,a,b);wb(b);wb(a);if(!d){break a}xb(g+16|0);break a}c=P()|0;break d}c=P()|0;wb(g+32|0);if(!d){break d}}xb(g+16|0);break d;case 1:b=c+1|0;l:{if(y[c+1|0]){su(g+32|0,b);break l}Kc(g+32|0,16747)}b=y[b|0];x[27524]=0;b=Q(55,g+16|0,(b?10710:16747)|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break e}c=a;a=g+32|0;vi(c,a,b);wb(b);wb(a);break a;case 2:m:{if(oh(y[c|0])){Kc(g+32|0,17802);break m}d=y[c+2|0];if(d){wf(g+32|0,1,hO(x[x[b+8>>2]+88>>2],d));break m}Kc(g+32|0,17802)}b=17802;if(!oh(y[c|0])){b=y[c+2|0]?5508:17802}x[27524]=0;b=Q(55,g+16|0,b|0)|0;c=x[27524];x[27524]=0;if((c|0)!=1){c=a;a=g+32|0;vi(c,a,b);wb(b);wb(a);break a}c=P()|0;wb(g+32|0);break d;case 4:n:{if(oh(y[c|0])){i=g,j=nk(y[c+2|0],y[c+4|0])&255,x[i>>2]=j;aB(g+32|0,g);break n}if(y[c+2|0]){su(g+32|0,c+4|0);break n}Kc(g+32|0,16747)}b=5492;if(!oh(y[c|0])){b=y[c+2|0]?5492:16747}x[27524]=0;b=Q(55,g+16|0,b|0)|0;c=x[27524];x[27524]=0;if((c|0)!=1){c=a;a=g+32|0;vi(c,a,b);wb(b);wb(a);break a}c=P()|0;wb(g+32|0);break d;case 3:o:{if(oh(y[c|0])){i=g,j=(nk(y[c+3|0],y[c+5|0])&3840)!=0,v[i|0]=j;b=ib-32|0;ib=b;x[b+8>>2]=-1;x[b+12>>2]=0;x[b>>2]=0;Kb(b+16|0);x[27524]=0;x[b>>2]=x[b>>2]&-1332|1058;x[b+4>>2]=1;U(1112,g+32|0,g|0,b|0);d=x[27524];x[27524]=0;p:{if((d|0)!=1){nm(b);ib=b+32|0;break p}a=P()|0;nm(b);S(a|0);p()}break o}d=y[c+3|0];if(d){wf(g+32|0,1,gO(x[x[b+8>>2]+84>>2],d));break o}Kc(g+32|0,16748)}b=12271;if(!oh(y[c|0])){b=y[c+3|0]?12271:16748}x[27524]=0;b=Q(55,g+16|0,b|0)|0;c=x[27524];x[27524]=0;if((c|0)!=1){c=a;a=g+32|0;vi(c,a,b);wb(b);wb(a);break a}c=P()|0;wb(g+32|0);break d;case 5:break f;default:break c}}q:{if(oh(y[c|0])){i=g,j=nk(y[c+3|0],y[c+5|0])&255,x[i>>2]=j;aB(g+32|0,g);break q}if(y[c+3|0]){su(g+32|0,c+5|0);break q}Kc(g+32|0,16747)}b=11075;if(!oh(y[c|0])){b=y[c+3|0]?11075:16747}x[27524]=0;b=Q(55,g+16|0,b|0)|0;c=x[27524];x[27524]=0;if((c|0)!=1){c=a;a=g+32|0;vi(c,a,b);wb(b);wb(a);break a}c=P()|0;wb(g+32|0);break d}c=P()|0;wb(g+32|0)}S(c|0);p()}c=a;a=Kb(g+32|0);b=Kb(g+16|0);vi(c,a,b);wb(b);wb(a)}ib=g+48|0}function tia(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0;h=ib-4144|0;ib=h;g=Fb(y[a+14|0]|y[a+15|0]<<8);a:{if(!g|g>>>0>20){break a}j=b+480190|0;if(z[j>>1]<=y[a+23|0]){break a}md(d,32);w[d+34>>1]=1;f=h+24|0;g=a+20|0;x[f>>2]=g;x[f+4>>2]=(g+80|0)-g>>2;LS(h+4136|0,x[h+24>>2],x[h+28>>2],Fb(y[a+14|0]|y[a+15|0]<<8));g=x[h+4136>>2];k=y[Bb(g,0)+3|0];x[h+24>>2]=1;k=x[Yc(Oi(b,k+1|0)+24|0,f)>>2];i=f;f=x[h+4140>>2];LS(i,g,f,c?f:1);r=1/+(k>>>0);f=x[h+24>>2];g=Bb(f,x[h+28>>2]);k=x[h+4136>>2];j=z[j>>1];while(1){if((f|0)==(g|0)){b:{s=Xg(d);if(!s){break b}g=x[h+4140>>2];k=h+4120|0;x[k>>2]=0;x[k+4>>2]=0;sc(k+8|0);if(g){f=ib-16|0;ib=f;x[f+12>>2]=4925421;x[f+8>>2]=2147483647;j=x[Hb(f+12|0,f+8|0)>>2];ib=f+16|0;if(g>>>0>j>>>0){_c();p()}if(g>>>0>=4925422){Vg();p()}g=D(g,872);f=mc(g);x[k>>2]=f;x[k+4>>2]=f;C=Db(k),E=f+g|0,x[C>>2]=E;f=ib-16|0;ib=f;x[f>>2]=k;j=x[k+4>>2];x[f+4>>2]=j;x[f+8>>2]=g+j;i=x[f+4>>2];g=x[f+8>>2];while(1){if((g|0)==(i|0)){ic(f);ib=f+16|0}else{zS(Rb(i,0,872));i=i+872|0;x[f+4>>2]=i;continue}break}}j=(e<<12>>>0)/1e4|0;t=x[k>>2];n=x[h+4136>>2];u=x[h+4140>>2];B=b+480190|0;f=0;i=0;while(1){if((f|0)==(u|0)){g=b+24648|0}else{g=Bb(n,f);e=KS(t,f);l=y[g+3|0];c:{if(l>>>0>=z[B>>1]){break c}o=v[g+1|0];if((o|0)<0){break c}m=0;g=y[g+2|0];if((g+14&255)>>>0<=5){m=v[g+26814|0]}g=Oi(b,l+1|0);l=x[g+24>>2];q=r*(ki(+(m<<24>>24)/96+ +(o-v[Bb(n,0)+1|0]|0)/12)*+(l>>>0));if(q<=0){break c}m=JS(q);x[e+8>>2]=m;l=kb;x[e+12>>2]=l;x[e+16>>2]=x[g+20>>2];o=x[g>>2];x[e+76>>2]=o;x[e+88>>2]=z[g+34>>1]&1023;d:{if(c){x[e+664>>2]=i;i=Xe(+(o>>>0)/xA(m,l))+i|0;g=j;break d}g=(j>>>0)/(Fb(y[a+14|0]|y[a+15|0]<<8)>>>0)|0}x[e+20>>2]=g;x[e+24>>2]=g}f=f+1|0;continue}break}b=0;while(1){e:{a=x[d>>2];if(a>>>0>b>>>0){Rb(h+24|0,0,4096);x[h+16>>2]=512;x[h+12>>2]=a-b;c=x[Hb(h+16|0,h+12|0)>>2];C=h,E=Cb(x[k>>2]),x[C+16>>2]=E;j=Cb(x[k+4>>2]);while(1){a=x[h+16>>2];if(!Mb(a,j)){break e}f:{g:{if(!x[a+16>>2]){break g}e=x[a+664>>2];if(e>>>0>=c>>>0){x[a+664>>2]=e-c;break g}f=x[a+88>>2];x[h+12>>2]=c-e;C=h,E=Xe((+A[a+76>>2]-xA(x[a>>2],x[a+4>>2]))/xA(x[a+8>>2],x[a+12>>2])),x[C+8>>2]=E;i=x[Hb(h+12|0,h+8|0)>>2];x[27524]=0;X(x[((f&1|(f&64?18:16))<<2)+27408>>2],a|0,g|0,(h+24|0)+(e<<3)|0,i|0);e=x[27524];x[27524]=0;if((e|0)==1){break f}x[a+664>>2]=0;if(A[a+76>>2]>A[a+4>>2]){break g}x[a+16>>2]=0}x[h+16>>2]=x[h+16>>2]+872;continue}break}a=P()|0;iu(k);S(a|0);p()}iu(k);break b}e=x[d+20>>2]+(b<<1)|0;f=h+24|0;a=ib-16|0;ib=a;x[a+12>>2]=c;wc(a+12|0,512);i=x[a+12>>2];while(1){if(i){j=kd(x[f>>2]+2048|0,12);j=(j|0)>=32767?32767:j;w[e>>1]=(j|0)<=-32768?-32768:j;f=f+8|0;e=e+2|0;i=i-1|0;continue}break}ib=a+16|0;b=b+c|0;continue}}f=(s|0)!=0}else{i=y[f+3|0];h:{if(i>>>0>=j>>>0){break h}n=v[f+1|0];if((n|0)<0){break h}i=Oi(b,i+1|0);m=x[i>>2];q=ki(+(n-v[Bb(k,0)+1|0]|0)/-12);C=d,E=x[d>>2]+Xe(r*(q*+(m>>>0)*+A[i+24>>2]))|0,x[C>>2]=E}f=f+4|0;continue}break}}ib=h+4144|0;return f|0}function Mla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=ib-400|0;ib=e;g=ib-32|0;ib=g;d=g+8|0;tB(d,b);lv(g,d);x[27524]=0;U(467,e+240|0,x[g>>2],x[g+4>>2]);b=x[27524];x[27524]=0;a:{if((b|0)!=1){Rc(g+8|0);ib=g+32|0;break a}a=P()|0;Rc(g+8|0);S(a|0);p()}x[27524]=0;U(450,e+128|0,x[e+240>>2],x[e+244>>2]);b=x[27524];x[27524]=0;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{if((b|0)!=1){x[27524]=0;g=Q(90,e+256|0,e+128|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break z}wb(e+128|0);ec(e+240|0);if(c>>>0<2189){break g}b=bm(e+128|0,g);x[27524]=0;c=Q(453,e+112|0,10062)|0;d=x[27524];x[27524]=0;if((d|0)==1){break x}x[27524]=0;x[e+96>>2]=19988503;x[e+100>>2]=0;U(454,b|0,c|0,e+96|0);d=x[27524];x[27524]=0;if((d|0)==1){break w}Zb(c);v[e+111|0]=0;x[27524]=0;c=Q(453,e+96|0,10956)|0;d=x[27524];x[27524]=0;if((d|0)==1){break i}x[27524]=0;U(455,b|0,e+111|0,c|0);d=x[27524];x[27524]=0;if((d|0)==1){break v}Zb(c);c=0;c=y[e+111|0]?c:x[a+1298404>>2];f=x[a+4>>2];x[27524]=0;d=Q(453,e+80|0,15783)|0;h=x[27524];x[27524]=0;if((h|0)==1){break u}x[27524]=0;X(456,b|0,f|0,d|0,c|0);f=x[27524];x[27524]=0;if((f|0)==1){break t}Zb(d);x[27524]=0;d=Q(453,e- -64|0,15460)|0;f=x[27524];x[27524]=0;if((f|0)==1){break s}x[27524]=0;X(457,b|0,a|0,d|0,c|0);c=x[27524];x[27524]=0;if((c|0)==1){break r}Zb(d);x[27524]=0;c=Q(453,e+48|0,15359)|0;d=x[27524];x[27524]=0;if((d|0)==1){break q}x[27524]=0;d=a+484360|0;U(458,b|0,d|0,c|0);f=x[27524];x[27524]=0;if((f|0)==1){break p}Zb(c);x[27524]=0;c=Q(453,e+32|0,26662)|0;f=x[27524];x[27524]=0;if((f|0)==1){break o}x[27524]=0;U(459,b|0,a+484344|0,c|0);f=x[27524];x[27524]=0;if((f|0)==1){break n}Zb(c);f=x[a+1298404>>2];x[27524]=0;c=Q(453,e+16|0,26668)|0;h=x[27524];x[27524]=0;if((h|0)==1){break m}x[27524]=0;X(460,b|0,d|0,c|0,f|0);d=x[27524];x[27524]=0;if((d|0)==1){break l}Zb(c);if(Rk(y[b|0])){x[27524]=0;c=Q(1,e|0,16262)|0;d=x[27524];x[27524]=0;if((d|0)==1){break k}a=x[a+1298472>>2];x[27524]=0;U(380,a|0,1,c|0);a=x[27524];x[27524]=0;if((a|0)==1){break j}xb(c)}rh(b);break f}a=P()|0;break y}a=P()|0;wb(e+128|0)}ec(e+240|0);break b}a=P()|0;break h}a=P()|0;Zb(c);break h}a=P()|0;Zb(c);break h}a=P()|0;break h}a=P()|0;Zb(d);break h}a=P()|0;break h}a=P()|0;Zb(d);break h}a=P()|0;break h}a=P()|0;Zb(c);break h}a=P()|0;break h}a=P()|0;Zb(c);break h}a=P()|0;break h}a=P()|0;Zb(c);break h}a=P()|0;break h}a=P()|0;xb(c);break h}a=P()|0}rh(b);break c}b=Kb(e+128|0);d=x[a+1298404>>2];f=x[a+4>>2];x[27524]=0;d=fa(461,f|0,g|0,b|0,d|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break e}A:{if((d|0)!=1){x[27524]=0;c=Q(1,e+112|0,16568)|0;d=x[27524];x[27524]=0;B:{if((d|0)!=1){a=x[a+1298472>>2];x[27524]=0;U(380,a|0,1,c|0);a=x[27524];x[27524]=0;if((a|0)==1){break B}xb(c);break A}a=P()|0;break d}a=P()|0;xb(c);break d}d=x[a+1298404>>2];x[27524]=0;X(462,g|0,a|0,d|0,c>>>0<2188|0);a=x[27524];x[27524]=0;if((a|0)==1){break e}}xb(b)}Cf(g);ib=e+400|0;return}a=P()|0}xb(b)}Cf(g)}S(a|0);p()}function PU(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=a+b|0;c=x[a+4>>2];a:{b:{if(c&1){break b}if(!(c&3)){break a}c=x[a>>2];b=c+b|0;c:{a=a-c|0;if((a|0)!=x[27405]){if(c>>>0<=255){e=x[a+8>>2];c=c>>>3|0;d=x[a+12>>2];if((d|0)!=(e|0)){break c}i=109600,j=x[27400]&toa(-2,c),x[i>>2]=j;break b}h=x[a+24>>2];c=x[a+12>>2];d:{if((c|0)!=(a|0)){d=x[a+8>>2];x[d+12>>2]=c;x[c+8>>2]=d;break d}e:{e=a+20|0;d=x[e>>2];if(d){break e}e=a+16|0;d=x[e>>2];if(d){break e}c=0;break d}while(1){g=e;c=d;e=c+20|0;d=x[e>>2];if(d){continue}e=c+16|0;d=x[c+16>>2];if(d){continue}break}x[g>>2]=0}if(!h){break b}e=x[a+28>>2];d=(e<<2)+109904|0;f:{if(x[d>>2]==(a|0)){x[d>>2]=c;if(c){break f}i=109604,j=x[27401]&toa(-2,e),x[i>>2]=j;break b}x[h+(x[h+16>>2]==(a|0)?16:20)>>2]=c;if(!c){break b}}x[c+24>>2]=h;d=x[a+16>>2];if(d){x[c+16>>2]=d;x[d+24>>2]=c}d=x[a+20>>2];if(!d){break b}x[c+20>>2]=d;x[d+24>>2]=c;break b}c=x[f+4>>2];if((c&3)!=3){break b}x[27402]=b;x[f+4>>2]=c&-2;x[a+4>>2]=b|1;x[f>>2]=b;return}x[e+12>>2]=d;x[d+8>>2]=e}c=x[f+4>>2];g:{if(!(c&2)){if(x[27406]==(f|0)){x[27406]=a;b=x[27403]+b|0;x[27403]=b;x[a+4>>2]=b|1;if(x[27405]!=(a|0)){break a}x[27402]=0;x[27405]=0;return}if(x[27405]==(f|0)){x[27405]=a;b=x[27402]+b|0;x[27402]=b;x[a+4>>2]=b|1;x[a+b>>2]=b;return}b=(c&-8)+b|0;h:{if(c>>>0<=255){e=x[f+8>>2];c=c>>>3|0;d=x[f+12>>2];if((d|0)==(e|0)){i=109600,j=x[27400]&toa(-2,c),x[i>>2]=j;break h}x[e+12>>2]=d;x[d+8>>2]=e;break h}h=x[f+24>>2];c=x[f+12>>2];i:{if((f|0)!=(c|0)){d=x[f+8>>2];x[d+12>>2]=c;x[c+8>>2]=d;break i}j:{d=f+20|0;e=x[d>>2];if(e){break j}d=f+16|0;e=x[d>>2];if(e){break j}c=0;break i}while(1){g=d;c=e;d=c+20|0;e=x[d>>2];if(e){continue}d=c+16|0;e=x[c+16>>2];if(e){continue}break}x[g>>2]=0}if(!h){break h}e=x[f+28>>2];d=(e<<2)+109904|0;k:{if(x[d>>2]==(f|0)){x[d>>2]=c;if(c){break k}i=109604,j=x[27401]&toa(-2,e),x[i>>2]=j;break h}x[h+(x[h+16>>2]==(f|0)?16:20)>>2]=c;if(!c){break h}}x[c+24>>2]=h;d=x[f+16>>2];if(d){x[c+16>>2]=d;x[d+24>>2]=c}d=x[f+20>>2];if(!d){break h}x[c+20>>2]=d;x[d+24>>2]=c}x[a+4>>2]=b|1;x[a+b>>2]=b;if(x[27405]!=(a|0)){break g}x[27402]=b;return}x[f+4>>2]=c&-2;x[a+4>>2]=b|1;x[a+b>>2]=b}if(b>>>0<=255){c=(b&-8)+109640|0;d=x[27400];b=1<<(b>>>3);l:{if(!(d&b)){x[27400]=b|d;b=c;break l}b=x[c+8>>2]}x[c+8>>2]=a;x[b+12>>2]=a;x[a+12>>2]=c;x[a+8>>2]=b;return}e=31;if(b>>>0<=16777215){c=b>>>8|0;g=c+1048320>>>16&8;c=c<<g;e=c+520192>>>16&4;c=c<<e;d=c+245760>>>16&2;c=(c<<d>>>15|0)-(d|(e|g))|0;e=(c<<1|b>>>c+21&1)+28|0}x[a+28>>2]=e;x[a+16>>2]=0;x[a+20>>2]=0;g=(e<<2)+109904|0;m:{d=x[27401];c=1<<e;n:{if(!(d&c)){x[27401]=c|d;x[g>>2]=a;x[a+24>>2]=g;break n}e=b<<((e|0)!=31?25-(e>>>1|0)|0:0);c=x[g>>2];while(1){d=c;if((x[c+4>>2]&-8)==(b|0)){break m}c=e>>>29|0;e=e<<1;g=d+(c&4)|0;c=x[g+16>>2];if(c){continue}break}x[g+16>>2]=a;x[a+24>>2]=d}x[a+12>>2]=a;x[a+8>>2]=a;return}b=x[d+8>>2];x[b+12>>2]=a;x[d+8>>2]=a;x[a+24>>2]=0;x[a+12>>2]=d;x[a+8>>2]=b}}function Nna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;e=ib-736|0;ib=e;yc(b);f=ib-16|0;ib=f;h=e+120|0;FX(f+8|0,h);g=x[f+12>>2];j=b;kc(f,x[b>>2],x[b+8>>2],x[f+8>>2],x[f+12>>2]);b=x[f+4>>2];if((b|0)==(g|0)){Yb(j,x[f+12>>2])}ib=f+16|0;b=(b|0)==(g|0);if(!b){EX(h)}a:{if(!b){break a}if(!GX(e+120|0)){break a}b:{if(!c){break b}zd(a,67108864);gg(a);b=y[e+145|0];w[a+480190>>1]=31;w[a+480188>>1]=b;x[a+480228>>2]=256/(b>>>0);b=xc(e,8127);Gb(a+1298344|0,b);xb(b);b=xc(e,10713);Gb(a+1298356|0,b);xb(b);d=e+96|0;_f(d,4177);f=y[e+144|0];x[e+72>>2]=f>>>4;b=0;x[27524]=0;x[e+116>>2]=f&15;X(306,e|0,d|0,e+72|0,e+116|0);d=x[27524];x[27524]=0;c:{d:{if((d|0)!=1){Gb(a+1298368|0,e);xb(e);$b(e+96|0);x[a+1298404>>2]=28;Uq(Tb(x[a+484360>>2],y[a+484376|0]),e+168|0,y[e+167|0]+1|0);while(1){e:{if((b|0)==31){tC(j,a+1298308|0,32);d=1;break e}d=b+1|0;g=D(d,104)+a|0;h=g+484380|0;md(h,1);f=(e+120|0)+(b<<2)|0;q=h,r=ac(y[f+176|0]|y[f+177|0]<<8|(y[f+178|0]<<16|y[f+179|0]<<24)),x[q>>2]=r;k=ac(y[f+300|0]|y[f+301|0]<<8|(y[f+302|0]<<16|y[f+303|0]<<24));x[g+484384>>2]=k;f=ac(y[f+424|0]|y[f+425|0]<<8|(y[f+426|0]<<16|y[f+427|0]<<24));x[g+484388>>2]=f+k;if(f){f=g+484414|0;w[f>>1]=z[f>>1]|2}Jk(h);b=(e+120|0)+b|0;v[e|0]=y[b+548|0];v[e+96|0]=64;q=g+484410|0,r=y[Ub(e,e+96|0)|0]<<2,w[q>>1]=r;v[g+484417|0]=y[b+579|0]<<4;b=d;continue}break}while(1){if((d|0)!=32){DX(j,((d<<5)+a|0)+946304|0,30);d=d+1|0;continue}break}n=c&1;if(n){Fg(a+484344|0,y[e+166|0]+1|0)}k=a+484344|0;m=a+480188|0;f=0;while(1){if(y[e+166|0]<f>>>0){d=1;if(!(c&2)){break a}b=Zc(e,8,1,1,0);while(1){if((d|0)==32){break b}Eg(b,(D(d,104)+a|0)+484380|0,j);d=d+1|0;continue}}g=Oh(e+96|0);f:{g:{if(y[e+146|0]){x[27524]=0;b=T(275,j|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break f}x[27524]=0;U(194,e+72|0,j|0,b|0);b=x[27524];x[27524]=0;if((b|0)==1){break f}break g}b=z[m>>1];x[27524]=0;U(194,e+72|0,j|0,b<<8);b=x[27524];x[27524]=0;if((b|0)==1){break d}}b=e+72|0;d=hc(e,b);fd(g,d);yb(d);yb(b);h:{if(!n){break h}x[27524]=0;b=W(230,k|0,f&65535,64)|0;d=x[27524];x[27524]=0;if((d|0)==1){break d}if(!b){break h}b=0;if(y[e+146|0]){h=0;x[27524]=0;R(307,g|0,e|0);b=x[27524];x[27524]=0;if((b|0)==1){break d}i:while(1){if((h|0)==64){break h}i=e+h|0;b=128;d=0;l=Xb(x[k>>2],f);l=qf(x[l>>2],x[x[l+48>>2]+12>>2],h);while(1){if(z[m>>1]<=d>>>0){h=h+1|0;continue i}j:{if(!(y[i|0]&b)){break j}x[27524]=0;R(308,g|0,l+D(d,6)|0);o=x[27524];x[27524]=0;if((o|0)!=1){break j}break d}b=b>>>1|0;d=d+1|0;continue}}}k:while(1){d=0;h=b&65535;if(h>>>0>=z[m>>1]){break h}while(1){if((d|0)==64){b=b+1|0;continue k}i=Xb(x[k>>2],f);i=hd(x[i>>2],x[x[i+48>>2]+12>>2],d,h);x[27524]=0;R(308,g|0,i|0);i=x[27524];x[27524]=0;if((i|0)!=1){d=d+1|0;continue}break}break}break d}yb(g);f=f+1|0;continue}break}break d}d=P()|0;$b(e+96|0);break c}d=P()|0;yb(g)}S(d|0);p()}d=1}ib=e+736|0;return d|0}function gaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=ib-128|0;ib=e;a:{if(Qe(b)){break a}f=y[WJ(b)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}f=e+112|0;iw(f,b,0,Eb(b)-1|0);Ac(b,f);wb(f)}g=e+112|0;Yd(g);f=x[e+112>>2];Yd(e+96|0);f=VJ(f,x[e+100>>2],b);Yd(g);b:{c:{d:{e:{if((f|0)==x[e+116>>2]){if(de(b,21631)){a=ba(8)|0;x[27524]=0;U(964,e+112|0,17610,c|0);b=x[27524];x[27524]=0;if((b|0)==1){break d}lc(a,e+112|0);x[27524]=0;U(123,a|0,50060,962);a=x[27524];x[27524]=0;if((a|0)!=1){break b}b=P()|0;wb(e+112|0);break c}if(!d){break e}a=ba(8)|0;x[27524]=0;U(964,e+80|0,17646,b|0);b=x[27524];x[27524]=0;f:{g:{h:{i:{j:{if((b|0)!=1){x[27524]=0;R(975,e+96|0,e+80|0);b=x[27524];x[27524]=0;if((b|0)==1){break j}x[27524]=0;U(533,e+112|0,e+96|0,c|0);b=x[27524];x[27524]=0;d=1;if((b|0)==1){break i}lc(a,e+112|0);x[27524]=0;U(123,a|0,50060,962);b=x[27524];x[27524]=0;if((b|0)!=1){break b}b=P()|0;wb(e+112|0);d=0;break h}b=P()|0;break f}b=P()|0;d=1;break g}b=P()|0}wb(e+96|0)}wb(e+80|0);if(!d){break c}}ca(a|0);break c}k:{switch(x[f+4>>2]){case 0:ye(e+72|0,b);b=ib-192|0;ib=b;f=b+16|0;wi(f,c);x[27524]=0;R(89,b+32|0,f|0);c=x[27524];x[27524]=0;l:{m:{n:{o:{p:{if((c|0)!=1){x[27524]=0;c=Q(90,b+48|0,b+32|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break p}wb(b+32|0);wb(b+16|0);f=x[x[c>>2]-12>>2];x[27524]=0;g=ga(62)|0;h=x[27524];x[27524]=0;if((h|0)==1){break n}x[27524]=0;U(63,b+8|0,c+f|0,g|0);f=x[27524];x[27524]=0;if((f|0)==1){break n}_b(b+8|0);x[27524]=0;f=Q(1090,c|0,b+32|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break n}c=jh(x[(f+x[x[f>>2]-12>>2]|0)+16>>2]);g=y[b+32|0];Cf(f);ib=b+192|0;b=(c^-1)&(g|0)!=0;break l}a=P()|0;break o}a=P()|0;wb(b+32|0)}wb(b+16|0);break m}a=P()|0;Cf(c)}S(a|0);p()}c=x[e+76>>2];x[e+8>>2]=x[e+72>>2];x[e+12>>2]=c;ey(a,e+8|0,b,d);break e;case 1:ye(e- -64|0,b);b=ib-192|0;ib=b;f=b+16|0;wi(f,c);x[27524]=0;R(89,b+32|0,f|0);c=x[27524];x[27524]=0;q:{r:{s:{t:{u:{if((c|0)!=1){x[27524]=0;c=Q(90,b+48|0,b+32|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break u}wb(b+32|0);wb(b+16|0);f=x[x[c>>2]-12>>2];x[27524]=0;g=ga(62)|0;h=x[27524];x[27524]=0;if((h|0)==1){break s}x[27524]=0;U(63,b+8|0,c+f|0,g|0);f=x[27524];x[27524]=0;if((f|0)==1){break s}_b(b+8|0);x[27524]=0;f=Q(97,c|0,b+32|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break s}c=jh(x[(f+x[x[f>>2]-12>>2]|0)+16>>2]);g=x[b+32>>2];h=x[b+36>>2];Cf(f);ib=b+192|0;b=c?0:g;c=c?0:h;break q}a=P()|0;break t}a=P()|0;wb(b+32|0)}wb(b+16|0);break r}a=P()|0;Cf(c)}S(a|0);p()}f=x[e+68>>2];x[e+16>>2]=x[e+64>>2];x[e+20>>2]=f;cy(a,e+16|0,b,c,d);break e;case 2:ye(e+56|0,b);i=jI(c);b=x[e+60>>2];x[e+24>>2]=x[e+56>>2];x[e+28>>2]=b;dy(a,e+24|0,i,d);break e;case 3:break k;default:break e}}ye(e+48|0,b);ye(e+40|0,c);b=x[e+52>>2];x[e+32>>2]=x[e+48>>2];x[e+36>>2]=b;by(a,e+32|0,x[e+40>>2],x[e+44>>2],d)}ib=e+128|0;return}b=P()|0;ca(a|0)}S(b|0)}p()}function w_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=ib-352|0;ib=d;e=ib-16|0;ib=e;x[a+4>>2]=0;v[a|0]=0;f=a+40|0;wn(f,32);v[e+15|0]=0;vn(f,e+15|0);ib=e+16|0;e=x[a+36>>2];a:{if(!fh(x[x[e>>2]-12>>2]+e|0)){Ah(a,2,16777216);break a}f=d+88|0;Pd(f,e);e=x[f+12>>2];x[a+16>>2]=x[f+8>>2];x[a+20>>2]=e;x[f>>2]=3;h=x[a+36>>2];g=d+24|0;e=0;while(1){if(A[f>>2]>e>>>0){si(h,e+g|0);e=e+1|0;continue}break}if(Qb(g,25968,3)){Ah(a,2,512);break a}v[d+351|0]=0;si(x[a+36>>2],d+351|0);Rb(d+88|0,0,256);e=y[d+351|0];if(e){ri(x[a+36>>2],d+88|0,e)}g=b;b=Tk(d+24|0,d+88|0,e);e=Bw(g,b);Zb(b);if(!e){Ah(a,2,4096)}if(Rk(y[a|0])){break a}si(x[a+36>>2],d+87|0);g=y[d+87|0];b=g&3;w[a+24>>1]=(b|0)==3?4:b;if(_i(g,6)){b=d+24|0;Pc(b,a+32|0,9);bf(b,1)}x[d+80>>2]=0;_E(x[a+36>>2],d+80|0);b=x[d+80>>2];v[d+79|0]=0;if(b>>>0>=2){si(x[a+36>>2],d+87|0);e=-1;if(!y[d+87|0]){si(x[a+36>>2],d+79|0);e=-2}em(x[a+36>>2],b+e|0)}x[d+64>>2]=0;x[d+68>>2]=0;b:{if(!_i(g,4)){break b}Qk(x[a+36>>2],d- -64|0);b=x[d+68>>2];e=x[d+64>>2];x[a+64>>2]=e;x[a+68>>2]=b;f=x[c+4>>2];if((f|0)==(b|0)&A[c>>2]>=e>>>0|b>>>0<f>>>0){break b}Ah(a,1,4)}if(_i(g,5)){si(x[a+36>>2],d+87|0);em(x[a+36>>2],y[d+87|0])}c=y[d+79|0];c:{if(!_i(c,0)){break c}si(x[a+36>>2],d+87|0);b=y[d+87|0];b=b&1?-1:b>>>1|0;w[a+24>>1]=b;if(b){break c}Ah(a,1,2)}x[a+8>>2]=0;e=1;if(_i(c,1)){_E(x[a+36>>2],a+8|0)}h=_i(g,2);b=d+24|0;f=a+32|0;Pc(b,f,6);bf(b,h);h=_i(g,3);Pc(b,f,7);bf(b,h);h=z[a+24>>1];Pc(b,f,5);bf(b,(h|0)!=0);g=_i(g,7);Pc(b,f,8);bf(b,g);Pc(b,f,5);d:{if(zb(x[x[d+24>>2]>>2],x[d+28>>2])){break d}Pc(d+8|0,f,6);if(zb(x[x[d+8>>2]>>2],x[d+12>>2])){break d}Pc(d+56|0,f,7);if(zb(x[x[d+56>>2]>>2],x[d+60>>2])){break d}Pc(d+48|0,f,8);e=zb(x[x[d+48>>2]>>2],x[d+52>>2])}b=d+40|0;Pc(b,f,11);bf(b,e);Pc(d+24|0,f,11);if(_i(c,2)){w[d+8>>1]=0;tw(x[a+36>>2],d+8|0);b=x[a+36>>2];e=z[d+8>>1];Pc(d+24|0,f,9);em(b,D(e,zb(x[x[d+24>>2]>>2],x[d+28>>2])?2:1))}if(_i(c,3)){em(x[a+36>>2],5)}Qk(x[a+36>>2],d- -64|0);c=x[d+68>>2];g=c;b=x[d+64>>2];if(!c&b>>>0>=16001|c){Ah(a,2,8192);break a}x[a+104>>2]=b;if(!b){Ah(a,1,1)}Pc(d+24|0,f,11);e:{if(!zb(x[x[d+24>>2]>>2],x[d+28>>2])){break e}Qk(x[a+36>>2],d- -64|0);c=x[d+68>>2];g=c;b=x[d+64>>2];if(sw(b,c)){break e}Ah(a,2,2048);break a}c=d+8|0;Pd(c,x[a+36>>2]);e=x[a+16>>2];h=x[a+20>>2];i=x[c+4>>2];x[d+24>>2]=x[c>>2];x[d+28>>2]=i;i=x[c+12>>2];x[d+32>>2]=x[c+8>>2];x[d+36>>2]=i;c=x[d+32>>2];h=x[d+36>>2]-(h+(e>>>0>c>>>0)|0)|0;x[d+32>>2]=c-e;x[d+36>>2]=h;e=x[d+32>>2];c=x[d+36>>2];if((c|0)<0){Ah(a,2,16384);break a}x[a+96>>2]=e;x[a+100>>2]=c;c=d+24|0;Pc(c,f,11);e=x[a+100>>2];h=b;i=x[a+96>>2];b=zb(x[x[d+24>>2]>>2],x[d+28>>2]);x[a+72>>2]=b?h:i;x[a+76>>2]=b?g:e;Pc(c,f,11);if(!zb(x[x[d+24>>2]>>2],x[d+28>>2])){b=x[a+100>>2]+x[a+20>>2]|0;e=x[a+16>>2];c=e+x[a+96>>2]|0;x[a+80>>2]=c;x[a+84>>2]=c>>>0<e>>>0?b+1|0:b}a=d+24|0;Pc(a,f,10);bf(a,1)}ib=d+352|0}function EO(a,b){var c=0,d=0,e=0,f=0,g=E(0),h=0,i=0,j=0,k=0,l=E(0),m=E(0),n=0,o=0,p=0,q=0,r=0,s=E(0),t=0;if(b){Wy(a);c=a+24596|0;x[c>>2]=0;x[c+4>>2]=0;x[a+24588>>2]=0;x[a+24592>>2]=0;JO(a)}DO(a+24648|0);o=x[a+24620>>2];f=ib-144|0;ib=f;d=!b;e=a+397456|0;c=x[e+4>>2];if(c>>>0>=29){x[e+4>>2]=0;c=0}h=D(c,44)+47552|0;if(!((h|0)==x[e+8>>2]&d)){x[e+8>>2]=h;m=E(o>>>0);c=f+8|0;d=x[h+24>>2];x[c>>2]=d;j=x[h+16>>2];x[c+4>>2]=j;x[c+8>>2]=x[h+4>>2];k=(d|0)>(j|0)?d:j;if((k|0)<=-601){i=j;j=k+600|0;x[c+4>>2]=i-j;x[c>>2]=d-j}g=E(B[h+36>>2]*E(79.30999755859375));a:{if(E(F(g))<E(2147483648)){d=~~g;break a}d=-2147483648}x[c+16>>2]=d- -8192;g=E(E(E(B[h+32>>2]*E(.0036000001709908247))+E(.15000000596046448))*E(32767));b:{if(E(F(g))<E(2147483648)){d=~~g;break b}d=-2147483648}x[c+20>>2]=(d|0)>=32512?32512:d;j=0;g=B[h+8>>2];l=E(E(H(B[h+20>>2],E(.10000000149011612)))*m);c:{if(E(F(l))<E(2147483648)){d=~~l;break c}d=-2147483648}k=(d|0)<=96?96:d;i=k-7500|0;n=k>>>0>=i>>>0?i:0;l=E(B[h+28>>2]*m);d:{if(E(F(l))<E(2147483648)){i=~~l;break d}i=-2147483648}d=n+(i+((d|0)<96?d-96|0:0)|0)|0;i=(d|0)<=128?128:d;p=i>>>0>=3800?3800:i;x[c+24>>2]=p;n=(d|0)<128?d-128|0:0;g=E(g*m);e:{if(E(F(g))<E(2147483648)){q=~~g;break e}q=-2147483648}d=i-3800|0;i=(q+n|0)+(d>>>0<=i>>>0?d:0)|0;x[c+32>>2]=i;n=k>>>0>=7500?7500:k;while(1){if((j|0)==8){g=E(i|0);l=E(ze(E(.0010000000474974513),(i|0)<4721?E(1):E(E(4720)/g))*E(32768));f:{if(E(F(l))<E(2147483648)){d=~~l;break f}d=-2147483648}x[c+12>>2]=d;g=E(B[h+12>>2]*g);r=c,s=ze(E(.0010000000474974513),g<=E(4720)?E(1):E(E(4720)/g)),B[r+28>>2]=s}else{d=D(j,12);k=d+c|0;w[k+42>>1]=z[d+48842>>1];w[k+36>>1]=z[d+48836>>1];w[k+40>>1]=z[d+48840>>1];w[k+38>>1]=z[d+48838>>1];x[k+44>>2]=n+((D(x[d+48832>>2],p)+50|0)/100|0);j=j+1|0;continue}break}x[e+20>>2]=x[f+40>>2];c=FM(GM(x[f+16>>2]),m);w[e+86>>1]=c;w[e+84>>1]=c;c=z[f+24>>1]<<1;w[e+94>>1]=c;w[e+92>>1]=c;c=0;while(1){if((c|0)==8){x[e+49892>>2]=x[f+32>>2];c=x[f+12>>2];if((c|0)>-9e3){c=EM(c)}else{c=0}x[e+80>>2]=c;d=e+49948|0;c=x[f+8>>2];if((c|0)>=-8999){c=EM(c)}else{c=0}x[d>>2]=c;c=x[f+28>>2];d=e+49932|0;x[d>>2]=268464128;x[d+4>>2]=1879052288;c=c>>>0>=32512?32512:c;w[e+49906>>1]=c;w[e+49904>>1]=c;w[e+49902>>1]=c;w[e+49900>>1]=c;x[f+4>>2]=x[f+20>>2];re(f+4|0,0,32752);c=z[f+4>>1];w[e+49914>>1]=c;w[e+49910>>1]=0;w[e+49912>>1]=0;w[e+49908>>1]=c;g=B[f+36>>2];r=f,t=FM(E(g*g),m),x[r>>2]=t;re(f,256,32512);c=z[f>>1];w[e+49922>>1]=c;w[e+49918>>1]=0;w[e+49920>>1]=0;w[e+49916>>1]=c}else{d=(c<<4)+e|0;h=(f+8|0)+D(c,12)|0;j=x[h+44>>2];x[d+100>>2]=j;x[d+104>>2]=j;w[d+108>>1]=z[h+36>>1];w[d+110>>1]=z[h+42>>1];w[d+112>>1]=z[h+40>>1];w[d+114>>1]=z[h+38>>1];c=c+1|0;continue}break}}c=a+397448|0;d=a+397452|0;if(b){x[e+16>>2]=0;IM(e,c,d)}b=D(o,5);if(b>>>0>A[e+20>>2]){x[e+20>>2]=b}ib=f+144|0;b=x[a+1298300>>2];if(Ed(b)){qR(b,x[a+24620>>2])}}function aZ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,w=0;e=ib-32|0;ib=e;x[e+28>>2]=b;a:{if((d|0)<=0){break a}x[e+8>>2]=d;x[e+16>>2]=214748364;u=e,w=D(x[Hb(e+28|0,e+16|0)>>2],20),x[u+20>>2]=w;wn(c,x[Hb(e+8|0,e+20|0)>>2]);x[e+12>>2]=b;x[e+8>>2]=a;while(1){b:{c:{d:{e:{if((d|0)<=0){break e}g=xh(a,b,i);h=xh(a,b,i+4|0);f=xh(a,b,i+5|0);u=e,w=xh(a,b,i+6|0)<<8|xh(a,b,i+7|0),x[u+24>>2]=w;n=f|h<<8;t=i+8|0;f:{g:{switch(g|0){case 0:i=0;if(d>>>0<n>>>0){i=ba(8)|0;x[27524]=0;a=T(197,i|0)|0;b=x[27524];x[27524]=0;if((b|0)!=1){break f}break d}while(1){if((i|0)!=(n|0)){u=e,w=xh(a,b,i+t|0),v[u+20|0]=w;vn(c,e+20|0);i=i+1|0;continue}break};s=n;break b;case 1:break g;default:break e}}gi(e+24|0,d);s=x[e+24>>2];o=xh(a,b,i+10|0);v[e+20|0]=o;vn(c,e+20|0);j=i+11|0;n=n+3&65532;i=s-1|0;h=0;l=0;q=0;m=0;while(1){if((i|0)<=0){break c}f=Ig(j,h,1,e+8|0);h:{i:{j:{k:{l:{if((l|0)<=7){if(f){g=h;break i}g=h+1|0;m=8;break l}g=h+1|0;m:{if(!f){if(!Ig(j,g,1,e+8|0)){break i}k=2;n:{o:{f=h+2|0;if(!Ig(j,f,1,e+8|0)){break o}k=3;f=h+3|0;if(!Ig(j,f,1,e+8|0)){break o}k=Ig(j,f,3,e+8|0);g=h+6|0;break n}g=f+1|0}f=4;p:{q:{r:{h=((m<<3)+k|0)-17|0;s:{if((h|0)<0){a=ba(8)|0;x[27524]=0;b=T(197,a|0)|0;c=x[27524];x[27524]=0;if((c|0)!=1){break r}break s}if(h>>>0<56){break p}a=ba(8)|0;x[27524]=0;b=T(197,a|0)|0;c=x[27524];x[27524]=0;if((c|0)!=1){break q}}b=P()|0;ca(a|0);S(b|0);p()}ha(b|0,26072,172);p()}ha(b|0,26072,172);p()}m=y[h+26112|0];if((m|0)!=8){break k}break m}f=4;if((m|0)!=8){break k}}m=8;f=1;if((q|0)>19){break k}}f=0;break j}q=q+8|0}while(1){if(!((f|0)<0|(i|0)<=0)){k=(g|0)/8|0;h=k+j|0;r=xh(x[e+8>>2],x[e+12>>2],h);o=o-kd((xh(x[e+8>>2],x[e+12>>2],h+1|0)<<8|r<<16|xh(x[e+8>>2],x[e+12>>2],h+2|0))<<(g-(k<<3)|0)+8,32-m|0)|0;v[e+20|0]=o;vn(c,e+20|0);f=f-1|0;i=i-1|0;g=g+m|0;continue}break}l=(l|0)==31?31:l+1|0;h=g;break h}t:{u:{v:{f=g+1|0;if(!Ig(j,f,1,e+8|0)){h=2;break v}f=g+2|0;if(!Ig(j,f,1,e+8|0)){h=4;break v}f=g+3|0;if(!Ig(j,f,1,e+8|0)){h=6;break v}f=g+5|0;if(!Ig(j,g+4|0,1,e+8|0)){g=g+8|0;f=Ig(j,f,3,e+8|0)+8|0;break t}g=g+10|0;h=16;f=Ig(j,f,5,e+8|0);break u}g=f+2|0;f=Ig(j,f+1|0,1,e+8|0)}f=f+h|0}w:{if(Ig(j,g,1,e+8|0)){k=-256;h=12;break w}g=g+1|0;h=Ig(j,g,1,e+8|0);k=h?-4352:0;h=h?14:8}r=g+1|0;g=Ig(j,r,h,e+8|0);if(f>>>0>=3){l=l-((f|0)!=3)|0;l=((l|0)<=1?1:l)-1|0}k=(g^-1)+k|0;g=cd(x[c>>2],x[c+4>>2])+k|0;if(g>>>0<k>>>0){h=h+r|0;while(1){if((f|0)<=0|(i|0)<=0){break h}o=y[Jb(x[c>>2],g)|0];v[e+20|0]=o;vn(c,e+20|0);i=i-1|0;g=g+1|0;f=f-1|0;continue}}i=ba(8)|0;x[27524]=0;a=T(197,i|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break d}ha(a|0,26072,172);p()}q=q-(q>>3)|0;continue}}ha(a|0,26072,172);p()}i=pc(x[c>>2],x[c+4>>2])^1;break a}a=P()|0;ca(i|0);S(a|0);p()}x[e+24>>2]=i}d=d-s|0;i=n+t|0;continue}}ib=e+32|0;return i|0}function LV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=ib-176|0;ib=g;i=zg(g+160|0);a:{b:{c:{if(d){x[27524]=0;U(474,a|0,i|0,c|0);c=x[27524];x[27524]=0;if((c|0)!=1){break c}break b}x[27524]=0;U(475,a|0,i|0,c|0);c=x[27524];x[27524]=0;if((c|0)==1){break b}}k=Nb(g+144|0);m=b+480192|0;n=b+1298472|0;c=1;while(1){d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{h=c&65535;if(h>>>0<=z[m>>1]){x[27524]=0;w[g+142>>1]=0;R(476,a|0,g+142|0);d=x[27524];x[27524]=0;t:{u:{v:{w:{if((d|0)!=1){j=ib-16|0;ib=j;o=z[g+142>>1];d=Td(i);e=gc(i);f=ib-16|0;ib=f;while(1){if(d){l=ro(z[d+16>>1],o);e=l?e:d;d=x[(l?d+4|0:d)>>2];continue}break}d=x[Wb(f+8|0,e)>>2];ib=f+16|0;x:{if(Mb(d,eg(i))){if(!ro(z[g+142>>1],z[ud(d)>>1])){break x}}d=eg(i)}d=Wb(j+8|0,d);ib=j+16|0;j=((h<<2)+b|0)+900380|0;if(!x[j>>2]){break d}d=x[d>>2];if(!Rg(d,Gf(i))){break u}x[27524]=0;d=Q(3,g+128|0,ud(d)+4|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break t}x[27524]=0;e=Q(1,g+112|0,16758)|0;f=x[27524];x[27524]=0;if((f|0)==1){break v}f=Aq(d,e);xb(e);if(f){break p}e=x[b+4>>2];x[27524]=0;e=Q(477,e|0,d|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break r}x[x[j>>2]+44>>2]=e;if(!x[x[j>>2]+44>>2]){break w}break e}c=P()|0;break f}x[27524]=0;e=Q(1,g+96|0,13371)|0;f=x[27524];x[27524]=0;y:{z:{A:{if((f|0)!=1){B:{if(!Aq(d,e)){x[27524]=0;f=Q(1,g+80|0,13621)|0;h=x[27524];x[27524]=0;if((h|0)==1){break A}h=Aq(d,f);xb(f);xb(e);if(h){break B}break s}xb(e)}x[27524]=0;e=T(478,d|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break z}x[g+56>>2]=e;e=x[b+4>>2];f=x[ge(g+72|0,g+56|0)>>2];x[27524]=0;e=Q(479,e|0,f|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break y}yg(g+56|0);if(e){break e}break s}c=P()|0;break g}c=P()|0;xb(e);break g}c=P()|0;break g}c=P()|0;yg(g+56|0);break g}c=P()|0;break g}d=x[j>>2];if(!d){break d}x[d+44>>2]=0;break d}c=P()|0;break f}Wl(k);KV(i);ib=g+176|0;return}e=Cb(x[k>>2]);h=Cb(x[k+4>>2]);f=ib-16|0;ib=f;x[f+8>>2]=e;while(1){C:{if(!Mb(e,h)){break C}if(Aq(e,d)){break C}e=x[yq(f+8|0)>>2];continue}break}ib=f+16|0;if(Mb(e,Cb(x[k+4>>2]))){break p}x[27524]=0;R(480,k|0,d|0);e=x[27524];x[27524]=0;if((e|0)!=1){break q}}c=P()|0;break g}x[27524]=0;e=Q(1,g+24|0,17459)|0;f=x[27524];x[27524]=0;if((f|0)==1){break o}x[27524]=0;U(481,g+40|0,e|0,d|0);f=x[27524];x[27524]=0;if((f|0)==1){break n}x[27524]=0;f=Q(1,g+8|0,16311)|0;h=x[27524];x[27524]=0;if((h|0)==1){break m}x[27524]=0;U(2,g+56|0,g+40|0,f|0);h=x[27524];x[27524]=0;if((h|0)==1){break l}h=x[n>>2];x[27524]=0;U(380,h|0,2,g+56|0);h=x[27524];x[27524]=0;if((h|0)==1){break k}xb(g+56|0);xb(f);xb(g+40|0);xb(e)}x[x[j>>2]+44>>2]=0;break e}c=P()|0;break g}c=P()|0;break h}c=P()|0;break i}c=P()|0;break j}c=P()|0;xb(g+56|0)}xb(f)}xb(g+40|0)}xb(e)}xb(d)}Wl(k);break a}xb(d)}c=c+1|0;continue}}c=P()|0}KV(i);S(c|0);p()}function Wha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;j=ib-32|0;ib=j;a:{b:{if(Ut(a)>>>0<b>>>0){if((b|0)<0){break b}n=ko(j+16|0);x[27524]=0;R(736,n|0,b|0);b=x[27524];x[27524]=0;if((b|0)==1){break a}wl(j+8|0,x[a>>2]);Im(j,x[a>>2],x[a+4>>2]);m=ib-48|0;ib=m;c=x[n+4>>2];e=dc(m+40|0,x[j+8>>2],x[j+12>>2]);f=dc(m+32|0,x[j>>2],x[j+4>>2]);b=ib-16|0;ib=b;e=dc(b+8|0,x[e>>2],x[e+4>>2]);f=dc(b,x[f>>2],x[f+4>>2]);e=FT(x[e>>2],x[e+4>>2],x[f>>2],x[f+4>>2]);ib=b+16|0;e=c+e|0;x[n+4>>2]=e;c:{d:{if(!c){b=e-1|0;break d}b=e-1|0;if((b^c-1)>>>0<32){break c}}x[x[n>>2]+((e>>>0>=33?b>>>5|0:0)<<2)>>2]=0}f=dc(m+24|0,x[j+8>>2],x[j+12>>2]);e=dc(m+16|0,x[j>>2],x[j+4>>2]);b=m+8|0;So(b,x[n>>2],c);c=x[f>>2];o=ib-48|0;ib=o;f=x[f+4>>2];e:{if((f|0)==x[b+4>>2]){f=dc(o+40|0,c,f);c=dc(o+32|0,x[e>>2],x[e+4>>2]);b=dc(o+24|0,x[b>>2],x[b+4>>2]);e=ib-16|0;ib=e;g=x[f>>2];d=x[f+4>>2];c=vl(x[c>>2],x[c+4>>2],g,d);x[e+12>>2]=c;f:{if((c|0)<=0){c=x[b>>2];break f}if(d){i=32-d|0;x[e+8>>2]=i;k=c;c=x[rd(e+8|0,e+12|0)>>2];x[e+12>>2]=k-c;h=x[b>>2];d=-1<<d&-1>>>i-c;x[h>>2]=x[h>>2]&(d^-1)|d&x[g>>2];c=c+x[b+4>>2]|0;x[b+4>>2]=c&31;x[b>>2]=h+(c>>>3&536870908);g=x[f>>2]+4|0;x[f>>2]=g;c=x[e+12>>2]}k=g;d=(c|0)/32|0;g=d<<2;Wi(x[b>>2],k,g);d=c-(d<<5)|0;x[e+12>>2]=d;c=g+x[b>>2]|0;x[b>>2]=c;if((d|0)<=0){break f}c=f;f=g+x[f>>2]|0;x[c>>2]=f;c=x[b>>2];g=-1>>>32-d|0;x[c>>2]=x[c>>2]&(g^-1)|g&x[f>>2];x[b+4>>2]=x[e+12>>2]}dc(m,c,x[b+4>>2]);break e}g=dc(o+16|0,c,f);c=dc(o+8|0,x[e>>2],x[e+4>>2]);f=dc(o,x[b>>2],x[b+4>>2]);e=ib-16|0;ib=e;k=x[c>>2];d=x[c+4>>2];b=x[g>>2];c=x[g+4>>2];d=vl(k,d,b,c);x[e+12>>2]=d;g:{if((d|0)<=0){c=x[f+4>>2];break g}h:{if(!c){c=x[f+4>>2];break h}l=32-c|0;x[e+8>>2]=l;i=e+8|0;h=x[rd(i,e+12|0)>>2];x[e+12>>2]=d-h;d=x[f+4>>2];q=x[b>>2];x[e+8>>2]=h;k=32-d|0;x[e+4>>2]=k;b=x[f>>2];r=x[b>>2];i=x[Hb(i,e+4|0)>>2];l=q&(-1<<c&-1>>>l-h);x[b>>2]=(-1<<d&-1>>>k-i^-1)&r|(c>>>0<d>>>0?l<<d-c:l>>>c-d|0);d=d+i|0;c=d&31;x[f+4>>2]=c;d=b+(d>>>3&536870908)|0;x[f>>2]=d;b=h-i|0;if((b|0)>0){x[d>>2]=x[d>>2]&(-1>>>32-b^-1)|l>>>i+x[g+4>>2];x[f+4>>2]=b;c=b}b=x[g>>2]+4|0;x[g>>2]=b;d=x[e+12>>2]}h=32-c|0;i=-1<<c;l=i^-1;while(1){if((d|0)>=32){d=x[f>>2];b=x[b>>2];x[d>>2]=l&x[d>>2]|b<<c;x[f>>2]=d+4;x[d+4>>2]=i&x[d+4>>2]|b>>>h;d=x[e+12>>2]-32|0;x[e+12>>2]=d;b=x[g>>2]+4|0;x[g>>2]=b;continue}break}if((d|0)<=0){break g}l=x[b>>2];x[e+8>>2]=h;g=x[f>>2];b=x[g>>2];k=b;b=x[rd(e+12|0,e+8|0)>>2];k=k&(i&-1>>>h-b^-1);h=l&-1>>>32-d;x[g>>2]=k|h<<c;d=b+c|0;c=d&31;x[f+4>>2]=c;g=g+(d>>>3&536870908)|0;x[f>>2]=g;d=x[e+12>>2]-b|0;x[e+12>>2]=d;if((d|0)<=0){break g}x[g>>2]=x[g>>2]&(-1>>>32-d^-1)|h>>>b;c=x[e+12>>2];x[f+4>>2]=c}dc(m,x[f>>2],c)}ib=e+16|0;ib=o+48|0;ib=m+48|0;bu(a,n);$e(n)}ib=j+32|0;return}_c();p()}a=P()|0;$e(n);S(a|0);p()}function AE(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a=ib-176|0;ib=a;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{if((c|0)<=5){aw(a+128|0,c);x[27524]=0;c=Q(1,a+112|0,17746)|0;d=x[27524];x[27524]=0;if((d|0)==1){break E}x[27524]=0;U(2,a+144|0,a+128|0,c|0);d=x[27524];x[27524]=0;if((d|0)==1){break D}x[27524]=0;d=Q(3,a+80|0,e|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break C}x[27524]=0;e=Q(1,a- -64|0,19574)|0;f=x[27524];x[27524]=0;if((f|0)==1){break B}x[27524]=0;U(4,a+96|0,d|0,e|0);f=x[27524];x[27524]=0;if((f|0)==1){break A}x[27524]=0;U(2,a+160|0,a+144|0,a+96|0);f=x[27524];x[27524]=0;if((f|0)==1){break z}xb(a+96|0);xb(e);xb(d);d=a+144|0;xb(d);xb(c);xb(a+128|0);c=x[b>>2];x[27524]=0;U(5,d|0,1,(c?c:21631)|0);c=x[27524];x[27524]=0;if((c|0)==1){break t}c=x[b+4>>2];x[27524]=0;U(5,a+128|0,1,(c?c:21631)|0);c=x[27524];x[27524]=0;if((c|0)==1){break s}b=x[b+8>>2];x[27524]=0;x[a+48>>2]=b;R(6,a+96|0,a+48|0);b=x[27524];x[27524]=0;if((b|0)==1){break r}x[27524]=0;Q(7,482728,17625)|0;b=x[27524];x[27524]=0;if((b|0)==1){break q}x[27524]=0;U(8,a+48|0,0,a+144|0);b=x[27524];x[27524]=0;if((b|0)==1){break p}x[27524]=0;Q(9,482728,a+48|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break o}x[27524]=0;Q(7,482728,17419)|0;b=x[27524];x[27524]=0;if((b|0)==1){break o}x[27524]=0;U(8,a+32|0,0,a+96|0);b=x[27524];x[27524]=0;if((b|0)==1){break n}x[27524]=0;Q(9,482728,a+32|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break m}x[27524]=0;Q(7,482728,17417)|0;b=x[27524];x[27524]=0;if((b|0)==1){break m}x[27524]=0;Q(7,482728,17746)|0;b=x[27524];x[27524]=0;if((b|0)==1){break m}x[27524]=0;U(8,a+16|0,0,a+160|0);b=x[27524];x[27524]=0;if((b|0)==1){break l}x[27524]=0;Q(9,482728,a+16|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break k}x[27524]=0;Q(7,482728,13397)|0;b=x[27524];x[27524]=0;if((b|0)==1){break k}x[27524]=0;U(8,a|0,0,a+128|0);b=x[27524];x[27524]=0;if((b|0)==1){break j}x[27524]=0;Q(9,482728,a|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break i}x[27524]=0;Q(7,482728,13395)|0;b=x[27524];x[27524]=0;if((b|0)==1){break i}x[27524]=0;T(10,482728)|0;b=x[27524];x[27524]=0;if((b|0)==1){break i}wb(a);wb(a+16|0);wb(a+32|0);wb(a+48|0);xb(a+96|0);xb(a+128|0);xb(a+144|0);xb(a+160|0)}ib=a+176|0;return}b=P()|0;break u}b=P()|0;break v}b=P()|0;break w}b=P()|0;break x}b=P()|0;break y}b=P()|0;xb(a+96|0)}xb(e)}xb(d)}xb(a+144|0)}xb(c)}xb(a+128|0);break a}b=P()|0;break b}b=P()|0;break c}b=P()|0;break d}b=P()|0;break e}b=P()|0;break e}b=P()|0;break f}b=P()|0;break f}b=P()|0;break g}b=P()|0;break g}b=P()|0;break h}b=P()|0;break h}b=P()|0;wb(a)}wb(a+16|0)}wb(a+32|0)}wb(a+48|0)}xb(a+96|0)}xb(a+128|0)}xb(a+144|0)}xb(a+160|0)}S(b|0);p()}function OM(a){var b=E(0),c=E(0),d=0,e=E(0),f=E(0),g=0,h=0,i=E(0),k=0,m=E(0),p=E(0),s=0,t=E(0),u=0,v=E(0),w=E(0);d=a+4208|0;tQ(Bb(d,0),B[a+4272>>2]);b=E(E(B[Bb(d,0)>>2]*E(15920))+E(80));t=ze(E(10),E(E(E(B[Bb(d,2)>>2]+E(-.5))*E(30))/E(40)));c=E(E(b/E(A[x[a+16>>2]+24620>>2]))*E(6.2831854820251465));b=eN(c);v=Mp(c);w=b;f=E(E(c*E(E(E(B[Bb(d,1)>>2]*E(35))+E(1))*E(.02888113260269165)))/b);m=(l(2,(q(f),j(2))&-2147483648|1056964608),r());g=(q(f),j(2))&2147483647;c=(l(2,g),r());a:{if(g>>>0<=1118925334){b:{c:{d:{e:{f:{g:{h=(q(c),j(2));d=h&2147483647;if(d>>>0>=1100331076){if(d>>>0>2139095040){break c}b=E(-1);if((h|0)<0){break b}if(!(c>E(88.7216796875))){break g}b=E(c*E(17014118346046923e22));break b}if(d>>>0<1051816473){break e}if(d>>>0>1065686417){break g}if((h|0)>=0){d=1;e=E(905800061445916e-20);b=E(c+E(-.6931381225585938));break f}d=-1;e=E(-905800061445916e-20);b=E(c+E(.6931381225585938));break f}b=E(E(c*E(1.4426950216293335))+(l(2,(q(c),j(2))&-2147483648|1056964608),r()));h:{if(E(F(b))<E(2147483648)){d=~~b;break h}d=-2147483648}b=E(d|0);e=E(b*E(905800061445916e-20));b=E(c+E(b*E(-.6931381225585938)))}c=E(b-e);e=E(E(b-c)-e);break d}if(d>>>0<855638016){break c}d=0}b=E(c*E(.5));i=E(c*b);p=E(E(i*E(E(i*E(.0015807170420885086))+E(-.03333321213722229)))+E(1));b=E(E(3)-E(p*b));p=E(i*E(E(p-b)/E(E(6)-E(c*b))));b=E(c-E(E(c*p)-i));if(!d){break b}e=E(E(E(c*E(p-e))-e)-i);i:{switch(d+1|0){case 0:b=E(E(E(c-e)*E(.5))+E(-.5));break b;case 2:b=E(E(e-E(c+E(.5)))*E(-2));if(c<E(-.25)){break b}b=E(c-e);b=E(E(b+b)+E(1));break b;default:break i}}h=d<<23;b=(l(2,h+1065353216|0),r());if(d>>>0>=57){c=E(E(c-e)+E(1));b=E(((d|0)==128?E(E(c+c)*E(17014118346046923e22)):E(c*b))+E(-1));break b}i=(l(2,1065353216-h|0),r());c=E((d>>>0<=22?E(E(E(1)-i)+E(c-e)):E(E(c-E(e+i))+E(1)))*b)}b=c}if(g>>>0<=1065353215){if(g>>>0<964689920){break a}f=E(m*E(E(b+b)-E(E(b*b)/E(b+E(1)))));break a}f=E(m*E(b+E(b/E(b+E(1)))));break a}m=E(E(m+m)*E(1661534994731145e20));b=E(c+E(-162.88958740234375));d=wx(b)&2047;j:{k:{if(wx(E(88))>>>0>d>>>0){break k}c=E(0);if(((q(b),j(2))|0)==-8388608){break j}c=E(b+b);if(wx(E(O))>>>0<=d>>>0){break j}if(b>E(88.72283172607422)){c=rE(0);break j}if(!(b<E(-103.97207641601562))){break k}c=QD(0);break j}k=C[165]*+b;s=C[164];u=k+s;k=k-(u-s);s=(C[166]*k+C[167])*(k*k)+(C[168]*k+1);o(+u);j(1)|0;d=j(0)|0;h=d<<15;d=((d&31)<<3)+1024|0;g=x[d>>2];d=x[d+4>>2]+h|0;l(0,g|0);l(1,(g>>>0<g>>>0?d+1|0:d)|0);c=E(s*+n())}f=E(E(m*c)*E(1661534994731145e20))}c=E(w*f);f=E(c/t);b=E(f+E(1));B[a+4236>>2]=E(E(1)-f)/b;f=E(E(v*E(-2))/b);B[a+4232>>2]=f;c=E(c*t);B[a+4228>>2]=E(E(1)-c)/b;B[a+4224>>2]=f;B[a+4220>>2]=E(c+E(1))/b}function gZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=ib-160|0;ib=d;yc(b);ap(a);a:{if(!Rv(b,d+120|0)){break a}if(!WD(d+120|0)){break a}j=x[b+8>>2];b:{if(!bd(b,y[d+136|0]|y[d+137|0]<<8|(y[d+138|0]<<16|y[d+139|0]<<24))){break b}while(1){c:{if((y[d+132|0]|y[d+133|0]<<8|(y[d+134|0]<<16|y[d+135|0]<<24))>>>0>h>>>0){if(Ob(x[b>>2],x[b+8>>2],5)){break c}}f=i&1;break b}f=0;g=1;d:{if((y[d+124|0]|y[d+125|0]<<8)>>>0>=64){if((Ci(b)|0)<=0){break d}}while(1){l=Re(b);if(l){m=f>>>0>4;e=m&g;if(!((g^1)&1|m)){e=(Xp(l<<24>>24)&255)==y[f+13061|0]}g=e;f=f+1|0;continue}break}Yb(b,4);i=(f|0)==5?g&1?1:i:i}h=h+1|0;continue}}bd(b,j);if(!f){break a}if(!Ob(x[b>>2],x[b+8>>2],VD(d+120|0))){break a}if(!c){k=1;break a}g=ib-16|0;ib=g;e=d+120|0;bd(b,y[e+16|0]|y[e+17|0]<<8|(y[e+18|0]<<16|y[e+19|0]<<24));i=d+104|0;f=Nb(i);c=y[e+12|0]|y[e+13|0]<<8|(y[e+14|0]<<16|y[e+15|0]<<24);x[27524]=0;R(185,f|0,c|0);c=x[27524];x[27524]=0;e:{f:{g:{if((c|0)!=1){c=0;h:{i:{while(1){if((y[e+12|0]|y[e+13|0]<<8|(y[e+14|0]<<16|y[e+15|0]<<24))>>>0<=c>>>0){break h}h=x[b+8>>2];j=x[b>>2];x[27524]=0;h=W(160,j|0,h|0,5)|0;j=x[27524];x[27524]=0;if((j|0)==1){break g}if(!h){break h}h=y[e+4|0]|y[e+5|0]<<8;x[27524]=0;U(186,g|0,b|0,h|0);h=x[27524];x[27524]=0;if((h|0)!=1){x[27524]=0;R(187,f|0,g|0);h=x[27524];x[27524]=0;if((h|0)==1){break i}c=c+1|0;wb(g);continue}break}c=P()|0;break f}c=P()|0;wb(g);break f}ib=g+16|0;break e}c=P()|0;break f}c=P()|0}ve(f);S(c|0);p()}x[27524]=0;X(180,d+88|0,b|0,e|0,i|0);c=x[27524];x[27524]=0;j:{if((c|0)!=1){x[27524]=0;Q(159,b|0,x[d+144>>2])|0;c=x[27524];x[27524]=0;k:{if((c|0)!=1){g=d+36|0;l:{m:{n:{o:{while(1){p:{q:{if(A[d+140>>2]>k>>>0){c=x[b+8>>2];e=x[b>>2];x[27524]=0;c=W(160,e|0,c|0,8)|0;e=x[27524];x[27524]=0;if((e|0)==1){break q}if(c){break p}}k=pc(x[a>>2],x[a+4>>2])^1;uc(d+88|0);ve(d+104|0);break a}b=P()|0;break k}x[27524]=0;ea(181,d- -64|0,b|0,d+120|0,d+88|0,d+104|0);c=x[27524];x[27524]=0;if((c|0)!=1){e=bp(d- -64|0);x[27524]=0;c=T(182,x[d+64>>2])|0;f=x[27524];x[27524]=0;if((f|0)==1){break o}if(c){x[27524]=0;c=T(183,d+24|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break n}e=x[e>>2];r:{if((e|0)<0){break r}f=x[d+104>>2];if(wd(f,x[d+108>>2])>>>0<=e>>>0){break r}x[27524]=0;U(11,d+8|0,22,Cd(f,e)|0);e=x[27524];x[27524]=0;if((e|0)==1){break m}e=d+8|0;Gb(c,e);xb(e)}Pv(g,d- -64|0);x[27524]=0;R(184,a|0,c|0);e=x[27524];x[27524]=0;if((e|0)==1){break m}sr(c)}k=k+1|0;yb(d- -64|0);continue}break}b=P()|0;break k}b=P()|0;break l}b=P()|0;break l}b=P()|0;sr(c)}yb(d- -64|0);break k}b=P()|0}uc(d+88|0);break j}b=P()|0}ve(d+104|0);S(b|0);p()}ib=d+160|0;return k|0}function cy(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=ib-160|0;ib=f;x[f+152>>2]=c;x[f+156>>2]=d;g=x[b+4>>2];a:{if(!g){break a}h=x[b>>2];i=y[gl(h,g)|0];if((i|0)==33){e=1}else{if((i|0)!=63){break a}e=0}ol(f+128|0,h,g,g-1|0);g=x[f+132>>2];x[b>>2]=x[f+128>>2];x[b+4>>2]=g}g=f+128|0;Yd(g);h=x[f+128>>2];Yd(f+112|0);i=fl(h,x[f+116>>2],b);Yd(g);g=x[b+4>>2];h=x[b>>2];b:{c:{d:{e:{f:{g:{h:{if((i|0)==x[f+132>>2]){a=qc(f+144|0,21631);c=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=c;if(Nc(h,g,f+8|0)){a=ba(8)|0;x[27524]=0;R(968,f+112|0,f+152|0);b=x[27524];x[27524]=0;if((b|0)==1){break g}x[27524]=0;U(973,f+128|0,17610,f+112|0);b=x[27524];x[27524]=0;if((b|0)==1){break f}lc(a,f+128|0);e=0;x[27524]=0;U(123,a|0,50060,962);b=x[27524];x[27524]=0;if((b|0)!=1){break b}b=P()|0;wb(f+128|0);break e}if(!e){break h}a=ba(8)|0;c=x[b>>2];b=x[b+4>>2];x[27524]=0;c=Qh(f+80|0,c,b);b=x[27524];x[27524]=0;i:{j:{k:{l:{m:{n:{o:{p:{if((b|0)!=1){x[27524]=0;U(973,f+96|0,17646,c|0);b=x[27524];x[27524]=0;if((b|0)==1){break p}x[27524]=0;R(975,f+112|0,f+96|0);b=x[27524];x[27524]=0;e=1;if((b|0)==1){break o}x[27524]=0;R(968,f- -64|0,f+152|0);b=x[27524];x[27524]=0;if((b|0)==1){break n}x[27524]=0;U(977,f+128|0,f+112|0,f- -64|0);b=x[27524];x[27524]=0;if((b|0)==1){break m}lc(a,f+128|0);x[27524]=0;U(123,a|0,50060,962);b=x[27524];x[27524]=0;if((b|0)!=1){break b}b=P()|0;wb(f+128|0);e=0;break l}b=P()|0;break d}b=P()|0;e=1;break i}b=P()|0;break j}b=P()|0;break k}b=P()|0}wb(f- -64|0)}wb(f+112|0)}wb(f+96|0)}wb(c);if(e){break d}break c}b=qc(f+56|0,21631);e=x[b+4>>2];x[f+32>>2]=x[b>>2];x[f+36>>2]=e;if(Nc(h,g,f+32|0)){a=ba(8)|0;x[27524]=0;R(968,f+112|0,f+152|0);b=x[27524];x[27524]=0;q:{r:{if((b|0)!=1){x[27524]=0;U(973,f+128|0,17610,f+112|0);b=x[27524];x[27524]=0;if((b|0)==1){break r}lc(a,f+128|0);e=0;x[27524]=0;U(123,a|0,50060,962);b=x[27524];x[27524]=0;if((b|0)!=1){break b}b=P()|0;wb(f+128|0);break q}b=P()|0;break d}b=P()|0;e=1}wb(f+112|0);if(e){break d}break c}b=qc(f+48|0,10883);e=x[b+4>>2];x[f+24>>2]=x[b>>2];x[f+28>>2]=e;if(Nc(h,g,f+24|0)){ay(a,Dc(c,d));break h}b=qc(f+40|0,8575);e=x[b+4>>2];x[f+16>>2]=x[b>>2];x[f+20>>2]=e;if(!Nc(h,g,f+16|0)){break h}a=x[a+32>>2];b=Ht(c,d);b=b>>>0>=4?1:b;c=ib-16|0;ib=c;s:{if((ik(y[a+140|0])|0)==(b|0)){d=a+120|0;Ns(y[d+20|0]);b=ib-16|0;ib=b;x[b+8>>2]=c+8;a=ib-16|0;ib=a;e=x[19580];x[a+8>>2]=x[19579];x[a+12>>2]=e;e=x[19578];x[a>>2]=x[19577];x[a+4>>2]=e;lb[x[Dp(a,ik(y[d+20|0]))>>2]](b+8|0,d);ib=a+16|0;ib=b+16|0;break s}RJ(a,b,SJ(a))}ib=c+16|0}ib=f+160|0;return}b=P()|0;break d}b=P()|0;e=1}wb(f+112|0);if(!e){break c}}ca(a|0)}S(b|0)}p()}function $F(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0;i=ib-48|0;ib=i;o(+a);e=j(1)|0;d=j(0)|0;a:{b:{h=e;k=e&2147483647;c:{if(k>>>0<=1074752122){if((h&1048575)==598523){break c}if(k>>>0<=1073928572){if((e|0)>0|(e|0)>=0){a=a+-1.5707963267341256;c=a+-6077100506506192e-26;C[b>>3]=c;C[b+8>>3]=a-c+-6077100506506192e-26;d=1;break a}a=a+1.5707963267341256;c=a+6077100506506192e-26;C[b>>3]=c;C[b+8>>3]=a-c+6077100506506192e-26;d=-1;break a}if((e|0)>0|(e|0)>=0){a=a+-3.1415926534682512;c=a+-1.2154201013012384e-10;C[b>>3]=c;C[b+8>>3]=a-c+-1.2154201013012384e-10;d=2;break a}a=a+3.1415926534682512;c=a+1.2154201013012384e-10;C[b>>3]=c;C[b+8>>3]=a-c+1.2154201013012384e-10;d=-2;break a}if(k>>>0<=1075594811){if(k>>>0<=1075183036){if((k|0)==1074977148){break c}if((e|0)>0|(e|0)>=0){a=a+-4.712388980202377;c=a+-1.8231301519518578e-10;C[b>>3]=c;C[b+8>>3]=a-c+-1.8231301519518578e-10;d=3;break a}a=a+4.712388980202377;c=a+1.8231301519518578e-10;C[b>>3]=c;C[b+8>>3]=a-c+1.8231301519518578e-10;d=-3;break a}if((k|0)==1075388923){break c}if((e|0)>0|(e|0)>=0){a=a+-6.2831853069365025;c=a+-2.430840202602477e-10;C[b>>3]=c;C[b+8>>3]=a-c+-2.430840202602477e-10;d=4;break a}a=a+6.2831853069365025;c=a+2.430840202602477e-10;C[b>>3]=c;C[b+8>>3]=a-c+2.430840202602477e-10;d=-4;break a}if(k>>>0>1094263290){break b}}f=a*.6366197723675814+6755399441055744+-6755399441055744;c=a+f*-1.5707963267341256;g=f*6077100506506192e-26;p=c-g;e=p<-.7853981633974483;if(F(f)<2147483648){d=~~f}else{d=-2147483648}d:{if(e){d=d-1|0;f=f+-1;g=f*6077100506506192e-26;c=a+f*-1.5707963267341256;break d}if(!(p>.7853981633974483)){break d}d=d+1|0;f=f+1;g=f*6077100506506192e-26;c=a+f*-1.5707963267341256}a=c-g;C[b>>3]=a;o(+a);h=j(1)|0;j(0)|0;e=k>>>20|0;e:{if((e-(h>>>20&2047)|0)<17){break e}g=c;a=f*6077100506303966e-26;c=c-a;g=f*20222662487959506e-37-(g-c-a);a=c-g;C[b>>3]=a;h=e;o(+a);e=j(1)|0;j(0)|0;if((h-(e>>>20&2047)|0)<50){break e}g=c;a=f*20222662487111665e-37;c=c-a;g=f*84784276603689e-45-(g-c-a);a=c-g;C[b>>3]=a}C[b+8>>3]=c-a-g;break a}if(k>>>0>=2146435072){a=a-a;C[b>>3]=a;C[b+8>>3]=a;d=0;break a}l(0,d|0);l(1,e&1048575|1096810496);a=+n();d=0;h=1;while(1){m=(i+16|0)+(d<<3)|0;if(F(a)<2147483648){d=~~a}else{d=-2147483648}c=+(d|0);C[m>>3]=c;a=(a-c)*16777216;d=1;m=h;h=0;if(m){continue}break}C[i+32>>3]=a;d=2;while(1){h=d;d=d-1|0;if(C[(i+16|0)+(h<<3)>>3]==0){continue}break}d=zI(i+16|0,i,(k>>>20|0)-1046|0,h+1|0,1);a=C[i>>3];if((e|0)<0){C[b>>3]=-a;C[b+8>>3]=-C[i+8>>3];d=0-d|0;break a}C[b>>3]=a;C[b+8>>3]=C[i+8>>3]}ib=i+48|0;return d}function oM(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=ib-192|0;ib=d;e=x[b+4>>2];a:{if(!e){break a}f=x[b>>2];g=y[gl(f,e)|0];if((g|0)==33){c=1}else{if((g|0)!=63){break a}c=0}ol(d+168|0,f,e,e-1|0);e=x[d+172>>2];x[b>>2]=x[d+168>>2];x[b+4>>2]=e}f=d+168|0;Yd(f);e=x[d+168>>2];Yd(d+152|0);e=fl(e,x[d+156>>2],b);Yd(f);b:{c:{d:{e:{if((e|0)==x[d+172>>2]){a=x[b+4>>2];e=x[b>>2];f=qc(d+184|0,21631);g=x[f+4>>2];x[d>>2]=x[f>>2];x[d+4>>2]=g;if(Nc(e,a,d)){a=ba(8)|0;x[27524]=0;c=Q(55,d+168|0,10420)|0;b=x[27524];x[27524]=0;if((b|0)==1){break d}lc(a,c);x[27524]=0;U(123,a|0,50060,962);a=x[27524];x[27524]=0;if((a|0)!=1){break b}b=P()|0;wb(c);break c}e=0;if(!c){break e}a=ba(8)|0;c=x[b+4>>2];b=x[b>>2];x[27524]=0;e=Qh(d+152|0,b,c);b=x[27524];x[27524]=0;f:{g:{h:{if((b|0)!=1){x[27524]=0;U(973,d+168|0,17646,e|0);b=x[27524];x[27524]=0;if((b|0)==1){break h}lc(a,d+168|0);c=0;x[27524]=0;U(123,a|0,50060,962);b=x[27524];x[27524]=0;if((b|0)!=1){break b}b=P()|0;wb(d+168|0);break g}b=P()|0;break f}b=P()|0;c=1}wb(e);if(!c){break c}}ca(a|0);break c}if(x[e+4>>2]){a=ba(8)|0;x[27524]=0;c=Q(55,d+168|0,11480)|0;b=x[27524];x[27524]=0;if((b|0)!=1){lc(a,c);x[27524]=0;U(123,a|0,50060,962);a=x[27524];x[27524]=0;if((a|0)!=1){break b}b=P()|0;wb(c);break c}b=P()|0;ca(a|0);break c}c=x[b+4>>2];b=x[b>>2];e=qc(d+144|0,21631);f=x[e+4>>2];x[d+72>>2]=x[e>>2];x[d+76>>2]=f;if(Nc(b,c,d+72|0)){a=ba(8)|0;x[27524]=0;c=Q(55,d+168|0,10420)|0;b=x[27524];x[27524]=0;if((b|0)!=1){lc(a,c);x[27524]=0;U(123,a|0,50060,962);a=x[27524];x[27524]=0;if((a|0)!=1){break b}b=P()|0;wb(c);break c}b=P()|0;ca(a|0);break c}e=qc(d+136|0,7410);f=x[e+4>>2];x[d+64>>2]=x[e>>2];x[d+68>>2]=f;i:{if(!Nc(b,c,d- -64|0)){e=qc(d+128|0,7392);f=x[e+4>>2];x[d+56>>2]=x[e>>2];x[d+60>>2]=f;if(!Nc(b,c,d+56|0)){break i}}e=y[a+60|0]!=0;break e}e=qc(d+120|0,6937);f=x[e+4>>2];x[d+48>>2]=x[e>>2];x[d+52>>2]=f;j:{if(!Nc(b,c,d+48|0)){e=qc(d+112|0,6918);f=x[e+4>>2];x[d+40>>2]=x[e>>2];x[d+44>>2]=f;if(!Nc(b,c,d+40|0)){break j}}e=y[a+61|0]!=0;break e}e=qc(d+104|0,7021);f=x[e+4>>2];x[d+32>>2]=x[e>>2];x[d+36>>2]=f;if(Nc(b,c,d+32|0)){e=y[a+62|0]!=0;break e}e=qc(d+96|0,6067);f=x[e+4>>2];x[d+24>>2]=x[e>>2];x[d+28>>2]=f;if(Nc(b,c,d+24|0)){e=y[a+63|0]!=0;break e}e=qc(d+88|0,7459);f=x[e+4>>2];x[d+16>>2]=x[e>>2];x[d+20>>2]=f;if(Nc(b,c,d+16|0)){e=y[a+64|0]!=0;break e}e=qc(d+80|0,13340);f=x[e+4>>2];x[d+8>>2]=x[e>>2];x[d+12>>2]=f;e=0;if(!Nc(b,c,d+8|0)){break e}e=x[x[a+24>>2]+24668>>2]!=0}ib=d+192|0;return e|0}b=P()|0;ca(a|0)}S(b|0)}p()}function Fm(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=ib-80|0;ib=e;h=Nb(a);x[27524]=0;a=T(283,b|0)|0;c=x[27524];x[27524]=0;a:{b:{c:{d:{e:{if((c|0)==1){break e}c=x[b+8>>2];d=x[b>>2];x[27524]=0;c=W(160,d|0,c|0,a|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break e}if(c){break d}x[27524]=0;a=T(206,b|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break e}x[27524]=0;Q(192,b|0,a|0)|0;a=x[27524];x[27524]=0;if((a|0)!=1){break c}}a=P()|0;break a}x[27524]=0;U(194,e+32|0,b|0,a|0);b=x[27524];x[27524]=0;f:{g:{h:{if((b|0)!=1){b=e+32|0;c=hc(e+56|0,b);yb(b);if(a>>>0<10){break g}x[27524]=0;b=T(713,c|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break b}if(!b){break g}x[27524]=0;b=T(283,c|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break b}x[e+28>>2]=b;a=a-10|0;wc(e+28|0,a>>>0>25264513?-1:D(a,170));x[27524]=0;d=x[e+28>>2];R(289,h|0,d|0);a=x[27524];x[27524]=0;if((a|0)!=1){break h}break b}a=P()|0;break a}b=0;i:while(1){f=0;j:{k:{while(1){if(f){break j}a=x[c+8>>2];f=x[c>>2];x[27524]=0;a=Q(714,f|0,a|0)|0;f=x[27524];x[27524]=0;l:{m:{n:{o:{if((f|0)!=1){if(a){break j}x[27524]=0;a=T(523,c|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break b}f=1;switch(a|0){case 3:break l;case 2:break m;case 1:break n;case 0:break o;default:continue}}break b}x[27524]=0;a=T(210,c|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break b}if(a>>>0>d>>>0){continue}g=x[c+8>>2];i=x[c>>2];x[27524]=0;g=W(160,i|0,g|0,a|0)|0;i=x[27524];x[27524]=0;if((i|0)==1){break b}if(!g){continue}he(e+32|0,x[h>>2],x[h+4>>2]);Nq(e+16|0,x[e+32>>2],x[e+36>>2],b,a);x[27524]=0;tn(463,e+8|0,c,x[e+16>>2],x[e+20>>2]);f=x[27524];x[27524]=0;if((f|0)!=1){d=d-a|0;b=a+b|0;continue i}break b}x[27524]=0;a=T(210,c|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break b}g=a<<2;if(g>>>0>d>>>0){continue}x[27524]=0;i=Q(715,c|0,e+24|0)|0;j=x[27524];x[27524]=0;if((j|0)==1){break b}if(!i){continue}while(1){if(!(a&255)){break k}f=e+24|0;i=gc(f);wh(f,i,Yf(Cb(x[h>>2]),b));b=b+4|0;a=a-1|0;continue}}if(d>>>0<8){continue}x[27524]=0;a=Q(715,c|0,e+24|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break b}if(!a){continue}a=e+24|0;f=gc(a);wh(a,f,Yf(Cb(x[h>>2]),b));wh(a,f,Yf(Yf(Cb(x[h>>2]),b),4));d=d-8|0;b=b+8|0;continue i}x[27524]=0;a=T(210,c|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break b}if(a>>>0>d>>>0){continue}break}d=d-a|0;b=a+b|0;continue}d=d-g|0;continue}break}if(!d){break f}a=Nb(e+32|0);bu(a,h);ec(a);break f}x[27524]=0;U(331,c|0,h|0,a|0);a=x[27524];x[27524]=0;if((a|0)==1){break b}}yb(c)}ib=e+80|0;return}a=P()|0;yb(c)}ec(h);S(a|0);p()}function _ja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=ib-560|0;ib=f;a:{if(!bd(b,1464)){break a}if(!so(b,f+556|0)){break a}zd(a,1);Lb(Lb(fg(a+1074312|0,83),84,1),85,1);b:{if(qe(f+556|0,26905)){d=f+32|0;e=xc(d,8378);Gb(a+1298344|0,e);xb(e);e=xc(d,14818);Gb(a+1298356|0,e);xb(e);d=xc(d,14883);Gb(a+1298368|0,d);break b}if(!qe(f+556|0,15516)){break a}d=f+32|0;e=xc(d,8552);Gb(a+1298344|0,e);xb(e);e=xc(d,12236);Gb(a+1298356|0,e);xb(e);d=xc(d,15423);Gb(a+1298368|0,d)}xb(d);x[a+1298404>>2]=28;bd(b,0);vB(b,a+1298308|0,20);w[a+480190>>1]=31;d=1;while(1)if((d|0)==32){if(g>>>0>40){break a}d=f+552|0;xv(d,b);m=Lc(d);if(y[f+552|0]>128){break a}e=f+32|0;d=ib-16|0;ib=d;c:{if(!Ob(x[b>>2],x[b+8>>2],512)){lU(e);break c}uC(d+8|0,e);sd(d,b,x[d+8>>2],x[d+12>>2])}ib=d+16|0;d=0;e=y[m|0];while(1){n=(d|0)==512;if(!n){g=(f+32|0)+d|0;d=d+1|0;if(e>>>0>=y[g|0]){continue}break a}break}if(!c){break a}x[a+480260>>2]=56;x[a+480264>>2]=13696;x[a+480204>>2]=125e4;x[a+480196>>2]=6;w[a+480192>>1]=0;w[a+480188>>1]=4;x[a+480228>>2]=64;x[a+480208>>2]=x[a+480208>>2]|18874368;uh(a,0);o=a+484376|0;Dg(Tb(x[a+484360>>2],y[o|0]),y[f+552|0]);l=a+484344|0;Fg(l,y[f+552|0]);while(1)if(y[f+552|0]<=i>>>0){if(!(c&2)){break a}bd(b,(y[m|0]<<8)+1468|0);d=1;while(1){if((d|0)==32){break a}c=(D(d,104)+a|0)+484380|0;if(x[c>>2]){Eg(Zc(f+8|0,8,1,0,0),c,b)}d=d+1|0;continue}}else{s=bc(x[Tb(x[a+484360>>2],y[o|0])>>2],i),t=i,w[s>>1]=t;d:{if(!vh(l,i&65535,64)){break d}r=i<<2;e=0;e:while(1){if((e|0)==4){s=f,t=Cb(x[Xb(x[l>>2],i)>>2]),x[s+24>>2]=t;e=0;while(1){if((e|0)==64){break d}d=0;f:{while(1){if((d&65535)>>>0>=4){g:{v[f+30|0]=p;v[f+31|0]=q;d=h&255;if(d){break g}h=0;break f}}else{g=x[f+24>>2];h:{if((y[g+3|0]&254)!=16){break h}v[g+3|0]=16;h=0;k=y[g+5|0];if(k>>>0<16){break h}h=k>>>4|0;v[g+5|0]=h;j=h;h=k&15;g=(j|0)==(h|0)|!h;p=g?p:j;q=g?q:h;h=!g}d=d+1|0;MA(f+24|0);continue}break}ue(Xb(x[l>>2],i),Te(Me(f+8|0,16,y[(d+f|0)+29|0]),e));h=h+1|0;h=(h&255)==3?1:h}e=e+1|0;continue}}bd(b,(y[f+32+(e+r)|0]<<8)+1468|0);g=0;d=Xb(x[l>>2],i);d=hd(x[d>>2],x[x[d+48>>2]+12>>2],0,e&65535);while(1)if((g|0)==64){e=e+1|0;continue e}else{j=f+8|0;$u(j,b,d);k=y[f+8|0];j=y[Lc(j)|0];i:{if(!(!(k|j)|(k-5&255)>>>0<5|(k|0)==14&j>>>0>15)){Xf(d,k,j);break i}v[d+3|0]=0}d=d+24|0;g=g+1|0;continue}}}i=i+1|0;continue}}else{g=UA(b,f+32|0,(D(d,104)+a|0)+484380|0,((d<<5)+a|0)+946304|0,1)+g|0;d=d+1|0;continue}}ib=f+560|0;return n|0}function Eea(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;x[a+24588>>2]=0;x[a+24592>>2]=0;x[a+8>>2]=43600;x[a+4>>2]=0;x[a>>2]=32192;b=a+24596|0;x[b>>2]=0;x[b+4>>2]=0;mq(a+24604|0);jP(a+24648|0,0);x[a+397448>>2]=0;x[a+397452>>2]=0;b=a+397456|0;x[b>>2]=8;x[b+4>>2]=0;x[b+16>>2]=0;x[b+20>>2]=0;v[b+12|0]=0;x[b+8>>2]=0;w[b+24>>1]=0;Rb(b+28|0,0,40);Rb(b+68|0,0,49824);Rb(b+49892|0,0,32832);v[a+480224|0]=0;w[a+480212>>1]=0;x[a+480204>>2]=0;x[a+480208>>2]=0;x[a+480180>>2]=0;x[a+480184>>2]=0;b=a+480186|0;w[b>>1]=0;w[b+2>>1]=0;w[b+4>>1]=0;w[b+6>>1]=0;x[a+480240>>2]=65536;x[a+480244>>2]=65536;h=Nb(a+480248|0);x[a+480272>>2]=0;c=a+484344|0;b=a+480280|0;while(1){v[b+8|0]=0;x[b>>2]=0;x[b+4>>2]=4194432;nD(b+9|0);b=b+32|0;if((c|0)!=(b|0)){continue}break}f=Nb(c);x[f+12>>2]=a;x[27524]=0;i=Q(814,a+484360|0,a|0)|0;b=x[27524];x[27524]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((b|0)!=1){c=a+900380|0;b=a+484380|0;while(1){x[27524]=0;b=T(687,b|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break i}b=b+104|0;if((c|0)!=(b|0)){continue}break}x[27524]=0;T(815,a+901404|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break h}d=a+906300|0;b=0;while(1){dP(d+D(b,160)|0);b=b+1|0;if((b|0)!=250){continue}break}x[a+946300>>2]=0;e=a+1074304|0;g=a+946304|0;b=g;while(1){b=Rt(b)+32|0;if((e|0)!=(b|0)){continue}break}x[a+1074304>>2]=0;x[a+1074308>>2]=0;rr(a+1074312|0);x[27524]=0;Z(816);b=x[27524];x[27524]=0;if((b|0)==1){break g}s=a,t=cP(),x[s+1074328>>2]=t;b=a+1074332|0;x[b+12>>2]=1065353216;UO(b,4);x[27524]=0;e=T(817,a+1074376|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break g}x[27524]=0;j=W(587,a+1298264|0,a|0,255)|0;b=x[27524];x[27524]=0;if((b|0)==1){break f}k=sc(a+1298300|0);l=sc(a+1298304|0);m=Kb(a+1298308|0);n=Kb(a+1298320|0);o=Kb(a+1298332|0);q=iP(a+1298344|0);r=Nb(a+1298412|0);v[a+1298424|0]=0;b=a+1298432|0;x[b>>2]=0;x[b+4>>2]=0;x[b+32>>2]=0;x[b+36>>2]=1072693248;x[b+24>>2]=0;x[b+28>>2]=0;x[b+16>>2]=0;x[b+20>>2]=0;x[b+8>>2]=0;x[b+12>>2]=0;x[a+1298472>>2]=0;Zp(a+12|0);fz(a+8204|0);fz(a+12300|0);b=a+1074408|0;x[b>>2]=4;x[b+4>>2]=16;x[a+480216>>2]=4;x[a+480220>>2]=16;Rb(c,0,1024);bP(g);x[27524]=0;b=T(818,12)|0;c=x[27524];x[27524]=0;if((c|0)==1){break e}x[b>>2]=0;x[b+4>>2]=0;x[b+8>>2]=0;s=a,t=Nb(b),x[s+4>>2]=t;return a|0}b=P()|0;break a}b=P()|0;break b}b=P()|0;break b}b=P()|0;break c}b=P()|0;break d}b=P()|0;hP(r);iz(q);wb(o);xb(n);wb(m);hz(l);gz(k);Ft(j)}uz(e)}gP(d)}fA(i)}ZO(f);uc(h);S(b|0);p()}function Hda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=ib-48|0;ib=c;a:{b:{if(!Mb(x[b>>2],x[b+4>>2])){break b}l=x[b+12>>2];k=Cg(x[x[b+48>>2]+12>>2]);d=k;f=c+32|0;x[f>>2]=0;x[f+4>>2]=0;sc(f+8|0);if(d){Hu(f,d);g=ib-16|0;ib=g;e=Rq(g,f,d);d=x[e+4>>2];h=x[e+8>>2];while(1){if((d|0)==(h|0)){ic(e);ib=g+16|0}else{v[d|0]=0;v[d+1|0]=0;v[d+2|0]=0;v[d+3|0]=0;v[d+4|0]=0;v[d+5|0]=0;Bg(d);d=d+6|0;x[e+4>>2]=d;continue}break}}while(1){c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{if(j>>>0>=l>>>0){break r}if(!fh(x[x[a>>2]-12>>2]+a|0)){break r}x[27524]=0;v[c+31|0]=0;Q(881,a|0,c+31|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break a}d=v[c+31|0];if(!d){j=j+1|0;continue}v[c+30|0]=0;s:{if((d|0)>=0){break s}x[27524]=0;Q(881,a|0,c+30|0)|0;e=x[27524];x[27524]=0;if((e|0)!=1){break s}break a}v[c+29|0]=0;Jj(c+16|0);t:{d=d&127;g=(d?d-1|0:0)&65535;i=g>>>0>=k>>>0;u:{v:{if(!i){h=hd(x[b>>2],x[x[b+48>>2]+12>>2],j,g);d=y[c+30|0];if(d&1){break v}e=Hd(x[f>>2],g);break u}h=c+16|0;d=y[c+30|0];if(!(d&1)){break t}}x[27524]=0;Q(881,a|0,c+29|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break a}if(i){break t}e=Hd(x[f>>2],g);v[e|0]=y[c+29|0]}v[h|0]=y[e|0];d=y[c+30|0];if(!(d&2)){break p}break q}if(d&2){break q}break o}Ck(f);break b}x[27524]=0;Q(881,a|0,c+29|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break a}if(i){break o}e=Hd(x[f>>2],g);v[e+1|0]=y[c+29|0]}v[h+1|0]=y[e+1|0];if(d&4){break n}break m}if(!(d&4)){break l}}x[27524]=0;Q(881,a|0,c+29|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break a}if(i){break l}e=Hd(x[f>>2],g);v[e+2|0]=y[c+29|0]}v[h+2|0]=y[e+2|0];if(!(d&8)){break j}break k}if(!(d&8)){break i}}x[27524]=0;Q(881,a|0,c+29|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break a}if(i){break i}e=Hd(x[f>>2],g);v[e+4|0]=y[c+29|0]}v[h+4|0]=y[e+4|0];if(d&16){break h}break g}if(!(d&16)){break f}}x[27524]=0;Q(881,a|0,c+29|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break a}if(i){break f}e=Hd(x[f>>2],g);v[e+3|0]=y[c+29|0]}v[h+3|0]=y[e+3|0];if(!(d&32)){break d}break e}if(!(d&32)){break c}}x[27524]=0;Q(881,a|0,c+29|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break a}if(i){break c}e=Hd(x[f>>2],g);v[e+5|0]=y[c+29|0]}v[h+5|0]=y[e+5|0]}if(!(d&64)){continue}x[27524]=0;Q(881,a|0,c+15|0)|0;d=x[27524];x[27524]=0;if((d|0)!=1){x[27524]=0;Q(882,a|0,y[c+15|0])|0;d=x[27524];x[27524]=0;if((d|0)!=1){continue}}break}break a}ib=c+48|0;return}a=P()|0;Ck(f);S(a|0);p()}function tja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=ib-32|0;ib=g;a:{if(!Ob(x[a>>2],x[a+8>>2],2)){vh(c+484344|0,b,64);break a}l=c+484344|0;m=Bd(Mj(a),1,1024);if(!vh(l,b,m)){break a}p=z[c+480188>>1];q=c+480190|0;b:while(1){if((k|0)==(m|0)){break a}i=0;e=Xb(x[l>>2],b);n=qf(x[e>>2],x[x[e+48>>2]+12>>2],k);while(1)if((i|0)==(p|0)){k=k+1|0;continue b}else{f=g+24|0;Um(f,a);e=D(i,6)+n|0;r=Ze(f);f=Si(f);h=y[g+24|0];c:{if((h-1&255)>>>0>35){break c}v[e|0]=h+48;o=y[Lc(g+24|0)|0];h=o+1|0;v[e+1|0]=h;j=h;h=h&255;if((j|0)!=(h|0)|h>>>0>z[q>>1]){break c}h=Oi(c,h);j=Jb(d,i);if(!(!y[j|0]|z[h+30>>1]>255)){v[e+4|0]=64;v[e+2|0]=1}h=x[Bb(h+68|0,0)>>2];if(!(y[j|0]|h?y[j|0]?(h|0)==1:0:1)){break c}v[e+1|0]=o+101}d:{e:{switch(y[r|0]){case 1:if(!y[f|0]){break d}v[e+3|0]=2;v[e+5|0]=y[f|0];break d;case 2:if(!y[f|0]){break d}v[e+3|0]=3;v[e+5|0]=y[f|0];break d;case 12:if(!y[f|0]){break d}v[e+3|0]=1;v[e+5|0]=y[f|0];break d;case 13:if(!y[f|0]){break d}v[e+3|0]=39;v[g+23|0]=15;s=e,t=y[Ub(g+23|0,f)|0]|16,v[s+5|0]=t;break d;case 30:if(!y[f|0]){break d}v[e+3|0]=38;v[g+22|0]=15;s=e,t=y[Ub(g+22|0,f)|0]|16,v[s+5|0]=t;break d;case 21:if(!y[f|0]){break d}v[e+3|0]=39;v[g+21|0]=15;s=e,t=y[Ub(g+21|0,f)|0]|80,v[s+5|0]=t;break d;case 17:if(!y[f|0]){break d}v[e+3|0]=38;v[g+20|0]=15;s=e,t=y[Ub(g+20|0,f)|0]|80,v[s+5|0]=t;break d;case 15:v[e+3|0]=19;v[e+5|0]=y[f|0]!=0;break d;case 25:v[e+3|0]=12;v[e+5|0]=y[f|0];break d;case 27:mo(e);v[e|0]=255;break d;case 28:if(y[f|0]>31){break d}v[e+3|0]=16;v[e+5|0]=y[f|0];break d;case 31:h=y[f|0];if(h&15){s=e,t=y[Jb(d,i)|0]?22:11,v[s+3|0]=t;v[e+5|0]=y[f|0]&15;h=y[f|0]}f:{g:{switch(h>>>4|0){case 4:if((h|0)!=64){break f}case 0:case 1:case 2:case 3:if(y[Jb(d,i)|0]){v[e+3|0]=21;v[e+5|0]=y[f|0];break f}v[e+2|0]=1;f=y[f|0];v[e+3|0]=0;v[e+4|0]=f;break f;case 5:v[e+5|0]=y[e+5|0]<<4;break f;case 6:v[g+19|0]=y[e+5|0];v[g+18|0]=14;s=e,t=y[Ub(g+19|0,g+18|0)|0]|240,v[s+5|0]=t;break f;case 7:v[g+17|0]=y[e+5|0];v[g+16|0]=14;s=e,t=y[Ub(g+17|0,g+16|0)|0]<<4|15,v[s+5|0]=t;break f;default:break g}}v[e+3|0]=0}if((y[e+3|0]-21&255)>>>0>1){break d}f=D(v[Jb(d,i)|0]+i|0,6)+n|0;$q(g+8|0,y[f+3|0],y[f+5|0],1);if(y[g+8|0]){h=z[g+8>>1];v[f+4|0]=h>>>8;v[f+2|0]=h}v[f+3|0]=y[e+3|0];v[f+5|0]=y[e+5|0];break d;case 0:break d;default:break e}}v[e+3|0]=0}i=i+1|0;continue}}}ib=g+32|0}function le(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{b:{c:{switch(b|0){case 1:b=0;a=Kb(a);d=Eb(c);x[27524]=0;R(46,a|0,d|0);d=x[27524];x[27524]=0;d:{if((d|0)!=1){e:{while(1){if(Eb(c)>>>0>b>>>0){d=x[Hi(c,b)>>2];x[27524]=0;R(47,a|0,(d>>>0>=128?63:d)<<24>>24);d=x[27524];x[27524]=0;if((d|0)==1){break e}b=b+1|0;continue}break}break d}}break a}return;case 2:b=0;a=Kb(a);d=Eb(c);x[27524]=0;R(46,a|0,d|0);d=x[27524];x[27524]=0;f:{if((d|0)!=1){g:{while(1){if(Eb(c)>>>0>b>>>0){d=x[Hi(c,b)>>2];x[27524]=0;R(47,a|0,(d>>>0>=256?63:d)<<24>>24);d=x[27524];x[27524]=0;if((d|0)==1){break g}b=b+1|0;continue}break}break f}}break a}return;case 3:ff(a,c,50496);return;case 4:ff(a,c,51520);return;case 5:ff(a,c,52544);return;case 6:ff(a,c,53568);return;case 7:ff(a,c,54592);return;case 8:ff(a,c,55616);return;case 9:ff(a,c,56640);return;case 10:ff(a,c,57664);return;case 11:ff(a,c,58688);return;case 12:ff(a,c,59712);return;case 13:ff(a,c,60736);return;case 14:ff(a,c,61760);return;case 15:ff(a,c,62784);return;case 16:ff(a,c,63808);return;case 17:ff(a,c,64832);return;case 18:ff(a,c,65856);return;case 19:ff(a,c,66880);return;case 20:ff(a,c,67904);return;case 21:ff(a,c,68928);return;case 22:ff(a,c,69952);return;case 23:ff(a,c,70976);return;case 24:Lz(a,c,72e3);return;case 25:Lz(a,c,50496);return;case 26:Lz(a,c,68928);return;default:a=ba(8)|0;x[27524]=0;b=Q(45,a|0,11015)|0;c=x[27524];x[27524]=0;if((c|0)!=1){break b}b=P()|0;ca(a|0);S(b|0);p();case 0:break c}}e=ib-16|0;ib=e;f=Kb(a);h:{while(1){i:{j:{k:{if(Eb(c)>>>0>g>>>0){b=x[Hi(c,g)>>2];if(b>>>0>=2097152){x[27524]=0;R(47,f|0,63);a=x[27524];x[27524]=0;if((a|0)!=1){break j}break i}a=0;while(1){if((a|0)==6){b=7;a=6;break k}d=b&63;v[(e+10|0)+a|0]=d;if(b>>>0>=64){a=a+1|0;b=b>>>6|0;continue}break}if(a){b=a+1|0;if((b|0)!=2){break k}a=1;b=2;if((d|0)!=1){break k}a=y[e+10|0]|64}else{a=y[e+10|0]}x[27524]=0;R(47,f|0,a<<24>>24);a=x[27524];x[27524]=0;if((a|0)!=1){break j}break i}ib=e+16|0;break h}i=(-1<<b^-1)<<7-a;d=b-1|0;j=d+(e+10|0)|0;a=b;while(1){if(!a){break j}l:{if((a|0)==(b|0)){a=y[j|0];x[27524]=0;R(47,f|0,(a|i)<<24>>24);h=x[27524];x[27524]=0;a=d;break l}x[27524]=0;a=a-1|0;R(47,f|0,v[a+(e+10|0)|0]|-128);h=x[27524];x[27524]=0}if((h|0)!=1){continue}break}break i}g=g+1|0;continue}break}a=P()|0;wb(f);S(a|0);p()}return}ha(b|0,108328,25);p()}b=P()|0;wb(a);S(b|0);p()}function W4(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0,f=0,g=0;d=ib-192|0;ib=d;x[d+184>>2]=c;a:{b:{c:{if(b>=.8){x[27524]=0;e=ga(1100)|0;f=x[27524];x[27524]=0;d:{e:{f:{if((f|0)!=1){x[d+80>>2]=e;x[27524]=0;c=T(1101,c|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break e}x[d+176>>2]=c;Mn(e,c);a=te(d+152|0,a);x[27524]=0;f=x[a+12>>2];c=d- -64|0;x[c>>2]=x[a+8>>2];x[c+4>>2]=f;x[d+72>>2]=x[a+16>>2];c=x[a+4>>2];x[d+56>>2]=x[a>>2];x[d+60>>2]=c;a=W(1093,e|0,d+56|0,15)|0;c=x[27524];x[27524]=0;if((c|0)==1){break f}if(a){x[27524]=0;Y(819,e|0);a=x[27524];x[27524]=0;g=1;if((a|0)==1){break f}}kh(d+176|0);lh(d+80|0);break b}c=V(0)|0;break c}c=V(0)|0;kh(d+176|0);break d}c=V(0)|0}lh(d+80|0);break c}if(b>=.6){x[27524]=0;e=ga(1100)|0;f=x[27524];x[27524]=0;g:{h:{i:{if((f|0)!=1){x[d+80>>2]=e;x[27524]=0;c=T(1101,c|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break h}x[d+176>>2]=c;Mn(e,c);a=te(d+128|0,a);x[27524]=0;c=x[a+12>>2];x[d+40>>2]=x[a+8>>2];x[d+44>>2]=c;x[d+48>>2]=x[a+16>>2];c=x[a+4>>2];x[d+32>>2]=x[a>>2];x[d+36>>2]=c;a=W(1093,e|0,d+32|0,2)|0;c=x[27524];x[27524]=0;if((c|0)==1){break i}if(a){x[27524]=0;Y(819,e|0);a=x[27524];x[27524]=0;g=.8;if((a|0)==1){break i}}kh(d+176|0);lh(d+80|0);break b}c=V(0)|0;break c}c=V(0)|0;kh(d+176|0);break g}c=V(0)|0}lh(d+80|0);break c}g=.2;if(b>=.2){x[27524]=0;e=ga(1100)|0;f=x[27524];x[27524]=0;j:{k:{l:{if((f|0)!=1){x[d+80>>2]=e;x[27524]=0;c=T(1101,c|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break k}x[d+176>>2]=c;Mn(e,c);a=te(d+104|0,a);x[27524]=0;c=x[a+12>>2];x[d+16>>2]=x[a+8>>2];x[d+20>>2]=c;x[d+24>>2]=x[a+16>>2];c=x[a+4>>2];x[d+8>>2]=x[a>>2];x[d+12>>2]=c;a=W(1093,e|0,d+8|0,0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break l}g=0;if(a){x[27524]=0;Y(819,e|0);a=x[27524];x[27524]=0;g=.6;if((a|0)==1){break l}}kh(d+176|0);lh(d+80|0);break b}c=V(0)|0;break c}c=V(0)|0;kh(d+176|0);break j}c=V(0)|0}lh(d+80|0);break c}if(!(b>=.1)){break b}x[27524]=0;U(207,d+80|0,a|0,2048);c=x[27524];x[27524]=0;if((c|0)!=1){c=Le(d+80|0);a=x[a>>2];x[27524]=0;e=x[d+80>>2];a=T(164,a|0)|0;f=x[27524];x[27524]=0;m:{if((f|0)==1){break m}x[27524]=0;a=UF(1102,3,0,c,e,a,0);c=x[27524];x[27524]=0;if((c|0)==1){break m}g=C[(a<<3)+78336>>3];Rc(d+80|0);break b}c=V(0)|0;Rc(d+80|0);break c}c=V(0)|0}_(c|0)|0;x[27524]=0;Z(18);a=x[27524];x[27524]=0;g=0;if((a|0)==1){break a}}Xc(d+184|0);ib=d+192|0;return+g}a=P()|0;Xc(d+184|0);S(a|0);p()}function Pha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;d=ib+-64|0;ib=d;w[d+62>>1]=c;Mf(d+62|0,32);j=Nb(a);x[27524]=0;o=z[d+62>>1];R(527,j|0,o|0);a=x[27524];x[27524]=0;a:{b:{if((a|0)!=1){k=b+480190|0;q=b+480192|0;c:{d:{while(1){if((r&65535)>>>0>=o>>>0){break d}e=1;c=z[k>>1];a=c+1|0;w[d+60>>1]=a;e:{f:{g:{if((a&65535)>>>0<4e3){break g}h:{while(1){f=e&65535;if(f>>>0>c>>>0){break h}i:{g=Oi(b,f);if(!_d(x[g>>2],x[g+20>>2])){if(!Mb(NA(Cb(x[j>>2]),Cb(x[j+4>>2]),e),Cb(x[j+4>>2]))){break i}c=z[k>>1]}e=e+1|0;continue}break}w[d+60>>1]=e;a=1;while(1){if(z[q>>1]<a>>>0){a=e}else{j:{c=x[((a<<2)+b|0)+900380>>2];if(!c){break j}c=c+236|0;g=Kq(c);while(1){if((c|0)==(g|0)){break j}if((f|0)==z[c>>1]){w[c>>1]=0}c=c+2|0;continue}}a=a+1|0;continue}break}}if((a&65535)>>>0<4e3){break g}e=ko(d+48|0);x[27524]=0;a=Q(752,b|0,e|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break b}if(!a){break e}x[27524]=0;R(753,b|0,e|0);c=x[27524];x[27524]=0;a=1;if((c|0)==1){break b}while(1){c=a&65535;if(c>>>0<=z[q>>1]){k:{c=x[((c<<2)+b|0)+900380>>2];if(!c){break k}c=c+236|0;f=Kq(c);while(1){if((c|0)==(f|0)){break k}g=z[c>>1];l:{if(g>>>0>=A[d+52>>2]){break l}Ab(d+40|0,x[e>>2],g);if(zb(x[x[d+40>>2]>>2],x[d+44>>2])){break l}w[c>>1]=0}c=c+2|0;continue}}a=a+1|0;continue}break}wl(d+24|0,x[e>>2]);gS(d+32|0,x[d+24>>2],x[d+28>>2],1);Im(d+16|0,x[e>>2],x[d+52>>2]);m=ib-16|0;ib=m;g=d+40|0;c=dc(m,x[d+32>>2],x[d+36>>2]);a=vl(x[d+16>>2],x[d+20>>2],x[d+32>>2],x[d+36>>2]);f=ib-16|0;ib=f;x[f+12>>2]=a;h=x[c+4>>2];m:{if(h){i=32-h|0;x[f+8>>2]=i;n=x[Hb(f+8|0,f+12|0)>>2];l=-1<<h&-1>>>i-n;i=x[c>>2];l=l&(x[i>>2]^-1);if(l){dc(g,i,poa(l));break m}if((a|0)==(n|0)){gS(g,i,h,a);break m}a=a-n|0;x[f+12>>2]=a;x[c>>2]=i+4}while(1){if(a>>>0>=32){h=x[c>>2];i=x[h>>2];if((i|0)!=-1){dc(g,h,poa(i^-1));break m}else{x[c>>2]=h+4;a=a-32|0;x[f+12>>2]=a;continue}}break}if(!a){dc(g,x[c>>2],0);break m}c=x[c>>2];h=(x[c>>2]^-1)&-1>>>32-a;if(!h){dc(g,c,a);break m}dc(g,c,poa(h))}ib=f+16|0;ib=m+16|0;wl(d+8|0,x[e>>2]);a=vl(x[d+40>>2],x[d+44>>2],x[d+8>>2],x[d+12>>2]);w[d+60>>1]=a;$e(e);if((a&65535)>>>0>3999){break f}}x[27524]=0;R(261,j|0,d+60|0);c=x[27524];x[27524]=0;if((c|0)==1){break c}if(z[k>>1]>=(a&65535)>>>0){break f}w[k>>1]=a}r=r+1|0;continue}break}$e(e)}ib=d- -64|0;return}c=P()|0;break a}c=P()|0;break a}c=P()|0;$e(e)}jd(j);S(c|0);p()}function w5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=ib-192|0;ib=d;h=KJ(d+176|0);x[h>>2]=50268;Nb(h+4|0);Mn(x[a+24>>2],h);e=x[a+24>>2];i=y[a+62|0];f=y[a+61|0];g=y[a+60|0];b=te(d+152|0,b);x[27524]=0;j=x[b+12>>2];x[d+16>>2]=x[b+8>>2];x[d+20>>2]=j;x[d+24>>2]=x[b+16>>2];j=x[b+4>>2];x[d+8>>2]=x[b>>2];x[d+12>>2]=j;b=g?13:15;b=f?b&14:b;b=W(1093,e|0,d+8|0,(i?b&3:b)|0)|0;e=x[27524];x[27524]=0;a:{b:{c:{d:{e:{if((e|0)==1){break e}if(!b){b=ba(8)|0;x[27524]=0;c=Q(55,d+136|0,11906)|0;a=x[27524];x[27524]=0;if((a|0)!=1){lc(b,c);x[27524]=0;U(123,b|0,50060,962);a=x[27524];x[27524]=0;if((a|0)!=1){break a}a=P()|0;wb(c);break b}a=P()|0;ca(b|0);break b}if(!y[a+63|0]){x[27524]=0;R(1094,a|0,a+36|0);b=x[27524];x[27524]=0;if((b|0)==1){break e}}v[a+28|0]=1;Mn(x[a+24>>2],x[a+4>>2]);x[27524]=0;R(1095,d+136|0,h|0);b=x[27524];x[27524]=0;if((b|0)==1){break c}k=d,l=Cb(x[d+136>>2]),x[k+128>>2]=l;e=a+68|0;i=Cb(x[d+140>>2]);f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{while(1){b=x[d+128>>2];if(!Mb(b,i)){k=d,l=Ni(x[c>>2]),x[k+112>>2]=l;c=Gf(c);while(1){b=x[d+112>>2];if(!Rg(b,c)){break d}x[27524]=0;e=ud(b);b=Q(54,d+32|0,e|0)|0;i=x[27524];x[27524]=0;if((i|0)==1){break h}x[27524]=0;X(974,a|0,b|0,e+12|0,0);e=x[27524];x[27524]=0;if((e|0)==1){break g}wb(b);Ug(d+112|0);continue}}f=x[a+24>>2];g=x[b>>2];x[27524]=0;j=f;f=b+4|0;U(1096,j|0,g|0,f|0);g=x[27524];x[27524]=0;if((g|0)!=1){b=x[b>>2];x[27524]=0;R(1097,d- -64|0,b|0);b=x[27524];x[27524]=0;if((b|0)==1){break r}x[27524]=0;R(1021,d+80|0,d- -64|0);b=x[27524];x[27524]=0;if((b|0)==1){break q}x[27524]=0;b=Q(55,d+48|0,17746)|0;g=x[27524];x[27524]=0;if((g|0)==1){break p}x[27524]=0;U(977,d+96|0,d+80|0,b|0);g=x[27524];x[27524]=0;if((g|0)==1){break o}x[27524]=0;U(533,d+112|0,d+96|0,f|0);f=x[27524];x[27524]=0;if((f|0)==1){break n}x[27524]=0;R(187,e|0,d+112|0);f=x[27524];x[27524]=0;if((f|0)==1){break m}wb(d+112|0);wb(d+96|0);wb(b);wb(d+80|0);xb(d- -64|0);qq(d+128|0);continue}break}a=P()|0;break f}a=P()|0;break f}a=P()|0;break i}a=P()|0;break j}a=P()|0;break k}a=P()|0;break l}a=P()|0;wb(d+112|0)}wb(d+96|0)}wb(b)}wb(d+80|0)}xb(d- -64|0);break f}a=P()|0;break f}a=P()|0;wb(b)}Qx(d+136|0);break b}a=P()|0;break b}Qx(d+136|0);Ls(h);ib=d+192|0;return}a=P()|0}Ls(h);S(a|0)}p()}function me(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;a:{b:{c:{switch(b|0){case 1:b=0;a=Kb(a);d=Eb(c);x[27524]=0;R(48,a|0,d|0);d=x[27524];x[27524]=0;d:{if((d|0)!=1){e:{while(1){if(Eb(c)>>>0>b>>>0){d=v[ng(c,b)|0];x[27524]=0;R(49,a|0,((d|0)<0?65533:d&255)|0);d=x[27524];x[27524]=0;if((d|0)==1){break e}b=b+1|0;continue}break}break d}}break a}return;case 2:b=0;a=Kb(a);d=Eb(c);x[27524]=0;R(48,a|0,d|0);d=x[27524];x[27524]=0;f:{if((d|0)!=1){while(1){if(Eb(c)>>>0<=b>>>0){break f}d=y[ng(c,b)|0];x[27524]=0;R(49,a|0,d|0);d=x[27524];x[27524]=0;if((d|0)!=1){b=b+1|0;continue}break}}break a}return;case 3:ef(a,c,50496);return;case 4:ef(a,c,51520);return;case 5:ef(a,c,52544);return;case 6:ef(a,c,53568);return;case 7:ef(a,c,54592);return;case 8:ef(a,c,55616);return;case 9:ef(a,c,56640);return;case 10:ef(a,c,57664);return;case 11:ef(a,c,58688);return;case 12:ef(a,c,59712);return;case 13:ef(a,c,60736);return;case 14:ef(a,c,61760);return;case 15:ef(a,c,62784);return;case 16:ef(a,c,63808);return;case 17:ef(a,c,64832);return;case 18:ef(a,c,65856);return;case 19:ef(a,c,66880);return;case 20:ef(a,c,67904);return;case 21:ef(a,c,68928);return;case 22:ef(a,c,69952);return;case 23:ef(a,c,70976);return;case 24:Gz(a,c,72e3);return;case 25:Gz(a,c,50496);return;case 26:Gz(a,c,68928);return;default:a=ba(8)|0;x[27524]=0;b=Q(45,a|0,11015)|0;c=x[27524];x[27524]=0;if((c|0)!=1){break b}b=P()|0;ca(a|0);S(b|0);p();case 0:break c}}e=ib-16|0;ib=e;f=Kb(a);g=e,h=Bt(c),x[g+8>>2]=h;g=e,h=yt(c),x[g>>2]=h;a=0;g:{h:{while(1){i:{if(!Fi(e+8|0,e)){if(!a){break i}x[27524]=0;R(49,f|0,65533);a=x[27524];x[27524]=0;if((a|0)!=1){break i}break h}b=y[x[e+8>>2]];j:{k:{if(!a){if(b<<24>>24>=0){a=0;x[27524]=0;R(49,f|0,b|0);b=x[27524];x[27524]=0;if((b|0)!=1){break j}break h}if((b&224)==192){d=b&31;a=1;break j}if((b&240)==224){d=b&15;a=2;break j}d=65533;if((b&248)!=240){break k}d=b&7;a=3;break j}if((b&192)!=128){d=0;x[27524]=0;R(49,f|0,65533);c=x[27524];x[27524]=0;a=0;if((c|0)==1){break h}}d=b&63|d<<6;a=a-1|0;if(a){break j}}a=0;x[27524]=0;R(49,f|0,d|0);b=x[27524];x[27524]=0;d=0;if((b|0)==1){break h}}Ie(e+8|0);continue}break}ib=e+16|0;break g}a=P()|0;Gc(f);S(a|0);p()}return}ha(b|0,108328,25);p()}b=P()|0;Gc(a);S(b|0);p()}function NY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=ib-384|0;ib=f;yc(b);d=ib-16|0;ib=d;h=f+344|0;jD(d+8|0,h);e=x[d+12>>2];kc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);i=x[d+4>>2];if((i|0)==(e|0)){Yb(b,x[d+12>>2])}ib=d+16|0;d=(e|0)==(i|0);if(!d){iD(h)}a:{if(!d){break a}if(!lD(f+344|0)){break a}if(!Ob(x[b>>2],x[b+8>>2],Ec(kD(y[f+379|0]),kb))){break a}b:{if(!c){break b}zd(a,2097152);gg(a);uh(a,1);w[a+480188>>1]=8;x[a+480196>>2]=y[f+376|0];x[a+480204>>2]=D(y[f+377|0],1e4);j=a+480190|0;w[j>>1]=y[f+378|0];d=y[f+381|0];if(d>>>0<y[f+380|0]){_e(Tb(x[a+484360>>2],y[a+484376|0]),d)}d=f+80|0;g=xc(d,6522);Gb(a+1298344|0,g);xb(g);g=xc(d,11058);Gb(a+1298356|0,g);xb(g);x[a+1298404>>2]=4;yv(b,d);er(Tb(x[a+484360>>2],y[a+484376|0]),d,y[f+380|0],65535,65535);g=1;while(1){i=g&65535;if(i>>>0>z[j>>1]){Yb(b,D(64-y[f+378|0]|0,37));h=a+484344|0;Fg(h,y[f+379|0]);i=c&1;g=0;while(1)if(y[f+379|0]<=g>>>0){if(!(c&2)){break b}c=Zc(f+40|0,8,1,0,0);d=a+480190|0;g=1;while(1){e=g&65535;if(e>>>0>z[d>>1]){break b}Eg(c,(D(e,104)+a|0)+484380|0,b);g=g+1|0;continue}}else{c:{d:{if(i){if(vh(h,g&65535,64)){break d}}Yb(b,2048);break c}d=Xb(x[h>>2],g);n=f,o=Cb(x[d>>2]),x[n+40>>2]=o;j=Cb(x[d+4>>2]);while(1){d=x[f+40>>2];if(!Mb(d,j)){break c}e=f+24|0;Um(e,b);k=Lc(e);m=Ze(e);e=Si(e);l=y[f+24|0];if((l-1&255)>>>0<=106){v[d|0]=l+13}v[d+1|0]=y[k|0];Xf(d,y[m|0],y[e|0]);Hk(f+40|0);continue}}g=g+1|0;continue}}else{d=f+40|0;gD(b,d);h=ib-16|0;ib=h;e=(D(i,104)+a|0)+484380|0;md(e,0);v[e+37|0]=y[d+22|0]<<4;v[h+15|0]=y[d+23|0];v[h+14|0]=64;n=e,o=y[Ub(h+15|0,h+14|0)|0]<<2,w[n+30>>1]=o;v[e+36|0]=y[d+24|0];x[e>>2]=y[d+25|0]|y[d+26|0]<<8|(y[d+27|0]<<16|y[d+28|0]<<24);k=y[d+33|0]|y[d+34|0]<<8|(y[d+35|0]<<16|y[d+36|0]<<24);if(!(k>>>0<3|k+(y[d+29|0]|y[d+30|0]<<8|(y[d+31|0]<<16|y[d+32|0]<<24))>>>0>(y[d+25|0]|y[d+26|0]<<8|(y[d+27|0]<<16|y[d+28|0]<<24))>>>0)){w[e+34>>1]=z[e+34>>1]|2;x[e+4>>2]=y[d+29|0]|y[d+30|0]<<8|(y[d+31|0]<<16|y[d+32|0]<<24);x[e+8>>2]=(y[d+33|0]|y[d+34|0]<<8|(y[d+35|0]<<16|y[d+36|0]<<24))+(y[d+29|0]|y[d+30|0]<<8|(y[d+31|0]<<16|y[d+32|0]<<24))}ib=h+16|0;e=f+8|0;Ll(e,2,d);d=f+24|0;Fc(d,e);Cc(((i<<5)+a|0)+946304|0,d);g=g+1|0;wb(d);continue}}}g=1}ib=f+384|0;return g|0}function Wda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=ib-16|0;ib=h;f=x[a+8>>2];e=x[a>>2];x[27524]=0;f=Q(606,e|0,f|0)|0;e=x[27524];x[27524]=0;a:{b:{if((e|0)!=1){if(f){break b}x[27524]=0;f=T(210,a|0)|0;e=x[27524];x[27524]=0;c:{if((e|0)==1){break c}x[27524]=0;j=d+484344|0;k=Bd(f+1|0,1,1024);f=W(230,j|0,b|0,k|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break c}if(!f){break b}d=z[d+480188>>1];if(!d){break b}l=d-1|0;d=0;while(1){if(d>>>0>=k>>>0){break b}f=x[a+8>>2];e=x[a>>2];x[27524]=0;f=W(160,e|0,f|0,1)|0;e=x[27524];x[27524]=0;d:{if((e|0)!=1){if(!f){break b}x[27524]=0;i=T(210,a|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break a}if(i){break d}d=d+1|0;continue}break a}e=x[j>>2];w[h+14>>1]=i&31;w[h+12>>1]=l;e=Xb(e,b);e=hd(x[e>>2],x[x[e+48>>2]+12>>2],d,z[Tc(h+14|0,h+12|0)>>1]);if(i>>>0<32){continue}e:{if(i<<24>>24>=0){break e}x[27524]=0;g=T(210,a|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break a}v[e+5|0]=g;x[27524]=0;g=T(210,a|0)|0;f=x[27524];x[27524]=0;f:{g:{if((f|0)!=1){if(g>>>0<26){break g}break f}break a}f=y[g+42720|0];v[e+3|0]=f;h:{switch(f-1|0){case 0:if(!y[e+5|0]){break f}break e;case 12:if(y[e+2|0]){break e}v[e+2|0]=1;f=y[e+5|0];v[e+5|0]=0;v[e+3|0]=0;m=e,n=Bd(f,0,64),v[m+4|0]=n;break e;case 5:case 6:case 10:case 23:case 28:f=y[e+5|0]&240;if(!f){break e}v[e+5|0]=f;break e;case 8:f=y[e+5|0];if(f>>>0<=128){m=e,n=Ag(f<<1),v[m+5|0]=n;break e}if((f|0)!=164){break e}v[e+5|0]=145;v[e+3|0]=20;break e;case 13:f=y[e+5|0];v[e+5|0]=D(f>>>4|0,10)+(f&15);break e;case 18:nv(e);break e;case 16:if(y[e+5|0]>31){break e}v[e+3|0]=16;break e;case 27:break h;default:break e}}g=y[e+5|0];f=g&240;i:{if((f|0)==16){f=2}else{if((f|0)!=32){break i}f=3}v[e+3|0]=f}v[e+5|0]=g&15|224;break e}v[e+3|0]=0}j:{k:{if(!(i&64)){break k}x[27524]=0;R(264,h+8|0,a|0);f=x[27524];x[27524]=0;if((f|0)==1){break j}v[e+1|0]=y[h+8|0];g=y[Lc(h+8|0)|0];v[e|0]=g;f=255;if((g|0)!=128){f=253;if(g>>>0<129){break k}}v[e|0]=f}if(!(i&32)){continue}v[e+2|0]=1;x[27524]=0;g=T(210,a|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break a}v[e+4|0]=g;if(!c){continue}v[e+4|0]=(g<<6>>>0)/127;continue}break}break a}break a}break a}yb(a);ib=h+16|0;return}b=P()|0;yb(a);S(b|0);p()}function uY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,z=0,B=0,C=0,E=0,F=0;f=ib-32|0;ib=f;k=Bg(f+24|0);o=k+3|0;p=k+5|0;q=k+4|0;r=k+2|0;s=k+1|0;d=f+16|0;t=d|5;u=d|3;while(1){a:{if(A[a+12>>2]>l>>>0){z=qf(x[a>>2],x[x[a+48>>2]+12>>2],l);b:while(1){if(!Ob(x[c>>2],x[c+8>>2],1)){break a}d=Re(c);if((d|0)==255){break a}m=d<<24>>24;d=m&31;g=D(d,6)+z|0;i=Cg(x[x[a+48>>2]+12>>2])>>>0>d>>>0;j=i?g:k;e=1;if(!(m&64)){d=Re(c);h=d<<24>>24;e=255;d=d&127;c:{d:{if((d|0)==1){break d}e=d-1|0;if(b?e>>>0<=120:0){break d}if((d-109&255)>>>0<159|b){break c}e=d+13|0}v[j|0]=e}E=i?g+1|0:s,F=Re(c),v[E|0]=F;e=(h|0)<0}h=i?g+3|0:o;d=i?g+5|0:p;n=i?g+4|0:q;i=i?g+2|0:r;while(1){e:{f:{g:{if(e&1){x[f+16>>2]=y[j|0]|y[j+1|0]<<8|(y[j+2|0]<<16|y[j+3|0]<<24);w[f+20>>1]=y[j+4|0]|y[j+5|0]<<8;e=Re(c);g=e&63;B=e<<24>>24;if(e&64){v[i|0]=1;v[n|0]=g;break e}e=Re(c);v[d|0]=e;if(g>>>0<=15){Xf(j,g,e);h:{i:{j:{e=y[h|0];switch(e-9|0){case 1:case 2:case 3:break f;case 4:break i;case 0:break j;default:break h}}v[h|0]=9;v[d|0]=D(y[d|0]&15,17);break f}v[h|0]=0;v[i|0]=1;x[f+12>>2]=y[d|0]+1>>>1;x[f+8>>2]=64;E=n,F=x[rd(f+12|0,f+8|0)>>2],v[E|0]=F;break f}if((e|0)!=19){break f}if(y[d|0]==128){break g}nv(j);break f}if(g>>>0>44){break f}v[h|0]=y[g+26224|0];k:{switch(g-16|0){case 0:if(e>>>0>1){break g}v[d|0]=e|158;break f;case 1:case 2:v[f+12|0]=15;E=d,F=y[Ub(f+12|0,d)|0]|224,v[E|0]=F;break f;case 5:case 6:x[f+12>>2]=16;x[f+8>>2]=e+1;E=d,F=x[rd(f+12|0,f+8|0)>>2]/2|240,v[E|0]=F;break f;case 14:l:{m:{n:{o:{p:{g=e>>>4|0;switch(g-1|0){case 1:break n;case 0:break o;default:break p}}switch(g-10|0){case 1:break l;case 0:break m;default:break g}}v[h|0]=2;v[d|0]=e|240;break f}v[h|0]=3;v[d|0]=e|240;break f}v[h|0]=11;v[d|0]=(e<<3&120)+8|15;break f}v[h|0]=11;v[d|0]=(e&15)+1>>>1|240;break f;case 12:break k;default:break f}}x[f+12>>2]=e+1>>>1;x[f+8>>2]=64;E=d,F=x[rd(f+12|0,f+8|0)>>2],v[E|0]=F;break f}if((m|0)>=0){continue b}break a}v[h|0]=0}mv(h,d,u,t);e=y[f+19|0];C=Ri(e);g=y[h|0];if(C>>>0<=Ri(g)>>>0){break e}if(!y[i|0]){$q(f,g,y[d|0],1);g=y[f+1|0];v[i|0]=y[f|0];v[n|0]=g}v[h|0]=e;v[d|0]=y[f+21|0]}e=(B|0)<0;continue}}}ib=f+32|0;return}l=l+1|0;continue}}function Pfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0;f=ib-48|0;ib=f;s=x[a+16>>2];t=qg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);b=0;o=x[a+128>>2];if(o){e=x[a+8>>2];k=x[a+12>>2];p=rg(e,k,o);q=kb;i=x[a+76>>2];Zf(x[a>>2],x[a+4>>2],rf(e,k,d),kb);k=i>>>0<kb>>>0?d:0}else{k=0}j=a+112|0;while(1){if((b|0)!=2){e=b<<3;h=e+(f+16|0)|0;e=a+e|0;x[h+4>>2]=x[e+44>>2];x[h+8>>2]=x[e+48>>2];b=b+1|0;continue}break}l=x[a+40>>2];m=x[a+36>>2];b=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=b;u=x[a+8>>2];w=x[a+12>>2];while(1){if(d){d=d-1|0;b=x[f+12>>2];e=x[f+8>>2];x[f+40>>2]=e;x[f+44>>2]=0;k=k-1|0;p=k?p:0;q=k?q:0;n=(((b&2147483647)<<1|e>>>31)&-2)+s|0;e=o;a:{b:while(1){c:{if((e|0)<=0){Pb(j,x[a+120>>2],x[a+124>>2]);h=x[a+116>>2];if(!h){break a}e=((x[f+44>>2]&2147483647)<<1|x[f+40>>2]>>>31)&-2;g=0;b=0;break c}h=((x[f+44>>2]&2147483647)<<1|x[f+40>>2]>>>31)&-2;b=0;g=0;while(1)if((b|0)==2){Sd(j,(g|0)/8<<16>>16);Rd(j,4);Pb(f+40|0,p,q);e=e-1|0;continue b}else{g=(v[n+(b+h|0)|0]<<8)+g|0;b=b+1|0;continue}}break}while(1){if((b|0)!=2){g=(v[n+(b+e|0)|0]<<8)+g|0;b=b+1|0;continue}break}Sd(j,(g|0)/8<<16>>16);Rd(j,h);x[j>>2]=x[j>>2];x[j+4>>2]=0}b=pg(j,t);x[f+4>>2]=b;x[f>>2]=b;y=x[a+72>>2];b=x[a+68>>2];z=b;A=b>>31;b=x[a+64>>2];B=b;C=b>>31;b=x[a+60>>2];E=b;F=b>>31;b=0;while(1){if((b|0)!=2){r=(b<<2)+f|0;e=x[r>>2];i=(f+16|0)+(b<<3)|0;G=x[i+8>>2];g=x[i+4>>2];x[i+8>>2]=g;n=e<<8;e=n;e=qoa(E,F,e,e>>31);h=kb;H=i;i=e;e=Vb(g,-16777216,16776704);e=qoa(B,C,e,e>>31);g=i+e|0;i=kb+h|0;i=e>>>0>g>>>0?i+1|0:i;e=Vb(G,-16777216,16776704);h=qoa(z,A,e,e>>31);g=h+g|0;e=kb+i|0;e=g>>>0<h>>>0?e+1|0:e;h=g+8388608|0;e=h>>>0<8388608?e+1|0:e;e=Vc(h,e,24);x[H+4>>2]=e-(n&y);x[r>>2]=(e|0)/256;b=b+1|0;continue}break}b=x[a+32>>2];m=x[a+28>>2]+m|0;x[c>>2]=x[c>>2]+D(x[f>>2],m>>12);l=b+l|0;x[c+4>>2]=x[c+4>>2]+D(x[f+4>>2],l>>12);Pb(f+8|0,u,w);c=c+8|0;continue}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;x[a+40>>2]=l;x[a+20>>2]=m>>12;x[a+36>>2]=m;x[a+24>>2]=l>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+16|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}ib=f+48|0}function i8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a=Kb(a);x[27524]=0;Z(109);c=x[27524];x[27524]=0;a:{b:{if((c|0)==1){c=Ua(50060,108196,108780,0)|0;d=jb;c:{d:{e:{if((da(50060)|0)==(d|0)){c=_(c|0)|0;x[27524]=0;b=Q(947,a|0,b|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break e}x[27524]=0;b=Q(947,b|0,17746)|0;d=x[27524];x[27524]=0;if((d|0)==1){break e}x[27524]=0;d=Q(947,b|0,17722)|0;b=x[27524];x[27524]=0;if((b|0)==1){break e}b=lb[x[x[c>>2]+8>>2]](c)|0;x[27524]=0;Q(947,d|0,(b?b:21631)|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break e}x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){break b}b=P()|0;break a}f:{if((da(108196)|0)==(d|0)){c=_(c|0)|0;x[27524]=0;b=Q(947,a|0,b|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break f}x[27524]=0;b=Q(947,b|0,17746)|0;d=x[27524];x[27524]=0;if((d|0)==1){break f}x[27524]=0;d=Q(947,b|0,17697)|0;b=x[27524];x[27524]=0;if((b|0)==1){break f}b=lb[x[x[c>>2]+8>>2]](c)|0;x[27524]=0;Q(947,d|0,(b?b:21631)|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break f}x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){break b}b=P()|0;break a}e=da(108780)|0;c=_(c|0)|0;g:{if((d|0)==(e|0)){x[27524]=0;b=Q(947,a|0,b|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break g}x[27524]=0;b=Q(947,b|0,17746)|0;d=x[27524];x[27524]=0;if((d|0)==1){break g}x[27524]=0;d=Q(947,b|0,17713)|0;b=x[27524];x[27524]=0;if((b|0)==1){break g}b=lb[x[x[c>>2]+8>>2]](c)|0;x[27524]=0;Q(947,d|0,(b?b:21631)|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break g}x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){break b}b=P()|0;break a}x[27524]=0;b=Q(947,a|0,b|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break d}x[27524]=0;b=Q(947,b|0,17746)|0;c=x[27524];x[27524]=0;if((c|0)==1){break d}x[27524]=0;Q(947,b|0,13708)|0;b=x[27524];x[27524]=0;if((b|0)==1){break d}x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){break b}b=P()|0;break a}b=P()|0;x[27524]=0;Z(18);c=x[27524];x[27524]=0;if((c|0)!=1){break a}break c}b=P()|0;x[27524]=0;Z(18);c=x[27524];x[27524]=0;if((c|0)!=1){break a}break c}b=P()|0;x[27524]=0;Z(18);c=x[27524];x[27524]=0;if((c|0)==1){break c}break a}b=P()|0;x[27524]=0;Z(18);c=x[27524];x[27524]=0;if((c|0)!=1){break a}}V(0)|0;Sb()}p()}return}wb(a);S(b|0);p()}function Lt(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;i=ib-16|0;ib=i;f=x[a+24>>2];h=Uz(f,y[a+32|0]);j=x[h>>2];a:{if(Oc(j,x[h+4>>2])>>>0<=b>>>0){break a}if(XQ(f,z[bc(j,b)>>1])>>>0<=c>>>0){break a}h=x[a>>2];b:{if(wd(h,x[a+4>>2])>>>0>b>>>0){if(A[Cd(h,b)+4>>2]>c>>>0){break b}}eo(a,0);if(wd(x[a>>2],x[a+4>>2])>>>0<=b>>>0){break a}f=x[a+24>>2]}cc(i,x[d>>2],z[f+480188>>1]);d=i+8|0;h=x[i>>2];f=e?-2046629010:-2078137563;e=e?-1352371636:-873292572;j=x[i+4>>2];while(1){if(!g&(k|0)==(j|0)){x[d>>2]=f;x[d+4>>2]=e}else{l=y[KS(h,k)+841|0];m=l^qoa(f^k,e^g,435,256);l=!l;f=(q=f,r=qoa(m,kb,435,256),s=l,s?q:r);e=l?e:kb;k=k+1|0;g=k?g:g+1|0;continue}break}e=d;d=0;f=Bm(i,b,c);h=ib-16|0;ib=h;k=a+12|0;g=MQ(z[f>>1],x[f+4>>2],Td(k),gc(k));c:{if(Mb(g,eg(k))){j=z[f>>1];l=x[f+4>>2];f=ud(g);if(!ql(j,l,z[f>>1],x[f+4>>2])){break c}}g=eg(k)}f=x[Wb(h+8|0,g)>>2];ib=h+16|0;if(Rg(f,Gf(k))){d=ud(f);d=pc(x[d+8>>2],x[d+12>>2])^1}h=x[e>>2]!=-2078137563|x[e+4>>2]!=-873292572;Ab(i,x[Cd(x[a>>2],b)>>2],c);g=1;m=zb(x[x[i>>2]>>2],x[i+4>>2])^1;j=d|h;if(!(m|j)){break a}d:{e:{f:{g:{if(d){l=ud(f);f=Cb(x[l+8>>2]);n=Cb(x[l+12>>2]);o=x[e>>2];p=x[e+4>>2];j=ib-16|0;ib=j;x[j+8>>2]=f;while(1){if(!(!Mb(f,n)|x[f>>2]==(o|0)&x[f+4>>2]==(p|0))){f=x[Nt(j+8|0)>>2];continue}break}ib=j+16|0;if(Mb(f,Cb(x[l+12>>2]))){break a}if(!h){break e}break g}if(h){break g}if(!j){break d}break f}x[a+28>>2]=x[a+28>>2]+1}if(d|m){break e}d=KQ(k,Bm(i,b,c));h:{if(A[d+4>>2]<A[Db(d)>>2]){g=ib-16|0;ib=g;d=JQ(g,d);HQ(x[d+4>>2]);x[d+4>>2]=x[d+4>>2]+8;ic(d);ib=g+16|0;break h}f=ib-32|0;ib=f;g=Db(d);g=wr(f+8|0,xr(d,ah(x[d>>2],x[d+4>>2])+1|0),ah(x[d>>2],x[d+4>>2]),g);HQ(x[g+8>>2]);x[g+8>>2]=x[g+8>>2]+8;Dd(d,g);vr(g);ib=f+32|0}}d=KQ(k,Bm(i,b,c));i:{if(A[d+4>>2]<A[Db(d)>>2]){g=ib-16|0;ib=g;d=JQ(g,d);IQ(x[d+4>>2],x[e>>2],x[e+4>>2]);x[d+4>>2]=x[d+4>>2]+8;ic(d);ib=g+16|0;break i}f=ib-32|0;ib=f;g=Db(d);g=wr(f+8|0,xr(d,ah(x[d>>2],x[d+4>>2])+1|0),ah(x[d>>2],x[d+4>>2]),g);IQ(x[g+8>>2],x[e>>2],x[e+4>>2]);x[g+8>>2]=x[g+8>>2]+8;Dd(d,g);vr(g);ib=f+32|0}}Ab(i,x[Cd(x[a>>2],b)>>2],c);bf(i,1);g=0}ib=i+16|0;return g|0}function iy(a){a=a|0;var b=0,c=0,d=E(0),e=0;Rb(a+4960|0,0,76);v[a+5044|0]=0;x[a+5036>>2]=0;x[a+5040>>2]=0;b=x[a+4292>>2];d=B[a+4268>>2];x[27524]=0;e=a+4504|0;if(d<E(4294967296)&d>=E(0)){c=~~d>>>0}else{c=0}ea(935,e|0,67,5,c|0,b|0);b=x[27524];x[27524]=0;a:{if((b|0)==1){break a}b=x[a+4296>>2];x[27524]=0;ea(935,a+4528|0,62,5,c|0,b|0);b=x[27524];x[27524]=0;if((b|0)==1){break a}b=x[a+4300>>2];x[27524]=0;ea(935,a+4552|0,53,5,c|0,b|0);b=x[27524];x[27524]=0;if((b|0)==1){break a}b=x[a+4304>>2];x[27524]=0;ea(935,a+4576|0,43,5,c|0,b|0);b=x[27524];x[27524]=0;if((b|0)==1){break a}b=x[a+4308>>2];x[27524]=0;ea(935,a+4600|0,32,5,c|0,b|0);b=x[27524];x[27524]=0;if((b|0)==1){break a}b=x[a+4312>>2];x[27524]=0;ea(935,a+4624|0,22,5,c|0,b|0);b=x[27524];x[27524]=0;if((b|0)==1){break a}b=x[a+4316>>2];x[27524]=0;ea(935,a+4648|0,75,5,c|0,b|0);b=x[27524];x[27524]=0;if((b|0)==1){break a}b=x[a+4320>>2];x[27524]=0;ea(935,a+4672|0,69,5,c|0,b|0);b=x[27524];x[27524]=0;if((b|0)==1){break a}b=x[a+4324>>2];x[27524]=0;ea(935,a+4696|0,60,5,c|0,b|0);b=x[27524];x[27524]=0;if((b|0)==1){break a}b=x[a+4328>>2];x[27524]=0;ea(935,a+4720|0,48,5,c|0,b|0);b=x[27524];x[27524]=0;if((b|0)==1){break a}b=x[a+4332>>2];x[27524]=0;ea(935,a+4744|0,36,5,c|0,b|0);b=x[27524];x[27524]=0;if((b|0)==1){break a}b=x[a+4336>>2];x[27524]=0;ea(935,a+4768|0,25,5,c|0,b|0);b=x[27524];x[27524]=0;if((b|0)==1){break a}x[27524]=0;ea(935,a+4792|0,0,0,0,0);b=x[27524];x[27524]=0;if((b|0)==1){break a}b=x[a+4344>>2];x[27524]=0;ea(935,a+4816|0,3,0,c|0,b|0);b=x[27524];x[27524]=0;if((b|0)==1){break a}b=x[a+4348>>2];x[27524]=0;ea(935,a+4840|0,3,0,c|0,b|0);b=x[27524];x[27524]=0;if((b|0)==1){break a}x[27524]=0;ea(935,a+4864|0,407,1,c|0,0);b=x[27524];x[27524]=0;if((b|0)==1){break a}x[27524]=0;ea(935,a+4888|0,400,1,c|0,0);b=x[27524];x[27524]=0;if((b|0)==1){break a}x[27524]=0;ea(935,a+4912|0,10,0,c|0,-1);b=x[27524];x[27524]=0;if((b|0)==1){break a}x[27524]=0;ea(935,a+4936|0,10,0,c|0,-1);c=x[27524];x[27524]=0;if((c|0)==1){break a}v[a+5045|0]=1;return}c=V(108196)|0;if((jb|0)==(da(108196)|0)){_(c|0)|0;v[a+5045|0]=0;$();return}S(c|0);p()}function Hka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=ib-32|0;ib=e;a:{b:{if(!c){break b}n=e,o=Re(a),v[n+16|0]=o;vn(b,e+16|0);k=c-1|0;c=0;while(1){f=1;if(!k){break a}c:{d:{d=c<<1;c=d&254;if(!c){if(!vf(a,e+16|0)){break b}g=1;d=y[e+16|0]<<1|1;c=d&255;if(d>>>0<=255){break d}break c}if((d&65535)>>>0<=255){break d}g=1;break c}if(!vf(a,e+16|0)){break b}UW(b,e+16|0);k=k-1|0;continue}while(1){e:{f:{g:{d=c<<1&254;if(d){c=(c&65535)>>>0>127}else{if(!vf(a,e+16|0)){break g}c=y[e+16|0]<<1|1;d=c&255;c=c>>>0>255}g=vq(g,1)+c|0;c=d<<1&254;if(c){break f}if(!vf(a,e+16|0)){break g}d=y[e+16|0]<<1|1;c=d&255;if(d>>>0>255){continue}break e}c=0;break e}if(d>>>0>127){continue}}break}h:{if((g|0)<=2){j=0;h=g-2|0;break h}if(!vf(a,e+16|0)){break b}d=vq(g-3|0,8)|y[e+16|0];j=((d|0)>1279?2:1)+((d|0)>31999)|0;m=d^-1;h=0}d=c<<1&254;if(d){f=c>>>0>127}else{if(!vf(a,e+16|0)){break b}c=y[e+16|0]<<1|1;d=c&255;f=c>>>0>255}l=vq(h,1);c=d<<1&254;if(c){d=d>>>0>127}else{if(!vf(a,e+16|0)){break b}d=y[e+16|0]<<1|1;c=d&255;d=d>>>0>255}g=1;h=k;d=vq(f+l|0,1)+d|0;if(!d){while(1){i:{j:{k:{d=c<<1&254;if(d){c=(c&65535)>>>0>127}else{if(!vf(a,e+16|0)){break k}c=y[e+16|0]<<1|1;d=c&255;c=c>>>0>255}g=vq(g,1)+c|0;c=d<<1&254;if(c){break j}if(!vf(a,e+16|0)){break k}d=y[e+16|0]<<1|1;c=d&255;if(d>>>0>255){continue}break i}c=0;break i}if(d>>>0>127){continue}}break}d=g+2|0}g=h;h=d+j|0;f=0;if(g>>>0<h>>>0|(h|0)<=0|(m|0)>=0){break a}d=x[b+4>>2];f=0;if((0-cd(x[b>>2],d)|0)>(m|0)){break a}d=Wb(e+24|0,Cb(d));v[e+16|0]=0;g=e+16|0;l=ib-32|0;ib=l;f=x[d>>2];d=x[b>>2];i=to(f,Cb(d))+d|0;d=x[Db(b)>>2];j=x[b+4>>2];l:{if(h>>>0<=d-j>>>0){d=h;f=j-i|0;if(d>>>0>f>>>0){To(b,h-f|0,g);d=f;if(!d){break l}}WW(b,i,j,h+i|0);hi(i,d,g+(g>>>0>=i>>>0?g>>>0<A[b+4>>2]?h:0:0)|0);break l}d=Db(b);d=am(l+8|0,Zl(b,cd(x[b>>2],j)+h|0),i-x[b>>2]|0,d);wV(d,h,g);i=VW(b,d,i);$l(d)}Cb(i);ib=l+32|0;n=e,o=Yf(JU(Cb(x[b+4>>2]),h),m),x[n+16>>2]=o;n=e,o=JU(Cb(x[b+4>>2]),h),x[n+8>>2]=o;d=h;while(1){f=y[IU(e+16|0)|0];n=IU(e+8|0),o=f,v[n|0]=o;f=d>>>0>1;d=d-1|0;if(f){continue}break}k=k-h|0;continue}}f=0}ib=e+32|0;return f|0}function Ofa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0;f=ib-48|0;ib=f;s=x[a+16>>2];t=qg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);b=0;o=x[a+128>>2];if(o){e=x[a+8>>2];j=x[a+12>>2];p=rg(e,j,o);q=kb;g=x[a+76>>2];Zf(x[a>>2],x[a+4>>2],rf(e,j,d),kb);j=g>>>0<kb>>>0?d:0}else{j=0}i=a+112|0;while(1){if((b|0)!=2){e=b<<3;h=e+(f+16|0)|0;e=a+e|0;x[h+4>>2]=x[e+44>>2];x[h+8>>2]=x[e+48>>2];b=b+1|0;continue}break}m=x[a+40>>2];n=x[a+36>>2];b=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=b;u=x[a+8>>2];v=x[a+12>>2];a:while(1){if(d){d=d-1|0;b=x[f+12>>2];e=x[f+8>>2];x[f+40>>2]=e;x[f+44>>2]=0;j=j-1|0;p=j?p:0;q=j?q:0;l=((((b&2147483647)<<1|e>>>31)&2147483646)<<1)+s|0;b=o;while(1)if((b|0)<=0){Pb(i,x[a+120>>2],x[a+124>>2]);h=x[a+116>>2];if(h){b=(x[f+44>>2]&2147483647)<<1|x[f+40>>2]>>>31;Sd(i,(w[(b<<1|2)+l>>1]+w[l+((b&2147483646)<<1)>>1]|0)/8<<16>>16);Rd(i,h);x[i>>2]=x[i>>2];x[i+4>>2]=0}b=pg(i,t);x[f+4>>2]=b;x[f>>2]=b;y=x[a+72>>2];b=x[a+68>>2];z=b;A=b>>31;b=x[a+64>>2];B=b;C=b>>31;b=x[a+60>>2];E=b;F=b>>31;b=0;while(1){if((b|0)!=2){r=(b<<2)+f|0;e=x[r>>2];g=(f+16|0)+(b<<3)|0;G=x[g+8>>2];k=x[g+4>>2];x[g+8>>2]=k;l=e<<8;e=l;e=qoa(E,F,e,e>>31);h=kb;H=g;g=e;e=Vb(k,-16777216,16776704);e=qoa(B,C,e,e>>31);k=g+e|0;g=kb+h|0;g=e>>>0>k>>>0?g+1|0:g;e=Vb(G,-16777216,16776704);h=qoa(z,A,e,e>>31);k=h+k|0;e=kb+g|0;e=h>>>0>k>>>0?e+1|0:e;h=k+8388608|0;e=h>>>0<8388608?e+1|0:e;e=Vc(h,e,24);x[H+4>>2]=e-(l&y);x[r>>2]=(e|0)/256;b=b+1|0;continue}break}b=x[a+32>>2];n=x[a+28>>2]+n|0;x[c>>2]=x[c>>2]+D(x[f>>2],n>>12);m=b+m|0;x[c+4>>2]=x[c+4>>2]+D(x[f+4>>2],m>>12);Pb(f+8|0,u,v);c=c+8|0;continue a}else{e=(x[f+44>>2]&2147483647)<<1|x[f+40>>2]>>>31;Sd(i,(w[(e<<1|2)+l>>1]+w[l+((e&2147483646)<<1)>>1]|0)/8<<16>>16);Rd(i,4);Pb(f+40|0,p,q);b=b-1|0;continue}}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;x[a+40>>2]=m;x[a+20>>2]=n>>12;x[a+36>>2]=n;x[a+24>>2]=m>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+16|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}ib=f+48|0}function Dt(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=ib-16|0;ib=e;f=D(c,872)+b|0;g=f+704|0;x[g>>2]=x[g>>2]|524288;a:{b:{if(!(x[a+480208>>2]&8)){Ab(e+8|0,a+1074312|0,15);if(zb(x[x[e+8>>2]>>2],x[e+12>>2])){break b}}if(x[a+480180>>2]!=268435456){break a}}i=D(c,872)+b|0;d=d?d:y[(D(c,872)+b|0)+1427|0];v[i+1427|0]=d;v[i+1428|0]=d}if(d){w[(D(c,872)+b|0)+1384>>1]=d}c:{d:{h=f+616|0;j=x[h+656>>2];if(Aj(j)){a=z[(D(c,872)+b|0)+1384>>1];if(!a){break d}f=0;d=x[b+16>>2];f=d?x[(D(c,872)+b|0)+1472>>2]:f;l=0-a|0;k=a;h=D(c,872)+b|0;i=h+1324|0;a=x[i>>2];m=(+(d>>>0)+1)*+(((a|0)<0?l:k)|0)/+A[b+40>>2];e:{if(F(m)<2147483648){d=~~m;break e}d=-2147483648}h=h+1472|0;x[h>>2]=d;if(y[g+2|0]&16){d=D(x[x[j+44>>2]+36>>2]+1|0,d);x[h>>2]=d}d=d-f|0;g=d>>31;f=a>>31;if((f^a)-f>>>0<=(d^g)-g>>>0){if(!a){break d}b=D(c,872)+b|0;c=b+1468|0;x[c>>2]=a+x[c>>2];x[i>>2]=0;a=b+1467|0;v[a|0]=y[a|0]|64;d=0;break c}b=D(c,872)+b|0;c=b+1468|0;x[c>>2]=d+x[c>>2];x[i>>2]=a-d;a=b+1467|0;v[a|0]=y[a|0]|64;break d}i=a+1074312|0;Ab(e+8|0,i,118);if(!(!zb(x[x[e+8>>2]>>2],x[e+12>>2])|!(y[g+1|0]&2))){d=0;if(Wc(y[(D(c,872)+b|0)+1404|0])){break c}}g=1;j=D(c,872)+b|0;f=j+1467|0;f:{if(!(v[f|0]&1)){break f}d=x[a+480180>>2];if(d&524352){break f}if(x[b+40>>2]==1){Ab(e+8|0,i,6);if(zb(x[x[e+8>>2]>>2],x[e+12>>2])){break f}d=x[a+480180>>2]}g=0;if((d|0)!=8){break f}g=(y[a+480208|0]&2)>>>1|0}k=x[a+480180>>2];d=z[j+1384>>1];if(!((k|0)!=268435456|d>>>0<240)){g=v[f|0]&1;d=d-240|0}d=D((k|0)==64?2:4,d);j=D(c,872)+b|0;b=j+1316|0;g:{if(!x[b>>2]){break g}c=j+1324|0;if(!x[c>>2]|!g){break g}k=sj(a)?d:0-d|0;l=x[b>>2];n=x[c>>2];if(!(!(y[f|0]&16)&(l|0)>=(n|0))){mk(a,h,b,k,1);c=x[c>>2];if((c|0)>=x[b>>2]){break g}x[b>>2]=c;break g}if((l|0)<=(n|0)){break g}mk(a,h,b,0-k|0,1);h=x[b>>2];c=x[c>>2];h:{if((h|0)<(c|0)){x[b>>2]=c;break h}if((c|0)!=(h|0)){break g}}Ab(e+8|0,i,112);if(!zb(x[x[e+8>>2]>>2],x[e+12>>2])){break g}v[f|0]=y[f|0]|16}c=x[b>>2];b=j+1324|0;i:{if((c|0)!=x[b>>2]){break i}Ab(e+8|0,i,25);if(!zb(x[x[e+8>>2]>>2],x[e+12>>2])&x[a+480180>>2]!=1){break i}x[b>>2]=0}d=g?d:0;break c}d=0}ib=e+16|0;return d}function nM(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=ib-112|0;ib=d;e=x[b+4>>2];a:{if(!e){break a}f=x[b>>2];h=y[gl(f,e)|0];if((h|0)==33){c=1}else{if((h|0)!=63){break a}c=0}ol(d+88|0,f,e,e-1|0);e=x[d+92>>2];x[b>>2]=x[d+88>>2];x[b+4>>2]=e}f=d+88|0;Yd(f);e=x[d+88>>2];Yd(d+72|0);e=fl(e,x[d+76>>2],b);Yd(f);b:{c:{d:{e:{if((e|0)==x[d+92>>2]){a=x[b+4>>2];e=x[b>>2];f=qc(d+104|0,21631);h=x[f+4>>2];x[d>>2]=x[f>>2];x[d+4>>2]=h;if(Nc(e,a,d)){a=ba(8)|0;x[27524]=0;c=Q(55,d+88|0,10420)|0;b=x[27524];x[27524]=0;if((b|0)==1){break d}lc(a,c);x[27524]=0;U(123,a|0,50060,962);a=x[27524];x[27524]=0;if((a|0)!=1){break b}b=P()|0;wb(c);break c}g=0;if(!c){break e}a=ba(8)|0;c=x[b+4>>2];b=x[b>>2];x[27524]=0;e=Qh(d+72|0,b,c);b=x[27524];x[27524]=0;f:{g:{h:{if((b|0)!=1){x[27524]=0;U(973,d+88|0,17646,e|0);b=x[27524];x[27524]=0;if((b|0)==1){break h}lc(a,d+88|0);c=0;x[27524]=0;U(123,a|0,50060,962);b=x[27524];x[27524]=0;if((b|0)!=1){break b}b=P()|0;wb(d+88|0);break g}b=P()|0;break f}b=P()|0;c=1}wb(e);if(!c){break c}}ca(a|0);break c}if(x[e+4>>2]!=2){a=ba(8)|0;x[27524]=0;c=Q(55,d+88|0,11480)|0;b=x[27524];x[27524]=0;if((b|0)!=1){lc(a,c);x[27524]=0;U(123,a|0,50060,962);a=x[27524];x[27524]=0;if((a|0)!=1){break b}b=P()|0;wb(c);break c}b=P()|0;ca(a|0);break c}c=x[b+4>>2];b=x[b>>2];e=qc(d- -64|0,21631);f=x[e+4>>2];x[d+32>>2]=x[e>>2];x[d+36>>2]=f;if(Nc(b,c,d+32|0)){a=ba(8)|0;x[27524]=0;c=Q(55,d+88|0,10420)|0;b=x[27524];x[27524]=0;if((b|0)!=1){lc(a,c);x[27524]=0;U(123,a|0,50060,962);a=x[27524];x[27524]=0;if((a|0)!=1){break b}b=P()|0;wb(c);break c}b=P()|0;ca(a|0);break c}e=qc(d+56|0,7707);f=x[e+4>>2];x[d+24>>2]=x[e>>2];x[d+28>>2]=f;if(Nc(b,c,d+24|0)){g=1;if(!Qd(y[a+28|0])){break e}g=65536/+A[x[a+24>>2]+480244>>2];break e}e=qc(d+48|0,7759);f=x[e+4>>2];x[d+16>>2]=x[e>>2];x[d+20>>2]=f;if(Nc(b,c,d+16|0)){g=1;if(!Qd(y[a+28|0])){break e}g=+A[x[a+24>>2]+480240>>2]*152587890625e-16;break e}e=qc(d+40|0,7777);f=x[e+4>>2];x[d+8>>2]=x[e>>2];x[d+12>>2]=f;g=0;if(!Nc(b,c,d+8|0)){break e}g=+A[x[a+24>>2]+480236>>2]*152587890625e-16}ib=d+112|0;return+g}b=P()|0;ca(a|0)}S(b|0)}p()}function Uba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=E(0),g=E(0),h=E(0),i=0,j=0,k=0,l=E(0),m=0,n=E(0),o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=E(0),z=0,A=0,C=0,D=0,G=0,H=0,I=E(0),J=0,K=0,L=0,M=0,N=0,O=E(0),P=0,Q=E(0);a:{if(!x[a+4316>>2]){break a}if(!fi(a+44|0)){break a}G=a+4300|0;H=a+4288|0;J=a+4264|0;K=a+4276|0;e=x[a+44>>2];s=Hc(e,0);t=Hc(e,1);e=x[a+56>>2];u=Hc(e,0);v=Hc(e,1);L=lb[x[x[a>>2]+196>>2]](a)|0;w=E(E(lb[x[x[a>>2]+204>>2]](a))/E(100));I=E(lb[x[x[a>>2]+192>>2]](a));z=lb[x[x[a>>2]+216>>2]](a)|0;M=z&1;o=x[a+4324>>2];i=x[a+4320>>2];m=x[a+4328>>2];k=x[a+4312>>2];N=x[a+4276>>2];p=x[a+4264>>2];A=x[a+4256>>2];C=y[a+4260|0];r=a+4316|0;D=d;while(1){if(D){h=B[t>>2];l=B[s>>2];j=x[r>>2];e=Qn(j,k+A|0);j=Qn(j,k);b:{if(C){P=Bb(H,m),Q=l,B[P>>2]=Q;P=Bb(G,m),Q=h,B[P>>2]=Q;q=Bb(p,e);P=Bb(p,j),Q=E(E(B[q>>2]*w)+l),B[P>>2]=Q;g=E(E(B[Bb(N,e)>>2]*w)+h);e=K;break b}g=E(E(B[Bb(p,e)>>2]*w)+E(E(l+h)*E(.5)));e=J}P=Bb(x[e>>2],j),Q=g,B[P>>2]=Q;c:{if(L){f=B[a+4244>>2];g=E(f+B[a+4236>>2]);B[a+4236>>2]=g;f=E(f+B[a+4240>>2]);B[a+4240>>2]=f;if(g>E(1)){g=E(g+E(-2));B[a+4236>>2]=g}if(f>E(1)){f=E(f+E(-2));B[a+4240>>2]=f}g=E(F(g));g=E(E(g+g)+E(-1));f=E(F(f));f=E(E(f+f)+E(-1));break c}f=B[a+4240>>2];n=B[a+4244>>2];g=E(E(f*n)+B[a+4236>>2]);B[a+4236>>2]=g;f=E(f-E(g*n));B[a+4240>>2]=f}if(C){e=(m+2|0)%3|0;l=B[Bb(H,e)>>2];h=B[Bb(G,e)>>2]}e=x[r>>2];j=Bb(p,Qn(e,i+k|0));q=e;e=k+4096|0;O=B[Bb(p,Qn(q,e+i|0))>>2];n=B[j>>2];B[u>>2]=E(E(E(E(E(O-n)*E(E(i&4095)*E(.000244140625)))+n)-l)*I)+l;i=x[(C?4276:4264)+a>>2];j=x[r>>2];q=Bb(i,Qn(j,k+o|0));n=B[Bb(i,Qn(j,e+o|0))>>2];l=B[q>>2];B[v>>2]=E(E(E(E(E(n-l)*E(E(o&4095)*E(.000244140625)))+l)-h)*I)+h;m=((m|0)<=0?m+3|0:m)-1|0;x[a+4328>>2]=m;k=(((k|0)<=0?x[r>>2]<<12:0)+k|0)-4096|0;x[a+4312>>2]=k;h=M?f:g;f=B[a+4248>>2];h=E(h*f);d:{if(E(F(h))<E(2147483648)){e=~~h;break d}e=-2147483648}o=(z>>>0>1?e:0-e|0)+A|0;x[a+4324>>2]=o;i=z>>>0<4;t=t+4|0;s=s+4|0;g=E(g*f);e:{if(E(F(g))<E(2147483648)){e=~~g;break e}e=-2147483648}i=(i?e:0-e|0)+A|0;x[a+4320>>2]=i;D=D-1|0;v=v+4|0;u=u+4|0;continue}else{e=a;a=x[a+56>>2];zi(e,b,c,Hc(a,0),Hc(a,1),d)}break}}}function Tfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0;f=ib-48|0;ib=f;q=x[a+16>>2];r=qg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);b=0;m=x[a+128>>2];if(m){e=x[a+8>>2];k=x[a+12>>2];n=rg(e,k,m);o=kb;i=x[a+76>>2];Zf(x[a>>2],x[a+4>>2],rf(e,k,d),kb);k=i>>>0<kb>>>0?d:0}else{k=0}j=a+112|0;while(1){if((b|0)!=2){e=b<<3;h=e+(f+16|0)|0;e=a+e|0;x[h+4>>2]=x[e+44>>2];x[h+8>>2]=x[e+48>>2];b=b+1|0;continue}break}s=x[a+24>>2];t=x[a+20>>2];b=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=b;u=x[a+8>>2];w=x[a+12>>2];while(1){if(d){d=d-1|0;b=x[f+12>>2];e=x[f+8>>2];x[f+40>>2]=e;x[f+44>>2]=0;k=k-1|0;n=k?n:0;o=k?o:0;l=(((b&2147483647)<<1|e>>>31)&-2)+q|0;e=m;a:{b:while(1){c:{if((e|0)<=0){Pb(j,x[a+120>>2],x[a+124>>2]);h=x[a+116>>2];if(!h){break a}e=((x[f+44>>2]&2147483647)<<1|x[f+40>>2]>>>31)&-2;g=0;b=0;break c}h=((x[f+44>>2]&2147483647)<<1|x[f+40>>2]>>>31)&-2;b=0;g=0;while(1)if((b|0)==2){Sd(j,(g|0)/8<<16>>16);Rd(j,4);Pb(f+40|0,n,o);e=e-1|0;continue b}else{g=(v[l+(b+h|0)|0]<<8)+g|0;b=b+1|0;continue}}break}while(1){if((b|0)!=2){g=(v[l+(b+e|0)|0]<<8)+g|0;b=b+1|0;continue}break}Sd(j,(g|0)/8<<16>>16);Rd(j,h);x[j>>2]=x[j>>2];x[j+4>>2]=0}b=pg(j,r);x[f+4>>2]=b;x[f>>2]=b;y=x[a+72>>2];b=x[a+68>>2];z=b;A=b>>31;b=x[a+64>>2];B=b;C=b>>31;b=x[a+60>>2];E=b;F=b>>31;b=0;while(1){if((b|0)!=2){p=(b<<2)+f|0;e=x[p>>2];i=(f+16|0)+(b<<3)|0;G=x[i+8>>2];g=x[i+4>>2];x[i+8>>2]=g;l=e<<8;e=l;e=qoa(E,F,e,e>>31);h=kb;H=i;i=e;e=Vb(g,-16777216,16776704);e=qoa(B,C,e,e>>31);g=i+e|0;i=kb+h|0;i=e>>>0>g>>>0?i+1|0:i;e=Vb(G,-16777216,16776704);h=qoa(z,A,e,e>>31);g=h+g|0;e=kb+i|0;e=g>>>0<h>>>0?e+1|0:e;h=g+8388608|0;e=h>>>0<8388608?e+1|0:e;e=Vc(h,e,24);x[H+4>>2]=e-(l&y);x[p>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f>>2],t);x[c+4>>2]=x[c+4>>2]+D(x[f+4>>2],s);Pb(f+8|0,u,w);c=c+8|0;continue}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+16|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}ib=f+48|0}function Faa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=E(0),f=0,g=0,h=0,i=0,j=E(0),k=0,l=E(0),m=E(0),n=E(0),o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=E(0),A=0,C=0,D=0,F=0,G=E(0),H=0,I=0,J=0,K=0,L=0,M=0,N=E(0),O=E(0),P=E(0),Q=E(0),R=E(0),S=0,T=E(0);if(fi(a+44|0)){f=x[a+44>>2];A=Hc(f,0);C=Hc(f,1);f=x[a+56>>2];D=Hc(f,0);F=Hc(f,1);t=x[a+4296>>2];g=t+1|0;k=a+4304|0;f=a+4272|0;u=g+x[Bb(f,0)>>2]&4095;o=k+(u<<4)|0;v=g+x[Bb(f,1)>>2]&4095;p=((v<<4)+k|0)+4|0;w=g+x[Bb(f,2)>>2]&4095;q=((w<<4)+k|0)+8|0;h=Bb(f,3);i=x[Bb(f,4)>>2];r=x[a+4300>>2];i=i+r|0;y=g+x[h>>2]&4095;s=((y<<4)+k|0)+12|0;h=x[Bb(f,5)>>2]+r|0;g=a+4232|0;I=a+69840|0;J=a+78032|0;f=d;while(1){if(f){N=B[s>>2];O=B[q>>2];P=B[p>>2];Q=B[o>>2];z=B[C>>2];R=B[A>>2];K=i&1023;i=(K<<3)+I|0;j=B[i+4>>2];u=u-1&4095;o=(u<<4)+k|0;e=B[o>>2];s=r<<3;q=s+I|0;v=v-1&4095;p=((v<<4)+k|0)+4|0;l=B[p>>2];m=l;n=E(l*E(.6180340051651001));G=B[i>>2];l=B[Bb(g,0)>>2];n=E(n+E(G*l));B[q+4>>2]=m+E(n*E(-.6180340051651001));m=e;e=E(E(j*l)+E(e*E(-.6180340051651001)));B[q>>2]=m+E(e*E(.6180340051651001));B[o>>2]=n;B[p>>2]=e;L=h&1023;h=(L<<3)+J|0;l=B[h+4>>2];w=w-1&4095;H=(w<<4)+k|0;q=H+8|0;e=B[q>>2];M=s+J|0;y=y-1&4095;i=(y<<4)+k|0;s=i+12|0;j=B[s>>2];m=j;G=B[h>>2];n=B[Bb(g,1)>>2];j=E(E(j*E(.6180340051651001))+E(G*n));B[M+4>>2]=m+E(j*E(-.6180340051651001));m=e;e=E(E(l*n)+E(e*E(-.6180340051651001)));B[M>>2]=m+E(e*E(.6180340051651001));B[H+8>>2]=j;B[i+12>>2]=e;e=E(R+E(1.0000000031710769e-30));B[D>>2]=j+E(E(e*B[a+4224>>2])+B[o>>2]);j=E(z+E(1.0000000031710769e-30));B[F>>2]=E(E(j*B[a+4224>>2])+B[p>>2])+B[i+12>>2];h=(t<<4)+k|0;l=e;e=B[a+4228>>2];z=E(l*e);S=h,T=E(z+E(E(B[o>>2]*B[Bb(g,2)>>2])+E(Q*B[Bb(g,3)>>2]))),B[S>>2]=T;e=E(j*e);S=h,T=E(e+E(E(B[p>>2]*B[Bb(g,4)>>2])+E(P*B[Bb(g,5)>>2]))),B[S+4>>2]=T;S=h,T=E(E(E(B[H+8>>2]*B[Bb(g,6)>>2])+E(O*B[Bb(g,7)>>2]))-e),B[S+8>>2]=T;S=h,T=E(z+E(E(B[i+12>>2]*B[Bb(g,8)>>2])+E(N*B[Bb(g,9)>>2]))),B[S+12>>2]=T;f=f-1|0;F=F+4|0;D=D+4|0;C=C+4|0;A=A+4|0;h=L-1|0;i=K-1|0;r=r-1&1023;t=t-1&4095;continue}else{x[a+4300>>2]=r;x[a+4296>>2]=t;f=a;a=x[a+56>>2];zi(f,b,c,Hc(a,0),Hc(a,1),d)}break}}}function hN(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=ib-128|0;ib=j;a:{b:{c:{if(!Cm(f,g,h,i,0,0,0,0)){break c}m=i&65535;n=i>>>16&32767;d:{e:{if((n|0)!=32767){l=4;if(n){break e}l=f|h|(g|m)?3:2;break d}l=!(f|h|(g|m))}}r=e>>>16|0;o=r&32767;if((o|0)==32767){break c}if(l){break b}}Jd(j+16|0,b,c,d,e,f,g,h,i);e=x[j+16>>2];d=x[j+20>>2];c=x[j+24>>2];b=x[j+28>>2];GN(j,e,d,c,b,e,d,c,b);d=x[j+8>>2];e=x[j+12>>2];h=x[j>>2];i=x[j+4>>2];break a}m=e&65535|o<<16;p=m;l=d;m=h;q=i>>>16&32767;k=i&65535|q<<16;if((Cm(b,c,l,p,f,g,h,k)|0)<=0){if(Cm(b,c,l,p,f,g,m,k)){h=b;i=c;break a}Jd(j+112|0,b,c,d,e,0,0,0,0);d=x[j+120>>2];e=x[j+124>>2];h=x[j+112>>2];i=x[j+116>>2];break a}if(o){i=c;h=b}else{Jd(j+96|0,b,c,l,p,0,0,0,1081540608);h=x[j+108>>2];p=h;l=x[j+104>>2];o=(h>>>16|0)-120|0;i=x[j+100>>2];h=x[j+96>>2]}if(!q){Jd(j+80|0,f,g,m,k,0,0,0,1081540608);f=x[j+92>>2];k=f;m=x[j+88>>2];q=(k>>>16|0)-120|0;g=x[j+84>>2];f=x[j+80>>2]}s=k&65535|65536;p=p&65535|65536;if((o|0)>(q|0)){while(1){t=l-m|0;k=(g|0)==(i|0)&f>>>0>h>>>0|g>>>0>i>>>0;n=(p-((l>>>0<m>>>0)+s|0)|0)-(t>>>0<k>>>0)|0;k=t-k|0;f:{if((n|0)>0|(n|0)>=0){l=h;h=h-f|0;i=i-((f>>>0>l>>>0)+g|0)|0;if(!(h|k|(i|n))){Jd(j+32|0,b,c,d,e,0,0,0,0);d=x[j+40>>2];e=x[j+44>>2];h=x[j+32>>2];i=x[j+36>>2];break a}n=n<<1|k>>>31;l=k<<1|i>>>31;p=n;break f}n=p<<1|l>>>31;l=l<<1|i>>>31;p=n}n=i<<1|h>>>31;h=h<<1;i=n;o=o-1|0;if((q|0)<(o|0)){continue}break}o=q}q=l-m|0;n=(g|0)==(i|0)&f>>>0>h>>>0|g>>>0>i>>>0;k=(p-((l>>>0<m>>>0)+s|0)|0)-(q>>>0<n>>>0)|0;m=q-n|0;g:{if((k|0)<0){m=l;k=p;break g}l=h;h=h-f|0;i=i-((f>>>0>l>>>0)+g|0)|0;if(h|m|(i|k)){break g}Jd(j+48|0,b,c,d,e,0,0,0,0);d=x[j+56>>2];e=x[j+60>>2];h=x[j+48>>2];i=x[j+52>>2];break a}if((k|0)==65535|k>>>0<65535){while(1){b=i>>>31|0;o=o-1|0;p=i<<1|h>>>31;h=h<<1;i=p;c=b;b=m;k=k<<1|b>>>31;m=c|b<<1;if(k>>>0<65536){continue}break}}b=r&32768;if((o|0)<=0){Jd(j- -64|0,h,i,m,k&65535|(b|o+120)<<16,0,0,0,1065811968);d=x[j+72>>2];e=x[j+76>>2];h=x[j+64>>2];i=x[j+68>>2];break a}d=m;e=k&65535|(b|o)<<16}x[a>>2]=h;x[a+4>>2]=i;x[a+8>>2]=d;x[a+12>>2]=e;ib=j+128|0}function tga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0;e=ib-48|0;ib=e;a:{b:{c:{j=x[a+12>>2];l=x[a+8>>2];d:{if((j|0)<=1&l>>>0<=805306368|(j|0)<=0){if((j|0)>=-2&l>>>0>=3489660928|(j|0)>-2){break c}if((j|0)==-2&l>>>0>2147483647|(j|0)==-1){break d}break b}if((j|0)==1&l>>>0>2147483648|j>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}s=b;t=x[a+16>>2];b=0;while(1){if((b|0)!=2){f=b<<3;k=f+(e+24|0)|0;f=a+f|0;x[k+4>>2]=x[f+44>>2];x[k+8>>2]=x[f+48>>2];b=b+1|0;continue}break}m=x[a+40>>2];n=x[a+36>>2];b=x[a+4>>2];x[e+16>>2]=x[a>>2];x[e+20>>2]=b;u=x[a+32>>2];v=x[a+28>>2];y=x[a+72>>2];b=x[a+68>>2];z=b;A=b>>31;b=x[a+64>>2];B=b;C=b>>31;b=x[a+60>>2];E=b;F=b>>31;while(1){if(d){b=x[e+16>>2];G=((((x[e+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+t|0;b=(b>>>16&65520)+s|0;H=w[b+14>>1];g=w[b+12>>1];q=w[b+10>>1];r=w[b+8>>1];h=w[b+6>>1];k=w[b+4>>1];f=w[b+2>>1];b=w[b>>1];o=0;p=0;while(1){if((p|0)!=2){i=G+(p<<1)|0;x[(e+8|0)+(p<<2)>>2]=(((((((D(w[i-8>>1],f)+D(w[i-12>>1],b)|0)+D(w[i-4>>1],k)|0)+D(w[i>>1],h)|0)+D(w[i+4>>1],r)|0)+D(w[i+8>>1],q)|0)+D(g,w[i+12>>1])|0)+D(H,w[i+16>>1])|0)/32768;p=p+1|0;continue}break}while(1){if((o|0)!=2){q=(e+8|0)+(o<<2)|0;b=x[q>>2];g=(e+24|0)+(o<<3)|0;r=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;k=b<<8;b=k;b=qoa(E,F,b,b>>31);f=kb;i=g;g=b;b=Vb(h,-16777216,16776704);b=qoa(B,C,b,b>>31);h=g+b|0;g=kb+f|0;g=b>>>0>h>>>0?g+1|0:g;b=Vb(r,-16777216,16776704);f=qoa(z,A,b,b>>31);h=f+h|0;b=kb+g|0;b=f>>>0>h>>>0?b+1|0:b;f=h+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Vc(f,b,24);x[i+4>>2]=b-(k&y);x[q>>2]=(b|0)/256;o=o+1|0;continue}break}n=n+v|0;x[c>>2]=x[c>>2]+D(x[e+8>>2],n>>12);m=m+u|0;x[c+4>>2]=x[c+4>>2]+D(x[e+12>>2],m>>12);Pb(e+16|0,l,j);c=c+8|0;d=d-1|0;continue}break}b=x[e+20>>2];x[a>>2]=x[e+16>>2];x[a+4>>2]=b;x[a+40>>2]=m;x[a+20>>2]=n>>12;x[a+36>>2]=n;x[a+24>>2]=m>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(e+24|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}ib=e+48|0}function nia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=ib-128|0;ib=d;a:{b:{c:{d:{switch(y[a|0]-23|0){case 0:e=v[a+1|0];f=d,g=KB(c,+y[a+2|0]*1e4/240),v[f|0]=g;x[d+96>>2]=127;x[d+80>>2]=(D(y[a+3|0],127)>>>0)/185;f=d,g=x[rd(d+96|0,d+80|0)>>2],v[f+127|0]=g;e:{switch(((e>>>0)%5|0)-1|0){case 0:bv(d+80|0,15584);x[27524]=0;R(548,d- -64|0,d|0);a=x[27524];x[27524]=0;f:{g:{h:{i:{if((a|0)!=1){x[27524]=0;R(548,d+48|0,d+127|0);a=x[27524];x[27524]=0;if((a|0)==1){break i}x[27524]=0;X(549,d+96|0,d+80|0,d- -64|0,d+48|0);a=x[27524];x[27524]=0;if((a|0)==1){break h}a=d+96|0;ye(d+112|0,a);pf(b,x[d+112>>2],x[d+116>>2]);wb(a);wb(d+48|0);wb(d- -64|0);Zb(d+80|0);break b}a=P()|0;break f}a=P()|0;break g}a=P()|0;wb(d+48|0)}wb(d- -64|0)}break c;case 1:bv(d+80|0,15531);x[27524]=0;R(548,d- -64|0,d|0);a=x[27524];x[27524]=0;j:{k:{l:{m:{if((a|0)!=1){x[27524]=0;R(548,d+48|0,d+127|0);a=x[27524];x[27524]=0;if((a|0)==1){break m}x[27524]=0;X(549,d+96|0,d+80|0,d- -64|0,d+48|0);a=x[27524];x[27524]=0;if((a|0)==1){break l}a=d+96|0;ye(d+40|0,a);pf(b,x[d+40>>2],x[d+44>>2]);wb(a);wb(d+48|0);wb(d- -64|0);Zb(d+80|0);break b}a=P()|0;break j}a=P()|0;break k}a=P()|0;wb(d+48|0)}wb(d- -64|0)}break c;default:break e}}a=qc(d+32|0,15611);pf(b,x[a>>2],x[a+4>>2]);break b;case 1:break d;default:break a}}c=v[a+1|0];v[d+127|0]=(c|0)<5?c:0;c=v[a+2|0];v[d+31|0]=(c|0)<0?127:c;a=v[a+3|0];v[d+30|0]=(a|0)<0?127:a;a=ib-16|0;ib=a;c=Kc(a,4051);$c(d+80|0,c);wb(c);ib=a+16|0;x[27524]=0;R(548,d- -64|0,d+127|0);a=x[27524];x[27524]=0;n:{o:{p:{q:{r:{s:{if((a|0)!=1){x[27524]=0;R(548,d+48|0,d+31|0);a=x[27524];x[27524]=0;if((a|0)==1){break s}x[27524]=0;R(548,d|0,d+30|0);a=x[27524];x[27524]=0;if((a|0)==1){break r}x[27524]=0;ea(716,d+96|0,d+80|0,d- -64|0,d+48|0,d|0);a=x[27524];x[27524]=0;if((a|0)==1){break q}a=d+96|0;ye(d+16|0,a);pf(b,x[d+16>>2],x[d+20>>2]);wb(a);wb(d);wb(d+48|0);wb(d- -64|0);Zb(d+80|0);break b}a=P()|0;break n}a=P()|0;break o}a=P()|0;break p}a=P()|0;wb(d)}wb(d+48|0)}wb(d- -64|0)}}Zb(d+80|0);S(a|0);p()}e=1}ib=d+128|0;return e|0}function uga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0;e=ib-48|0;ib=e;a:{b:{c:{j=x[a+12>>2];l=x[a+8>>2];d:{if((j|0)<=1&l>>>0<=805306368|(j|0)<=0){if((j|0)>=-2&l>>>0>=3489660928|(j|0)>-2){break c}if((j|0)==-2&l>>>0>2147483647|(j|0)==-1){break d}break b}if((j|0)==1&l>>>0>2147483648|j>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}s=b;t=x[a+16>>2];b=0;while(1){if((b|0)!=2){f=b<<3;k=f+(e+24|0)|0;f=a+f|0;x[k+4>>2]=x[f+44>>2];x[k+8>>2]=x[f+48>>2];b=b+1|0;continue}break}m=x[a+40>>2];n=x[a+36>>2];b=x[a+4>>2];x[e+16>>2]=x[a>>2];x[e+20>>2]=b;u=x[a+32>>2];y=x[a+28>>2];z=x[a+72>>2];b=x[a+68>>2];A=b;B=b>>31;b=x[a+64>>2];C=b;E=b>>31;b=x[a+60>>2];F=b;G=b>>31;while(1){if(d){b=x[e+16>>2];H=(((x[e+20>>2]&2147483647)<<1|b>>>31)&-2)+t|0;b=(b>>>16&65520)+s|0;I=w[b+14>>1];g=w[b+12>>1];q=w[b+10>>1];r=w[b+8>>1];h=w[b+6>>1];k=w[b+4>>1];f=w[b+2>>1];b=w[b>>1];o=0;p=0;while(1){if((p|0)!=2){i=p+H|0;x[(e+8|0)+(p<<2)>>2]=(((((((D(v[i-4|0],f)+D(v[i-6|0],b)|0)+D(v[i-2|0],k)|0)+D(v[i|0],h)|0)+D(v[i+2|0],r)|0)+D(v[i+4|0],q)|0)+D(g,v[i+6|0])|0)+D(I,v[i+8|0])<<8)/32768;p=p+1|0;continue}break}while(1){if((o|0)!=2){q=(e+8|0)+(o<<2)|0;b=x[q>>2];g=(e+24|0)+(o<<3)|0;r=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;k=b<<8;b=k;b=qoa(F,G,b,b>>31);f=kb;i=g;g=b;b=Vb(h,-16777216,16776704);b=qoa(C,E,b,b>>31);h=g+b|0;g=kb+f|0;g=b>>>0>h>>>0?g+1|0:g;b=Vb(r,-16777216,16776704);f=qoa(A,B,b,b>>31);h=f+h|0;b=kb+g|0;b=f>>>0>h>>>0?b+1|0:b;f=h+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Vc(f,b,24);x[i+4>>2]=b-(k&z);x[q>>2]=(b|0)/256;o=o+1|0;continue}break}n=n+y|0;x[c>>2]=x[c>>2]+D(x[e+8>>2],n>>12);m=m+u|0;x[c+4>>2]=x[c+4>>2]+D(x[e+12>>2],m>>12);Pb(e+16|0,l,j);c=c+8|0;d=d-1|0;continue}break}b=x[e+20>>2];x[a>>2]=x[e+16>>2];x[a+4>>2]=b;x[a+40>>2]=m;x[a+20>>2]=n>>12;x[a+36>>2]=n;x[a+24>>2]=m>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(e+24|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}ib=e+48|0}function Lla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=E(0),h=0,i=E(0);d=ib-112|0;ib=d;c=ib-16|0;ib=c;e=b+16|0;sV(c+8|0,e);f=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);h=x[c+4>>2];if((h|0)==(f|0)){Yb(a,x[c+12>>2])}ib=c+16|0;if((f|0)!=(h|0)){Rb(e,0,128)}v[b+79|0]=0;v[b+143|0]=0;x[b+152>>2]=-2147483648;x[b+156>>2]=-2147483648;c=d- -64|0;ae(c,a,Jg(a));f=hc(d+88|0,c);yb(c);x[27524]=0;c=T(206,f|0)|0;e=x[27524];x[27524]=0;a:{b:{if((e|0)==1){break b}x[27524]=0;R(289,b+4|0,c|0);c=x[27524];x[27524]=0;if((c|0)==1){break b}he(d+56|0,x[b+4>>2],x[b+8>>2]);x[27524]=0;tn(463,d- -64|0,f,x[d+56>>2],x[d+60>>2]);c=x[27524];x[27524]=0;if((c|0)!=1){x[27524]=0;c=T(161,a|0)|0;e=x[27524];x[27524]=0;c:{if((e|0)==1){break c}x[27524]=0;U(194,d+32|0,a|0,c|0);a=x[27524];x[27524]=0;if((a|0)==1){break c}a=d+32|0;c=hc(d- -64|0,a);yb(a);a=x[c>>2];x[27524]=0;a=T(182,a|0)|0;e=x[27524];x[27524]=0;d:{if((e|0)!=1){e:{f:{if(!a){break f}while(1){g:{a=x[c+8>>2];e=x[c>>2];x[27524]=0;a=W(160,e|0,a|0,5)|0;e=x[27524];x[27524]=0;if((e|0)==1){break e}if(!a){break f}x[27524]=0;Q(464,c|0,d+28|0)|0;a=x[27524];x[27524]=0;h:{if((a|0)!=1){a=4;if(!Qb(d+28|0,13554,4)){break h}if(!Qb(d+28|0,14115,4)){break h}x[27524]=0;a=T(161,c|0)|0;e=x[27524];x[27524]=0;if((e|0)!=1){break h}a=P()|0;break d}a=P()|0;break d}x[27524]=0;U(194,d+8|0,c|0,a|0);a=x[27524];x[27524]=0;i:{j:{k:{if((a|0)!=1){a=d+8|0;e=hc(d+32|0,a);yb(a);if(Qb(d+28|0,13554,4)){break k}x[27524]=0;g=E(za(465,e|0));a=x[27524];x[27524]=0;if((a|0)==1){break g}B[d+8>>2]=g;x[d+4>>2]=0;x[d>>2]=1065353216;g=B[xq(d+8|0,d+4|0,d)>>2];B[b+144>>2]=g;i=E(F(g));if((i<E(11754943508222875e-54)^-1)&(!(i>=E(O))&g==g)){break j}x[b+144>>2]=0;break j}a=P()|0;break d}if(Qb(d+28|0,14115,4)){break j}x[27524]=0;a=T(161,e|0)|0;h=x[27524];x[27524]=0;if((h|0)==1){break i}x[b+148>>2]=a}yb(e);continue}}break}a=P()|0;yb(e);break d}yb(c);yb(f);ib=d+112|0;return}a=P()|0;break d}a=P()|0}yb(c);break a}a=P()|0;break a}a=P()|0;break a}a=P()|0}yb(f);S(a|0);p()}function cR(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0;c=ib-176|0;ib=c;i=1;p=2;d=x[a+12>>2];q=1<<d;m=q;a:while(1){if(d>>>0>=p>>>0){m=m>>>2|0;v=D(i,3);w=i<<1;h=0;b:while(1){if((h|0)==(m|0)){p=p+2|0;i=i<<2;d=x[a+12>>2];continue a}d=x[a>>2];e=Kd(d,h<<1);qO(c+160|0,C[e>>3],C[e+8>>3]);d=Kd(d,h);qO(c+144|0,C[d>>3],C[d+8>>3]);Di(c+128|0,C[c+144>>3],C[c+152>>3],C[c+160>>3],C[c+168>>3]);d=h<<p;e=i+d|0;y=d>>>0>e>>>0?d:e;while(1)if((d|0)==(y|0)){h=h+1|0;continue b}else{f=x[b>>2];e=Kd(f,d);g=e+8|0;j=x[g+4>>2];x[c+120>>2]=x[g>>2];x[c+124>>2]=j;g=x[e+4>>2];x[c+112>>2]=x[e>>2];x[c+116>>2]=g;k=d+i|0;g=Kd(f,k);n=C[g+8>>3];o=C[g>>3];r=d+w|0;g=Kd(f,r);j=x[g+12>>2];x[c+104>>2]=x[g+8>>2];x[c+108>>2]=j;j=x[g+4>>2];x[c+96>>2]=x[g>>2];x[c+100>>2]=j;s=d+v|0;f=Kd(f,s);t=C[f+8>>3];u=C[f>>3];g=c+80|0;f=c+112|0;kl(g,f,o,n);j=c- -64|0;qj(j,f,o,n);l=c+96|0;kl(c+48|0,l,u,t);f=c+16|0;qj(f,l,u,t);Di(c+32|0,0,1,C[c+16>>3],C[c+24>>3]);kl(f,g,C[c+48>>3],C[c+56>>3]);l=x[c+28>>2];x[e+8>>2]=x[c+24>>2];x[e+12>>2]=l;l=x[c+20>>2];x[e>>2]=x[c+16>>2];x[e+4>>2]=l;kl(c,j,C[c+32>>3],C[c+40>>3]);Di(f,C[c+160>>3],C[c+168>>3],C[c>>3],C[c+8>>3]);e=Kd(x[b>>2],k);k=x[c+28>>2];x[e+8>>2]=x[c+24>>2];x[e+12>>2]=k;k=x[c+20>>2];x[e>>2]=x[c+16>>2];x[e+4>>2]=k;qj(c,g,C[c+48>>3],C[c+56>>3]);Di(f,C[c+144>>3],C[c+152>>3],C[c>>3],C[c+8>>3]);e=Kd(x[b>>2],r);g=x[c+28>>2];x[e+8>>2]=x[c+24>>2];x[e+12>>2]=g;g=x[c+20>>2];x[e>>2]=x[c+16>>2];x[e+4>>2]=g;qj(c,j,C[c+32>>3],C[c+40>>3]);Di(f,C[c+128>>3],C[c+136>>3],C[c>>3],C[c+8>>3]);e=Kd(x[b>>2],s);f=x[c+28>>2];x[e+8>>2]=x[c+24>>2];x[e+12>>2]=f;f=x[c+20>>2];x[e>>2]=x[c+16>>2];x[e+4>>2]=f;d=d+1|0;continue}}}break}c:{if(!(d&1)){break c}i=q>>>1|0;d=0;while(1){if((d|0)==(i|0)){break c}h=x[b>>2];a=Kd(h,d+i|0);m=Kd(h,d);n=C[a>>3];o=C[a+8>>3];qj(c+160|0,m,n,o);h=x[c+172>>2];x[a+8>>2]=x[c+168>>2];x[a+12>>2]=h;h=x[c+164>>2];x[a>>2]=x[c+160>>2];x[a+4>>2]=h;Iy(Kd(x[b>>2],d),n,o);d=d+1|0;continue}}ib=c+176|0}function ue(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=ib-16|0;ib=h;e=x[a>>2];a:{if(pc(e,x[a+4>>2])){break a}g=x[b+4>>2];if(g>>>0>=A[a+12>>2]){break a}c=z[b+8>>1];i=x[x[a+48>>2]+12>>2];f=Cg(i);if(c>>>0>=f>>>0&(c|0)!=65535){break a}d=(c|0)==65535;l=d?f-1|0:c;f=g;g=d?0:c;c=hd(e,i,f,g);f=y[b+12|0];j=f&4;b:{c:{if(f&2){break c}k=y[b+10|0];e=c;d=g;while(1){if((d&65535)>>>0>(l&65535)>>>0){break c}d:{if(!j){if((k|0)!=y[e+3|0]){break d}break b}if((k|0)==y[e+2|0]){break b}}e=e+6|0;d=d+1|0;continue}}k=l&65535;d=c;e=g;while(1){if(k>>>0>=(e&65535)>>>0){e:{if(!j){if(y[d+3|0]){break e}v[d+3|0]=y[b+10|0];v[d+5|0]=y[b+11|0];break b}if(y[d+2|0]){break e}v[d+2|0]=y[b+10|0];v[d+4|0]=y[b+11|0];break b}d=d+6|0;e=e+1|0;continue}break}f:{if(!(f&1)){break f}d=x[i+480180>>2]&2;g:{h:{i:{if(!j){while(1){if((g&65535)>>>0<=(l&65535)>>>0){j:{k:{switch(y[c+3|0]-9|0){case 4:if(!AW(x[x[i+8>>2]+88>>2])){break j}d=1;v[c+2|0]=1;v[c+4|0]=y[c+5|0];v[c+3|0]=y[b+10|0];v[c+5|0]=y[b+11|0];break a;case 0:break k;default:break j}}l:{if(d){e=y[c+5|0];if(e>>>0>128){break j}v[c+2|0]=2;v[c+3|0]=y[b+10|0];a=1;break l}v[c+2|0]=2;v[c+3|0]=y[b+10|0];e=y[c+5|0];a=2}v[c+4|0]=a+e>>>a;v[c+5|0]=y[b+11|0];break b}c=c+6|0;g=g+1|0;continue}break}if(!j){break i}}e=y[b+11|0];g=13;m:{switch(y[b+10|0]-1|0){case 1:g=9;e=Nl(D(d?2:4,e));break;case 0:break m;default:break g}}v[b+11|0]=e;v[b+10|0]=g;f=f&254;break h}v[h+15|0]=0;v[h+14|0]=0;g=b;c=!d;d=y[b+10|0];n:{if(!(c|(d|0)!=9)){e=y[b+11|0];if(e>>>0>128){break g}d=2;c=e>>>1|0;break n}e=h+8|0;$q(e,d,y[b+11|0],1);ZB(h,h+15|0,h+14|0);YB(h,e);d=y[h+15|0];if(!d){f=y[b+12|0];break g}f=y[b+12|0];c=y[h+14|0]}v[g+11|0]=c;v[b+10|0]=d;f=f&254}v[b+12|0]=f}d=1;if(f&1){break f}v[b+12|0]=f^4;if(ue(a,b)){break a}}d=0;o:{p:{switch(x[b>>2]-1|0){case 0:c=x[b+4>>2]+1|0;if(c>>>0>=A[a+12>>2]){break a}x[b+4>>2]=c;break o;case 1:break p;default:break a}}c=x[b+4>>2];if(!c){break a}x[b+4>>2]=c-1}v[b+12|0]=y[b+12|0]|1;d=ue(a,b);break a}d=1}ib=h+16|0;return d}function Sfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0;f=ib-48|0;ib=f;q=x[a+16>>2];r=qg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);b=0;m=x[a+128>>2];if(m){e=x[a+8>>2];j=x[a+12>>2];n=rg(e,j,m);o=kb;g=x[a+76>>2];Zf(x[a>>2],x[a+4>>2],rf(e,j,d),kb);j=g>>>0<kb>>>0?d:0}else{j=0}i=a+112|0;while(1){if((b|0)!=2){e=b<<3;h=e+(f+16|0)|0;e=a+e|0;x[h+4>>2]=x[e+44>>2];x[h+8>>2]=x[e+48>>2];b=b+1|0;continue}break}s=x[a+24>>2];t=x[a+20>>2];b=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=b;u=x[a+8>>2];v=x[a+12>>2];a:while(1){if(d){d=d-1|0;b=x[f+12>>2];e=x[f+8>>2];x[f+40>>2]=e;x[f+44>>2]=0;j=j-1|0;n=j?n:0;o=j?o:0;l=((((b&2147483647)<<1|e>>>31)&2147483646)<<1)+q|0;b=m;while(1)if((b|0)<=0){Pb(i,x[a+120>>2],x[a+124>>2]);h=x[a+116>>2];if(h){b=(x[f+44>>2]&2147483647)<<1|x[f+40>>2]>>>31;Sd(i,(w[(b<<1|2)+l>>1]+w[l+((b&2147483646)<<1)>>1]|0)/8<<16>>16);Rd(i,h);x[i>>2]=x[i>>2];x[i+4>>2]=0}b=pg(i,r);x[f+4>>2]=b;x[f>>2]=b;y=x[a+72>>2];b=x[a+68>>2];z=b;A=b>>31;b=x[a+64>>2];B=b;C=b>>31;b=x[a+60>>2];E=b;F=b>>31;b=0;while(1){if((b|0)!=2){p=(b<<2)+f|0;e=x[p>>2];g=(f+16|0)+(b<<3)|0;G=x[g+8>>2];k=x[g+4>>2];x[g+8>>2]=k;l=e<<8;e=l;e=qoa(E,F,e,e>>31);h=kb;H=g;g=e;e=Vb(k,-16777216,16776704);e=qoa(B,C,e,e>>31);k=g+e|0;g=kb+h|0;g=e>>>0>k>>>0?g+1|0:g;e=Vb(G,-16777216,16776704);h=qoa(z,A,e,e>>31);k=h+k|0;e=kb+g|0;e=h>>>0>k>>>0?e+1|0:e;h=k+8388608|0;e=h>>>0<8388608?e+1|0:e;e=Vc(h,e,24);x[H+4>>2]=e-(l&y);x[p>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f>>2],t);x[c+4>>2]=x[c+4>>2]+D(s,x[f+4>>2]);Pb(f+8|0,u,v);c=c+8|0;continue a}else{e=(x[f+44>>2]&2147483647)<<1|x[f+40>>2]>>>31;Sd(i,(w[(e<<1|2)+l>>1]+w[l+((e&2147483646)<<1)>>1]|0)/8<<16>>16);Rd(i,4);Pb(f+40|0,n,o);b=b-1|0;continue}}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+16|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}ib=f+48|0}function Afa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;h=ib-16|0;ib=h;c=Af(a,c);Pd(h,x[a+36>>2]);j=a;a:{if(!c){Pc(h,a+32|0,5);e=0;if(zb(x[x[h>>2]>>2],x[h+4>>2])){break a}}e=ib-240|0;ib=e;g=bm(e+128|0,x[a+36>>2]);x[27524]=0;f=Q(453,e+112|0,27816)|0;a=x[27524];x[27524]=0;b:{c:{d:{e:{if((a|0)!=1){x[27524]=0;x[e+96>>2]=19988503;x[e+100>>2]=0;U(454,g|0,f|0,e+96|0);a=x[27524];x[27524]=0;if((a|0)==1){break e}Zb(f);if(!Rk(y[g|0])){break d}break b}b=P()|0;break c}b=P()|0;Zb(f);break c}v[e+111|0]=0;x[27524]=0;f=Q(453,e+96|0,5508)|0;a=x[27524];x[27524]=0;f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{if((a|0)!=1){x[27524]=0;U(455,g|0,e+111|0,f|0);a=x[27524];x[27524]=0;if((a|0)==1){break q}Zb(f);f=Kb(e+80|0);x[27524]=0;a=Q(453,e- -64|0,10032)|0;i=x[27524];x[27524]=0;if((i|0)==1){break p}x[27524]=0;U(761,g|0,f|0,a|0);i=x[27524];x[27524]=0;if((i|0)==1){break o}Zb(a);x[27524]=0;U(11,e+48|0,(y[e+111|0]?0:d)|0,f|0);d=x[27524];x[27524]=0;if((d|0)==1){break n}x[27524]=0;R(277,b|0,e+48|0);d=x[27524];x[27524]=0;if((d|0)==1){break m}d=e+48|0;xb(d);w[e+46>>1]=0;x[27524]=0;d=Q(453,d|0,10692)|0;a=x[27524];x[27524]=0;if((a|0)==1){break g}x[27524]=0;W(483,g|0,e+46|0,d|0)|0;a=x[27524];x[27524]=0;if((a|0)==1){break l}Zb(d);Mf(e+46|0,4e3);x[27524]=0;d=Q(453,e+32|0,13369)|0;a=x[27524];x[27524]=0;if((a|0)==1){break k}i=z[e+46>>1];a=x[Wb(e+24|0,i)>>2];x[27524]=0;X(762,g|0,b|0,d|0,a|0);a=x[27524];x[27524]=0;if((a|0)==1){break j}Zb(d);w[e+22>>1]=65535;x[27524]=0;d=Q(453,e+8|0,8912)|0;a=x[27524];x[27524]=0;if((a|0)==1){break i}x[27524]=0;k=W(483,g|0,e+22|0,d|0)|0;a=x[27524];x[27524]=0;if((a|0)==1){break h}a=z[e+22>>1];Zb(d);if(a>>>0<i>>>0&k){_e(b,a)}wb(f);break b}b=P()|0;break c}b=P()|0;Zb(f);break c}b=P()|0;break f}b=P()|0;Zb(a);break f}b=P()|0;break f}b=P()|0;xb(e+48|0);break f}b=P()|0;Zb(d);break f}b=P()|0;break f}b=P()|0;Zb(d);break f}b=P()|0;break f}b=P()|0;Zb(d);break f}b=P()|0}wb(f)}rh(g);S(b|0);p()}rh(g);ib=e+240|0;e=c}af(j,e);ib=h+16|0}function zi(a,b,c,d,e,f){var g=0,h=0,i=0,j=E(0),k=E(0),l=0,m=0,n=E(0),o=E(0),p=E(0),q=0,r=E(0);m=lb[x[x[a>>2]+140>>2]](a)|0;g=x[a+20>>2];h=m?h:y[g+25|0];j=B[g+144>>2];k=E(1);if(!(lb[x[x[a>>2]+140>>2]](a)|0)){k=B[x[a+20>>2]+144>>2]}j=E(E(1)-j);a:{if((lb[x[x[a>>2]+156>>2]](a)|0)<=0){break a}if(!tN(y[x[a+20>>2]+24|0])){break a}j=E(E(j+j)+E(-1));k=E(-j)}n=B[a+4196>>2];k=E(k*n);j=E(j*n);g=0;l=x[a+44>>2];m=Hc(l,0);l=Hc(l,1);b:{c:{d:{e:{f:{g:{h:{h=h&255;switch(h|0){case 0:break h;case 5:break c;case 4:break d;case 3:break e;case 2:break f;case 1:break g;default:break b}}while(1){if((f|0)==(h|0)){break b}g=h<<2;i=g+b|0;B[i>>2]=B[i>>2]+E(E(B[d+g>>2]*j)+E(k*B[g+m>>2]));i=c+g|0;B[i>>2]=B[i>>2]+E(E(B[e+g>>2]*j)+E(k*B[g+l>>2]));h=h+1|0;continue}}while(1){if((f|0)==(g|0)){break b}h=g<<2;i=h+b|0;B[i>>2]=B[i>>2]+E(B[h+m>>2]-E(B[d+h>>2]*j));i=c+h|0;B[i>>2]=B[i>>2]+E(B[h+l>>2]-E(B[e+h>>2]*j));g=g+1|0;continue}}while(1){if((f|0)==(g|0)){break b}h=g<<2;i=h+b|0;B[i>>2]=B[i>>2]+E(B[d+h>>2]-E(B[h+m>>2]*k));i=c+h|0;B[i>>2]=B[i>>2]+E(B[e+h>>2]-E(B[h+l>>2]*k));g=g+1|0;continue}}while(1){if((f|0)==(g|0)){break b}h=g<<2;i=h+b|0;B[i>>2]=B[i>>2]-E(B[d+h>>2]-E(B[h+m>>2]*j));i=c+h|0;B[i>>2]=B[i>>2]-E(B[e+h>>2]-E(B[h+l>>2]*j));g=g+1|0;continue}}while(1){if((f|0)==(g|0)){break b}h=g<<2;i=h+b|0;k=B[i>>2];q=i;r=k;n=B[h+m>>2];i=c+h|0;o=B[i>>2];p=B[h+l>>2];k=E(E(E(E(k+n)+o)+p)*E(.5));B[q>>2]=r-E(E(k+E(k-E(B[d+h>>2]*j)))-n);B[i>>2]=o-E(E(k+E(k-E(B[e+h>>2]*j)))-p);g=g+1|0;continue}}g=tN(y[x[a+20>>2]+24|0]);j=g?E(j*E(.5)):j;k=g?E(k*E(.5)):k;h=0;while(1){if((f|0)==(h|0)){break b}g=h<<2;i=g+b|0;n=E(B[d+g>>2]-B[g+m>>2]);o=E(B[g+l>>2]-B[e+g>>2]);B[i>>2]=B[i>>2]+E(E(j*n)+E(k*o));g=c+g|0;B[g>>2]=B[g>>2]+E(E(k*n)+E(j*o));h=h+1|0;continue}}i:{if(!((y[x[a+20>>2]+24|0]&4)>>>2|0)){break i}if(lb[x[x[a>>2]+140>>2]](a)|0){break i}g=0;while(1){if((f|0)==(g|0)){break i}a=g<<2;d=a+b|0;B[d>>2]=B[a+m>>2]+B[d>>2];d=a+c|0;B[d>>2]=B[a+l>>2]+B[d>>2];g=g+1|0;continue}}}function sH(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;e=x[b>>2];a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if(!d){break k}h=x[d>>2];if(!h){break k}if(!a){g=c;break j}x[d>>2]=0;g=c;break i}l:{if(!x[x[120026]>>2]){if(!a){break l}if(!c){break a}d=c;while(1){g=v[e|0];if(g){x[a>>2]=g&57343;a=a+4|0;e=e+1|0;d=d-1|0;if(d){continue}break a}break}x[a>>2]=0;x[b>>2]=0;return c-d|0}if(!a){g=c;d=0;break g}g=c;d=0;break h}return xf(e)}d=1;break g}d=1}while(1){if(!d){if(!g){break a}while(1){m:{f=y[e|0];h=f-1|0;n:{o:{if(h>>>0>126){d=f;break o}if(e&3|g>>>0<5){break n}p:{while(1){d=x[e>>2];if((d|d-16843009)&-2139062144){break p}x[a>>2]=d&255;x[a+4>>2]=y[e+1|0];x[a+8>>2]=y[e+2|0];x[a+12>>2]=y[e+3|0];a=a+16|0;e=e+4|0;g=g-4|0;if(g>>>0>4){continue}break}d=y[e|0]}f=d&255;h=f-1|0}if(h>>>0>126){break m}}x[a>>2]=f;a=a+4|0;e=e+1|0;g=g-1|0;if(g){continue}break a}break}f=f-194|0;if(f>>>0>50){break e}e=e+1|0;h=x[(f<<2)+98016>>2];d=1;continue}d=y[e|0];f=d>>>3|0;if((f-16|f+(h>>26))>>>0>7){break f}q:{r:{f=e+1|0;d=d-128|h<<6;s:{if((d|0)>=0){break s}i=y[f|0]-128|0;if(i>>>0>63){break r}f=e+2|0;d=i|d<<6;if((d|0)>=0){break s}f=y[f|0]-128|0;if(f>>>0>63){break r}d=f|d<<6;f=e+3|0}e=f;x[a>>2]=d;g=g-1|0;a=a+4|0;break q}x[12e4]=25;e=e-1|0;break c}d=0;continue}}while(1){t:{if(!d){u:{v:{d=y[e|0];if(!(e&3|d-1>>>0>126)){d=x[e>>2];if(!((d|d-16843009)&-2139062144)){break v}}f=e;break u}while(1){g=g-4|0;d=x[e+4>>2];f=e+4|0;e=f;if(!((d-16843009|d)&-2139062144)){continue}break}}e=d&255;if(e-1>>>0<=126){e=f+1|0;g=g-1|0;break t}h=e-194|0;if(h>>>0>50){e=f;break e}e=f+1|0;h=x[(h<<2)+98016>>2];d=1;continue}d=y[e|0]>>>3|0;if((d-16|d+(h>>26))>>>0>7){break f}d=e+1|0;w:{if(!(h&33554432)){break w}if((y[d|0]&192)!=128){e=e-1|0;break d}d=e+2|0;if(!(h&524288)){break w}if((y[d|0]&192)!=128){e=e-1|0;break d}d=e+3|0}e=d;g=g-1|0}d=0;continue}}e=e-1|0;if(h){break d}d=y[e|0]}if(d&255){break d}if(a){x[a>>2]=0;x[b>>2]=0}return c-g|0}x[12e4]=25;if(!a){break b}}x[b>>2]=e}return-1}x[b>>2]=e;return c}function xga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0;e=ib-48|0;ib=e;a:{b:{c:{j=x[a+12>>2];l=x[a+8>>2];d:{if((j|0)<=1&l>>>0<=805306368|(j|0)<=0){if((j|0)>=-2&l>>>0>=3489660928|(j|0)>-2){break c}if((j|0)==-2&l>>>0>2147483647|(j|0)==-1){break d}break b}if((j|0)==1&l>>>0>2147483648|j>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}q=b;r=x[a+16>>2];b=0;while(1){if((b|0)!=2){f=b<<3;k=f+(e+24|0)|0;f=a+f|0;x[k+4>>2]=x[f+44>>2];x[k+8>>2]=x[f+48>>2];b=b+1|0;continue}break}s=x[a+24>>2];t=x[a+20>>2];b=x[a+4>>2];x[e+16>>2]=x[a>>2];x[e+20>>2]=b;u=x[a+72>>2];b=x[a+68>>2];v=b;y=b>>31;b=x[a+64>>2];z=b;A=b>>31;b=x[a+60>>2];B=b;C=b>>31;while(1){if(d){b=x[e+16>>2];E=((((x[e+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+r|0;b=(b>>>16&65520)+q|0;F=w[b+14>>1];g=w[b+12>>1];o=w[b+10>>1];p=w[b+8>>1];h=w[b+6>>1];k=w[b+4>>1];f=w[b+2>>1];b=w[b>>1];m=0;n=0;while(1){if((n|0)!=2){i=E+(n<<1)|0;x[(e+8|0)+(n<<2)>>2]=(((((((D(w[i-8>>1],f)+D(w[i-12>>1],b)|0)+D(w[i-4>>1],k)|0)+D(w[i>>1],h)|0)+D(w[i+4>>1],p)|0)+D(w[i+8>>1],o)|0)+D(g,w[i+12>>1])|0)+D(F,w[i+16>>1])|0)/32768;n=n+1|0;continue}break}while(1){if((m|0)!=2){o=(e+8|0)+(m<<2)|0;b=x[o>>2];g=(e+24|0)+(m<<3)|0;p=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;k=b<<8;b=k;b=qoa(B,C,b,b>>31);f=kb;i=g;g=b;b=Vb(h,-16777216,16776704);b=qoa(z,A,b,b>>31);h=g+b|0;g=kb+f|0;g=b>>>0>h>>>0?g+1|0:g;b=Vb(p,-16777216,16776704);f=qoa(v,y,b,b>>31);h=f+h|0;b=kb+g|0;b=f>>>0>h>>>0?b+1|0:b;f=h+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Vc(f,b,24);x[i+4>>2]=b-(k&u);x[o>>2]=(b|0)/256;m=m+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[e+8>>2],t);x[c+4>>2]=x[c+4>>2]+D(x[e+12>>2],s);Pb(e+16|0,l,j);c=c+8|0;d=d-1|0;continue}break}b=x[e+20>>2];x[a>>2]=x[e+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(e+24|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}ib=e+48|0}function Y9(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0;j=ib-96|0;ib=j;a:{b:{c:{k=tq(1,32);d:{e:{if(!k){a=qm(ba(4)|0);x[27524]=0;U(123,a|0,108196,26);a=x[27524];x[27524]=0;if((a|0)!=1){break a}i=V(0)|0;break e}x[k+12>>2]=f;x[k+8>>2]=e;x[k+4>>2]=d;f=c?c:939;x[k>>2]=f;c=zg(j+80|0);f:{g:{h:{if(!i){break h}while(1){e=x[i>>2];if(!e){break h}l=x[i+4>>2];i:{if(l){x[27524]=0;e=Q(55,j- -64|0,e|0)|0;m=x[27524];x[27524]=0;j:{if((m|0)!=1){x[27524]=0;m=Q(950,c|0,e|0)|0;n=x[27524];x[27524]=0;if((n|0)==1){break j}x[27524]=0;R(274,m|0,l|0);l=x[27524];x[27524]=0;if((l|0)==1){break j}break i}i=V(0)|0;break f}i=V(0)|0;wb(e);break f}x[27524]=0;e=Q(55,j+48|0,e|0)|0;l=x[27524];x[27524]=0;if((l|0)==1){break g}Ys(c,e)}wb(e);i=i+8|0;continue}}e=x[a+8>>2];i=x[a+4>>2];l=x[a>>2];x[27524]=0;a=T(818,104)|0;m=x[27524];x[27524]=0;k:{l:{m:{if((m|0)!=1){x[j+44>>2]=e;x[j+40>>2]=i;x[j+36>>2]=l;x[j+32>>2]=b;x[27524]=0;b=Q(951,f|0,d|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break m}x[j+16>>2]=b;b=x[ge(j+24|0,j+16|0)>>2];d=x[j+44>>2];x[j+8>>2]=x[j+40>>2];x[j+12>>2]=d;x[27524]=0;d=x[j+36>>2];x[j>>2]=x[j+32>>2];x[j+4>>2]=d;b=fa(981,a|0,j|0,b|0,c|0)|0;d=x[27524];x[27524]=0;if((d|0)!=1){break k}i=V(0)|0;Xc(j+16|0);break l}i=V(0)|0;break f}i=V(0)|0}Ib(a);break f}x[k+28>>2]=b;Xc(j+16|0);x[k+24>>2]=b+8;pl(c);break d}i=V(0)|0}pl(c);_(i|0)|0;x[27524]=0;X(945,11236,k|0,g|0,h|0);a=x[27524];x[27524]=0;if((a|0)!=1){x[27524]=0;Z(18);a=x[27524];x[27524]=0;if((a|0)!=1){a=x[k+28>>2];if(a){lb[x[x[a>>2]+4>>2]](a)}x[k+24>>2]=0;x[k+28>>2]=0;a=x[k+20>>2];if(a){Ib(a);x[k+20>>2]=0}Ib(k);k=0;break d}i=V(0)|0;break e}i=V(0)|0;x[27524]=0;Z(18);a=x[27524];x[27524]=0;if((a|0)==1){break b}}_(i|0)|0;k=0;x[27524]=0;X(945,11236,0,g|0,h|0);a=x[27524];x[27524]=0;if((a|0)==1){break c}$()}ib=j+96|0;return k|0}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)==1){break b}S(a|0);p()}V(0)|0;Sb()}p()}function Bu(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if(!a){return Gd(b)}if(b>>>0>=4294967232){x[12e4]=48;return 0}g=b>>>0<11?16:b+11&-8;f=a-8|0;j=x[f+4>>2];e=j&-8;a:{if(!(j&3)){if(g>>>0<256){break a}if(e>>>0>=g+4>>>0){c=f;if(e-g>>>0<=x[27520]<<1>>>0){break a}}c=0;break a}h=e+f|0;b:{if(e>>>0>=g>>>0){d=e-g|0;if(d>>>0<16){break b}x[f+4>>2]=j&1|g|2;c=f+g|0;x[c+4>>2]=d|3;x[h+4>>2]=x[h+4>>2]|1;PU(c,d);break b}if(x[27406]==(h|0)){e=e+x[27403]|0;if(e>>>0<=g>>>0){break a}x[f+4>>2]=j&1|g|2;d=f+g|0;c=e-g|0;x[d+4>>2]=c|1;x[27403]=c;x[27406]=d;break b}if(x[27405]==(h|0)){d=e+x[27402]|0;if(d>>>0<g>>>0){break a}c=d-g|0;c:{if(c>>>0>=16){x[f+4>>2]=j&1|g|2;e=f+g|0;x[e+4>>2]=c|1;d=d+f|0;x[d>>2]=c;x[d+4>>2]=x[d+4>>2]&-2;break c}x[f+4>>2]=d|j&1|2;c=d+f|0;x[c+4>>2]=x[c+4>>2]|1;c=0;e=0}x[27405]=e;x[27402]=c;break b}d=x[h+4>>2];if(d&2){break a}k=e+(d&-8)|0;if(k>>>0<g>>>0){break a}m=k-g|0;d:{if(d>>>0<=255){e=x[h+8>>2];c=d>>>3|0;d=x[h+12>>2];if((d|0)==(e|0)){n=109600,o=x[27400]&toa(-2,c),x[n>>2]=o;break d}x[e+12>>2]=d;x[d+8>>2]=e;break d}l=x[h+24>>2];i=x[h+12>>2];e:{if((i|0)!=(h|0)){c=x[h+8>>2];x[c+12>>2]=i;x[i+8>>2]=c;break e}f:{e=h+20|0;c=x[e>>2];if(c){break f}e=h+16|0;c=x[e>>2];if(c){break f}i=0;break e}while(1){d=e;i=c;e=c+20|0;c=x[e>>2];if(c){continue}e=i+16|0;c=x[i+16>>2];if(c){continue}break}x[d>>2]=0}if(!l){break d}d=x[h+28>>2];c=(d<<2)+109904|0;g:{if(x[c>>2]==(h|0)){x[c>>2]=i;if(i){break g}n=109604,o=x[27401]&toa(-2,d),x[n>>2]=o;break d}x[(x[l+16>>2]==(h|0)?16:20)+l>>2]=i;if(!i){break d}}x[i+24>>2]=l;c=x[h+16>>2];if(c){x[i+16>>2]=c;x[c+24>>2]=i}c=x[h+20>>2];if(!c){break d}x[i+20>>2]=c;x[c+24>>2]=i}if(m>>>0<=15){x[f+4>>2]=j&1|k|2;c=f+k|0;x[c+4>>2]=x[c+4>>2]|1;break b}x[f+4>>2]=j&1|g|2;d=f+g|0;x[d+4>>2]=m|3;c=f+k|0;x[c+4>>2]=x[c+4>>2]|1;PU(d,m)}c=f}if(c){return c+8|0}f=Gd(b);if(!f){return 0}c=x[a-4>>2];c=(c&3?-4:-8)+(c&-8)|0;rc(f,a,b>>>0>c>>>0?c:b);Ib(a);return f}function yga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0;e=ib-48|0;ib=e;a:{b:{c:{j=x[a+12>>2];l=x[a+8>>2];d:{if((j|0)<=1&l>>>0<=805306368|(j|0)<=0){if((j|0)>=-2&l>>>0>=3489660928|(j|0)>-2){break c}if((j|0)==-2&l>>>0>2147483647|(j|0)==-1){break d}break b}if((j|0)==1&l>>>0>2147483648|j>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}q=b;r=x[a+16>>2];b=0;while(1){if((b|0)!=2){f=b<<3;k=f+(e+24|0)|0;f=a+f|0;x[k+4>>2]=x[f+44>>2];x[k+8>>2]=x[f+48>>2];b=b+1|0;continue}break}s=x[a+24>>2];t=x[a+20>>2];b=x[a+4>>2];x[e+16>>2]=x[a>>2];x[e+20>>2]=b;u=x[a+72>>2];b=x[a+68>>2];y=b;z=b>>31;b=x[a+64>>2];A=b;B=b>>31;b=x[a+60>>2];C=b;E=b>>31;while(1){if(d){b=x[e+16>>2];F=(((x[e+20>>2]&2147483647)<<1|b>>>31)&-2)+r|0;b=(b>>>16&65520)+q|0;G=w[b+14>>1];g=w[b+12>>1];o=w[b+10>>1];p=w[b+8>>1];h=w[b+6>>1];k=w[b+4>>1];f=w[b+2>>1];b=w[b>>1];m=0;n=0;while(1){if((n|0)!=2){i=n+F|0;x[(e+8|0)+(n<<2)>>2]=(((((((D(v[i-4|0],f)+D(v[i-6|0],b)|0)+D(v[i-2|0],k)|0)+D(v[i|0],h)|0)+D(v[i+2|0],p)|0)+D(v[i+4|0],o)|0)+D(g,v[i+6|0])|0)+D(G,v[i+8|0])<<8)/32768;n=n+1|0;continue}break}while(1){if((m|0)!=2){o=(e+8|0)+(m<<2)|0;b=x[o>>2];g=(e+24|0)+(m<<3)|0;p=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;k=b<<8;b=k;b=qoa(C,E,b,b>>31);f=kb;i=g;g=b;b=Vb(h,-16777216,16776704);b=qoa(A,B,b,b>>31);h=g+b|0;g=kb+f|0;g=b>>>0>h>>>0?g+1|0:g;b=Vb(p,-16777216,16776704);f=qoa(y,z,b,b>>31);h=f+h|0;b=kb+g|0;b=f>>>0>h>>>0?b+1|0:b;f=h+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Vc(f,b,24);x[i+4>>2]=b-(k&u);x[o>>2]=(b|0)/256;m=m+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[e+8>>2],t);x[c+4>>2]=x[c+4>>2]+D(x[e+12>>2],s);Pb(e+16|0,l,j);c=c+8|0;d=d-1|0;continue}break}b=x[e+20>>2];x[a>>2]=x[e+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(e+24|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}ib=e+48|0}function T1(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;j=ib-16|0;ib=j;k=ix(g);o=Tw(g);ih(j,o);x[f>>2]=d;a:{b:{c:{i=a;g=y[i|0];switch(g-43|0){case 0:case 2:break c;default:break b}}x[27524]=0;g=Q(1182,k|0,g<<24>>24)|0;i=x[27524];x[27524]=0;if((i|0)==1){break a}i=x[f>>2];x[f>>2]=i+4;x[i>>2]=g;i=a+1|0}d:{g=i;if(!((c-g|0)<2|y[g|0]!=48|(y[g+1|0]|32)!=120)){x[27524]=0;g=Q(1182,k|0,48)|0;h=x[27524];x[27524]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+4;x[h>>2]=g;g=v[i+1|0];x[27524]=0;g=Q(1182,k|0,g|0)|0;h=x[27524];x[27524]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+4;x[h>>2]=g;i=i+2|0;g=i;while(1){if(c>>>0<=g>>>0){break d}h=v[g|0];Fd();if(!FH(h)){break d}g=g+1|0;continue}}while(1){if(c>>>0<=g>>>0){break d}h=v[g|0];Fd();if(!hk(h)){break d}g=g+1|0;continue}}e:{if(Qe(j)){h=x[f>>2];x[27524]=0;X(1176,k|0,i|0,g|0,h|0);h=x[27524];x[27524]=0;if((h|0)==1){break a}x[f>>2]=x[f>>2]+(g-i<<2);break e}dm(i,g);x[27524]=0;r=T(1174,o|0)|0;h=x[27524];x[27524]=0;if((h|0)==1){break a}h=i;while(1){if(g>>>0<=h>>>0){hs((i-a<<2)+d|0,x[f>>2]);break e}f:{if(v[Qc(j,l)|0]<=0){break f}if(v[Qc(j,l)|0]!=(m|0)){break f}m=x[f>>2];x[f>>2]=m+4;x[m>>2]=r;l=(Eb(j)-1>>>0>l>>>0)+l|0;m=0}q=v[h|0];x[27524]=0;q=Q(1182,k|0,q|0)|0;n=x[27524];x[27524]=0;if((n|0)!=1){n=x[f>>2];x[f>>2]=n+4;x[n>>2]=q;h=h+1|0;m=m+1|0;continue}break}break a}g:{while(1){if(c>>>0>g>>>0){i=y[g|0];if((i|0)==46){x[27524]=0;i=T(1177,o|0)|0;h=x[27524];x[27524]=0;if((h|0)==1){break a}l=x[f>>2];h=l+4|0;x[f>>2]=h;x[l>>2]=i;g=g+1|0;break g}x[27524]=0;i=Q(1182,k|0,i<<24>>24)|0;h=x[27524];x[27524]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+4;x[h>>2]=i;g=g+1|0;continue}break}h=x[f>>2]}x[27524]=0;X(1176,k|0,g|0,c|0,h|0);i=x[27524];x[27524]=0;if((i|0)==1){break a}i=f;f=x[f>>2]+(c-g<<2)|0;x[i>>2]=f;x[e>>2]=(b|0)==(c|0)?f:(b-a<<2)+d|0;wb(j);ib=j+16|0;return}a=P()|0;wb(j);S(a|0);p()}function tM(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0;j=ib-96|0;ib=j;a:{b:{c:{d:{e:{f:{k=tq(1,28);if(!k){a=qm(ba(4)|0);x[27524]=0;U(123,a|0,108196,26);a=x[27524];x[27524]=0;if((a|0)!=1){break a}break f}x[k+12>>2]=f;x[k+8>>2]=e;x[k+4>>2]=d;f=c?c:939;x[k>>2]=f;c=zg(j+80|0);g:{h:{i:{if(!i){break i}while(1){e=x[i>>2];if(!e){break i}l=x[i+4>>2];j:{if(l){x[27524]=0;e=Q(55,j- -64|0,e|0)|0;m=x[27524];x[27524]=0;k:{if((m|0)!=1){x[27524]=0;m=Q(950,c|0,e|0)|0;n=x[27524];x[27524]=0;if((n|0)==1){break k}x[27524]=0;R(274,m|0,l|0);l=x[27524];x[27524]=0;if((l|0)==1){break k}break j}i=V(0)|0;break g}i=V(0)|0;wb(e);break g}x[27524]=0;e=Q(55,j+48|0,e|0)|0;l=x[27524];x[27524]=0;if((l|0)==1){break h}Ys(c,e)}wb(e);i=i+8|0;continue}}e=x[a+8>>2];i=x[a+4>>2];l=x[a>>2];x[27524]=0;a=T(818,80)|0;m=x[27524];x[27524]=0;l:{m:{n:{if((m|0)!=1){x[j+44>>2]=e;x[j+40>>2]=i;x[j+36>>2]=l;x[j+32>>2]=b;x[27524]=0;b=Q(951,f|0,d|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break n}x[j+16>>2]=b;b=x[ge(j+24|0,j+16|0)>>2];d=x[j+44>>2];x[j+8>>2]=x[j+40>>2];x[j+12>>2]=d;x[27524]=0;d=x[j+36>>2];x[j>>2]=x[j+32>>2];x[j+4>>2]=d;b=fa(952,a|0,j|0,b|0,c|0)|0;d=x[27524];x[27524]=0;if((d|0)!=1){break l}i=V(0)|0;Xc(j+16|0);break m}i=V(0)|0;break g}i=V(0)|0}Ib(a);break g}x[k+24>>2]=b;Xc(j+16|0);pl(c);i=k;break d}i=V(0)|0}pl(c);_(i|0)|0;x[27524]=0;X(945,15181,k|0,g|0,h|0);a=x[27524];x[27524]=0;if((a|0)!=1){x[27524]=0;Z(18);a=x[27524];x[27524]=0;if((a|0)==1){break f}a=x[k+24>>2];if(a){Ib(Kp(a))}i=0;x[k+24>>2]=0;a=x[k+20>>2];if(a){Ib(a);x[k+20>>2]=0}Ib(k);break d}i=V(0)|0;x[27524]=0;Z(18);a=x[27524];x[27524]=0;if((a|0)!=1){break e}break b}i=V(0)|0}_(i|0)|0;i=0;x[27524]=0;X(945,15181,0,g|0,h|0);a=x[27524];x[27524]=0;if((a|0)==1){break c}$()}ib=j+96|0;return i|0}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)==1){break b}S(a|0);p()}V(0)|0;Sb()}p()}function mM(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=ib-96|0;ib=d;e=x[b+4>>2];a:{if(!e){break a}f=x[b>>2];g=y[gl(f,e)|0];if((g|0)==33){c=1}else{if((g|0)!=63){break a}c=0}ol(d+72|0,f,e,e-1|0);e=x[d+76>>2];x[b>>2]=x[d+72>>2];x[b+4>>2]=e}f=d+72|0;Yd(f);e=x[d+72>>2];Yd(d+56|0);e=fl(e,x[d+60>>2],b);Yd(f);b:{c:{d:{e:{if((e|0)==x[d+76>>2]){a=x[b+4>>2];e=x[b>>2];f=qc(d+88|0,21631);g=x[f+4>>2];x[d>>2]=x[f>>2];x[d+4>>2]=g;if(Nc(e,a,d)){a=ba(8)|0;x[27524]=0;c=Q(55,d+72|0,10420)|0;b=x[27524];x[27524]=0;if((b|0)==1){break d}lc(a,c);x[27524]=0;U(123,a|0,50060,962);a=x[27524];x[27524]=0;if((a|0)!=1){break b}b=P()|0;wb(c);break c}e=0;f=0;if(!c){break e}c=ba(8)|0;a=x[b+4>>2];b=x[b>>2];x[27524]=0;e=Qh(d+56|0,b,a);a=x[27524];x[27524]=0;f:{g:{h:{if((a|0)!=1){x[27524]=0;U(973,d+72|0,17646,e|0);a=x[27524];x[27524]=0;if((a|0)==1){break h}lc(c,d+72|0);a=0;x[27524]=0;U(123,c|0,50060,962);b=x[27524];x[27524]=0;if((b|0)!=1){break b}b=P()|0;wb(d+72|0);break g}b=P()|0;break f}b=P()|0;a=1}wb(e);if(!a){break c}}ca(c|0);break c}if(x[e+4>>2]!=1){a=ba(8)|0;x[27524]=0;c=Q(55,d+72|0,11480)|0;b=x[27524];x[27524]=0;if((b|0)!=1){lc(a,c);x[27524]=0;U(123,a|0,50060,962);a=x[27524];x[27524]=0;if((a|0)!=1){break b}b=P()|0;wb(c);break c}b=P()|0;ca(a|0);break c}c=x[b+4>>2];b=x[b>>2];e=qc(d+48|0,21631);f=x[e+4>>2];x[d+24>>2]=x[e>>2];x[d+28>>2]=f;if(Nc(b,c,d+24|0)){a=ba(8)|0;x[27524]=0;c=Q(55,d+72|0,10420)|0;b=x[27524];x[27524]=0;if((b|0)!=1){lc(a,c);x[27524]=0;U(123,a|0,50060,962);a=x[27524];x[27524]=0;if((a|0)!=1){break b}b=P()|0;wb(c);break c}b=P()|0;ca(a|0);break c}e=qc(d+40|0,10883);f=x[e+4>>2];x[d+16>>2]=x[e>>2];x[d+20>>2]=f;if(Nc(b,c,d+16|0)){a=x[a+8>>2];e=a;f=a>>31;break e}e=qc(d+32|0,8575);f=x[e+4>>2];x[d+8>>2]=x[e>>2];x[d+12>>2]=f;e=0;f=0;if(!Nc(b,c,d+8|0)){break e}e=ik(y[x[a+32>>2]+140|0]);f=0}ib=d+96|0;kb=f;return e|0}b=P()|0;ca(a|0)}S(b|0)}p()}function b2(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;j=ib-16|0;ib=j;k=rv(g);o=Zw(g);ih(j,o);x[f>>2]=d;a:{b:{c:{i=a;g=y[i|0];switch(g-43|0){case 0:case 2:break c;default:break b}}x[27524]=0;g=Q(20,k|0,g<<24>>24)|0;i=x[27524];x[27524]=0;if((i|0)==1){break a}i=x[f>>2];x[f>>2]=i+1;v[i|0]=g;i=a+1|0}d:{g=i;if(!((c-g|0)<2|y[g|0]!=48|(y[g+1|0]|32)!=120)){x[27524]=0;g=Q(20,k|0,48)|0;h=x[27524];x[27524]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+1;v[h|0]=g;g=v[i+1|0];x[27524]=0;g=Q(20,k|0,g|0)|0;h=x[27524];x[27524]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+1;v[h|0]=g;i=i+2|0;g=i;while(1){if(c>>>0<=g>>>0){break d}h=v[g|0];Fd();if(!FH(h)){break d}g=g+1|0;continue}}while(1){if(c>>>0<=g>>>0){break d}h=v[g|0];Fd();if(!hk(h)){break d}g=g+1|0;continue}}e:{if(Qe(j)){h=x[f>>2];x[27524]=0;X(1162,k|0,i|0,g|0,h|0);h=x[27524];x[27524]=0;if((h|0)==1){break a}x[f>>2]=x[f>>2]+(g-i|0);break e}dm(i,g);x[27524]=0;r=T(1160,o|0)|0;h=x[27524];x[27524]=0;if((h|0)==1){break a}h=i;while(1){if(g>>>0<=h>>>0){dm((i-a|0)+d|0,x[f>>2]);break e}f:{if(v[Qc(j,m)|0]<=0){break f}if(v[Qc(j,m)|0]!=(l|0)){break f}l=x[f>>2];x[f>>2]=l+1;v[l|0]=r;m=(Eb(j)-1>>>0>m>>>0)+m|0;l=0}q=v[h|0];x[27524]=0;q=Q(20,k|0,q|0)|0;n=x[27524];x[27524]=0;if((n|0)!=1){n=x[f>>2];x[f>>2]=n+1;v[n|0]=q;h=h+1|0;l=l+1|0;continue}break}break a}while(1){g:{if(c>>>0>g>>>0){i=y[g|0];if((i|0)!=46){break g}x[27524]=0;i=T(1163,o|0)|0;h=x[27524];x[27524]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+1;v[h|0]=i;g=g+1|0}i=x[f>>2];x[27524]=0;X(1162,k|0,g|0,c|0,i|0);i=x[27524];x[27524]=0;if((i|0)==1){break a}i=f;f=x[f>>2]+(c-g|0)|0;x[i>>2]=f;x[e>>2]=(b|0)==(c|0)?f:(b-a|0)+d|0;wb(j);ib=j+16|0;return}x[27524]=0;i=Q(20,k|0,i<<24>>24)|0;h=x[27524];x[27524]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+1;v[h|0]=i;g=g+1|0;continue}}a=P()|0;wb(j);S(a|0);p()}function rna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;d=ib-1104|0;ib=d;x[d+1100>>2]=c;i=eC(d+40|0,b);r=Pq(i);e=Nb(a);x[27524]=0;a=T(206,b|0)|0;c=x[27524];x[27524]=0;a:{if((c|0)!=1){x[d+8>>2]=a;x[d+36>>2]=85899345;t=d,u=D(x[Hb(d+8|0,d+36|0)>>2],50),x[t+24>>2]=u;a=x[Hb(d+1100|0,d+24|0)>>2];x[27524]=0;R(326,e|0,a|0);a=x[27524];x[27524]=0;if((a|0)!=1){x[27524]=0;h=T(338,d+24|0)|0;a=x[27524];x[27524]=0;if((a|0)!=1){x[27524]=0;f=Q(339,d+8|0,8192)|0;a=x[27524];x[27524]=0;b:{if((a|0)!=1){a=x[h>>2];c=0;while(1){if((c|0)!=256){g=Bb(a,c);v[g+2|0]=c;w[g>>1]=8192;c=c+1|0;continue}break}m=9;c:{d:while(1){g=0;n=257;while(1){s=m&255;e:{while(1){j=n&65535;while(1){x[27524]=0;o=Q(168,i|0,s|0)|0;a=x[27524];x[27524]=0;if((a|0)==1){break c}k=o&65535;if((k|0)==257|j>>>0<k>>>0){break e}if(cd(x[e>>2],x[e+4>>2])>>>0>=A[d+1100>>2]){break e}if((k|0)==256){m=9;continue d}c=j>>>0>k>>>0?o:g;a=x[h>>2];l=8192;while(1){c=c&65535;a=Bb(a,c);l=l-1|0;q=l&65535;t=Jb(x[f>>2],q),u=y[a+2|0],v[t|0]=u;a=x[h>>2];c=z[Bb(a,c)>>1];if(c>>>0<8192){continue}break}a=Wb(d,Cb(x[e+4>>2]));c=Yf(Cb(x[f>>2]),q);l=Cb(x[f+4>>2]);a=x[a>>2];x[27524]=0;X(327,e|0,a|0,c|0,l|0);a=x[27524];x[27524]=0;if((a|0)==1){break c}f:{if((j|0)!=(k|0)){break f}a=x[f>>2];x[27524]=0;R(340,e|0,Jb(a,q)|0);a=x[27524];x[27524]=0;if((a|0)!=1){break f}break c}if(j>>>0>=8192){g=o;continue}if(cd(x[e>>2],x[e+4>>2])>>>0>=A[d+1100>>2]){continue}break}a=y[Jb(x[f>>2],q)|0];c=Bb(x[h>>2],j);w[c>>1]=g;v[c+2|0]=a;a=n+1|0;n=8192;g=o;c=a&65535;if((c|0)==8192){continue}break}m=((c|0)==1<<s)+m|0;n=a;continue}break}break}a=Pq(i);x[27524]=0;Q(159,b|0,((a-r|0)+3&-4)+r|0)|0;a=x[27524];x[27524]=0;if((a|0)==1){break c}ec(f);uc(h);yb(i);ib=d+1104|0;return}c=P()|0;ec(f);break b}c=P()|0}uc(h);break a}c=P()|0;break a}c=P()|0;break a}c=P()|0}ec(e);yb(i);S(c|0);p()}function dR(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0;c=ib-176|0;ib=c;e=x[a+12>>2];j=1<<e;a:{if(!(e&1)){h=j>>>2|0;l=1;break a}l=j>>>1|0;e=0;while(1){if((e|0)==(l|0)){h=j>>>3|0;l=2;e=x[a+12>>2]}else{i=x[b>>2];h=Kd(i,e+l|0);d=Kd(i,e);o=C[h>>3];p=C[h+8>>3];qj(c+160|0,d,o,p);i=x[c+172>>2];x[h+8>>2]=x[c+168>>2];x[h+12>>2]=i;i=x[c+164>>2];x[h>>2]=x[c+160>>2];x[h+4>>2]=i;Iy(Kd(x[b>>2],e),o,p);e=e+1|0;continue}break}}i=e&-2;b:while(1){if(i){w=D(h,3);y=h<<1;j=0;c:while(1){if((j|0)==(l|0)){i=i-2|0;h=h>>>2|0;l=l<<2;continue b}d=x[a>>2];e=Kd(d,j<<1);d=Kd(d,j);o=C[d>>3];p=C[d+8>>3];r=C[e>>3];s=C[e+8>>3];Di(c+160|0,o,p,r,s);e=j<<i;d=h+e|0;z=d>>>0<e>>>0?e:d;while(1)if((e|0)==(z|0)){j=j+1|0;continue c}else{f=x[b>>2];d=Kd(f,e);g=x[d+12>>2];x[c+152>>2]=x[d+8>>2];x[c+156>>2]=g;g=x[d+4>>2];x[c+144>>2]=x[d>>2];x[c+148>>2]=g;g=c+128|0;t=e+h|0;k=Kd(f,t);Di(g,r,s,C[k>>3],C[k+8>>3]);u=e+y|0;k=Kd(f,u);Di(c+112|0,o,p,C[k>>3],C[k+8>>3]);m=C[c+160>>3];n=C[c+168>>3];v=e+w|0;f=Kd(f,v);Di(c+96|0,m,n,C[f>>3],C[f+8>>3]);k=c+80|0;f=c+144|0;m=C[c+112>>3];n=C[c+120>>3];kl(k,f,m,n);q=c- -64|0;qj(q,f,m,n);m=C[c+96>>3];n=C[c+104>>3];kl(c+48|0,g,m,n);f=c+16|0;rl(f,-0,-1);qj(c,g,m,n);Di(c+32|0,C[c+16>>3],C[c+24>>3],C[c>>3],C[c+8>>3]);kl(f,k,C[c+48>>3],C[c+56>>3]);g=x[c+28>>2];x[d+8>>2]=x[c+24>>2];x[d+12>>2]=g;g=x[c+20>>2];x[d>>2]=x[c+16>>2];x[d+4>>2]=g;qj(f,k,C[c+48>>3],C[c+56>>3]);d=Kd(x[b>>2],t);g=x[c+28>>2];x[d+8>>2]=x[c+24>>2];x[d+12>>2]=g;g=x[c+20>>2];x[d>>2]=x[c+16>>2];x[d+4>>2]=g;kl(f,q,C[c+32>>3],C[c+40>>3]);d=Kd(x[b>>2],u);g=x[c+28>>2];x[d+8>>2]=x[c+24>>2];x[d+12>>2]=g;g=x[c+20>>2];x[d>>2]=x[c+16>>2];x[d+4>>2]=g;qj(f,q,C[c+32>>3],C[c+40>>3]);d=Kd(x[b>>2],v);f=x[c+28>>2];x[d+8>>2]=x[c+24>>2];x[d+12>>2]=f;f=x[c+20>>2];x[d>>2]=x[c+16>>2];x[d+4>>2]=f;e=e+1|0;continue}}}break}ib=c+176|0}function JL(a,b,c){a=a|0;b=E(b);c=c|0;var d=0,e=E(0),f=E(0),g=E(0),h=E(0),i=E(0),k=E(0),m=0,n=0,o=0;d=ib-16|0;ib=d;a:{b:{c:{d:{switch(c-1|0){case 0:a=(q(b),j(2));e:{f:{g:{if((a|0)<=8388607){e=E(E(-1)/E(b*b));if(!(a&2147483647)){break e}e=E(E(b-b)/E(0));if((a|0)<0){break e}a=(q(E(b*E(33554432))),j(2));c=-152;break g}if(a>>>0>2139095039){break f}c=-127;b=E(0);if((a|0)==1065353216){break f}}a=a+4913933|0;k=E((a>>>23|0)+c|0);b=E((l(2,(a&8388607)+1060439283|0),r())+E(-1));f=E(b*E(b*E(.5)));g=E(b/E(b+E(2)));h=E(g*g);i=E(h*h);e=b;b=(l(2,(q(E(b-f)),j(2))&-4096),r());f=E(E(g*E(f+E(E(h*E(E(i*E(.2849878668785095))+E(.6666666269302368)))+E(i*E(E(i*E(.24279078841209412))+E(.40000972151756287))))))+E(E(e-b)-f));b=E(E(k*E(.3010292053222656))+E(E(b*E(.434326171875))+E(E(f*E(.434326171875))+E(E(k*E(7.903415166765626e-7))+E(E(f+b)*E(-3168997136526741e-20))))))}e=b}b=E(e*E(2e3));if(!(E(F(b))<E(2147483648))){break c}a=~~b;break b;case 1:a=(D(x[a+24604>>2],100)|0)/128|0;break b;case 2:c=ib-16|0;ib=c;h:{i:{j:{k:{a=y[a+24648|0];if(a>>>0>=6){a=ba(8)|0;x[27524]=0;c=Q(55,c|0,5126)|0;d=x[27524];x[27524]=0;if((d|0)==1){break k}lc(a,c);x[27524]=0;U(123,a|0,50060,962);a=x[27524];x[27524]=0;if((a|0)!=1){break i}d=P()|0;wb(c);break j}ib=c+16|0;a=x[(a<<2)+78352>>2];break h}d=P()|0;ca(a|0)}S(d|0)}p()}break b;case 3:x[d>>2]=0;m=x[a+24640>>2];c=ib-80|0;ib=c;a=x[a+24636>>2];x[c+40>>2]=a;x[c>>2]=m;n=c+40|0;o=x[Ve(n,c)>>2];l:{if((a|0)==x[mq(n)+32>>2]){a=-1;if(x[mq(c)+36>>2]==(m|0)){break l}}a=0;if((o|0)<=0){break l}a=(o+500>>>0)/1e3|0}x[d>>2]=a;ib=c+80|0;a=x[d>>2];break b;default:break d}}c=ba(8)|0;x[27524]=0;d=Q(55,d|0,10323)|0;a=x[27524];x[27524]=0;m:{if((a|0)!=1){lc(c,d);x[27524]=0;U(123,c|0,50060,962);a=x[27524];x[27524]=0;if((a|0)!=1){break a}a=P()|0;wb(d);break m}a=P()|0;ca(c|0)}S(a|0);p()}a=-2147483648}ib=d+16|0;return a|0}p()}function lM(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=ib-96|0;ib=e;f=x[c+4>>2];a:{if(!f){break a}g=x[c>>2];h=y[gl(g,f)|0];if((h|0)==33){d=1}else{if((h|0)!=63){break a}d=0}ol(e+72|0,g,f,f-1|0);f=x[e+76>>2];x[c>>2]=x[e+72>>2];x[c+4>>2]=f}f=e+72|0;Yd(f);g=x[e+72>>2];Yd(e+56|0);h=fl(g,x[e+60>>2],c);Yd(f);f=x[c+4>>2];g=x[c>>2];b:{c:{d:{e:{if((h|0)==x[e+76>>2]){b=qc(e+88|0,21631);h=x[b+4>>2];x[e>>2]=x[b>>2];x[e+4>>2]=h;if(Nc(g,f,e)){a=ba(8)|0;x[27524]=0;b=Q(55,e+72|0,10420)|0;c=x[27524];x[27524]=0;if((c|0)==1){break d}lc(a,b);x[27524]=0;U(123,a|0,50060,962);a=x[27524];x[27524]=0;if((a|0)!=1){break b}c=P()|0;wb(b);break c}if(d){a=ba(8)|0;b=x[c+4>>2];c=x[c>>2];x[27524]=0;b=Qh(e+56|0,c,b);c=x[27524];x[27524]=0;f:{g:{h:{if((c|0)!=1){x[27524]=0;U(973,e+72|0,17646,b|0);c=x[27524];x[27524]=0;if((c|0)==1){break h}lc(a,e+72|0);d=0;x[27524]=0;U(123,a|0,50060,962);c=x[27524];x[27524]=0;if((c|0)!=1){break b}c=P()|0;wb(e+72|0);break g}c=P()|0;break f}c=P()|0;d=1}wb(b);if(!d){break c}}ca(a|0);break c}Kb(a);break e}c=qc(e+48|0,21631);d=x[c+4>>2];x[e+24>>2]=x[c>>2];x[e+28>>2]=d;if(Nc(g,f,e+24|0)){a=ba(8)|0;x[27524]=0;b=Q(55,e+72|0,10420)|0;c=x[27524];x[27524]=0;if((c|0)!=1){lc(a,b);x[27524]=0;U(123,a|0,50060,962);a=x[27524];x[27524]=0;if((a|0)!=1){break b}c=P()|0;wb(b);break c}c=P()|0;ca(a|0);break c}c=qc(e+40|0,12317);d=x[c+4>>2];x[e+16>>2]=x[c>>2];x[e+20>>2]=d;if(Nc(g,f,e+16|0)){i:{switch(x[b+52>>2]){case 0:Kc(a,5604);break e;case 1:Kc(a,11181);break e;case 2:Kc(a,9154);break e;default:break i}}Kb(a);break e}c=qc(e+32|0,11418);d=x[c+4>>2];x[e+8>>2]=x[c>>2];x[e+12>>2]=d;if(Nc(g,f,e+8|0)){j:{switch(x[b+56>>2]){case 0:Kc(a,15573);break e;case 1:Kc(a,15578);break e;case 2:Kc(a,12591);break e;case 3:Kc(a,9218);break e;default:break j}}Kb(a);break e}Kb(a)}ib=e+96|0;return}c=P()|0;ca(a|0)}S(c|0)}p()}function dga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0;g=ib-48|0;ib=g;p=x[a+16>>2];while(1){if((f|0)!=2){e=f<<3;i=e+(g+24|0)|0;e=a+e|0;x[i+4>>2]=x[e+44>>2];x[i+8>>2]=x[e+48>>2];f=f+1|0;continue}break}i=x[a+40>>2];k=x[a+36>>2];f=x[a+4>>2];x[g+16>>2]=x[a>>2];x[g+20>>2]=f;q=b+24|0;r=x[a+32>>2];s=x[a+28>>2];t=x[a+72>>2];b=x[a+68>>2];u=b;v=b>>31;b=x[a+64>>2];y=b;z=b>>31;b=x[a+60>>2];A=b;B=b>>31;C=x[a+8>>2];E=x[a+12>>2];while(1){if(d){f=x[g+16>>2];l=((((x[g+20>>2]&2147483647)<<1|f>>>31)&2147483646)<<1)+p|0;b=(((f>>>16|0)+4&131064)<<1)+q|0;j=w[b+14>>1];h=w[b+12>>1];m=w[b+10>>1];n=w[b+8>>1];o=w[b+6>>1];F=w[b+4>>1];G=w[b+2>>1];H=w[b>>1];f=0;e=0;while(1){if((e|0)!=2){b=l+(e<<1)|0;x[(g+8|0)+(e<<2)>>2]=(((((D(w[b+8>>1],m)+D(w[b+4>>1],n)|0)+D(h,w[b+12>>1])|0)+D(j,w[b+16>>1])|0)/2|0)+((((D(w[b-8>>1],G)+D(w[b-12>>1],H)|0)+D(w[b-4>>1],F)|0)+D(w[b>>1],o)|0)/2|0)|0)/16384;e=e+1|0;continue}break}while(1){if((f|0)!=2){l=(g+8|0)+(f<<2)|0;e=x[l>>2];b=(g+24|0)+(f<<3)|0;j=x[b+8>>2];h=x[b+4>>2];x[b+8>>2]=h;m=e<<8;e=m;e=qoa(A,B,e,e>>31);n=kb;o=b;b=Vb(h,-16777216,16776704);h=qoa(y,z,b,b>>31);e=h+e|0;b=kb+n|0;b=e>>>0<h>>>0?b+1|0:b;h=e;e=Vb(j,-16777216,16776704);j=qoa(u,v,e,e>>31);e=h+j|0;b=kb+b|0;b=e>>>0<j>>>0?b+1|0:b;e=e+8388608|0;b=e>>>0<8388608?b+1|0:b;b=Vc(e,b,24);x[o+4>>2]=b-(m&t);x[l>>2]=(b|0)/256;f=f+1|0;continue}break}k=k+s|0;x[c>>2]=x[c>>2]+D(x[g+8>>2],k>>12);i=i+r|0;x[c+4>>2]=x[c+4>>2]+D(x[g+12>>2],i>>12);Pb(g+16|0,C,E);c=c+8|0;d=d-1|0;continue}break}b=x[g+20>>2];x[a>>2]=x[g+16>>2];x[a+4>>2]=b;x[a+40>>2]=i;x[a+20>>2]=k>>12;x[a+36>>2]=k;x[a+24>>2]=i>>12;f=0;while(1){if((f|0)!=2){b=f<<3;c=b+a|0;b=b+(g+24|0)|0;x[c+44>>2]=x[b+4>>2];x[c+48>>2]=x[b+8>>2];f=f+1|0;continue}break}ib=g+48|0}function ega(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0;g=ib-48|0;ib=g;p=x[a+16>>2];while(1){if((f|0)!=2){e=f<<3;i=e+(g+24|0)|0;e=a+e|0;x[i+4>>2]=x[e+44>>2];x[i+8>>2]=x[e+48>>2];f=f+1|0;continue}break}i=x[a+40>>2];k=x[a+36>>2];f=x[a+4>>2];x[g+16>>2]=x[a>>2];x[g+20>>2]=f;q=b+24|0;r=x[a+32>>2];s=x[a+28>>2];t=x[a+72>>2];b=x[a+68>>2];u=b;y=b>>31;b=x[a+64>>2];z=b;A=b>>31;b=x[a+60>>2];B=b;C=b>>31;E=x[a+8>>2];F=x[a+12>>2];while(1){if(d){f=x[g+16>>2];l=(((x[g+20>>2]&2147483647)<<1|f>>>31)&-2)+p|0;b=(((f>>>16|0)+4&131064)<<1)+q|0;j=w[b+14>>1];h=w[b+12>>1];m=w[b+10>>1];n=w[b+8>>1];o=w[b+6>>1];G=w[b+4>>1];H=w[b+2>>1];I=w[b>>1];f=0;e=0;while(1){if((e|0)!=2){b=e+l|0;x[(g+8|0)+(e<<2)>>2]=(((((D(v[b+4|0],m)+D(v[b+2|0],n)|0)+D(h,v[b+6|0])|0)+D(j,v[b+8|0])<<8)/2|0)+((((D(v[b-4|0],H)+D(v[b-6|0],I)|0)+D(v[b-2|0],G)|0)+D(v[b|0],o)<<8)/2|0)|0)/16384;e=e+1|0;continue}break}while(1){if((f|0)!=2){l=(g+8|0)+(f<<2)|0;e=x[l>>2];b=(g+24|0)+(f<<3)|0;j=x[b+8>>2];h=x[b+4>>2];x[b+8>>2]=h;m=e<<8;e=m;e=qoa(B,C,e,e>>31);n=kb;o=b;b=Vb(h,-16777216,16776704);h=qoa(z,A,b,b>>31);e=h+e|0;b=kb+n|0;b=e>>>0<h>>>0?b+1|0:b;h=e;e=Vb(j,-16777216,16776704);j=qoa(u,y,e,e>>31);e=h+j|0;b=kb+b|0;b=e>>>0<j>>>0?b+1|0:b;e=e+8388608|0;b=e>>>0<8388608?b+1|0:b;b=Vc(e,b,24);x[o+4>>2]=b-(m&t);x[l>>2]=(b|0)/256;f=f+1|0;continue}break}k=k+s|0;x[c>>2]=x[c>>2]+D(x[g+8>>2],k>>12);i=i+r|0;x[c+4>>2]=x[c+4>>2]+D(x[g+12>>2],i>>12);Pb(g+16|0,E,F);c=c+8|0;d=d-1|0;continue}break}b=x[g+20>>2];x[a>>2]=x[g+16>>2];x[a+4>>2]=b;x[a+40>>2]=i;x[a+20>>2]=k>>12;x[a+36>>2]=k;x[a+24>>2]=i>>12;f=0;while(1){if((f|0)!=2){b=f<<3;c=b+a|0;b=b+(g+24|0)|0;x[c+44>>2]=x[b+4>>2];x[c+48>>2]=x[b+8>>2];f=f+1|0;continue}break}ib=g+48|0}function laa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=ib-96|0;ib=d;f=1;a:{if(Qe(c)){break a}e=y[WJ(c)|0];if((e|0)!=33){if((e|0)!=63){break a}f=0}e=d+80|0;iw(e,c,0,Eb(c)-1|0);Ac(c,e);wb(e)}e=d+80|0;Yd(e);g=x[d+80>>2];Yd(d+72|0);g=VJ(g,x[d+76>>2],c);Yd(e);b:{c:{d:{e:{f:{if((g|0)==x[d+84>>2]){if(de(c,21631)){a=ba(8)|0;x[27524]=0;b=Q(55,d+80|0,10420)|0;c=x[27524];x[27524]=0;if((c|0)==1){break d}lc(a,b);x[27524]=0;U(123,a|0,50060,962);a=x[27524];x[27524]=0;if((a|0)!=1){break b}c=P()|0;wb(b);break c}if(!f){break f}a=ba(8)|0;x[27524]=0;U(964,d+80|0,17646,c|0);b=x[27524];x[27524]=0;if((b|0)!=1){lc(a,d+80|0);x[27524]=0;U(123,a|0,50060,962);a=x[27524];x[27524]=0;if((a|0)!=1){break b}c=P()|0;wb(d+80|0);break c}c=P()|0;ca(a|0);break c}e=Kb(d+80|0);g:{h:{i:{j:{switch(x[g+4>>2]){case 0:ye(d- -64|0,c);x[27524]=0;c=x[d+68>>2];x[d+8>>2]=x[d+64>>2];x[d+12>>2]=c;b=W(965,b|0,d+8|0,f|0)|0;c=x[27524];x[27524]=0;if((c|0)!=1){x[27524]=0;v[d+72|0]=b;R(966,a|0,d+72|0);a=x[27524];x[27524]=0;if((a|0)!=1){break g}}break i;case 1:ye(d+56|0,c);x[27524]=0;c=x[d+60>>2];x[d+16>>2]=x[d+56>>2];x[d+20>>2]=c;b=VF(b,d+16|0,f);c=kb;f=x[27524];x[27524]=0;if((f|0)!=1){x[27524]=0;x[d+72>>2]=b;x[d+76>>2]=c;R(968,a|0,d+72|0);a=x[27524];x[27524]=0;if((a|0)!=1){break g}}break i;case 2:ye(d+48|0,c);x[27524]=0;c=x[d+52>>2];x[d+24>>2]=x[d+48>>2];x[d+28>>2]=c;h=+ra(969,b|0,d+24|0,f|0);b=x[27524];x[27524]=0;if((b|0)!=1){x[27524]=0;C[d+72>>3]=h;R(970,a|0,d+72|0);a=x[27524];x[27524]=0;if((a|0)!=1){break g}}break i;case 3:break j;default:break h}}ye(d+40|0,c);x[27524]=0;c=x[d+44>>2];x[d+32>>2]=x[d+40>>2];x[d+36>>2]=c;X(971,a|0,b|0,d+32|0,f|0);a=x[27524];x[27524]=0;if((a|0)!=1){break g}}c=P()|0;wb(e);break c}$c(a,e)}wb(e);break e}Kb(a)}ib=d+96|0;return}c=P()|0;ca(a|0)}S(c|0)}p()}function Dka(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;c=ib-48|0;ib=c;a:{b:{c:{d:{e:{f:{if(Ed(x[a+24>>2])){break f}i=a+4|0;l=Eb(i);e=ib-32|0;ib=e;h=e+24|0;b=h;x[b>>2]=-1;x[b+4>>2]=-1;x[27524]=0;d=TF(39);f=x[27524];x[27524]=0;b=kb;if((f|0)==1){V(0)|0;Sb();p()}x[e+8>>2]=d;x[e+12>>2]=b;d=ib-16|0;ib=d;j=e+8|0;b=j;m=d,n=qoa(x[b>>2],x[b+4>>2],1e3,0),x[m>>2]=n;x[d+4>>2]=kb;f=Oe(d+8|0,d);b=x[f+4>>2];ib=d+16|0;x[e+16>>2]=x[f>>2];x[e+20>>2]=b;g=e+16|0;m=e,n=IA(x[g>>2],x[g+4>>2]),x[m+16>>2]=n;x[e+20>>2]=kb;h=VT(h,g,Db(g));x[27524]=0;d=TF(40);f=x[27524];x[27524]=0;b=kb;if((f|0)==1){V(0)|0;Sb();p()}k=a+24|0;x[e+8>>2]=d;x[e+12>>2]=b;m=e,n=OT(j),x[m+16>>2]=n;x[e+20>>2]=kb;m=e,n=IA(x[g>>2],x[g+4>>2]),x[m+16>>2]=n;x[e+20>>2]=kb;a=VT(h,g,Db(g));b=x[a>>2];a=x[a+4>>2];ib=e+32|0;if(l){d=Nb(c+32|0);x[27524]=0;x[c+16>>2]=a;R(33,d|0,c+16|0);a=x[27524];x[27524]=0;if((a|0)==1){break c}x[27524]=0;x[c+16>>2]=b;R(33,d|0,c+16|0);a=x[27524];x[27524]=0;if((a|0)==1){break d}a=0;g:{while(1){if(Eb(i)>>>0<=a>>>0){b=Cb(x[d>>2]);a=Cb(x[d+4>>2]);x[27524]=0;f=W(34,c+16|0,b|0,a|0)|0;a=x[27524];x[27524]=0;if((a|0)!=1){break g}a=P()|0;break b}b=y[Qc(i,a)|0];x[27524]=0;x[c+16>>2]=b;R(33,d|0,c+16|0);b=x[27524];x[27524]=0;if((b|0)!=1){a=a+1|0;continue}break}a=P()|0;break b}x[27524]=0;b=T(35,f|0)|0;a=x[27524];x[27524]=0;if((a|0)!=1){x[c+8>>2]=b;a=c+8|0;LA(k,a);Cj(a);Km(f);uc(d);break f}a=P()|0;Km(f);break b}kb=b;x[c+16>>2]=a;x[c+20>>2]=kb;b=Nb(c+32|0);x[27524]=0;U(38,b|0,c+16|0,c+24|0);a=x[27524];x[27524]=0;if((a|0)==1){a=P()|0;uc(b);S(a|0);p()}x[27524]=0;f=T(35,b|0)|0;a=x[27524];x[27524]=0;if((a|0)==1){break e}x[c+8>>2]=f;a=c+8|0;LA(k,a);Cj(a);Km(b)}ib=c+48|0;return}a=P()|0;Km(b);break a}a=P()|0;break b}a=P()|0}uc(d)}S(a|0);p()}function mk(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0;i=ib-16|0;ib=i;a:{if(!d){break a}j=x[c>>2];if(!j){break a}b:{c:{d:{e:{f=x[a+480180>>2];if((f|0)!=512){if((f|0)!=64){break e}f=D(d,20)+j|0;break d}f=((D(d,36318)|0)/1024|0)+j|0;break d}f:{g:{h:{if(y[a+480208|0]&16){if((f|0)==4){break h}f=d>>31;x[i+12>>2]=(f^d)-f;wc(i+12|0,1020);f=x[i+12>>2];h=c;i:{if((d|0)>0){if(f>>>0<=15){g=ib-16|0;ib=g;Ab(g+8|0,a+1074312|0,7);f=x[(f<<2)+(zb(x[x[g+8>>2]>>2],x[g+12>>2])?37024:37088)>>2];break i}g=ib-16|0;ib=g;Ab(g+8|0,a+1074312|0,7);f=x[(f&-4)+(zb(x[x[g+8>>2]>>2],x[g+12>>2])?37152:38176)>>2];break i}if(f>>>0<=15){g=ib-16|0;ib=g;Ab(g+8|0,a+1074312|0,7);f=x[(f<<2)+(zb(x[x[g+8>>2]>>2],x[g+12>>2])?37088:37024)>>2];break i}g=ib-16|0;ib=g;Ab(g+8|0,a+1074312|0,7);f=x[(f&-4)+(zb(x[x[g+8>>2]>>2],x[g+12>>2])?38176:37152)>>2]}ib=g+16|0;g=h;h=qoa(f,f>>31,j,j>>31)+32768|0;f=kb;f=Dc(roa(h,h>>>0<32768?f+1|0:f,65536,0),kb);x[g>>2]=f;if((f|0)!=(j|0)){break c}Ab(i,a+1074312|0,7);h=x[c>>2];if(!(zb(x[x[i>>2]>>2],x[i+4>>2])^(d|0)>0)){f=2147483647;d=1;if((h|0)==2147483647){break c}break f}d=-1;if((h|0)>=2){break f}f=h;break c}Ab(i,a+1074312|0,7);if(zb(x[x[i>>2]>>2],x[i+4>>2])){break g}j=x[c>>2]}f=j-d|0;break d}f=x[c>>2];if((d|0)<0){h=qoa(f,0,14317456,0);g=kb;f=qoa(f,0,0-d|0,0)+14317456|0;d=kb;f=JP(soa(h,g,f,f>>>0<14317456?d+1|0:d),kb);break d}d=qoa(f,f>>31,d,0);h=kb;if((h|0)>=0&d>>>0>=14317456|(h|0)>0){if(e){x[c>>2]=2147483647;break a}x[c>>2]=0;x[b+696>>2]=0;x[b+88>>2]=x[b+88>>2]|2101248;break a}d=JP(soa(qoa(f,0,14317456,0),kb,14317456-d|0,0-(h+(d>>>0>14317456)|0)|0),kb);x[c>>2]=d;if((d|0)>0){break a}break b}f=d+h|0}x[c>>2]=f}if((f|0)>0){break a}}x[c>>2]=1;if(x[a+480180>>2]!=2|e){break a}x[b+696>>2]=0;x[b+88>>2]=x[b+88>>2]|2101248}ib=i+16|0}function og(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;j=x[a+8>>2]+(D(z[a+14>>1],(y[a+80|0]?c:0)+b|0)>>>1|0)|0;x[a+8>>2]=j;i=y[a+79|0]?z[x[a>>2]+3836>>1]:i;c=z[a+20>>1];l=z[a+22>>1];m=z[a+70>>1];a:{b:{c:{d:{switch(x[a+16>>2]){case 1:b=z[x[a>>2]+3832>>1];f=z[a+26>>1]?z[a+48>>1]>>>z[x[a+52>>2]+((b>>>z[a+44>>1]&7)<<1)>>1]|0:0;g=b;b=z[a+46>>1];f=c+(b?g&b?0:f:f)|0;w[a+20>>1]=f;b=2;h=z[a+28>>1];if((h|0)<=f<<16>>16){break c}break b;case 2:if(y[a+78|0]){break b}case 3:b=0;f=z[x[a>>2]+3832>>1];h=z[a+30>>1]?z[a+60>>1]>>>z[x[a+64>>2]+((f>>>z[a+56>>1]&7)<<1)>>1]|0:0;g=f;f=z[a+58>>1];f=c+(f?g&f?0:h:h)|0;w[a+20>>1]=f;if(f<<16>>16<511){break b}x[a+16>>2]=-1;w[a+20>>1]=511;x[a+72>>2]=0;break a;default:b=0;x[a+72>>2]=0;break a;case 0:break d}}b=1;f=z[x[a>>2]+3832>>1];k=z[a+24>>1]?D((c^-1)<<16>>16,z[a+36>>1]>>>z[x[a+40>>2]+((f>>>z[a+32>>1]&7)<<1)>>1]|0)>>>3|0:0;g=f;f=z[a+34>>1];f=c+(f?g&f?0:k:k)|0;w[a+20>>1]=f;if(f<<16>>16>0){break b}}x[a+16>>2]=b;w[a+20>>1]=h}i=((c+l|0)+m|0)+i<<3;if(e){d=(w[a+74>>1]+w[a+72>>1]>>e)+d|0}d=(j>>>10|0)+d|0;c=d&255;b=d&65535;e:{f:{switch(z[a+12>>1]){case 0:d=(b&512)>>>9|0;b=z[((b&256?c^255:c)<<1)+28416>>1];break e;case 1:d=0;b=z[((b&512?0:b&256?c^255:c)<<1)+28416>>1];break e;case 2:d=0;b=z[((b&256?c^255:c)<<1)+28416>>1];break e;case 3:d=0;b=z[((b&256?0:c)<<1)+28416>>1];break e;case 4:e=0;d=0;if(!(b&512)){e=(c<<1^b<<24>>31)&254;d=(b&256)>>>8|0}b=z[(e<<1)+28416>>1];break e;case 5:d=0;if(b&512){b=0}else{c=c<<1&254;b=b&128?c^255:c}b=z[(b<<1)+28416>>1];break e;case 6:d=(d&512)>>>9|0;b=0;break e;default:break f}}c=d<<3&4088;d=(b&512)>>>9|0;b=d?c^4088:c}w[a+74>>1]=z[a+72>>1];c=a;a=b+i&65535;a=a>>>0>=8191?8191:a;b=0-d^z[((a&255)<<1)+27904>>1]+1024>>>(a>>>8)<<1;w[c+72>>1]=b}return b<<16>>16}function gU(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=ib-16|0;ib=f;v[a|0]=0;c=y[b|0];if(c){v[a|0]=c>>>0>96?-1:c+12|0}v[a+1|0]=y[b+1|0];c=y[b+2|0];d=c-16|0;a:{b:{if((d&255)>>>0<=128){v[a+2|0]=1;c=(d&254)>>>1|0;break b}c:{switch(((c&240)+96&240)>>>4|0){case 0:v[a+2|0]=4;c=c&15;break b;case 1:v[a+2|0]=3;c=c&15;break b;case 2:v[a+2|0]=6;c=c&15;break b;case 3:break c;default:break a}}v[a+2|0]=5;c=c&15}v[a+4|0]=c}c=y[b+6|0];e=y[b+4|0];d=y[b+5|0];d:{if(!(c|(e|d))){break d}e:{f:{g:{h:{i:{j:{switch(e|0){default:k:{switch(e-29|0){case 7:break f;case 5:break g;case 3:break h;case 0:break i;case 1:case 2:case 4:case 6:break d;default:break k}}if((e|0)==128){break e}if((e|0)!=157){break d}v[a+2|0]=15;v[a+3|0]=20;v[a+4|0]=c>>>3;v[f+15|0]=15;h=a,i=y[Ub(b+5|0,f+15|0)|0]|208,v[h+5|0]=i;break d;case 0:Xf(a,c,d);g=y[b+6|0]==15;break d;case 1:v[a+3|0]=2;h=a,i=Ag(c<<4|(d&240)>>>4),v[h+5|0]=i;break d;case 2:v[a+3|0]=3;h=a,i=Ag(c<<4|(d&240)>>>4),v[h+5|0]=i;break d;case 3:v[a+3|0]=4;h=a,i=Ag(c<<4|(d&240)>>>4),v[h+5|0]=i;break d;case 4:v[a+3|0]=5;v[a+5|0]=c&240|(d&240)>>>4;break d;case 8:if(d){v[a+5|0]=d;v[a+3|0]=9;break d}if((c-1&255)>>>0>1){break d}v[a+5|0]=145;v[a+3|0]=20;break d;case 12:v[a+3|0]=13;v[a+5|0]=c>>>1;break d;case 15:if(c){v[a+5|0]=c;v[a+3|0]=17;break d}v[a+3|0]=16;v[a+5|0]=d&15;break d;case 16:break j;case 5:case 6:case 7:case 9:case 10:case 11:case 13:case 14:break d}}zB(a,c,d,1);g=(y[a+3|0]&254)==16;break d}v[a+5|0]=d;v[a+3|0]=18;break d}v[a+3|0]=31;v[a+5|0]=c>>>1;break d}v[a+3|0]=31;v[a+5|0]=c>>>1&120;break d}v[a+5|0]=159;v[a+3|0]=20;break d}v[a+3|0]=21;v[a+5|0]=c>>>2}b=y[b+3|0];l:{if(!b){break l}if(!y[a+3|0]){v[a+5|0]=b;v[a+3|0]=9;break l}if(y[a+2|0]){break l}v[a+2|0]=2;v[a+4|0]=b>>>2}ib=f+16|0;return g}function W9(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0;k=ib+-64|0;ib=k;a:{b:{c:{j=tq(1,32);d:{e:{if(!j){a=qm(ba(4)|0);x[27524]=0;U(123,a|0,108196,26);a=x[27524];x[27524]=0;if((a|0)!=1){break a}i=V(0)|0;break e}x[j+12>>2]=f;x[j+8>>2]=e;x[j+4>>2]=d;f=c?c:939;x[j>>2]=f;c=zg(k+48|0);f:{g:{h:{if(!i){break h}while(1){e=x[i>>2];if(!e){break h}l=x[i+4>>2];i:{if(l){x[27524]=0;e=Q(55,k+32|0,e|0)|0;m=x[27524];x[27524]=0;j:{if((m|0)!=1){x[27524]=0;m=Q(950,c|0,e|0)|0;n=x[27524];x[27524]=0;if((n|0)==1){break j}x[27524]=0;R(274,m|0,l|0);l=x[27524];x[27524]=0;if((l|0)==1){break j}break i}i=V(0)|0;break f}i=V(0)|0;wb(e);break f}x[27524]=0;e=Q(55,k+16|0,e|0)|0;l=x[27524];x[27524]=0;if((l|0)==1){break g}Ys(c,e)}wb(e);i=i+8|0;continue}}x[27524]=0;e=T(818,104)|0;i=x[27524];x[27524]=0;k:{l:{m:{if((i|0)!=1){x[27524]=0;d=Q(951,f|0,d|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break m}x[k>>2]=d;d=x[ge(k+8|0,k)>>2];x[27524]=0;a=ja(982,e|0,a|0,b|0,d|0,c|0)|0;b=x[27524];x[27524]=0;if((b|0)!=1){break k}i=V(0)|0;Xc(k);break l}i=V(0)|0;break f}i=V(0)|0}Ib(e);break f}x[j+28>>2]=a;Xc(k);x[j+24>>2]=a+8;pl(c);break d}i=V(0)|0}pl(c);_(i|0)|0;x[27524]=0;X(945,4976,j|0,g|0,h|0);a=x[27524];x[27524]=0;if((a|0)!=1){x[27524]=0;Z(18);a=x[27524];x[27524]=0;if((a|0)!=1){a=x[j+28>>2];if(a){lb[x[x[a>>2]+4>>2]](a)}x[j+24>>2]=0;x[j+28>>2]=0;a=x[j+20>>2];if(a){Ib(a);x[j+20>>2]=0}Ib(j);j=0;break d}i=V(0)|0;break e}i=V(0)|0;x[27524]=0;Z(18);a=x[27524];x[27524]=0;if((a|0)==1){break b}}_(i|0)|0;j=0;x[27524]=0;X(945,4976,0,g|0,h|0);a=x[27524];x[27524]=0;if((a|0)==1){break c}$()}ib=k- -64|0;return j|0}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)==1){break b}S(a|0);p()}V(0)|0;Sb()}p()}function k1(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;a=ib-1072|0;ib=a;x[a+16>>2]=f;x[a+20>>2]=g;x[a+24>>2]=h;x[a+28>>2]=i;j=a+960|0;x[a+956>>2]=j;j=ax(j,100,11078,a+16|0);x[a+48>>2]=1151;k=a+48|0;o=xe(a+536|0,0,k);x[a+48>>2]=1151;k=xe(a+528|0,0,k);a:{b:{c:{d:{if(j>>>0<100){h=a+544|0;f=a+960|0;break d}j=Fd();x[a>>2]=f;x[a+4>>2]=g;x[a+8>>2]=h;x[a+12>>2]=i;j=dj(a+956|0,j,11078,a);if((j|0)!=-1){f=x[a+956>>2];cf(o,f);cf(k,Gd(j<<2));h=x[k>>2];if(!qk(h)){break d}}x[27524]=0;Z(1152);a=x[27524];x[27524]=0;if((a|0)!=1){break a}j=P()|0;break c}g=a+520|0;ed(g,d);x[27524]=0;r=T(1164,g|0)|0;g=x[27524];x[27524]=0;e:{f:{g:{h:{i:{j:{if((g|0)==1){break j}x[27524]=0;X(1176,r|0,f|0,f+j|0,h|0);g=x[27524];x[27524]=0;if((g|0)==1){break j}q=(j|0)>0?y[f|0]==45:q;i=Kb(a+488|0);f=Kb(a+472|0);g=Kb(a+456|0);x[27524]=0;na(1203,c|0,q|0,a+520|0,a+512|0,a+508|0,a+504|0,i|0,f|0,g|0,a+452|0);c=x[27524];x[27524]=0;if((c|0)==1){break i}x[a+36>>2]=1151;c=xe(a+40|0,0,a+36|0);m=a+48|0;n=x[a+452>>2];k:{if((n|0)<(j|0)){l=((Eb(g)+(j-n<<1)|0)+Eb(f)|0)+1|0;break k}l=(Eb(g)+Eb(f)|0)+2|0}l=l+n|0;if(l>>>0<101){break h}cf(c,Gd(l<<2));m=x[c>>2];if(m){break h}x[27524]=0;Z(1152);b=x[27524];x[27524]=0;if((b|0)!=1){break a}break g}j=P()|0;break e}j=P()|0;break f}l=x[d+4>>2];x[27524]=0;pa(1204,m|0,a+36|0,a+32|0,l|0,h|0,(j<<2)+h|0,r|0,q|0,a+512|0,x[a+508>>2],x[a+504>>2],i|0,f|0,g|0,n|0);h=x[27524];x[27524]=0;if((h|0)!=1){x[27524]=0;b=ka(1185,b|0,m|0,x[a+36>>2],x[a+32>>2],d|0,e|0)|0;d=x[27524];x[27524]=0;if((d|0)!=1){break b}}}j=P()|0;Uc(c)}Gc(g);Gc(f);wb(i)}_b(a+520|0)}Uc(k);Uc(o);S(j|0);p()}Uc(c);Gc(g);Gc(f);wb(i);_b(a+520|0);Uc(k);Uc(o);ib=a+1072|0;return b|0}p()}function GT(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;l=ib-16|0;ib=l;g=x[b>>2];i=x[b+4>>2];a:{if((i|0)==(f|0)){b=dc(l+8|0,e,f);j=ib-16|0;ib=j;e=vl(c,d,g,f);x[j+12>>2]=e;b:{if((e|0)<=0){e=x[b>>2];break b}c:{if(!f){f=x[b>>2];break c}h=32-f|0;x[j+8>>2]=h;c=x[rd(j+8|0,j+12|0)>>2];x[j+12>>2]=e-c;d=x[b>>2];e=-1<<f&-1>>>h-c;x[d>>2]=x[d>>2]&(e^-1)|e&x[g>>2];c=c+x[b+4>>2]|0;x[b+4>>2]=c&31;f=d+(c>>>3&536870908)|0;x[b>>2]=f;g=g+4|0;e=x[j+12>>2]}d=(e|0)/32|0;c=d<<2;Wi(f,g,c);d=e-(d<<5)|0;x[j+12>>2]=d;e=c+x[b>>2]|0;x[b>>2]=e;if((d|0)<=0){break b}d=-1>>>32-d|0;x[e>>2]=x[e>>2]&(d^-1)|d&x[c+g>>2];x[b+4>>2]=x[j+12>>2]}dc(a,e,x[b+4>>2]);ib=j+16|0;break a}j=a;h=dc(l,e,f);f=ib-16|0;ib=f;e=vl(c,d,g,i);x[f+12>>2]=e;d:{if((e|0)<=0){a=x[h+4>>2];break d}e:{if(!i){a=x[h+4>>2];break e}k=32-i|0;x[f+8>>2]=k;c=f+8|0;b=x[rd(c,f+12|0)>>2];x[f+12>>2]=e-b;a=x[h+4>>2];e=x[g>>2];x[f+8>>2]=b;m=32-a|0;x[f+4>>2]=m;d=x[h>>2];n=x[d>>2];c=x[Hb(c,f+4|0)>>2];e=e&(-1<<i&-1>>>k-b);x[d>>2]=(-1<<a&-1>>>m-c^-1)&n|(a>>>0>i>>>0?e<<a-i:e>>>i-a|0);k=a+c|0;a=k&31;x[h+4>>2]=a;d=d+(k>>>3&536870908)|0;x[h>>2]=d;b=b-c|0;if((b|0)>0){x[d>>2]=x[d>>2]&(-1>>>32-b^-1)|e>>>c+i;x[h+4>>2]=b;a=b}g=g+4|0;e=x[f+12>>2]}c=32-a|0;d=-1<<a;i=d^-1;while(1){if((e|0)>=32){b=x[h>>2];e=x[g>>2];x[b>>2]=i&x[b>>2]|e<<a;x[h>>2]=b+4;x[b+4>>2]=d&x[b+4>>2]|e>>>c;e=x[f+12>>2]-32|0;x[f+12>>2]=e;g=g+4|0;continue}break}if((e|0)<=0){break d}i=x[g>>2];x[f+8>>2]=c;g=x[h>>2];b=x[g>>2];k=b;b=x[rd(f+12|0,f+8|0)>>2];e=i&-1>>>32-e;x[g>>2]=k&(d&-1>>>c-b^-1)|e<<a;c=a+b|0;a=c&31;x[h+4>>2]=a;c=g+(c>>>3&536870908)|0;x[h>>2]=c;d=x[f+12>>2]-b|0;x[f+12>>2]=d;if((d|0)<=0){break d}x[c>>2]=x[c>>2]&(-1>>>32-d^-1)|e>>>b;a=x[f+12>>2];x[h+4>>2]=a}dc(j,x[h>>2],a);ib=f+16|0}ib=l+16|0}function BO(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=ib-16|0;ib=g;e=D(b,872)+a|0;j=e+1074992|0;a:{b:{i=x[e+1075080>>2];if(i&131072){h=a+480180|0;e=x[h>>2];i=1;c:{d:{e:{f=x[a+480208>>2];if(f&4096){if(!(e&16777248)){break e}i=!(f&4)}if((e|0)!=64){break d}break b}if((e|0)==64){break b}h=a+480180|0;i=0;break c}if(!i){break c}Ab(g+8|0,a+1074312|0,21);if(!zb(x[x[g+8>>2]>>2],x[g+12>>2])){break c}e=D(b,872)+a|0;f=e+1075811|0;v[f|0]=y[f|0]+(y[e+1075815|0]<<2)}f=D(b,872)+a|0;k=f+1075814|0;l=f+1075811|0;e=Uy(a,y[k|0],y[l|0]);f:{if(Aj(x[j+656>>2])){B[d>>2]=B[d>>2]+E(E(E(D(y[f+1075816|0],e)|0)*E(.05000000074505806))/E(7680));c=f+1075843|0;d=y[c|0];v[c|0]=d&159|64;if(x[a+1074416>>2]!=(x[a+1074392>>2]+1|0)){break f}v[c|0]=d|96;break f}d=x[a+480208>>2];if((d&2101248)==2101248){break a}f=x[h>>2];if(d&4096?f&67633152:0){break a}e=f&5?(y[k|0]&3)==1?0-e|0:e:e;k=a+1074312|0;Ab(g+8|0,k,21);f=x[a+480208>>2];g:{if(zb(x[x[g+8>>2]>>2],x[g+12>>2])){d=f&4;e=d?e:0-e|0;d=d?5:6;break g}d=5;h:{if(f&131072){break h}h=x[h>>2];d=8;if((h|0)==1024){break h}d=7;if(h&524304){break h}d=h&16777248?f&4?6:7:6}Ab(g+8|0,k,80);if(!zb(x[x[g+8>>2]>>2],x[g+12>>2])){break g}d=y[(D(b,872)+a|0)+1075783|0]==26?d+2|0:d}d=(0-D(y[(D(b,872)+a|0)+1075816|0],e)|0)/(1<<d)|0;mk(a,j,c,d,0);e=x[j+656>>2];c=_p(a,x[j+88>>2],e);if(!c){break f}lb[x[x[c>>2]+92>>2]](c,d,(e?v[e+33|0]:2)<<24>>24,b)}if(!i){break a}Ab(g+8|0,a+1074312|0,21);if(zb(x[x[g+8>>2]>>2],x[g+12>>2])){break a}v[l|0]=y[l|0]+y[(D(b,872)+a|0)+1075815|0];break a}if(!(y[e+1075662|0]&2)){break a}a=_p(a,i,x[j+656>>2]);if(!a){break a}lb[x[x[a>>2]+92>>2]](a,0,0,b);break a}a=D(b,872)+a|0;b=a+1075811|0;d=y[b|0];if(d&1){x[c>>2]=x[c>>2]+D(y[a+1075816|0],167)}v[b|0]=d+1}ib=g+16|0}function fq(a,b,c,d){var e=0,f=E(0),g=E(0),h=E(0),i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=ib-16|0;ib=e;x[e+12>>2]=w[b+780>>1]+y[b+837|0];x[e+8>>2]=w[b+782>>1]+(y[b+838|0]&127);re(e+12|0,0,127);re(e+8|0,0,127);k=a+1074312|0;Ab(e,k,1);j=x[e+12>>2];a:{if(zb(x[x[e>>2]>>2],x[e+4>>2])){i=x[e+8>>2];break a}w[b+780>>1]=0;v[b+837|0]=j;i=x[e+8>>2];w[b+782>>1]=0;v[b+838|0]=i}Ab(e,k,36);l=D(j,d+256|0);m=(l|0)/256|0;b:{if(!(!zb(x[x[e>>2]>>2],x[e+4>>2])|i|(l|0)<65024)){m=-1;if(!Wc(y[b+788|0])){break b}if(ok(y[b+790|0],y[b+791|0])|z[b+786>>1]|!(y[b+851|0]&2)){break b}x[b+88>>2]=x[b+88>>2]&-32769;break b}x[b+88>>2]=x[b+88>>2]|32768;f=ze(E(10),E(E(0-i|0)*E(.00937500037252903)));i=ib-16|0;ib=i;h=E(D(j,d+256|0)>>>0);c:{if(x[a+480180>>2]!=33554432){g=E(110);h=E(E(h/(y[a+480209|0]&128?E(10240):E(12288)))+E(.25));break c}g=E(125);h=E(E(h*E(6))/E(65024))}n=i,o=Yh(E(ze(E(2),h)*g)),x[n+12>>2]=o;re(i+12|0,120,2e4);d=x[i+12>>2];j=x[a+24620>>2];ib=i+16|0;Ab(e,k,36);h=E(E(((j|0)<d<<1?j>>>1|0:d)>>>0)*E(6.2831854820251465));d:{if(!(!zb(x[x[e>>2]>>2],x[e+4>>2])|x[a+480208>>2]&32768)){g=E(E(A[a+24620>>2])/h);h=E(E(E(f*g)+f)+E(-1));f=E(g*g);break d}g=E(f+f);f=E(h/E(A[a+24620>>2]));B[e>>2]=E(E(1)-g)*f;tQ(e,E(2));h=E(E(g-B[e>>2])/f);f=E(E(1)/E(f*f))}g=E(f+E(h+E(1)));h=E(E(f+E(f+h))/g);f=E(E(-f)/g);g=E(E(1)/g);e:{if(y[b+845|0]==1){n=b,o=Yh(E(E(E(1)-g)*E(16777216))),x[n+60>>2]=o;n=b,o=Yh(E(h*E(16777216))),x[n+64>>2]=o;n=b,o=Yh(E(f*E(16777216))),x[n+68>>2]=o;a=-1;break e}d=Yh(E(g*E(16777216)));x[b+60>>2]=d;n=b,o=Yh(E(h*E(16777216))),x[n+64>>2]=o;n=b,o=Yh(E(f*E(16777216))),x[n+68>>2]=o;a=0;if(d){break e}x[b+60>>2]=1}x[b+72>>2]=a;if(!c){break b}x[b+44>>2]=0;x[b+48>>2]=0;x[b+52>>2]=0;x[b+56>>2]=0}ib=e+16|0;return m}function M$(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;r=ib-16|0;ib=r;j=c;while(1){a:{if((d|0)==(j|0)){j=d;break a}if(!y[j|0]){break a}j=j+1|0;continue}break}x[h>>2]=f;x[e>>2]=c;while(1){b:{c:{d:{if((c|0)==(d|0)|(f|0)==(g|0)){break d}i=x[b+4>>2];x[r+8>>2]=x[b>>2];x[r+12>>2]=i;s=ib-16|0;ib=s;u=qi(s+8|0,x[a+8>>2]);m=j-c|0;k=0;o=0;n=ib-1040|0;ib=n;i=x[e>>2];x[n+12>>2]=i;p=f?f:n+16|0;l=f?g-f>>2:256;e:{f:{if(!(!i|!l)){while(1){g:{q=m>>>2|0;if(q>>>0<l>>>0&m>>>0<=131){break f}q=sH(p,n+12|0,l>>>0>q>>>0?q:l,b);if((q|0)==-1){k=-1;l=0;i=x[n+12>>2];break g}t=(n+16|0)!=(p|0)?q:0;l=l-t|0;p=(t<<2)+p|0;m=i+m|0;i=x[n+12>>2];m=i?m-i|0:0;k=k+q|0;if(!i){break g}if(l){continue}}break}}if(!i){break e}}if(!(!l|!m)){o=i;i=k;while(1){h:{k=ls(p,o,m,b);i:{if(k+2>>>0<=2){j:{switch(k+1|0){case 1:o=0;break i;case 0:break e;default:break j}}x[b>>2]=0;break i}i=i+1|0;o=k+o|0;l=l-1|0;if(l){break h}}k=i;break e}p=p+4|0;m=m-k|0;k=i;if(m){continue}break}break e}o=i}if(f){x[e>>2]=o}ib=n+1040|0;pi(u);ib=s+16|0;k:{l:{m:{n:{if((k|0)==-1){while(1){o:{x[h>>2]=f;if(x[e>>2]==(c|0)){break o}g=1;p:{q:{r:{b=mG(f,c,j-c|0,r+8|0,x[a+8>>2]);switch(b+2|0){case 0:break l;case 2:break p;case 1:break r;default:break q}}x[e>>2]=c;break n}g=b}c=c+g|0;f=x[h>>2]+4|0;continue}break}x[e>>2]=c;break d}f=x[h>>2]+(k<<2)|0;x[h>>2]=f;if((f|0)==(g|0)){break k}c=x[e>>2];if((d|0)==(j|0)){j=d;continue}if(!mG(f,c,1,b,x[a+8>>2])){break m}}a=2;break c}x[h>>2]=x[h>>2]+4;c=x[e>>2]+1|0;x[e>>2]=c;j=c;while(1){if((d|0)==(j|0)){j=d;break b}if(!y[j|0]){break b}j=j+1|0;continue}}x[e>>2]=c;a=1;break c}c=x[e>>2]}a=(c|0)!=(d|0)}ib=r+16|0;return a|0}f=x[h>>2];continue}}function o1(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;a=ib-464|0;ib=a;x[a+16>>2]=f;x[a+20>>2]=g;x[a+24>>2]=h;x[a+28>>2]=i;j=a+352|0;x[a+348>>2]=j;j=ax(j,100,11078,a+16|0);x[a+48>>2]=1151;k=a+48|0;o=xe(a+232|0,0,k);x[a+48>>2]=1151;k=xe(a+224|0,0,k);a:{b:{c:{d:{if(j>>>0<100){h=a+240|0;f=a+352|0;break d}j=Fd();x[a>>2]=f;x[a+4>>2]=g;x[a+8>>2]=h;x[a+12>>2]=i;j=dj(a+348|0,j,11078,a);if((j|0)!=-1){f=x[a+348>>2];cf(o,f);cf(k,Gd(j));h=x[k>>2];if(!qk(h)){break d}}x[27524]=0;Z(1152);a=x[27524];x[27524]=0;if((a|0)!=1){break a}j=P()|0;break c}g=a+216|0;ed(g,d);x[27524]=0;r=T(19,g|0)|0;g=x[27524];x[27524]=0;e:{f:{g:{h:{i:{j:{if((g|0)==1){break j}x[27524]=0;X(1162,r|0,f|0,f+j|0,h|0);g=x[27524];x[27524]=0;if((g|0)==1){break j}q=(j|0)>0?y[f|0]==45:q;i=Kb(a+192|0);f=Kb(a+176|0);g=Kb(a+160|0);x[27524]=0;na(1201,c|0,q|0,a+216|0,a+208|0,a+207|0,a+206|0,i|0,f|0,g|0,a+156|0);c=x[27524];x[27524]=0;if((c|0)==1){break i}x[a+36>>2]=1151;c=xe(a+40|0,0,a+36|0);m=a+48|0;n=x[a+156>>2];k:{if((n|0)<(j|0)){l=((Eb(g)+(j-n<<1)|0)+Eb(f)|0)+1|0;break k}l=(Eb(g)+Eb(f)|0)+2|0}l=l+n|0;if(l>>>0<101){break h}cf(c,Gd(l));m=x[c>>2];if(m){break h}x[27524]=0;Z(1152);b=x[27524];x[27524]=0;if((b|0)!=1){break a}break g}j=P()|0;break e}j=P()|0;break f}l=x[d+4>>2];x[27524]=0;pa(1202,m|0,a+36|0,a+32|0,l|0,h|0,h+j|0,r|0,q|0,a+208|0,v[a+207|0],v[a+206|0],i|0,f|0,g|0,n|0);h=x[27524];x[27524]=0;if((h|0)!=1){x[27524]=0;b=ka(15,b|0,m|0,x[a+36>>2],x[a+32>>2],d|0,e|0)|0;d=x[27524];x[27524]=0;if((d|0)!=1){break b}}}j=P()|0;Uc(c)}wb(g);wb(f);wb(i)}_b(a+216|0)}Uc(k);Uc(o);S(j|0);p()}Uc(c);wb(g);wb(f);wb(i);_b(a+216|0);Uc(k);Uc(o);ib=a+464|0;return b|0}p()}function sM(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0;k=ib+-64|0;ib=k;a:{b:{c:{d:{e:{f:{j=tq(1,28);if(!j){a=qm(ba(4)|0);x[27524]=0;U(123,a|0,108196,26);a=x[27524];x[27524]=0;if((a|0)!=1){break a}break f}x[j+12>>2]=f;x[j+8>>2]=e;x[j+4>>2]=d;f=c?c:939;x[j>>2]=f;c=zg(k+48|0);g:{h:{i:{if(!i){break i}while(1){e=x[i>>2];if(!e){break i}l=x[i+4>>2];j:{if(l){x[27524]=0;e=Q(55,k+32|0,e|0)|0;m=x[27524];x[27524]=0;k:{if((m|0)!=1){x[27524]=0;m=Q(950,c|0,e|0)|0;n=x[27524];x[27524]=0;if((n|0)==1){break k}x[27524]=0;R(274,m|0,l|0);l=x[27524];x[27524]=0;if((l|0)==1){break k}break j}i=V(0)|0;break g}i=V(0)|0;wb(e);break g}x[27524]=0;e=Q(55,k+16|0,e|0)|0;l=x[27524];x[27524]=0;if((l|0)==1){break h}Ys(c,e)}wb(e);i=i+8|0;continue}}x[27524]=0;e=T(818,80)|0;i=x[27524];x[27524]=0;l:{m:{n:{if((i|0)!=1){x[27524]=0;d=Q(951,f|0,d|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break n}x[k>>2]=d;d=x[ge(k+8|0,k)>>2];x[27524]=0;a=ja(956,e|0,a|0,b|0,d|0,c|0)|0;b=x[27524];x[27524]=0;if((b|0)!=1){break l}i=V(0)|0;Xc(k);break m}i=V(0)|0;break g}i=V(0)|0}Ib(e);break g}x[j+24>>2]=a;Xc(k);pl(c);i=j;break d}i=V(0)|0}pl(c);_(i|0)|0;x[27524]=0;X(945,15080,j|0,g|0,h|0);a=x[27524];x[27524]=0;if((a|0)!=1){x[27524]=0;Z(18);a=x[27524];x[27524]=0;if((a|0)==1){break f}a=x[j+24>>2];if(a){Ib(Kp(a))}i=0;x[j+24>>2]=0;a=x[j+20>>2];if(a){Ib(a);x[j+20>>2]=0}Ib(j);break d}i=V(0)|0;x[27524]=0;Z(18);a=x[27524];x[27524]=0;if((a|0)!=1){break e}break b}i=V(0)|0}_(i|0)|0;i=0;x[27524]=0;X(945,15080,0,g|0,h|0);a=x[27524];x[27524]=0;if((a|0)==1){break c}$()}ib=k- -64|0;return i|0}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)==1){break b}S(a|0);p()}V(0)|0;Sb()}p()}function Di(a,b,c,d,e){var f=0,g=0,h=0,i=0,k=0,m=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;q=c*d;r=b*e;m=q+r;s=b*d;t=c*e;p=s-t;a:{if(!Ji(p)){break a}if(!Ji(m)){break a}h=tf(b);f=tf(c);k=h|f;if((k|0)==1){o(+(f?1:0));f=j(1)|0;i=j(0)|0;o(+c);g=j(1)|0;j(0)|0;l(0,i|0);l(1,f&2147483647|g&-2147483648);c=+n();o(0);f=j(1)|0;i=j(0)|0;o(+d);g=j(1)|0;j(0)|0;l(0,i|0);l(1,f&2147483647|g&-2147483648);d=(u=+n(),v=d,w=Ji(d),w?u:v);o(0);f=j(1)|0;i=j(0)|0;o(+e);g=j(1)|0;j(0)|0;l(0,i|0);l(1,f&2147483647|g&-2147483648);e=(u=+n(),v=e,w=Ji(e),w?u:v);o(+(h?1:0));h=j(1)|0;g=j(0)|0;o(+b);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);b=+n()}h=tf(d);f=tf(e);b:{if(h|f){o(+(f?1:0));f=j(1)|0;g=j(0)|0;o(+e);k=j(1)|0;j(0)|0;l(0,g|0);l(1,f&2147483647|k&-2147483648);e=+n();o(+(h?1:0));h=j(1)|0;g=j(0)|0;o(+d);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);d=+n();o(0);h=j(1)|0;g=j(0)|0;o(+b);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);b=(u=+n(),v=b,w=Ji(b),w?u:v);o(0);h=j(1)|0;g=j(0)|0;o(+c);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);c=(u=+n(),v=c,w=Ji(c),w?u:v);break b}if(k){break b}c:{if(tf(s)){break c}if(tf(t)){break c}if(tf(r)){break c}if(!tf(q)){break a}}o(0);h=j(1)|0;g=j(0)|0;o(+b);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);b=(u=+n(),v=b,w=Ji(b),w?u:v);o(0);h=j(1)|0;g=j(0)|0;o(+c);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);c=(u=+n(),v=c,w=Ji(c),w?u:v);o(0);h=j(1)|0;g=j(0)|0;o(+d);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);d=(u=+n(),v=d,w=Ji(d),w?u:v);o(0);h=j(1)|0;g=j(0)|0;o(+e);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);e=(u=+n(),v=e,w=Ji(e),w?u:v)}m=(b*e+d*c)*O;p=(b*d-e*c)*O}rl(a,p,m)}function hga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0;g=ib-48|0;ib=g;o=x[a+16>>2];while(1){if((f|0)!=2){e=f<<3;j=e+(g+24|0)|0;e=a+e|0;x[j+4>>2]=x[e+44>>2];x[j+8>>2]=x[e+48>>2];f=f+1|0;continue}break}j=x[a+24>>2];p=x[a+20>>2];f=x[a+4>>2];x[g+16>>2]=x[a>>2];x[g+20>>2]=f;q=b+24|0;r=x[a+72>>2];b=x[a+68>>2];s=b;t=b>>31;b=x[a+64>>2];u=b;v=b>>31;b=x[a+60>>2];y=b;z=b>>31;A=x[a+8>>2];B=x[a+12>>2];while(1){if(d){f=x[g+16>>2];k=((((x[g+20>>2]&2147483647)<<1|f>>>31)&2147483646)<<1)+o|0;b=(((f>>>16|0)+4&131064)<<1)+q|0;i=w[b+14>>1];h=w[b+12>>1];l=w[b+10>>1];m=w[b+8>>1];n=w[b+6>>1];C=w[b+4>>1];E=w[b+2>>1];F=w[b>>1];f=0;e=0;while(1){if((e|0)!=2){b=k+(e<<1)|0;x[(g+8|0)+(e<<2)>>2]=(((((D(w[b+8>>1],l)+D(w[b+4>>1],m)|0)+D(h,w[b+12>>1])|0)+D(i,w[b+16>>1])|0)/2|0)+((((D(w[b-8>>1],E)+D(w[b-12>>1],F)|0)+D(w[b-4>>1],C)|0)+D(w[b>>1],n)|0)/2|0)|0)/16384;e=e+1|0;continue}break}while(1){if((f|0)!=2){k=(g+8|0)+(f<<2)|0;e=x[k>>2];b=(g+24|0)+(f<<3)|0;i=x[b+8>>2];h=x[b+4>>2];x[b+8>>2]=h;l=e<<8;e=l;e=qoa(y,z,e,e>>31);m=kb;n=b;b=Vb(h,-16777216,16776704);h=qoa(u,v,b,b>>31);e=h+e|0;b=kb+m|0;b=e>>>0<h>>>0?b+1|0:b;h=e;e=Vb(i,-16777216,16776704);i=qoa(s,t,e,e>>31);e=h+i|0;b=kb+b|0;b=e>>>0<i>>>0?b+1|0:b;e=e+8388608|0;b=e>>>0<8388608?b+1|0:b;b=Vc(e,b,24);x[n+4>>2]=b-(l&r);x[k>>2]=(b|0)/256;f=f+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[g+8>>2],p);x[c+4>>2]=x[c+4>>2]+D(j,x[g+12>>2]);Pb(g+16|0,A,B);c=c+8|0;d=d-1|0;continue}break}b=x[g+20>>2];x[a>>2]=x[g+16>>2];x[a+4>>2]=b;f=0;while(1){if((f|0)!=2){b=f<<3;c=b+a|0;b=b+(g+24|0)|0;x[c+44>>2]=x[b+4>>2];x[c+48>>2]=x[b+8>>2];f=f+1|0;continue}break}ib=g+48|0}function iZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;e=ib+-64|0;ib=e;yc(b);ap(a);a:{if(!ii(b,e+56|0)){break a}if(!_D(e+56|0)){break a}if(!c){l=1;break a}if(!Ob(x[b>>2],x[b+8>>2],4)){break a}ew(a);q=e,r=dw(),x[q+32>>2]=r;c=e+32|0;cw(_j(x[a+4>>2])+32|0,c);Ar(c);k=x[_j(x[a+4>>2])+32>>2];c=bh(x[b>>2]);if(c&1){break a}d=c-4|0;bd(b,d);h=ib-16|0;ib=h;c=h+8|0;Tv(c,b);f=y[Jb(c,0)|0];i=y[Jb(c,1)|0];c=y[Jb(c,2)|0];ib=h+16|0;h=c|(i<<8|f<<16);if(!h){break a}x[27524]=0;R(179,k|0,h|0);c=x[27524];x[27524]=0;l=1;if((c|0)==1){a=V(108196)|0;if((jb|0)==(da(108196)|0)){_(a|0)|0;$();l=0;break a}S(a|0);p()}bd(b,4);m=e+32|0;ZD(m,b);i=x[k>>2];f=ib-32|0;ib=f;b=x[e+32>>2];v[f+24|0]=y[b|0];v[f+25|0]=y[b+1|0];v[f+26|0]=y[b+2|0];v[f+27|0]=y[b+3|0];c=rr(f+8|0);d=b+d|0;x[c+12>>2]=d-4;x[c+8>>2]=b;Yj(c,y[d-1|0]);b=h;b:while(1){c:{d:{e:{if(!b){break e}if(Yj(c,1)){break d}d=1;while(1){g=Yj(c,2);d=g+d|0;if((g|0)==3){continue}break}x[f+4>>2]=d;wc(f+4|0,b);d=0;g=x[f+4>>2];while(1)if((d|0)==(g|0)){if(!b){break e}break d}else{b=b-1|0;q=i+b|0,r=Yj(c,8),v[q|0]=r;d=d+1|0;continue}}ib=f+32|0;break c}g=Yj(c,2);d=g+2|0;x[f+4>>2]=d;f:{if((g|0)==3){if(Yj(c,1)){g=y[Jb(f+24|0,3)|0]}else{g=7}g=Yj(c,g);while(1){j=Yj(c,3);d=j+d|0;if((j|0)==7){continue}break}x[f+4>>2]=d;break f}g=Yj(c,y[Jb(f+24|0,g)|0])}wc(f+4|0,b);d=0;o=x[f+4>>2];while(1){if((d|0)==(o|0)){continue b}j=0;n=b+g|0;if(h>>>0>n>>>0){j=y[i+n|0]}b=b-1|0;v[i+b|0]=j;d=d+1|0;continue}}break}he(e+16|0,x[k>>2],x[k+4>>2]);lg(e+24|0,x[e+16>>2],x[e+20>>2]);b=Id(e+8|0);c=x[b+4>>2];x[e>>2]=x[b>>2];x[e+4>>2]=c;b=yr(m,x[e+24>>2],x[e+28>>2],e);fd(_j(x[a+4>>2])+12|0,b);yb(b)}ib=e- -64|0;return l|0}function tfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0;h=ib-48|0;ib=h;f=fR(h+32|0,1<<x[b+12>>2]);g=x[f>>2];while(1){c=x[a>>2];if(ah(c,x[a+4>>2])>>>0>d>>>0){c=We(c,d);eR(Kd(g,d),C[c>>3]);d=d+1|0;continue}break}dR(b,f);w=h,y=Cb(x[f>>2]),x[w+8>>2]=y;v=Cb(x[f+4>>2]);while(1){g=x[h+8>>2];if(Mb(g,v)){m=C[g+8>>3];k=ib-32|0;ib=k;o(+C[g>>3]);e=j(1)|0;r=j(0)|0;o(+m);c=j(1)|0;s=j(0)|0;q=e&2147483647;t=c&2147483647;d=t;c=(q|0)==(d|0)&r>>>0<s>>>0|d>>>0>q>>>0;e=c?r:s;c=c?q:d;d=c;l(0,e|0);l(1,c|0);p=+n();u=c>>>20|0;i=p;a:{if((u|0)==2047){break a}c=(q|0)==(t|0)&r>>>0>s>>>0|q>>>0>t>>>0;l(0,(c?r:s)|0);c=c?q:t;l(1,c|0);m=+n();b:{if(!(d|e)){break b}c=c>>>20|0;if((c|0)==2047){break b}i=m+p;if((c-u|0)>=65){break a}c:{if(c>>>0>=1534){p=p*190109156629516e-225;m=m*190109156629516e-225;i=5.260135901548374e210;break c}i=1;if(u>>>0>572){break c}p=p*5.260135901548374e210;m=m*5.260135901548374e210;i=190109156629516e-225}EI(k+24|0,k+16|0,m);EI(k+8|0,k,p);i=i*M(C[k>>3]+C[k+16>>3]+C[k+8>>3]+C[k+24>>3]);break a}i=m}p=i;ib=k+32|0;eR(g,xp(p));qq(h+8|0);continue}break}cR(b,f);bR(f);e=x[f>>2];g=tk(e,x[f+4>>2])>>>1|0;c=g>>>0<=1?1:g;d=1;while(1){if((c|0)!=(d|0)){Wz(Kd(e,d),2);Wz(Kd(e,d+g|0),0);d=d+1|0;continue}break}dR(b,f);w=h,y=Cb(x[f>>2]),x[w+24>>2]=y;g=Cb(x[f+4>>2]);while(1){e=x[h+24>>2];if(Mb(e,g)){aR(h+8|0,C[e>>3],C[e+8>>3]);c=x[h+20>>2];x[e+8>>2]=x[h+16>>2];x[e+12>>2]=c;c=x[h+12>>2];x[e>>2]=x[h+8>>2];x[e+4>>2]=c;qq(h+24|0);continue}break}cR(b,f);bR(f);g=x[a>>2];c=ah(g,x[a+4>>2]);b=x[f>>2];d=0;while(1){if((c|0)==(d|0)){Gm(f);ib=h+48|0}else{a=Kd(b,d);w=We(g,d),z=C[a>>3],C[w>>3]=z;d=d+1|0;continue}break}}function is(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;i=ib-128|0;ib=i;x[i+120>>2]=b;k=oH(c,d);x[i+4>>2]=1151;m=mH(i+8|0,i+4|0);j=i+16|0;a:{b:{if(k>>>0>=101){j=Gd(k);if(!j){x[27524]=0;Z(1152);a=x[27524];x[27524]=0;if((a|0)!=1){break a}a=P()|0;break b}cf(m,j)}h=j;b=c;while(1){if((b|0)==(d|0)){c:{d:{e:while(1){f:{x[27524]=0;h=Q(1153,a|0,i+120|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break f}if(!(h&(k|0)!=0)){x[27524]=0;b=Q(1154,a|0,i+120|0)|0;a=x[27524];x[27524]=0;if((a|0)==1){break c}if(!b){break d}x[f>>2]=x[f>>2]|2;break d}b=x[a>>2];x[27524]=0;n=T(1155,b|0)|0;b=x[27524];x[27524]=0;g:{if((b|0)!=1){if(g){break g}x[27524]=0;n=Q(1156,e|0,n|0)|0;b=x[27524];x[27524]=0;if((b|0)!=1){break g}}a=P()|0;break b}r=o+1|0;s=0;h=j;b=c;while(1){if((b|0)==(d|0)){o=r;if(!s){continue e}x[27524]=0;T(1157,a|0)|0;b=x[27524];x[27524]=0;if((b|0)!=1){h=j;b=c;if(k+l>>>0<2){continue e}while(1){if((b|0)==(d|0)){continue e}h:{if(y[h|0]!=2){break h}if((Eb(b)|0)==(o|0)){break h}v[h|0]=0;l=l-1|0}h=h+1|0;b=b+12|0;continue}}a=P()|0;break b}i:{if(y[h|0]!=1){break i}q=v[ng(b,o)|0];j:{if(g){break j}x[27524]=0;q=Q(1156,e|0,q<<24>>24)|0;t=x[27524];x[27524]=0;if((t|0)!=1){break j}a=P()|0;break b}k:{if((n&255)==(q&255)){s=1;if((Eb(b)|0)!=(r|0)){break i}v[h|0]=2;l=l+1|0;break k}v[h|0]=0}k=k-1|0}h=h+1|0;b=b+12|0;continue}}break}a=P()|0;break b}l:{m:{while(1){if((c|0)==(d|0)){break m}if(y[j|0]!=2){j=j+1|0;c=c+12|0;continue}break}d=c;break l}x[f>>2]=x[f>>2]|4}Uc(m);ib=i+128|0;return d|0}a=P()|0}else{n:{if(!Qe(b)){v[h|0]=1;break n}v[h|0]=2;l=l+1|0;k=k-1|0}h=h+1|0;b=b+12|0;continue}break}}Uc(m);S(a|0)}p()}function iga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0;g=ib-48|0;ib=g;o=x[a+16>>2];while(1){if((f|0)!=2){e=f<<3;j=e+(g+24|0)|0;e=a+e|0;x[j+4>>2]=x[e+44>>2];x[j+8>>2]=x[e+48>>2];f=f+1|0;continue}break}j=x[a+24>>2];p=x[a+20>>2];f=x[a+4>>2];x[g+16>>2]=x[a>>2];x[g+20>>2]=f;q=b+24|0;r=x[a+72>>2];b=x[a+68>>2];s=b;t=b>>31;b=x[a+64>>2];u=b;y=b>>31;b=x[a+60>>2];z=b;A=b>>31;B=x[a+8>>2];C=x[a+12>>2];while(1){if(d){f=x[g+16>>2];k=(((x[g+20>>2]&2147483647)<<1|f>>>31)&-2)+o|0;b=(((f>>>16|0)+4&131064)<<1)+q|0;i=w[b+14>>1];h=w[b+12>>1];l=w[b+10>>1];m=w[b+8>>1];n=w[b+6>>1];E=w[b+4>>1];F=w[b+2>>1];G=w[b>>1];f=0;e=0;while(1){if((e|0)!=2){b=e+k|0;x[(g+8|0)+(e<<2)>>2]=(((((D(v[b+4|0],l)+D(v[b+2|0],m)|0)+D(h,v[b+6|0])|0)+D(i,v[b+8|0])<<8)/2|0)+((((D(v[b-4|0],F)+D(v[b-6|0],G)|0)+D(v[b-2|0],E)|0)+D(v[b|0],n)<<8)/2|0)|0)/16384;e=e+1|0;continue}break}while(1){if((f|0)!=2){k=(g+8|0)+(f<<2)|0;e=x[k>>2];b=(g+24|0)+(f<<3)|0;i=x[b+8>>2];h=x[b+4>>2];x[b+8>>2]=h;l=e<<8;e=l;e=qoa(z,A,e,e>>31);m=kb;n=b;b=Vb(h,-16777216,16776704);h=qoa(u,y,b,b>>31);e=h+e|0;b=kb+m|0;b=e>>>0<h>>>0?b+1|0:b;h=e;e=Vb(i,-16777216,16776704);i=qoa(s,t,e,e>>31);e=h+i|0;b=kb+b|0;b=e>>>0<i>>>0?b+1|0:b;e=e+8388608|0;b=e>>>0<8388608?b+1|0:b;b=Vc(e,b,24);x[n+4>>2]=b-(l&r);x[k>>2]=(b|0)/256;f=f+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[g+8>>2],p);x[c+4>>2]=x[c+4>>2]+D(j,x[g+12>>2]);Pb(g+16|0,B,C);c=c+8|0;d=d-1|0;continue}break}b=x[g+20>>2];x[a>>2]=x[g+16>>2];x[a+4>>2]=b;f=0;while(1){if((f|0)!=2){b=f<<3;c=b+a|0;b=b+(g+24|0)|0;x[c+44>>2]=x[b+4>>2];x[c+48>>2]=x[b+8>>2];f=f+1|0;continue}break}ib=g+48|0}function gs(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;i=ib-128|0;ib=i;x[i+120>>2]=b;k=oH(c,d);x[i+4>>2]=1151;m=mH(i+8|0,i+4|0);j=i+16|0;a:{b:{if(k>>>0>=101){j=Gd(k);if(!j){x[27524]=0;Z(1152);a=x[27524];x[27524]=0;if((a|0)!=1){break a}a=P()|0;break b}cf(m,j)}h=j;b=c;while(1){if((b|0)==(d|0)){c:{d:{e:while(1){f:{x[27524]=0;h=Q(1169,a|0,i+120|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break f}if(!(h&(k|0)!=0)){x[27524]=0;b=Q(1170,a|0,i+120|0)|0;a=x[27524];x[27524]=0;if((a|0)==1){break c}if(!b){break d}x[f>>2]=x[f>>2]|2;break d}b=x[a>>2];x[27524]=0;n=T(1171,b|0)|0;b=x[27524];x[27524]=0;g:{if((b|0)!=1){if(g){break g}x[27524]=0;n=Q(1172,e|0,n|0)|0;b=x[27524];x[27524]=0;if((b|0)!=1){break g}}a=P()|0;break b}r=o+1|0;s=0;h=j;b=c;while(1){if((b|0)==(d|0)){o=r;if(!s){continue e}x[27524]=0;T(1173,a|0)|0;b=x[27524];x[27524]=0;if((b|0)!=1){h=j;b=c;if(k+l>>>0<2){continue e}while(1){if((b|0)==(d|0)){continue e}h:{if(y[h|0]!=2){break h}if((Eb(b)|0)==(o|0)){break h}v[h|0]=0;l=l-1|0}h=h+1|0;b=b+12|0;continue}}a=P()|0;break b}i:{if(y[h|0]!=1){break i}q=x[Hi(b,o)>>2];j:{if(g){break j}x[27524]=0;q=Q(1172,e|0,q|0)|0;t=x[27524];x[27524]=0;if((t|0)!=1){break j}a=P()|0;break b}k:{if((n|0)==(q|0)){s=1;if((Eb(b)|0)!=(r|0)){break i}v[h|0]=2;l=l+1|0;break k}v[h|0]=0}k=k-1|0}h=h+1|0;b=b+12|0;continue}}break}a=P()|0;break b}l:{m:{while(1){if((c|0)==(d|0)){break m}if(y[j|0]!=2){j=j+1|0;c=c+12|0;continue}break}d=c;break l}x[f>>2]=x[f>>2]|4}Uc(m);ib=i+128|0;return d|0}a=P()|0}else{n:{if(!Qe(b)){v[h|0]=1;break n}v[h|0]=2;l=l+1|0;k=k-1|0}h=h+1|0;b=b+12|0;continue}break}}Uc(m);S(a|0)}p()}function Jga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0;g=ib-48|0;ib=g;o=x[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;h=e+(g+24|0)|0;e=a+e|0;x[h+4>>2]=x[e+44>>2];x[h+8>>2]=x[e+48>>2];b=b+1|0;continue}break}h=x[a+40>>2];k=x[a+36>>2];b=x[a+4>>2];x[g+16>>2]=x[a>>2];x[g+20>>2]=b;p=x[a+32>>2];q=x[a+28>>2];r=x[a+72>>2];b=x[a+68>>2];s=b;t=b>>31;b=x[a+64>>2];u=b;v=b>>31;b=x[a+60>>2];y=b;z=b>>31;A=x[a+8>>2];B=x[a+12>>2];while(1){if(d){e=x[g+16>>2];m=((((x[g+20>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+o|0;b=e>>>21&2040;j=w[b+39734>>1];i=w[b+39732>>1];n=w[b+39730>>1];l=w[b+39728>>1];b=0;e=0;while(1){if((e|0)!=2){f=m+(e<<1)|0;x[(g+8|0)+(e<<2)>>2]=(((D(w[f>>1],n)+D(w[f-4>>1],l)|0)+D(i,w[f+4>>1])|0)+D(j,w[f+8>>1])|0)/16384;e=e+1|0;continue}break}while(1){if((b|0)!=2){m=(g+8|0)+(b<<2)|0;f=x[m>>2];e=(g+24|0)+(b<<3)|0;j=x[e+8>>2];i=x[e+4>>2];x[e+8>>2]=i;n=f<<8;f=n;f=qoa(y,z,f,f>>31);l=kb;C=e;e=Vb(i,-16777216,16776704);i=qoa(u,v,e,e>>31);f=i+f|0;e=kb+l|0;e=f>>>0<i>>>0?e+1|0:e;l=f;f=Vb(j,-16777216,16776704);j=qoa(s,t,f,f>>31);f=l+j|0;e=kb+e|0;e=f>>>0<j>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Vc(f,e,24);x[C+4>>2]=e-(n&r);x[m>>2]=(e|0)/256;b=b+1|0;continue}break}k=k+q|0;x[c>>2]=x[c>>2]+D(x[g+8>>2],k>>12);h=h+p|0;x[c+4>>2]=x[c+4>>2]+D(x[g+12>>2],h>>12);Pb(g+16|0,A,B);c=c+8|0;d=d-1|0;continue}break}b=x[g+20>>2];x[a>>2]=x[g+16>>2];x[a+4>>2]=b;x[a+40>>2]=h;x[a+20>>2]=k>>12;x[a+36>>2]=k;x[a+24>>2]=h>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}ib=g+48|0}function zP(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;c=ib-16|0;ib=c;d=a+1074376|0;e=D(b,872);a:{if(x[(d+e|0)+704>>2]&134218752){break a}g=x[(a+e|0)+1075648>>2];if(!uj(g)|y[g+15|0]&2){break a}d=Ql(a,d,b,2,1)-1|0;if((d&255)>>>0>249){break a}h=x[Nd(a+906300|0,d)>>2];if(!h){break a}f=D(b,872)+a|0;j=f+1075780|0;d=y[j|0];b:{if(y[f+1075782|0]==1){v[c+8|0]=64;e=y[Ub(f+1075784|0,c+8|0)|0];break b}e=255;if(y[f+1075783|0]!=13){break b}v[c+8|0]=64;e=y[Ub((D(b,872)+a|0)+1075785|0,c+8|0)|0]}i=a+1074312|0;Ab(c+8|0,i,2);if(zb(x[x[c+8>>2]>>2],x[c+12>>2])){if(d){if(Wc(d)){d=y[Jb(g+108|0,d-1|0)|0]}wm(a,b,d,z[(D(b,872)+a|0)+1075680>>1]);break a}if((e|0)==255){break a}lb[x[x[h>>2]+76>>2]](h,39,e,b);break a}k=x[g+4>>2];c:{if(!d){break c}f=y[g+35|0]?k<<2:x[(D(b,872)+a|0)+1075680>>2];l=w[(D(b,872)+a|0)+1075768>>1];Ab(c+8|0,i,28);m=c,n=f+(zb(x[x[c+8>>2]>>2],x[c+12>>2])?l<<2:l)|0,x[m+4>>2]=n;re(c+4|0,0,256);f=d;if(Wc(d)){f=y[Jb(g+108|0,d-1|0)|0]}Ab(c+8|0,i,117);if(!zb(x[x[c+8>>2]>>2],x[c+12>>2])){if(ok(y[j+2|0],y[j+3|0])){break c}}wm(a,b,f&255,z[c+4>>1])}f=y[g+35|0];Ab(c+8|0,i,101);if(zb(x[x[c+8>>2]>>2],x[c+12>>2])){a=(d|0)!=0}else{a=Wc(d)}if(a^1|(f|0)!=1?(a|(e|0)==255)==1:0){break a}d:{switch(y[g+36|0]){case 1:a=x[h+20>>2];if((e|0)!=255){vt(a,E(E(E(e<<1)/E(-127))+E(1)));break a}vt(a,E(E(E(k<<1>>>0)/E(-127))+E(1)));break a;case 0:break d;default:break a}}if((e|0)!=255){v[c+8|0]=127;v[c+4|0]=e<<1;n=h,o=7,p=y[Ub(c+8|0,c+4|0)|0],q=b,m=x[x[h>>2]+76>>2],lb[m](n|0,o|0,p|0,q|0);break a}x[c+8>>2]=127;x[c+4>>2]=k<<1;q=h,p=7,o=y[Hb(c+8|0,c+4|0)|0],n=b,m=x[x[h>>2]+76>>2],lb[m](q|0,p|0,o|0,n|0)}ib=c+16|0}function Sha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=ib-48|0;ib=h;k=c+484344|0;Fg(k,y[b+70|0]|y[b+71|0]<<8);a:{b:{while(1){if((y[b+70|0]|y[b+71|0]<<8)>>>0<=j>>>0){break b}f=x[a+8>>2];e=Jg(a);Yb(a,1);c:{if((y[b+58|0]|y[b+59|0]<<8)==258){c=Re(a)+1|0;break c}c=_g(a)}d=_g(a);bd(a,e+f|0);ae(h,a,d);f=hc(h+24|0,h);yb(h);x[27524]=0;c=W(230,k|0,j&65535,(c?c>>>0>=1024?1024:c:64)|0)|0;e=x[27524];x[27524]=0;if((e|0)!=1){d:{if(!(c&(d|0)!=0)){break d}c=Xb(x[k>>2],j);m=h,n=Cb(x[c>>2]),x[m>>2]=n;l=Cb(x[c+4>>2]);while(1){c=x[h>>2];if(!Mb(c,l)){break d}x[27524]=0;d=T(210,f|0)|0;e=x[27524];x[27524]=0;e:{f:{g:{if((e|0)!=1){e=d<<24>>24;if((e|0)>=0){break g}if(e&1){x[27524]=0;d=T(210,f|0)|0;i=x[27524];x[27524]=0;if((i|0)==1){break a}v[c|0]=d}d=e&255;if(e&2){break f}break e}break a}v[c|0]=e;d=255}x[27524]=0;e=T(210,f|0)|0;i=x[27524];x[27524]=0;if((i|0)==1){break a}v[c+1|0]=e}i=0;e=0;if(d&4){x[27524]=0;e=T(210,f|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break a}}if(d&8){x[27524]=0;i=T(210,f|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break a}}if(d&16){x[27524]=0;d=T(210,f|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break a}v[c+5|0]=d}h:{i:{d=y[c|0];if(!d){break i}g=255;if((d|0)==97){break h}if(d>>>0>96){break i}g=d+12|0;break h}g=0}v[c|0]=g;d=y[c+5|0];j:{if((d|i)&255){Xf(c,i,d);break j}v[c+3|0]=0}if(y[c+1|0]==255){v[c+1|0]=0}d=e-16|0;k:{if((d&255)>>>0<=64){v[c+4|0]=d;v[c+2|0]=1;break k}if(e>>>0<96){break k}d=e&15;v[c+4|0]=d;e=e-96>>>4|0;v[c+2|0]=y[e+27150|0];if((e|0)!=6){break k}v[c+4|0]=d<<2}Hk(h);continue}}yb(f);j=j+1|0;continue}break}break a}ib=h+48|0;return}a=P()|0;yb(f);S(a|0);p()}function Jda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;c=ib-224|0;ib=c;e=bm(c+112|0,a);x[27524]=0;d=Q(453,c+96|0,43838)|0;a=x[27524];x[27524]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if((a|0)!=1){x[27524]=0;x[c+80>>2]=19988503;x[c+84>>2]=0;U(454,e|0,d|0,c+80|0);a=x[27524];x[27524]=0;if((a|0)==1){break n}Zb(d);if(Rk(y[e|0])){break e}x[27524]=0;d=Q(453,c+80|0,13294)|0;a=x[27524];x[27524]=0;if((a|0)==1){break m}x[27524]=0;X(485,e|0,b|0,d|0,877);a=x[27524];x[27524]=0;if((a|0)==1){break l}Zb(d);x[c+76>>2]=0;x[c+72>>2]=0;x[27524]=0;d=Q(453,c+56|0,16727)|0;a=x[27524];x[27524]=0;if((a|0)==1){break k}x[27524]=0;U(878,e|0,c+76|0,d|0);a=x[27524];x[27524]=0;if((a|0)==1){break j}Zb(d);x[27524]=0;d=Q(453,c+40|0,16699)|0;a=x[27524];x[27524]=0;if((a|0)==1){break i}x[27524]=0;U(878,e|0,c+72|0,d|0);a=x[27524];x[27524]=0;if((a|0)==1){break h}Zb(d);a=x[c+76>>2];d=x[c+72>>2];o:{if(!a|d>>>0<a>>>0){break o}f=x[x[x[x[b+48>>2]+12>>2]+8>>2]+40>>2];if(f>>>0<a>>>0|d>>>0>f>>>0){break o}x[b+20>>2]=d;x[b+16>>2]=a}d=Nb(c+24|0);x[27524]=0;f=Q(453,c+8|0,14120)|0;a=x[27524];x[27524]=0;if((a|0)==1){break d}x[27524]=0;U(879,e|0,d|0,f|0);a=x[27524];x[27524]=0;if((a|0)==1){break g}Zb(f);if(pc(x[d>>2],x[d+4>>2])){break f}a=x[b+16>>2];x[27524]=0;R(832,d|0,a|0);a=x[27524];x[27524]=0;if((a|0)!=1){break f}break c}a=P()|0;break a}a=P()|0;Zb(d);break a}a=P()|0;break a}a=P()|0;Zb(d);break a}a=P()|0;break a}a=P()|0;Zb(d);break a}a=P()|0;break a}a=P()|0;Zb(d);break a}a=P()|0;Zb(f);break b}x[27524]=0;R(880,b|0,d|0);a=x[27524];x[27524]=0;if((a|0)==1){break c}uc(d)}rh(e);ib=c+224|0;return}a=P()|0;break b}a=P()|0}uc(d)}rh(e);S(a|0);p()}function Kga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0,C=0,E=0;g=ib-48|0;ib=g;o=x[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;h=e+(g+24|0)|0;e=a+e|0;x[h+4>>2]=x[e+44>>2];x[h+8>>2]=x[e+48>>2];b=b+1|0;continue}break}h=x[a+40>>2];k=x[a+36>>2];b=x[a+4>>2];x[g+16>>2]=x[a>>2];x[g+20>>2]=b;p=x[a+32>>2];q=x[a+28>>2];r=x[a+72>>2];b=x[a+68>>2];s=b;t=b>>31;b=x[a+64>>2];u=b;y=b>>31;b=x[a+60>>2];z=b;A=b>>31;B=x[a+8>>2];C=x[a+12>>2];while(1){if(d){e=x[g+16>>2];m=(((x[g+20>>2]&2147483647)<<1|e>>>31)&-2)+o|0;b=e>>>21&2040;j=w[b+39734>>1];i=w[b+39732>>1];n=w[b+39730>>1];l=w[b+39728>>1];b=0;e=0;while(1){if((e|0)!=2){f=e+m|0;x[(g+8|0)+(e<<2)>>2]=(((D(v[f|0],n)+D(v[f-2|0],l)|0)+D(i,v[f+2|0])|0)+D(j,v[f+4|0])<<8)/16384;e=e+1|0;continue}break}while(1){if((b|0)!=2){m=(g+8|0)+(b<<2)|0;f=x[m>>2];e=(g+24|0)+(b<<3)|0;j=x[e+8>>2];i=x[e+4>>2];x[e+8>>2]=i;n=f<<8;f=n;f=qoa(z,A,f,f>>31);l=kb;E=e;e=Vb(i,-16777216,16776704);i=qoa(u,y,e,e>>31);f=i+f|0;e=kb+l|0;e=f>>>0<i>>>0?e+1|0:e;l=f;f=Vb(j,-16777216,16776704);j=qoa(s,t,f,f>>31);f=l+j|0;e=kb+e|0;e=f>>>0<j>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Vc(f,e,24);x[E+4>>2]=e-(n&r);x[m>>2]=(e|0)/256;b=b+1|0;continue}break}k=k+q|0;x[c>>2]=x[c>>2]+D(x[g+8>>2],k>>12);h=h+p|0;x[c+4>>2]=x[c+4>>2]+D(x[g+12>>2],h>>12);Pb(g+16|0,B,C);c=c+8|0;d=d-1|0;continue}break}b=x[g+20>>2];x[a>>2]=x[g+16>>2];x[a+4>>2]=b;x[a+40>>2]=h;x[a+20>>2]=k>>12;x[a+36>>2]=k;x[a+24>>2]=h>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}ib=g+48|0}function TN(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{b:{d=b;e=x[b>>2];if(e){if(!x[b+4>>2]){break b}g=x[b+4>>2];c:{if(!g){while(1){g=Hh(d);d=x[d+8>>2];if(!g){continue}break}break c}d=cW(g)}e=x[d>>2];if(e){break b}}e=x[d+4>>2];if(e){break b}e=0;g=1;break a}x[e+8>>2]=x[d+8>>2];g=0}d:{e:{if(Hh(d)){c=x[d+8>>2];x[c>>2]=e;if((a|0)==(d|0)){a=e;c=0;break d}c=c+4|0;break e}c=x[d+8>>2];x[c+4>>2]=e}c=x[c>>2]}h=!y[d+12|0];if((b|0)!=(d|0)){f=x[b+8>>2];x[d+8>>2]=f;i=f+(Hh(b)?0:4)|0,j=d,x[i>>2]=j;f=x[b>>2];x[d>>2]=f;pm(f,d);f=x[b+4>>2];x[d+4>>2]=f;if(f){pm(f,d)}v[d+12|0]=y[b+12|0];a=(a|0)==(b|0)?d:a}if(!(h|!a)){if(g){while(1){b=y[c+12|0];f:{g:{if(!Hh(c)){if(!b){v[c+12|0]=1;b=x[c+8>>2];v[b+12|0]=0;Fq(b);b=x[c>>2];a=(b|0)==(a|0)?c:a;c=x[b+4>>2]}b=x[c>>2];h:{if(!(y[b+12|0]?0:b)){b=x[c+4>>2];if(y[b+12|0]?0:b){break h}v[c+12|0]=0;i:{b=x[c+8>>2];if((b|0)!=(a|0)){if(y[b+12|0]){break i}a=b}v[a+12|0]=1;return}if(!Hh(b)){break g}b=x[b+8>>2]+4|0;break f}a=x[c+4>>2];if(y[a+12|0]?0:a){break h}v[b+12|0]=1;v[c+12|0]=0;Eq(c);c=x[c+8>>2]}a=x[c+8>>2];v[c+12|0]=y[a+12|0];v[a+12|0]=1;v[x[c+4>>2]+12|0]=1;Fq(a);return}if(!b){v[c+12|0]=1;b=x[c+8>>2];v[b+12|0]=0;Eq(b);b=x[c+4>>2];a=(b|0)==(a|0)?c:a;c=x[b>>2]}d=x[c>>2];j:{if(y[d+12|0]?0:d){break j}b=x[c+4>>2];if(!(y[b+12|0]?0:b)){v[c+12|0]=0;b=x[c+8>>2];if(!((a|0)!=(b|0)?y[b+12|0]:0)){v[b+12|0]=1;return}if(Hh(b)){b=x[b+8>>2]+4|0;break f}b=x[b+8>>2];break f}if(y[d+12|0]?0:d){break j}v[b+12|0]=1;v[c+12|0]=0;Fq(c);c=x[c+8>>2];d=x[c>>2]}a=x[c+8>>2];v[c+12|0]=y[a+12|0];v[a+12|0]=1;v[d+12|0]=1;Eq(a);return}b=x[b+8>>2]}c=x[b>>2];continue}}v[e+12|0]=1}}function Ala(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=ib-16|0;ib=g;i=Af(a,c);Pd(g,x[a+36>>2]);j=a;a:{if(!i){Pc(g,a+32|0,5);c=0;if(zb(x[x[g>>2]>>2],x[g+4>>2])){break a}}e=ib-192|0;ib=e;f=bm(e+80|0,x[a+36>>2]);x[27524]=0;a=Q(453,e- -64|0,27823)|0;c=x[27524];x[27524]=0;b:{c:{d:{e:{if((c|0)!=1){x[27524]=0;x[e>>2]=19988503;x[e+4>>2]=0;U(454,f|0,a|0,e|0);c=x[27524];x[27524]=0;if((c|0)==1){break e}Zb(a);if(!Rk(y[f|0])){break d}break b}c=P()|0;break c}c=P()|0;Zb(a);break c}v[e+63|0]=0;v[e+62|0]=0;x[27524]=0;a=Q(453,e+48|0,10032)|0;c=x[27524];x[27524]=0;f:{g:{h:{i:{if((c|0)!=1){x[27524]=0;U(493,f|0,e+63|0,a|0);c=x[27524];x[27524]=0;if((c|0)==1){break i}Zb(a);if(!y[e+63|0]){break b}Ff(e+63|0,50);x[27524]=0;a=Q(453,e+32|0,13184)|0;c=x[27524];x[27524]=0;if((c|0)==1){break f}x[27524]=0;U(493,f|0,e+62|0,a|0);c=x[27524];x[27524]=0;if((c|0)==1){break g}Zb(a);a=x[b>>2];c=wj(a,x[b+4>>2]);h=y[e+63|0];if(c>>>0<h>>>0){a=hA(e,x[b+12>>2]);x[27524]=0;U(494,b|0,h|0,a|0);c=x[27524];x[27524]=0;if((c|0)==1){break h}tl(a);a=x[b>>2]}k=z[Dj(a,0)+28>>1];c=0;j:{while(1){a=c&255;if(a>>>0>=h>>>0){a=y[e+62|0];n=b,o=wj(x[b>>2],x[b+4>>2])>>>0>a>>>0?a:0,v[n+16|0]=o;break b}_e(Dj(x[b>>2],a),k);l=x[b>>2];x[27524]=0;R(495,e|0,c|0);m=x[27524];x[27524]=0;if((m|0)!=1){x[27524]=0;X(496,f|0,Dj(l,a)|0,e|0,d|0);a=x[27524];x[27524]=0;if((a|0)==1){break j}c=c+1|0;Zb(e);continue}break}c=P()|0;break c}c=P()|0;Zb(e);break c}c=P()|0;break c}c=P()|0;Zb(a);break c}c=P()|0;tl(a);break c}c=P()|0;Zb(a);break c}c=P()|0}rh(f);S(c|0);p()}rh(f);ib=e+192|0;c=i}af(j,c);ib=g+16|0}function uP(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=ib-80|0;ib=g;c=zv(g+48|0,x[a>>2]);b=pp(g+40|0,x[a+4>>2]);TU(g+56|0,z[c>>1],b);c=pp(g+32|0,x[a+8>>2]);b=z[g+56>>1];d=ib-16|0;ib=d;v[d+8|0]=y[g+58|0];i=g- -64|0;kP(i,b,d+8|0,c);ib=d+16|0;h=ib-16|0;ib=h;e=ib-16|0;ib=e;d=pP(z[i>>1]);f=y[i+2|0];c=Ke(2);b=Ke(f);f=Ke(f);c=d-(b>>>0<=c>>>0)|0;b=(((c|0)<0?c-399|0:c)|0)/400|0;c=D(b,-400)+c|0;b=x[Wb(e+8|0,((((Ke(y[i+3|0])+D(b,146097)|0)+((D(f+(f>>>0>2?-3:9)|0,153)+2>>>0)/5|0)+(c>>>2)|0)+D(c,365)|0)-((c>>>0)/100|0)|0)-719469|0)>>2];ib=e+16|0;b=x[Wb(h+8|0,b)>>2];ib=h+16|0;c=Wb(g+24|0,x[a+12>>2]);f=ib-16|0;ib=f;e=ib-16|0;ib=e;d=ib-16|0;ib=d;b=x[Wb(d+8|0,D(b,24))>>2];ib=d+16|0;x[e>>2]=b;b=x[Wb(e+8|0,x[c>>2]+x[e>>2]|0)>>2];ib=e+16|0;b=x[Wb(f+8|0,b)>>2];ib=f+16|0;c=Wb(g+16|0,x[a+16>>2]);f=ib-16|0;ib=f;e=ib-16|0;ib=e;d=ib-16|0;ib=d;b=x[Wb(d+8|0,D(b,60))>>2];ib=d+16|0;x[e>>2]=b;b=x[Wb(e+8|0,x[c>>2]+x[e>>2]|0)>>2];ib=e+16|0;b=x[Wb(f+8|0,b)>>2];ib=f+16|0;e=Oe(g+8|0,a+24|0);f=ib-16|0;ib=f;a=ib-32|0;ib=a;h=ib-16|0;ib=h;d=ib-16|0;ib=d;j=d,k=qoa(b,b>>31,60,0),x[j>>2]=k;x[d+4>>2]=kb;b=Oe(d+8|0,d);c=x[b+4>>2];b=x[b>>2];ib=d+16|0;x[h+8>>2]=b;x[h+12>>2]=c;b=x[h+12>>2];x[a+8>>2]=x[h+8>>2];x[a+12>>2]=b;ib=h+16|0;d=x[a+8>>2];c=x[a+12>>2];b=x[e+4>>2];x[a>>2]=x[e>>2];x[a+4>>2]=b;c=x[a+4>>2]+c|0;b=x[a>>2];d=d+b|0;x[a+16>>2]=d;x[a+20>>2]=b>>>0>d>>>0?c+1|0:c;b=Oe(a+24|0,a+16|0);c=x[b+4>>2];b=x[b>>2];ib=a+32|0;a=Qz(f+8|0,b,c);c=x[a+4>>2];b=x[a>>2];ib=f+16|0;a=ib-16|0;ib=a;x[a+8>>2]=b;x[a+12>>2]=c;b=tt(g+72|0,a+8|0);ib=a+16|0;ib=g+80|0;kb=x[b+4>>2];return x[b>>2]}function v1(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;a=ib-624|0;ib=a;x[a+608>>2]=c;x[a+616>>2]=b;x[a+16>>2]=1186;h=xe(a+200|0,a+208|0,a+16|0);b=a+192|0;ed(b,e);x[27524]=0;i=T(1164,b|0)|0;b=x[27524];x[27524]=0;a:{b:{c:{d:{e:{f:{g:{if((b|0)!=1){v[a+191|0]=0;b=x[e+4>>2];x[27524]=0;b=qa(1194,a+616|0,c|0,d|0,a+192|0,b|0,f|0,a+191|0,i|0,h|0,a+196|0,a+608|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break d}if(!b){break e}b=y[14653]|y[14654]<<8|(y[14655]<<16|y[14656]<<24);v[a+183|0]=b;v[a+184|0]=b>>>8;v[a+185|0]=b>>>16;v[a+186|0]=b>>>24;b=y[14650]|y[14651]<<8|(y[14652]<<16|y[14653]<<24);x[a+176>>2]=y[14646]|y[14647]<<8|(y[14648]<<16|y[14649]<<24);x[a+180>>2]=b;x[27524]=0;X(1176,i|0,a+176|0,a+186|0,a+128|0);b=x[27524];x[27524]=0;if((b|0)==1){break g}x[a+4>>2]=1151;d=xe(a+8|0,0,a+4|0);e=a+16|0;b=x[a+196>>2];c=b-x[h>>2]|0;if((c|0)<393){break f}cf(d,Gd((c>>2)+2|0));e=x[d>>2];if(e){break f}x[27524]=0;Z(1152);b=x[27524];x[27524]=0;if((b|0)==1){break c}break a}c=P()|0;break b}c=P()|0;break b}if(y[a+191|0]){v[e|0]=45;e=e+1|0}c=x[h>>2];while(1){if(b>>>0<=c>>>0){v[e|0]=0;x[a>>2]=g;if((yH(a+16|0,a)|0)!=1){x[27524]=0;Y(1188,7948);b=x[27524];x[27524]=0;if((b|0)!=1){break a}break c}Uc(d)}else{b=a+128|0;j=e,k=y[(a+176|0)+(Sw(b,b+40|0,x[c>>2])-b>>2)|0],v[j|0]=k;e=e+1|0;c=c+4|0;b=x[a+196>>2];continue}break}}x[27524]=0;b=Q(1170,a+616|0,a+608|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break d}if(b){x[f>>2]=x[f>>2]|2}b=x[a+616>>2];_b(a+192|0);Uc(h);ib=a+624|0;return b|0}c=P()|0;break b}c=P()|0;Uc(d)}_b(a+192|0);Uc(h);S(c|0);p()}p()}function C1(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;a=ib-288|0;ib=a;x[a+272>>2]=c;x[a+280>>2]=b;x[a+16>>2]=1186;h=xe(a+152|0,a+160|0,a+16|0);b=a+144|0;ed(b,e);x[27524]=0;i=T(19,b|0)|0;b=x[27524];x[27524]=0;a:{b:{c:{d:{e:{f:{g:{if((b|0)!=1){v[a+143|0]=0;b=x[e+4>>2];x[27524]=0;b=qa(1187,a+280|0,c|0,d|0,a+144|0,b|0,f|0,a+143|0,i|0,h|0,a+148|0,a+260|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break d}if(!b){break e}b=y[14653]|y[14654]<<8|(y[14655]<<16|y[14656]<<24);v[a+135|0]=b;v[a+136|0]=b>>>8;v[a+137|0]=b>>>16;v[a+138|0]=b>>>24;b=y[14650]|y[14651]<<8|(y[14652]<<16|y[14653]<<24);x[a+128>>2]=y[14646]|y[14647]<<8|(y[14648]<<16|y[14649]<<24);x[a+132>>2]=b;x[27524]=0;X(1162,i|0,a+128|0,a+138|0,a+118|0);b=x[27524];x[27524]=0;if((b|0)==1){break g}x[a+4>>2]=1151;d=xe(a+8|0,0,a+4|0);e=a+16|0;b=x[a+148>>2];c=b-x[h>>2]|0;if((c|0)<99){break f}cf(d,Gd(c+2|0));e=x[d>>2];if(e){break f}x[27524]=0;Z(1152);b=x[27524];x[27524]=0;if((b|0)==1){break c}break a}c=P()|0;break b}c=P()|0;break b}if(y[a+143|0]){v[e|0]=45;e=e+1|0}c=x[h>>2];while(1){if(b>>>0<=c>>>0){v[e|0]=0;x[a>>2]=g;if((yH(a+16|0,a)|0)!=1){x[27524]=0;Y(1188,7948);b=x[27524];x[27524]=0;if((b|0)!=1){break a}break c}Uc(d)}else{b=a+118|0;j=e,k=y[((Bi(b,nW(b),c)-a|0)+a|0)+10|0],v[j|0]=k;e=e+1|0;c=c+1|0;b=x[a+148>>2];continue}break}}x[27524]=0;b=Q(1154,a+280|0,a+272|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break d}if(b){x[f>>2]=x[f>>2]|2}b=x[a+280>>2];_b(a+144|0);Uc(h);ib=a+288|0;return b|0}c=P()|0;break b}c=P()|0;Uc(d)}_b(a+144|0);Uc(h);S(c|0);p()}p()}function Ty(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=ib-16|0;ib=e;i=AO(b,c);a:{if(!x[b+656>>2]|!(v[i+6|0]&1)){break a}f=x[i>>2];j=a+1074312|0;Ab(e+8|0,j,31);g=zb(x[x[e+8>>2]>>2],x[e+12>>2]);d=Cv(x[b+656>>2],c);if(pc(x[d>>2],x[d+4>>2])){break a}g=f+(g^1)|0;Ab(e+8|0,j,31);f=y[d+12|0];b:{c:{if(!zb(x[x[e+8>>2]>>2],x[e+12>>2])){d:{if(!(f&2)){break d}h=y[d+14|0];k=!(x[a+480180>>2]&1048580)+z[Bb(x[d>>2],h)>>1]|0;if(!(y[b+89|0]&8)|(!(f&4)|(h|0)!=y[d+16|0])){f=l}else{Ab(e+8|0,j,70);f=zb(x[x[e+8>>2]>>2],x[e+12>>2])}if(f|(g|0)!=(k|0)){break d}g=z[Bb(x[d>>2],y[d+13|0])>>1]}if(!(!(y[d+12|0]&4)|y[b+89|0]&8)){a=x[d>>2];if((z[Bb(a,y[d+16|0])>>1]+1|0)!=(g|0)){break b}g=z[Bb(a,y[d+15|0])>>1];Ab(e+8|0,j,93);if(!zb(x[x[e+8>>2]>>2],x[e+12>>2])|(c|0)!=1|x[b+88>>2]&2048){break b}v[i+6|0]=y[i+6|0]&254;break b}k=1;f=z[Fj(x[d+4>>2])>>1];if(g>>>0>f>>>0){break c}break b}e:{f:{if(!(!(f&4)|y[b+669|0]&8)){if(z[i+4>>1]==65535){break f}Ab(e+8|0,j,97);if(zb(x[x[e+8>>2]>>2],x[e+12>>2])){break f}f=y[d+12|0]}if(f&2){h=x[d>>2];f=z[Bb(h,y[d+13|0])>>1];h=z[Bb(h,y[d+14|0])>>1]+1|0;break e}f=z[Fj(x[d+4>>2])>>1];k=g>>>0>f>>>0;h=f;break e}h=x[d>>2];f=z[Bb(h,y[d+15|0])>>1];h=z[Bb(h,y[d+16|0])>>1]+1|0}f=g>>>0<h>>>0?g:f}g:{if(!k|c){break g}g=x[a+480180>>2];c=x[b+88>>2];if(!(!(g&16777248)&(!(c&2048)|(g|0)==16384))){c=c|4096;x[b+88>>2]=c}if(y[Fj(x[d+4>>2])+2|0]|!(z[b+786>>1]|x[a+480180>>2]&16777248)){break g}x[b+696>>2]=0;x[b+720>>2]=0;x[b+680>>2]=0;x[b+88>>2]=c|4096}g=f}Ab(e+8|0,j,31);m=i,n=zb(x[x[e+8>>2]>>2],x[e+12>>2])+g|0,x[m>>2]=n}ib=e+16|0}function pt(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=ib-144|0;ib=f;a:{b:{c:{d:{e:{f:{g:{h:{if(!c){break h}h=x[c+4>>2];if(!h&A[c>>2]>=A[b+4>>2]|h){break h}a=ba(8)|0;x[27524]=0;b=Q(27,a|0,21631)|0;c=x[27524];x[27524]=0;if((c|0)!=1){break g}b=P()|0;ca(a|0);break a}if(!x[b>>2]){a=ba(8)|0;x[27524]=0;b=T(821,a|0)|0;c=x[27524];x[27524]=0;if((c|0)!=1){break f}b=P()|0;ca(a|0);break a}d=ib-16|0;ib=d;h=x[b+4>>2];lg(d+8|0,x[b>>2],h);g=f+120|0;tE(g,x[d+8>>2],x[d+12>>2]);x[g+12>>2]=0;ib=d+16|0;i:{j:{if(a&2){b=cn(f+96|0,g);x[27524]=0;b=T(822,b|0)|0;e=x[27524];x[27524]=0;d=1;if((e|0)==1){break i}if((b|0)==1){break j}d=cn(f+72|0,g);x[27524]=0;e=T(823,d|0)|0;i=x[27524];x[27524]=0;d=1;if((i|0)==1){break e}k=(e|0)==1;if(k){break j}d=cn(f+48|0,g);x[27524]=0;i=Q(824,d|0,c|0)|0;j=x[27524];x[27524]=0;d=1;if((j|0)==1){break d}l=(i|0)==1;if(l){break j}d=cn(f+24|0,g);x[27524]=0;j=Q(825,d|0,c|0)|0;m=x[27524];x[27524]=0;d=1;if((m|0)==1){break c}if((j|0)==1){break j}b=(b|0)==-1?-1:0;b=k?b:(e|0)==-1?-1:b;e=(j|0)==-1?-1:l?b:(i|0)==-1?-1:b}k:{if(!(a&1)){break k}b=31568;while(1){if((b|0)==32108){break k}a=x[b>>2];if(a){d=cn(f,g);x[27524]=0;a=Q(a|0,d|0,c|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break b}d=1;if((a|0)==1){break j}e=(a|0)==-1?-1:e}b=b+12|0;continue}}a=h;if(c){d=0;if((e|0)!=-1){break j}d=Ec(x[c>>2],x[c+4>>2])>>>0>a>>>0?-1:0;break j}d=0;if((e|0)!=-1){break j}d=a>>>0>2047?1:-1}ib=f+144|0;return d}b=P()|0;break a}ha(b|0,108488,25);p()}ha(b|0,108384,25);p()}b=P()|0;break a}b=P()|0;break a}b=P()|0;break a}b=P()|0}S(b|0);p()}function Zga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0;g=ib-48|0;ib=g;o=x[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;h=e+(g+24|0)|0;e=a+e|0;x[h+4>>2]=x[e+44>>2];x[h+8>>2]=x[e+48>>2];b=b+1|0;continue}break}h=x[a+40>>2];k=x[a+36>>2];b=x[a+4>>2];x[g+16>>2]=x[a>>2];x[g+20>>2]=b;p=x[a+32>>2];q=x[a+28>>2];r=x[a+72>>2];b=x[a+68>>2];s=b;t=b>>31;b=x[a+64>>2];u=b;v=b>>31;b=x[a+60>>2];y=b;z=b>>31;A=x[a+8>>2];B=x[a+12>>2];while(1){if(d){b=x[g+16>>2];l=b>>>18|0;j=((((x[g+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+o|0;b=0;e=0;while(1){if((e|0)!=2){i=j+(e<<1)|0;f=w[i>>1];x[(g+8|0)+(e<<2)>>2]=f+((D(l,w[i+4>>1]-f|0)|0)/16384|0);e=e+1|0;continue}break}while(1){if((b|0)!=2){l=(g+8|0)+(b<<2)|0;f=x[l>>2];e=(g+24|0)+(b<<3)|0;j=x[e+8>>2];i=x[e+4>>2];x[e+8>>2]=i;n=f<<8;f=n;f=qoa(y,z,f,f>>31);m=kb;C=e;e=Vb(i,-16777216,16776704);i=qoa(u,v,e,e>>31);f=i+f|0;e=kb+m|0;e=f>>>0<i>>>0?e+1|0:e;m=f;f=Vb(j,-16777216,16776704);j=qoa(s,t,f,f>>31);f=m+j|0;e=kb+e|0;e=f>>>0<j>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Vc(f,e,24);x[C+4>>2]=e-(r&n);x[l>>2]=(e|0)/256;b=b+1|0;continue}break}k=k+q|0;x[c>>2]=x[c>>2]+D(x[g+8>>2],k>>12);h=h+p|0;x[c+4>>2]=x[c+4>>2]+D(x[g+12>>2],h>>12);Pb(g+16|0,A,B);c=c+8|0;d=d-1|0;continue}break}b=x[g+20>>2];x[a>>2]=x[g+16>>2];x[a+4>>2]=b;x[a+40>>2]=h;x[a+20>>2]=k>>12;x[a+36>>2]=k;x[a+24>>2]=h>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}ib=g+48|0}function _ga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0,B=0,C=0;g=ib-48|0;ib=g;o=x[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;h=e+(g+24|0)|0;e=a+e|0;x[h+4>>2]=x[e+44>>2];x[h+8>>2]=x[e+48>>2];b=b+1|0;continue}break}h=x[a+40>>2];k=x[a+36>>2];b=x[a+4>>2];x[g+16>>2]=x[a>>2];x[g+20>>2]=b;p=x[a+32>>2];q=x[a+28>>2];r=x[a+72>>2];b=x[a+68>>2];s=b;t=b>>31;b=x[a+64>>2];u=b;w=b>>31;b=x[a+60>>2];y=b;z=b>>31;A=x[a+8>>2];B=x[a+12>>2];while(1){if(d){b=x[g+16>>2];l=b>>>10&4194048;j=(((x[g+20>>2]&2147483647)<<1|b>>>31)&-2)+o|0;b=0;e=0;while(1){if((e|0)!=2){i=e+j|0;f=v[i|0];x[(g+8|0)+(e<<2)>>2]=((D(l,v[i+2|0]-f|0)|0)/16384|0)+(f<<8);e=e+1|0;continue}break}while(1){if((b|0)!=2){l=(g+8|0)+(b<<2)|0;f=x[l>>2];e=(g+24|0)+(b<<3)|0;j=x[e+8>>2];i=x[e+4>>2];x[e+8>>2]=i;n=f<<8;f=n;f=qoa(y,z,f,f>>31);m=kb;C=e;e=Vb(i,-16777216,16776704);i=qoa(u,w,e,e>>31);f=i+f|0;e=kb+m|0;e=f>>>0<i>>>0?e+1|0:e;m=f;f=Vb(j,-16777216,16776704);j=qoa(s,t,f,f>>31);f=m+j|0;e=kb+e|0;e=f>>>0<j>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Vc(f,e,24);x[C+4>>2]=e-(r&n);x[l>>2]=(e|0)/256;b=b+1|0;continue}break}k=k+q|0;x[c>>2]=x[c>>2]+D(x[g+8>>2],k>>12);h=h+p|0;x[c+4>>2]=x[c+4>>2]+D(x[g+12>>2],h>>12);Pb(g+16|0,A,B);c=c+8|0;d=d-1|0;continue}break}b=x[g+20>>2];x[a>>2]=x[g+16>>2];x[a+4>>2]=b;x[a+40>>2]=h;x[a+20>>2]=k>>12;x[a+36>>2]=k;x[a+24>>2]=h>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}ib=g+48|0}function nha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0;g=ib-48|0;ib=g;p=x[a+16>>2];m=ag(1,2);b=kb;q=b;Pb(a,m,b);b=0;while(1){if((b|0)!=2){e=b<<3;h=e+(g+24|0)|0;e=a+e|0;x[h+4>>2]=x[e+44>>2];x[h+8>>2]=x[e+48>>2];b=b+1|0;continue}break}h=x[a+40>>2];i=x[a+36>>2];b=x[a+4>>2];x[g+16>>2]=x[a>>2];x[g+20>>2]=b;r=x[a+32>>2];s=x[a+28>>2];t=x[a+72>>2];b=x[a+68>>2];u=b;v=b>>31;b=x[a+64>>2];y=b;z=b>>31;b=x[a+60>>2];A=b;B=b>>31;C=x[a+8>>2];E=x[a+12>>2];while(1){if(d){d=d-1|0;f=((((x[g+20>>2]&2147483647)<<1|x[g+16>>2]>>>31)&2147483646)<<1)+p|0;b=0;e=0;while(1){if((e|0)!=2){x[(g+8|0)+(e<<2)>>2]=w[f+(e<<1)>>1];e=e+1|0;continue}break}while(1){if((b|0)!=2){n=(g+8|0)+(b<<2)|0;f=x[n>>2];e=(g+24|0)+(b<<3)|0;k=x[e+8>>2];j=x[e+4>>2];x[e+8>>2]=j;o=f<<8;f=o;f=qoa(A,B,f,f>>31);l=kb;F=e;e=Vb(j,-16777216,16776704);j=qoa(y,z,e,e>>31);f=j+f|0;e=kb+l|0;e=f>>>0<j>>>0?e+1|0:e;l=f;f=Vb(k,-16777216,16776704);k=qoa(u,v,f,f>>31);f=l+k|0;e=kb+e|0;e=f>>>0<k>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Vc(f,e,24);x[F+4>>2]=e-(t&o);x[n>>2]=(e|0)/256;b=b+1|0;continue}break}i=i+s|0;x[c>>2]=x[c>>2]+D(x[g+8>>2],i>>12);h=h+r|0;x[c+4>>2]=x[c+4>>2]+D(x[g+12>>2],h>>12);Pb(g+16|0,C,E);c=c+8|0;continue}break}b=x[g+20>>2];x[a>>2]=x[g+16>>2];x[a+4>>2]=b;x[a+40>>2]=h;x[a+20>>2]=i>>12;x[a+36>>2]=i;x[a+24>>2]=h>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}sg(a,m,q);ib=g+48|0}function i1(a,b,c,d,e,f,g,h,i,j,k,l,m,n,o){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,w=0,z=0,A=0,B=0,C=0;x[c>>2]=a;w=d&512;z=h<<2;while(1){if((u|0)==4){if(Eb(n)>>>0>1){f=ke(n);e=ib-16|0;ib=e;x[e+8>>2]=f;f=x[Pe(e+8|0)>>2];ib=e+16|0;B=c,C=ji(f,Zk(n),x[c>>2]),x[B>>2]=C}d=d&176;if((d|0)!=16){if((d|0)==32){a=x[c>>2]}x[b>>2]=a}}else{a:{b:{switch(v[i+u|0]){case 0:x[b>>2]=x[c>>2];break a;case 1:x[b>>2]=x[c>>2];h=os(g,32);p=x[c>>2];x[c>>2]=p+4;x[p>>2]=h;break a;case 3:if(Qe(n)){break a}h=x[Hi(n,0)>>2];p=x[c>>2];x[c>>2]=p+4;x[p>>2]=h;break a;case 2:if(Qe(m)|!w){break a}B=c,C=ji(ke(m),Zk(m),x[c>>2]),x[B>>2]=C;break a;case 4:break b;default:break a}}A=x[c>>2];e=e+z|0;h=e;while(1){c:{if(f>>>0<=h>>>0){break c}if(!$k(g,64,x[h>>2])){break c}h=h+4|0;continue}break}if((o|0)>0){p=x[c>>2];q=o;while(1){if(!(!q|e>>>0>=h>>>0)){h=h-4|0;s=x[h>>2];r=p+4|0;x[c>>2]=r;x[p>>2]=s;q=q-1|0;p=r;continue}break}d:{if(!q){s=0;break d}s=os(g,48);p=x[c>>2]}while(1){r=p+4|0;if((q|0)>0){x[p>>2]=s;q=q-1|0;p=r;continue}break}x[c>>2]=r;x[p>>2]=j}e:{if((e|0)==(h|0)){p=os(g,48);q=x[c>>2];h=q+4|0;x[c>>2]=h;x[q>>2]=p;break e}if(Qe(l)){s=-1}else{s=v[ng(l,0)|0]}q=0;t=0;while(1){if((e|0)!=(h|0)){r=x[c>>2];f:{if((q|0)!=(s|0)){p=r;r=q;break f}p=r+4|0;x[c>>2]=p;x[r>>2]=k;r=0;t=t+1|0;if(Eb(l)>>>0<=t>>>0){s=q;break f}s=-1;if(y[ng(l,t)|0]==127){break f}s=v[ng(l,t)|0]}h=h-4|0;q=x[h>>2];x[c>>2]=p+4;x[p>>2]=q;q=r+1|0;continue}break}h=x[c>>2]}hs(A,h)}u=u+1|0;continue}break}}function Nga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0;g=ib-48|0;ib=g;m=x[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;f=e+(g+24|0)|0;e=a+e|0;x[f+4>>2]=x[e+44>>2];x[f+8>>2]=x[e+48>>2];b=b+1|0;continue}break}n=x[a+24>>2];o=x[a+20>>2];b=x[a+4>>2];x[g+16>>2]=x[a>>2];x[g+20>>2]=b;p=x[a+72>>2];b=x[a+68>>2];q=b;r=b>>31;b=x[a+64>>2];s=b;t=b>>31;b=x[a+60>>2];u=b;v=b>>31;y=x[a+8>>2];z=x[a+12>>2];while(1){if(d){e=x[g+16>>2];k=((((x[g+20>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+m|0;b=e>>>21&2040;i=w[b+39734>>1];h=w[b+39732>>1];l=w[b+39730>>1];j=w[b+39728>>1];b=0;e=0;while(1){if((e|0)!=2){f=k+(e<<1)|0;x[(g+8|0)+(e<<2)>>2]=(((D(w[f>>1],l)+D(w[f-4>>1],j)|0)+D(h,w[f+4>>1])|0)+D(i,w[f+8>>1])|0)/16384;e=e+1|0;continue}break}while(1){if((b|0)!=2){k=(g+8|0)+(b<<2)|0;f=x[k>>2];e=(g+24|0)+(b<<3)|0;i=x[e+8>>2];h=x[e+4>>2];x[e+8>>2]=h;l=f<<8;f=l;f=qoa(u,v,f,f>>31);j=kb;A=e;e=Vb(h,-16777216,16776704);h=qoa(s,t,e,e>>31);f=h+f|0;e=kb+j|0;e=f>>>0<h>>>0?e+1|0:e;j=f;f=Vb(i,-16777216,16776704);i=qoa(q,r,f,f>>31);f=j+i|0;e=kb+e|0;e=f>>>0<i>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Vc(f,e,24);x[A+4>>2]=e-(l&p);x[k>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[g+8>>2],o);x[c+4>>2]=x[c+4>>2]+D(x[g+12>>2],n);Pb(g+16|0,y,z);c=c+8|0;d=d-1|0;continue}break}b=x[g+20>>2];x[a>>2]=x[g+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}ib=g+48|0}function ZM(a){var b=E(0),c=0,d=0,e=0,f=0,g=E(0),h=0,i=0,k=0,l=E(0),m=0,n=E(0);c=ib-16|0;ib=c;e=a+4208|0;b=ly(B[Bb(e,2)>>2]);f=x[a+16>>2]+24620|0;B[c+12>>2]=b/E(A[f>>2]);x[c+8>>2]=1056964608;b=Mp(E(B[rm(c+12|0,c+8|0)>>2]*E(6.2831854820251465)));b=E(M(E(E(E(b+b)+E(3))/E(5))));B[a+4236>>2]=b;B[a+4240>>2]=M(E(E(1)-E(b*b)));b=E(E(B[Bb(e,1)>>2]*E(29))+E(2));a:{if(b<E(4294967296)&b>=E(0)){i=~~b>>>0;break a}i=0}v[a+4272|0]=i;d=i;while(1){if(d&255){k=k+1|0;d=(d&254)>>>1|0;continue}break}v[a+4273|0]=k;l=ze(E(10),E(E(E(B[e>>2]*E(60))+E(-60))/E(20)));m=c,n=E(ly(B[Bb(e,3)>>2])/E(A[f>>2])),B[m+12>>2]=n;x[c+8>>2]=1056964608;g=B[rm(c+12|0,c+8|0)>>2];m=c,n=E(ly(B[Bb(e,4)>>2])/E(A[f>>2])),B[m+12>>2]=n;x[c+8>>2]=1056964608;b=E(E(B[rm(c+12|0,c+8|0)>>2]*E(6.2831854820251465))*E(.5));f=ib-16|0;ib=f;e=(q(b),j(2));d=e&2147483647;b:{if(d>>>0<=1061752794){if(d>>>0<964689920){break b}b=Jn(+b,0);break b}if(d>>>0<=1081824209){h=+b;if(d>>>0<=1075235811){b=Jn(((e|0)<0?1.5707963267948966:-1.5707963267948966)+h,1);break b}b=Jn(((e|0)<0?3.141592653589793:-3.141592653589793)+h,0);break b}if(d>>>0<=1088565717){h=+b;if(d>>>0<=1085271519){b=Jn(((e|0)<0?4.71238898038469:-4.71238898038469)+h,1);break b}b=Jn(((e|0)<0?6.283185307179586:-6.283185307179586)+h,0);break b}if(d>>>0>=2139095040){b=E(b-b);break b}d=ux(b,f+8|0);b=Jn(C[f+8>>3],d&1)}ib=f+16|0;b=E(E(E(1)-b)/E(b+E(1)));B[a+4268>>2]=b;g=Mp(E(g*E(6.2831854820251465)));B[a+4264>>2]=-g;B[a+4260>>2]=E(E(l*E(M(E(E(1)-E(g*g)))))*E(M(E(E(1)-E(b*b)))))*B[(i<<2)+45632>>2];ib=c+16|0}function FL(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=ib-48|0;ib=c;g=Nb(a);a:{b:{c:{d=b+36|0;a=x[d>>2];f=x[b+40>>2];d:{if(Mb(a,f)){sc(c+40|0);break d}x[27524]=0;R(1034,c+24|0,b|0);a=x[27524];x[27524]=0;if((a|0)==1){break b}x[27524]=0;a=T(1018,c+24|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break c}x[c+40>>2]=a;nf(c+24|0);f=x[b+40>>2];a=x[b+36>>2]}if(!Mb(a,f)){d=x[c+40>>2];a=x[d>>2]}f=x[d+4>>2];x[27524]=0;R(185,g|0,Xi(a,f)|0);a=x[27524];x[27524]=0;e:{if((a|0)!=1){i=c,j=Cb(x[d>>2]),x[i+16>>2]=j;f=Cb(x[d+4>>2]);f:{g:{h:{i:{j:{k:{while(1){a=x[c+16>>2];if(!Mb(a,f)){el(c+40|0);ib=c+48|0;return}d=y[a+16|0];e=x[x[b+24>>2]+484360>>2];x[27524]=0;d=Dj(e,d);R(1035,c|0,d|0);e=x[27524];x[27524]=0;if((e|0)!=1){x[27524]=0;R(1021,c+24|0,c|0);e=x[27524];x[27524]=0;if((e|0)==1){break k}x[27524]=0;R(187,g|0,c+24|0);e=x[27524];x[27524]=0;if((e|0)==1){break j}wb(c+24|0);xb(c);l:{if(!Qe(Jx(x[g+4>>2]))){break l}e=y[a+12|0];x[27524]=0;e=Q(315,d|0,e|0)|0;h=x[27524];x[27524]=0;if((h|0)==1){break f}if(!e){break l}e=x[b+24>>2];h=x[e+1298404>>2];a=z[bc(x[d>>2],x[a+12>>2])>>1];d=x[e+484344>>2];x[27524]=0;R(1028,c|0,Xb(d,a)|0);a=x[27524];x[27524]=0;if((a|0)==1){break h}x[27524]=0;X(239,c+24|0,0,h|0,c|0);a=x[27524];x[27524]=0;if((a|0)==1){break g}a=c+24|0;Ac(Jx(x[g+4>>2]),a);wb(a);wb(c)}xy(c+16|0);continue}break}a=P()|0;break e}a=P()|0;break i}a=P()|0;wb(c+24|0)}xb(c);break e}a=P()|0;break e}a=P()|0;wb(c);break e}a=P()|0;break e}a=P()|0}el(c+40|0);break a}a=P()|0;nf(c+24|0);break a}a=P()|0}ve(g);S(a|0);p()}function oha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0;g=ib-48|0;ib=g;p=x[a+16>>2];m=ag(1,2);b=kb;q=b;Pb(a,m,b);b=0;while(1){if((b|0)!=2){e=b<<3;h=e+(g+24|0)|0;e=a+e|0;x[h+4>>2]=x[e+44>>2];x[h+8>>2]=x[e+48>>2];b=b+1|0;continue}break}h=x[a+40>>2];i=x[a+36>>2];b=x[a+4>>2];x[g+16>>2]=x[a>>2];x[g+20>>2]=b;r=x[a+32>>2];s=x[a+28>>2];t=x[a+72>>2];b=x[a+68>>2];u=b;w=b>>31;b=x[a+64>>2];y=b;z=b>>31;b=x[a+60>>2];A=b;B=b>>31;C=x[a+8>>2];E=x[a+12>>2];while(1){if(d){d=d-1|0;f=(((x[g+20>>2]&2147483647)<<1|x[g+16>>2]>>>31)&-2)+p|0;b=0;e=0;while(1){if((e|0)!=2){x[(g+8|0)+(e<<2)>>2]=v[e+f|0]<<8;e=e+1|0;continue}break}while(1){if((b|0)!=2){n=(g+8|0)+(b<<2)|0;f=x[n>>2];e=(g+24|0)+(b<<3)|0;k=x[e+8>>2];j=x[e+4>>2];x[e+8>>2]=j;o=f<<8;f=o;f=qoa(A,B,f,f>>31);l=kb;F=e;e=Vb(j,-16777216,16776704);j=qoa(y,z,e,e>>31);f=j+f|0;e=kb+l|0;e=f>>>0<j>>>0?e+1|0:e;l=f;f=Vb(k,-16777216,16776704);k=qoa(u,w,f,f>>31);f=l+k|0;e=kb+e|0;e=f>>>0<k>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Vc(f,e,24);x[F+4>>2]=e-(t&o);x[n>>2]=(e|0)/256;b=b+1|0;continue}break}i=i+s|0;x[c>>2]=x[c>>2]+D(x[g+8>>2],i>>12);h=h+r|0;x[c+4>>2]=x[c+4>>2]+D(x[g+12>>2],h>>12);Pb(g+16|0,C,E);c=c+8|0;continue}break}b=x[g+20>>2];x[a>>2]=x[g+16>>2];x[a+4>>2]=b;x[a+40>>2]=h;x[a+20>>2]=i>>12;x[a+36>>2]=i;x[a+24>>2]=h>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}sg(a,m,q);ib=g+48|0}function pia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=ib-16|0;ib=f;k=f,l=Ej(b),x[k>>2]=l;e=ib-16|0;ib=e;h=a;c=Td(a);a:{if(c){g=gc(h);while(1){a=c;c=a+14|0;if(Yt(b,c)){g=a;c=x[a>>2];if(c){continue}break a}if(!Yt(c,b)){break a}g=a+4|0;c=x[a+4>>2];if(c){continue}break}break a}a=gc(h);g=a}x[e+12>>2]=a;b=x[g>>2];if(!b){i=ib-16|0;ib=i;a=gc(h);j=sh(e,mc(48),th(i+8|0,a));a=x[j>>2];b=x[f>>2];c=y[b+4|0]|y[b+5|0]<<8|(y[b+6|0]<<16|y[b+7|0]<<24);d=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);v[a+14|0]=d;v[a+15|0]=d>>>8;v[a+16|0]=d>>>16;v[a+17|0]=d>>>24;v[a+18|0]=c;v[a+19|0]=c>>>8;v[a+20|0]=c>>>16;v[a+21|0]=c>>>24;c=y[b+28|0]|y[b+29|0]<<8|(y[b+30|0]<<16|y[b+31|0]<<24);d=y[b+24|0]|y[b+25|0]<<8|(y[b+26|0]<<16|y[b+27|0]<<24);v[a+38|0]=d;v[a+39|0]=d>>>8;v[a+40|0]=d>>>16;v[a+41|0]=d>>>24;v[a+42|0]=c;v[a+43|0]=c>>>8;v[a+44|0]=c>>>16;v[a+45|0]=c>>>24;c=y[b+20|0]|y[b+21|0]<<8|(y[b+22|0]<<16|y[b+23|0]<<24);d=y[b+16|0]|y[b+17|0]<<8|(y[b+18|0]<<16|y[b+19|0]<<24);v[a+30|0]=d;v[a+31|0]=d>>>8;v[a+32|0]=d>>>16;v[a+33|0]=d>>>24;v[a+34|0]=c;v[a+35|0]=c>>>8;v[a+36|0]=c>>>16;v[a+37|0]=c>>>24;c=y[b+12|0]|y[b+13|0]<<8|(y[b+14|0]<<16|y[b+15|0]<<24);b=y[b+8|0]|y[b+9|0]<<8|(y[b+10|0]<<16|y[b+11|0]<<24);v[a+22|0]=b;v[a+23|0]=b>>>8;v[a+24|0]=b>>>16;v[a+25|0]=b>>>24;v[a+26|0]=c;v[a+27|0]=c>>>8;v[a+28|0]=c>>>16;v[a+29|0]=c>>>24;w[a+46>>1]=0;k=gc(j),l=1,v[k+4|0]=l;ib=i+16|0;Tg(h,x[e+12>>2],g,x[e>>2]);b=ce(e);zk(e);d=1}Sg(f+8|0,x[Wb(e,b)>>2],d);ib=e+16|0;a=vo(x[f+8>>2]);ib=f+16|0;return a+32|0}function Qfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0;g=ib-16|0;ib=g;u=x[a+16>>2];v=qg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);p=x[a+128>>2];a:{if(!p){n=x[a+8>>2];s=x[a+12>>2];i=x[a>>2];e=x[a+4>>2];o=0;break a}b=x[a+12>>2];s=b;n=x[a+8>>2];q=rg(n,b,p);r=kb;k=x[a+76>>2];i=x[a>>2];e=x[a+4>>2];Zf(i,e,rf(n,b,d),kb);o=k>>>0<kb>>>0?d:0}h=a+112|0;f=x[a+48>>2];l=x[a+40>>2];m=x[a+36>>2];b=x[a+44>>2];x[g>>2]=i;x[g+4>>2]=e;b:while(1){c:{k=b;if(!d){break c}d=d-1|0;x[g+8>>2]=i;x[g+12>>2]=0;o=o-1|0;b=o;q=b?q:0;r=b?r:0;e=(e<<1)+u|0;b=p;while(1)if((b|0)<=0){Pb(h,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){Sd(h,w[e+(x[g+12>>2]<<1)>>1]/4<<16>>16);Rd(h,b);x[h>>2]=x[h>>2];x[h+4>>2]=0}i=x[a+72>>2];y=x[a+32>>2];m=x[a+28>>2]+m|0;b=x[a+60>>2];e=b;j=b>>31;t=pg(h,v)<<8;b=t;b=qoa(e,j,b,b>>31);z=kb;e=b;b=x[a+64>>2];j=b;A=b>>31;b=Vb(k,-16777216,16776704);j=qoa(j,A,b,b>>31);e=e+j|0;b=kb+z|0;b=e>>>0<j>>>0?b+1|0:b;j=e;e=x[a+68>>2];f=Vb(f,-16777216,16776704);e=qoa(e,e>>31,f,f>>31);f=j+e|0;b=kb+b|0;b=e>>>0>f>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Vc(f,b,24);f=(b|0)/256|0;x[c>>2]=D(m>>12,f)+x[c>>2];l=l+y|0;x[c+4>>2]=x[c+4>>2]+D(l>>12,f);Pb(g,n,s);b=b-(i&t)|0;c=c+8|0;i=x[g>>2];e=x[g+4>>2];f=k;continue b}else{Sd(h,w[e+(x[g+12>>2]<<1)>>1]/4<<16>>16);Rd(h,4);Pb(g+8|0,q,r);b=b-1|0;continue}}break}x[a>>2]=i;x[a+4>>2]=e;x[a+40>>2]=l;x[a+20>>2]=m>>12;x[a+36>>2]=m;x[a+48>>2]=f;x[a+44>>2]=k;x[a+24>>2]=l>>12;ib=g+16|0}function vga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0;h=ib-16|0;ib=h;a:{b:{c:{i=x[a+12>>2];j=x[a+8>>2];d:{if((i|0)<=1&j>>>0<=805306368|(i|0)<=0){if((i|0)>=-2&j>>>0>=3489660928|(i|0)>-2){break c}if((i|0)==-2&j>>>0>2147483647|(i|0)==-1){break d}break b}if((i|0)==1&j>>>0>2147483648|i>>>0>1){break b}}p=b+196648|0;break a}p=b+131112|0;break a}p=b+262184|0}q=x[a+16>>2];f=x[a+48>>2];k=x[a+40>>2];l=x[a+36>>2];b=x[a+44>>2];e=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=e;r=x[a+32>>2];s=x[a+28>>2];t=x[a+72>>2];e=x[a+68>>2];u=e;v=e>>31;e=x[a+64>>2];y=e;z=e>>31;e=x[a+60>>2];A=e;B=e>>31;while(1){e=b;if(d){b=Vb(e,-16777216,16776704);b=qoa(y,z,b,b>>31);m=kb;n=b;g=(x[h+12>>2]<<1)+q|0;b=(x[h+8>>2]>>>16&65520)+p|0;g=(((((((D(w[g-4>>1],w[b+2>>1])+D(w[g-6>>1],w[b>>1])|0)+D(w[g-2>>1],w[b+4>>1])|0)+D(w[g>>1],w[b+6>>1])|0)+D(w[g+2>>1],w[b+8>>1])|0)+D(w[g+4>>1],w[b+10>>1])|0)+D(w[g+6>>1],w[b+12>>1])|0)+D(w[g+8>>1],w[b+14>>1])|0)/32768<<8;b=g;b=qoa(b,b>>31,A,B);n=n+b|0;o=kb+m|0;o=b>>>0>n>>>0?o+1|0:o;b=Vb(f,-16777216,16776704);f=qoa(u,v,b,b>>31);m=f+n|0;b=kb+o|0;b=f>>>0>m>>>0?b+1|0:b;f=m+8388608|0;b=f>>>0<8388608?b+1|0:b;f=Vc(f,b,24);b=(f|0)/256|0;l=l+s|0;x[c>>2]=D(b,l>>12)+x[c>>2];k=k+r|0;x[c+4>>2]=x[c+4>>2]+D(b,k>>12);Pb(h+8|0,j,i);b=f-(g&t)|0;c=c+8|0;d=d-1|0;f=e;continue}break}b=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=b;x[a+40>>2]=k;x[a+20>>2]=l>>12;x[a+36>>2]=l;x[a+48>>2]=f;x[a+44>>2]=e;x[a+24>>2]=k>>12;ib=h+16|0}function Oga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0;g=ib-48|0;ib=g;m=x[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;f=e+(g+24|0)|0;e=a+e|0;x[f+4>>2]=x[e+44>>2];x[f+8>>2]=x[e+48>>2];b=b+1|0;continue}break}n=x[a+24>>2];o=x[a+20>>2];b=x[a+4>>2];x[g+16>>2]=x[a>>2];x[g+20>>2]=b;p=x[a+72>>2];b=x[a+68>>2];q=b;r=b>>31;b=x[a+64>>2];s=b;t=b>>31;b=x[a+60>>2];u=b;y=b>>31;z=x[a+8>>2];A=x[a+12>>2];while(1){if(d){e=x[g+16>>2];k=(((x[g+20>>2]&2147483647)<<1|e>>>31)&-2)+m|0;b=e>>>21&2040;i=w[b+39734>>1];h=w[b+39732>>1];l=w[b+39730>>1];j=w[b+39728>>1];b=0;e=0;while(1){if((e|0)!=2){f=e+k|0;x[(g+8|0)+(e<<2)>>2]=(((D(v[f|0],l)+D(v[f-2|0],j)|0)+D(h,v[f+2|0])|0)+D(i,v[f+4|0])<<8)/16384;e=e+1|0;continue}break}while(1){if((b|0)!=2){k=(g+8|0)+(b<<2)|0;f=x[k>>2];e=(g+24|0)+(b<<3)|0;i=x[e+8>>2];h=x[e+4>>2];x[e+8>>2]=h;l=f<<8;f=l;f=qoa(u,y,f,f>>31);j=kb;B=e;e=Vb(h,-16777216,16776704);h=qoa(s,t,e,e>>31);f=h+f|0;e=kb+j|0;e=f>>>0<h>>>0?e+1|0:e;j=f;f=Vb(i,-16777216,16776704);i=qoa(q,r,f,f>>31);f=j+i|0;e=kb+e|0;e=f>>>0<i>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Vc(f,e,24);x[B+4>>2]=e-(l&p);x[k>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[g+8>>2],o);x[c+4>>2]=x[c+4>>2]+D(x[g+12>>2],n);Pb(g+16|0,z,A);c=c+8|0;d=d-1|0;continue}break}b=x[g+20>>2];x[a>>2]=x[g+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}ib=g+48|0}function ph(a,b,c,d,e){var f=0,g=0,h=0;if(!b){c=ib-16|0;ib=c;a:{if((d|0)==189){v[a+3843|0]=e>>>7;v[a+3844|0]=e>>>6&1;break a}b=d&224;if(!b){if((d|0)!=260){break a}b=0;d=1;while(1){if((b|0)==6){break a}f=D(b>>>0<3?b:b+6|0,44)+a|0;g=f+148|0;f=f+16|0;h=d&e;b:{if(h){go(f,g);break b}go(f,0)}v[g+40|0]=!h;b=b+1|0;d=d<<1&510;continue}}if(b-160>>>0<=32){b=d&15;if(b>>>0>8){break a}a=D(d&256?b+9|0:b,44)+a|0;x[c+8>>2]=a+16;b=x[a+52>>2];x[c+12>>2]=b;g=b?2:1;c:{b=d&240;if((b|0)!=160){if((b|0)==192){break c}if((b|0)!=176){break a}f=e&3;h=e>>>2&7;b=0;d=(e&32)!=0;while(1){if((b|0)==(g|0)){break a}a=x[(c+8|0)+(b<<2)>>2];sR(x[a>>2],d);sR(x[a+4>>2],d);w[a+22>>1]=h;aA(a);uR(a);v[a+21|0]=f;aA(a);uR(a);b=b+1|0;continue}}b=0;while(1){if((b|0)==(g|0)){break a}a=x[(c+8|0)+(b<<2)>>2];w[a+20>>1]=z[a+20>>1]&768|e&255;aA(a);b=b+1|0;continue}}v[a+58|0]=(e&32)>>>5;v[a+57|0]=(e&16)>>>4;b=e>>>1&7;w[a+46>>1]=b?9-b|0:0;w[a+48>>1]=e&1;break a}if((b|0)!=224&b>>>0>=129|-4144960>>>d&1){break a}f=a;a=v[(d&31)+29008|0];a=(f+D(d&256?a+18|0:a,84)|0)+808|0;d:{switch(b-32>>>5|0){case 0:v[a+79|0]=e>>>7;v[a+80|0]=(e&64)>>>6;v[a+78|0]=(e&32)>>>5;v[a+77|0]=(e&16)>>>4;ho(a);w[a+14>>1]=z[((e&15)<<1)+29040>>1];break a;case 1:w[a+68>>1]=y[(e>>>6|0)+21616|0];tR(a);w[a+22>>1]=(e&63)<<2;break a;case 2:w[a+24>>1]=e>>>4;ho(a);w[a+26>>1]=e&15;ho(a);break a;case 3:b=e>>>4|0;w[a+28>>1]=b>>>0>=15?496:b<<4;w[a+30>>1]=e&15;ho(a);break a;case 6:break d;default:break a}}w[a+12>>1]=e&7}ib=c+16|0;return}lb[x[x[b>>2]>>2]](b,c,d,e)}function eZ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=ib-48|0;ib=f;g=Ci(b)^-1;a:{if(tc(x[d>>2],x[d+4>>2])>>>0<=g>>>0){nt(a);break a}Ci(b);if((y[c+4|0]|y[c+5|0]<<8)>>>0>=60){Yb(b,4)}j=f,k=Ci(b),x[j+44>>2]=k;Yb(b,4);h=Ci(b);i=Ci(b);if(!((h|0)>0&(i|0)>36)){nt(a);break a}if(Jq(Cd(x[e>>2],x[Bb(x[d>>2],g)>>2]),13061)){nt(a);break a}$v(f,b,i,h);d=hc(f+24|0,f);yb(f);b=x[d>>2];x[27524]=0;b=T(182,b|0)|0;e=x[27524];x[27524]=0;b:{if((e|0)==1){break b}c:{d:{if(!b){x[27524]=0;T(191,a|0)|0;a=x[27524];x[27524]=0;if((a|0)!=1){break d}break b}b=y[c+4|0]|y[c+5|0]<<8;if(b>>>0<=39){x[27524]=0;Q(192,d|0,8)|0;b=x[27524];x[27524]=0;if((b|0)==1){break b}b=y[c+4|0]|y[c+5|0]<<8}if((b&65535)>>>0<=59){x[27524]=0;Q(192,d|0,16)|0;b=x[27524];x[27524]=0;if((b|0)==1){break b}}x[27524]=0;T(193,d|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break b}e:{f:{b=y[c+4|0]|y[c+5|0]<<8;g:{if(b>>>0>=120){x[27524]=0;T(193,d|0)|0;c=x[27524];x[27524]=0;b=8;break g}h:{if(b>>>0>=100){x[27524]=0;Q(192,d|0,4)|0;b=x[27524];x[27524]=0;if((b|0)==1){break b}break h}if(b>>>0<62){break f}}x[27524]=0;T(193,d|0)|0;c=x[27524];x[27524]=0;b=4}if((c|0)==1){break b}x[27524]=0;Q(192,d|0,b|0)|0;break e}x[27524]=0;T(193,d|0)|0}b=x[27524];x[27524]=0;if((b|0)==1){break b}x[27524]=0;b=T(193,d|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break c}x[27524]=0;U(194,f|0,d|0,b|0);b=x[27524];x[27524]=0;if((b|0)==1){break c}j=hc(a,f),k=x[f+44>>2],x[j+20>>2]=k;yb(f)}yb(d);break a}}a=P()|0;yb(d);S(a|0);p()}ib=f+48|0}function $x(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=E(0);e=ib-48|0;ib=e;a:{b:{c:{d:{e:{switch(b-1|0){case 1:b=(c<<7)/100|0;d=x[a+24>>2];if((b|0)==x[d+24604>>2]){break d}a=e+8|0;rc(a,d+24604|0,40);x[e+8>>2]=b;Xy(d,a);break d;case 2:f=x[a+24>>2];d=f+24664|0;b=x[d+4>>2];x[e+24>>2]=x[d>>2];x[e+28>>2]=b;d=f+24656|0;b=x[d+4>>2];x[e+16>>2]=x[d>>2];x[e+20>>2]=b;b=x[f+24652>>2];x[e+8>>2]=x[f+24648>>2];x[e+12>>2]=b;d=ib-16|0;ib=d;b=3;f:{g:{h:{if(!c|(c|0)>7){break h}b=2;if((c|0)>2){break h}b=1;if((c|0)==2){break h}b=0;if((c|0)>0){break h}c=ba(8)|0;x[27524]=0;b=Q(55,d|0,10739)|0;a=x[27524];x[27524]=0;i:{if((a|0)!=1){lc(c,b);x[27524]=0;U(123,c|0,50060,962);a=x[27524];x[27524]=0;if((a|0)!=1){break g}a=P()|0;wb(b);break i}a=P()|0;ca(c|0)}S(a|0);p()}ib=d+16|0;break f}p()}v[e+8|0]=b;a=x[a+24>>2];if(!Sx(e+8|0,a+24648|0)){break d}Vy(a,e+8|0);break d;case 3:f=e+8|0;d=x[a+24>>2];rc(f,d+24604|0,40);b=ib-48|0;ib=b;j:{if((c|0)==-1){Os(f,x[mq(b+8|0)+32>>2]);go(f,x[mq(b+8|0)+36>>2]);break j}if((c|0)<=0){Os(f,0);go(f,0);break j}a=D(c,1e3);Os(f,a);go(f,a)}ib=b+48|0;if(x[d+24636>>2]==x[e+40>>2]&x[d+24640>>2]==x[e+44>>2]){break d}Xy(d,e+8|0);break d;default:d=ba(8)|0;x[27524]=0;c=Q(55,e+8|0,10323)|0;a=x[27524];x[27524]=0;if((a|0)==1){break c}lc(d,c);x[27524]=0;U(123,d|0,50060,962);a=x[27524];x[27524]=0;if((a|0)!=1){break a}b=P()|0;wb(c);break b;case 0:break e}}g=a,h=ze(E(10),E(E(E(c|0)*E(.0010000000474974513))*E(.5))),B[g+48>>2]=h}ib=e+48|0;return}b=P()|0;ca(d|0)}S(b|0)}p()}function m1(a,b,c,d,e,f,g,h,i,j,k,l,m,n,o){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,w=0,z=0,A=0,B=0,C=0;x[c>>2]=a;z=d&512;while(1){if((u|0)==4){if(Eb(n)>>>0>1){f=Bt(n);e=ib-16|0;ib=e;x[e+8>>2]=f;f=x[Ie(e+8|0)>>2];ib=e+16|0;B=c,C=FG(f,yt(n),x[c>>2]),x[B>>2]=C}d=d&176;if((d|0)!=16){if((d|0)==32){a=x[c>>2]}x[b>>2]=a}}else{a:{b:{switch(v[i+u|0]){case 0:x[b>>2]=x[c>>2];break a;case 1:x[b>>2]=x[c>>2];p=Jl(g,32);q=x[c>>2];x[c>>2]=q+1;v[q|0]=p;break a;case 3:if(Qe(n)){break a}p=y[ng(n,0)|0];q=x[c>>2];x[c>>2]=q+1;v[q|0]=p;break a;case 2:if(Qe(m)|!z){break a}B=c,C=FG(Bt(m),yt(m),x[c>>2]),x[B>>2]=C;break a;case 4:break b;default:break a}}p=x[g+8>>2];A=x[c>>2];e=e+h|0;r=e;while(1){c:{if(f>>>0<=r>>>0){break c}if(!Bh(p,64,v[r|0])){break c}r=r+1|0;continue}break}p=o;if((p|0)>0){while(1){if(!(!p|e>>>0>=r>>>0)){r=r-1|0;q=y[r|0];s=x[c>>2];x[c>>2]=s+1;v[s|0]=q;p=p-1|0;continue}break}if(p){q=Jl(g,48)}else{q=0}while(1){s=x[c>>2];x[c>>2]=s+1;if((p|0)>0){v[s|0]=q;p=p-1|0;continue}break}v[s|0]=j}d:{if((e|0)==(r|0)){p=Jl(g,48);q=x[c>>2];x[c>>2]=q+1;v[q|0]=p;break d}if(Qe(l)){q=-1}else{q=v[ng(l,0)|0]}p=0;t=0;while(1){if((e|0)==(r|0)){break d}e:{if((p|0)!=(q|0)){s=p;break e}q=x[c>>2];x[c>>2]=q+1;v[q|0]=k;s=0;t=t+1|0;if(Eb(l)>>>0<=t>>>0){q=p;break e}q=-1;if(y[ng(l,t)|0]==127){break e}q=v[ng(l,t)|0]}r=r-1|0;p=y[r|0];w=x[c>>2];x[c>>2]=w+1;v[w|0]=p;p=s+1|0;continue}}dm(A,x[c>>2])}u=u+1|0;continue}break}}function wga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0;h=ib-16|0;ib=h;a:{b:{c:{i=x[a+12>>2];k=x[a+8>>2];d:{if((i|0)<=1&k>>>0<=805306368|(i|0)<=0){if((i|0)>=-2&k>>>0>=3489660928|(i|0)>-2){break c}if((i|0)==-2&k>>>0>2147483647|(i|0)==-1){break d}break b}if((i|0)==1&k>>>0>2147483648|i>>>0>1){break b}}n=b+196648|0;break a}n=b+131112|0;break a}n=b+262184|0}o=x[a+16>>2];b=x[a+48>>2];l=x[a+40>>2];m=x[a+36>>2];e=x[a+44>>2];f=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=f;p=x[a+32>>2];q=x[a+28>>2];r=x[a+72>>2];f=x[a+68>>2];s=f;t=f>>31;f=x[a+64>>2];u=f;y=f>>31;f=x[a+60>>2];z=f;A=f>>31;while(1){f=e;if(d){e=Vb(f,-16777216,16776704);e=qoa(u,y,e,e>>31);g=kb;j=e;b=Vb(b,-16777216,16776704);e=qoa(s,t,b,b>>31);j=j+e|0;b=kb+g|0;b=e>>>0>j>>>0?b+1|0:b;g=x[h+12>>2]+o|0;e=(x[h+8>>2]>>>16&65520)+n|0;g=(((((((D(v[g-2|0],w[e+2>>1])+D(v[g-3|0],w[e>>1])|0)+D(v[g-1|0],w[e+4>>1])|0)+D(v[g|0],w[e+6>>1])|0)+D(v[g+1|0],w[e+8>>1])|0)+D(v[g+2|0],w[e+10>>1])|0)+D(v[g+3|0],w[e+12>>1])|0)+D(v[g+4|0],w[e+14>>1])<<8)/32768<<8;e=g;e=qoa(e,e>>31,z,A);j=e+j|0;b=kb+b|0;b=e>>>0>j>>>0?b+1|0:b;e=j+8388608|0;b=e>>>0<8388608?b+1|0:b;e=Vc(e,b,24);b=(e|0)/256|0;m=m+q|0;x[c>>2]=D(b,m>>12)+x[c>>2];l=l+p|0;x[c+4>>2]=x[c+4>>2]+D(l>>12,b);Pb(h+8|0,k,i);e=e-(g&r)|0;c=c+8|0;d=d-1|0;b=f;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+40>>2]=l;x[a+20>>2]=m>>12;x[a+36>>2]=m;x[a+48>>2]=b;x[a+44>>2]=f;x[a+24>>2]=l>>12;ib=h+16|0}function ifa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,z=0,A=0,B=0;f=ib+-64|0;ib=f;a:{b:{c:{d:{e:{f:{g:{if(!a){break g}l=e<<2;if(l>>>0>d>>>0){break g}t=l-4|0;o=D(b,e);u=o-8|0;h:while(1){b=x[c+8>>2];h=x[c>>2];x[27524]=0;b=W(160,h|0,b|0,l|0)|0;h=x[27524];x[27524]=0;if((h|0)==1){break b}if(!(b&n>>>0<o>>>0)){break g}x[27524]=0;U(194,f+16|0,c|0,d|0);b=x[27524];x[27524]=0;if((b|0)==1){break c}b=f+16|0;h=hc(f+40|0,b);yb(b);x[27524]=0;R(564,b|0,h|0);b=x[27524];x[27524]=0;if((b|0)==1){break e}z=Le(f+16|0);q=x[f+16>>2];A=q-4|0;k=0;while(1){if((e|0)==(k|0)){Rc(f+16|0);yb(h);n=(q-l<<1)+n|0;continue h}x[27524]=0;g=T(557,h|0)|0;b=x[27524];x[27524]=0;if((b|0)!=1){x[27524]=0;b=T(210,h|0)|0;j=x[27524];x[27524]=0;if((j|0)==1){break f}x[f+8>>2]=b;re(f+8|0,0,89);x[27524]=0;Q(192,h|0,1)|0;b=x[27524];x[27524]=0;if((b|0)==1){break f}j=k+n|0;b=e+k<<2;i:while(1){j:{if(j>>>0>u>>>0){break j}m=0;if(b>>>0>A>>>0){break j}while(1)if((m|0)==8){b=b+t|0;continue i}else{r=x[f+8>>2];i=y[b+z|0];s=m&1;i=s?i>>>4|0:i&15;x[f+8>>2]=r+v[(i&7)+30280|0];B=g;g=w[(r<<1)+30288>>1];g=(((0-(i&1)&g>>2)+(g>>3)|0)+(i<<30>>31&g>>1)|0)+(g&i<<29>>31)|0;x[f+12>>2]=B+(i>>>0<8?g:0-g|0);re(f+8|0,0,88);re(f+12|0,-32768,32767);g=x[f+12>>2];w[(j<<1)+a>>1]=g;m=m+1|0;j=e+j|0;b=b+s|0;continue}}break}k=k+1|0;continue}break}break}break f}yb(c);ib=f- -64|0;return}b=P()|0;Rc(f+16|0);break d}b=P()|0}yb(h);break a}b=P()|0;break a}b=P()|0}yb(c);S(b|0);p()}function Rfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0;g=ib-16|0;ib=g;u=x[a+16>>2];w=qg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);p=x[a+128>>2];a:{if(!p){n=x[a+8>>2];s=x[a+12>>2];i=x[a>>2];e=x[a+4>>2];o=0;break a}b=x[a+12>>2];s=b;n=x[a+8>>2];q=rg(n,b,p);r=kb;k=x[a+76>>2];i=x[a>>2];e=x[a+4>>2];Zf(i,e,rf(n,b,d),kb);o=k>>>0<kb>>>0?d:0}h=a+112|0;f=x[a+48>>2];l=x[a+40>>2];m=x[a+36>>2];b=x[a+44>>2];x[g>>2]=i;x[g+4>>2]=e;b:while(1){c:{k=b;if(!d){break c}d=d-1|0;x[g+8>>2]=i;x[g+12>>2]=0;o=o-1|0;b=o;q=b?q:0;r=b?r:0;e=e+u|0;b=p;while(1)if((b|0)<=0){Pb(h,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){Sd(h,v[e+x[g+12>>2]|0]<<6);Rd(h,b);x[h>>2]=x[h>>2];x[h+4>>2]=0}i=x[a+72>>2];y=x[a+32>>2];m=x[a+28>>2]+m|0;b=x[a+60>>2];e=b;j=b>>31;t=pg(h,w)<<8;b=t;b=qoa(e,j,b,b>>31);z=kb;e=b;b=x[a+64>>2];j=b;A=b>>31;b=Vb(k,-16777216,16776704);j=qoa(j,A,b,b>>31);e=e+j|0;b=kb+z|0;b=e>>>0<j>>>0?b+1|0:b;j=e;e=x[a+68>>2];f=Vb(f,-16777216,16776704);e=qoa(e,e>>31,f,f>>31);f=j+e|0;b=kb+b|0;b=e>>>0>f>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Vc(f,b,24);f=(b|0)/256|0;x[c>>2]=D(m>>12,f)+x[c>>2];l=l+y|0;x[c+4>>2]=x[c+4>>2]+D(l>>12,f);Pb(g,n,s);b=b-(i&t)|0;c=c+8|0;i=x[g>>2];e=x[g+4>>2];f=k;continue b}else{Sd(h,v[e+x[g+12>>2]|0]<<6);Rd(h,4);Pb(g+8|0,q,r);b=b-1|0;continue}}break}x[a>>2]=i;x[a+4>>2]=e;x[a+40>>2]=l;x[a+20>>2]=m>>12;x[a+36>>2]=m;x[a+48>>2]=f;x[a+44>>2]=k;x[a+24>>2]=l>>12;ib=g+16|0}function fY(){var a=0,b=0,c=0;if(!y[483248]){a=ib-16|0;ib=a;Ts(482896);x[120736]=-1;x[120734]=482952;x[120732]=109288;x[120724]=93684;v[482948]=0;b=a+8|0;qs(b,482896);c=x[x[120724]+8>>2];x[27524]=0;R(c|0,482896,b|0);b=x[27524];x[27524]=0;a:{if((b|0)!=1){_b(a+8|0);ib=a+16|0;break a}b=P()|0;_b(a+8|0);Pn(482896);S(b|0);p()}Xs(482224);x[120556]=93816;x[120554]=93796;x[120555]=0;On(482224,482896);NH(482960,109432,483008);dx(482392,482960);NH(483016,109136,483064);dx(482560,483016);dx(482728,x[(x[x[120640]-12>>2]+482560|0)+24>>2]);MH(x[x[120554]-12>>2]+482216|0);SI(x[x[120640]-12>>2]+482560|0);MH(x[x[120640]-12>>2]+482560|0);a=ib-16|0;ib=a;aI(483072);x[120780]=-1;x[120778]=483128;x[120776]=109288;x[120768]=94076;v[483124]=0;b=a+8|0;qs(b,483072);c=x[x[120768]+8>>2];x[27524]=0;R(c|0,483072,b|0);b=x[27524];x[27524]=0;b:{if((b|0)!=1){_b(a+8|0);ib=a+16|0;break b}b=P()|0;_b(a+8|0);ts(483072);S(b|0);p()}JH(482312);x[120578]=94208;x[120576]=94188;x[120577]=0;On(482312,483072);LH(483136,109432,483184);cx(482476,483136);LH(483192,109136,483240);cx(482644,483192);cx(482812,x[(x[x[120661]-12>>2]+482644|0)+24>>2]);KH(x[x[120576]-12>>2]+482304|0);SI(x[x[120661]-12>>2]+482644|0);KH(x[x[120661]-12>>2]+482644|0);v[483248]=1}a=ib-16|0;ib=a;c:{if(cb(a+12|0,a+8|0)|0){break c}b=Gd((x[a+12>>2]<<2)+4|0);x[120814]=b;if(!b){break c}b=Gd(x[a+8>>2]);if(b){c=x[120814];x[c+(x[a+12>>2]<<2)>>2]=0;if(!(bb(c|0,b|0)|0)){break c}}x[120814]=0}ib=a+16|0;x[120008]=42;x[120026]=483348}function fea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ib-112|0;ib=c;Gj(c+88|0,b,1413829443);x[27524]=0;b=T(182,x[c+88>>2])|0;d=x[27524];x[27524]=0;a:{b:{c:{if((d|0)==1){break c}if(!b){x[27524]=0;U(777,c- -64|0,a+140|0,1413894985);a=x[27524];x[27524]=0;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{if((a|0)!=1){x[27524]=0;a=Q(854,c- -64|0,13604)|0;b=x[27524];x[27524]=0;if((b|0)==1){break e}b=28591;if(a){b=Kb(c+48|0);x[27524]=0;a=T(206,c- -64|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break m}x[27524]=0;U(272,c- -64|0,b|0,a|0);a=x[27524];x[27524]=0;if((a|0)==1){break m}x[27524]=0;d=Q(54,c+16|0,b|0)|0;a=x[27524];x[27524]=0;if((a|0)==1){break l}x[27524]=0;Y(855,c|0);a=x[27524];x[27524]=0;if((a|0)==1){break k}x[27524]=0;U(856,c+32|0,d|0,c|0);a=x[27524];x[27524]=0;if((a|0)==1){break j}a=c+32|0;e=Ac(b,a);wb(a);wb(c);wb(d);x[27524]=0;U(11,a|0,2,e|0);a=x[27524];x[27524]=0;if((a|0)==1){break h}x[27524]=0;a=T(748,c+32|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break g}xb(c+32|0);wb(e);b=a-1>>>0<19398657?1252:28591}yb(c- -64|0);break a}a=P()|0;break b}a=P()|0;break f}a=P()|0;break f}a=P()|0;break i}a=P()|0;wb(c)}wb(d);break f}a=P()|0;break f}a=P()|0;xb(c+32|0)}wb(b);break d}a=P()|0}yb(c- -64|0);break b}x[27524]=0;a=W(160,x[c+88>>2],x[c+96>>2],2)|0;b=x[27524];x[27524]=0;if((b|0)==1){break c}b=28591;if(!a){break a}x[27524]=0;b=T(198,c+88|0)|0;a=x[27524];x[27524]=0;if((a|0)!=1){break a}a=P()|0;break b}a=P()|0}yb(c+88|0);S(a|0);p()}yb(c+88|0);ib=c+112|0;return b|0}function bha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0;g=ib-48|0;ib=g;m=x[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;f=e+(g+24|0)|0;e=a+e|0;x[f+4>>2]=x[e+44>>2];x[f+8>>2]=x[e+48>>2];b=b+1|0;continue}break}n=x[a+24>>2];o=x[a+20>>2];b=x[a+4>>2];x[g+16>>2]=x[a>>2];x[g+20>>2]=b;p=x[a+72>>2];b=x[a+68>>2];q=b;r=b>>31;b=x[a+64>>2];s=b;t=b>>31;b=x[a+60>>2];u=b;v=b>>31;y=x[a+8>>2];z=x[a+12>>2];while(1){if(d){b=x[g+16>>2];j=b>>>18|0;i=((((x[g+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+m|0;b=0;e=0;while(1){if((e|0)!=2){h=i+(e<<1)|0;f=w[h>>1];x[(g+8|0)+(e<<2)>>2]=f+((D(j,w[h+4>>1]-f|0)|0)/16384|0);e=e+1|0;continue}break}while(1){if((b|0)!=2){j=(g+8|0)+(b<<2)|0;f=x[j>>2];e=(g+24|0)+(b<<3)|0;i=x[e+8>>2];h=x[e+4>>2];x[e+8>>2]=h;l=f<<8;f=l;f=qoa(u,v,f,f>>31);k=kb;A=e;e=Vb(h,-16777216,16776704);h=qoa(s,t,e,e>>31);f=h+f|0;e=kb+k|0;e=f>>>0<h>>>0?e+1|0:e;k=f;f=Vb(i,-16777216,16776704);i=qoa(q,r,f,f>>31);f=k+i|0;e=kb+e|0;e=f>>>0<i>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Vc(f,e,24);x[A+4>>2]=e-(p&l);x[j>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[g+8>>2],o);x[c+4>>2]=x[c+4>>2]+D(n,x[g+12>>2]);Pb(g+16|0,y,z);c=c+8|0;d=d-1|0;continue}break}b=x[g+20>>2];x[a>>2]=x[g+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}ib=g+48|0}function H_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;g=a;a=ib-2096|0;ib=a;it(a+48|0);a:{b:{c:{if(Wo(x[(x[x[c>>2]-12>>2]+c|0)+16>>2])){c=ba(8)|0;x[27524]=0;a=Q(55,a+32|0,10391)|0;b=x[27524];x[27524]=0;if((b|0)!=1){lc(c,a);x[27524]=0;U(123,c|0,50060,962);b=x[27524];x[27524]=0;if((b|0)!=1){break b}b=P()|0;wb(a);break c}b=P()|0;ca(c|0);break c}f=jJ(c);if(f){b=gJ(c)}else{b=0}x[a+24>>2]=b;x[a+28>>2]=0;b=2048;d:{while(1){e:{if(!b){break e}if(!iJ(x[(x[x[c>>2]-12>>2]+c|0)+16>>2])){break e}d=ri(c,(a+48|0)+e|0,b);d=x[(x[x[d>>2]-12>>2]+d|0)+16>>2];if(Wo(d)){c=ba(8)|0;x[27524]=0;a=Q(55,a+32|0,10391)|0;b=x[27524];x[27524]=0;if((b|0)==1){break d}lc(c,a);x[27524]=0;U(123,c|0,50060,962);b=x[27524];x[27524]=0;if((b|0)!=1){break b}b=P()|0;wb(a);break c}f:{if(KD(d)){break f}if(!jh(d)){break f}c=ba(8)|0;x[27524]=0;a=Q(55,a+32|0,10391)|0;b=x[27524];x[27524]=0;if((b|0)!=1){lc(c,a);x[27524]=0;U(123,c|0,50060,962);b=x[27524];x[27524]=0;if((b|0)!=1){break b}b=P()|0;wb(a);break c}b=P()|0;ca(c|0);break c}d=x[c+4>>2];b=b-d|0;e=d+e|0;continue}break}b=dc(a+16|0,a+48|0,e);c=x[b+4>>2];x[a+8>>2]=x[b>>2];x[a+12>>2]=c;b=pt(g,a+8|0,f?a+24|0:0);if(b+1>>>0>=3){c=ba(8)|0;x[27524]=0;a=Q(55,a+32|0,8005)|0;b=x[27524];x[27524]=0;if((b|0)!=1){lc(c,a);x[27524]=0;U(123,c|0,50060,962);b=x[27524];x[27524]=0;if((b|0)!=1){break b}b=P()|0;wb(a);break c}b=P()|0;ca(c|0);break c}ib=a+2096|0;break a}b=P()|0;ca(c|0)}S(b|0)}p()}return b|0}function cha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0;g=ib-48|0;ib=g;m=x[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;f=e+(g+24|0)|0;e=a+e|0;x[f+4>>2]=x[e+44>>2];x[f+8>>2]=x[e+48>>2];b=b+1|0;continue}break}n=x[a+24>>2];o=x[a+20>>2];b=x[a+4>>2];x[g+16>>2]=x[a>>2];x[g+20>>2]=b;p=x[a+72>>2];b=x[a+68>>2];q=b;r=b>>31;b=x[a+64>>2];s=b;t=b>>31;b=x[a+60>>2];u=b;w=b>>31;y=x[a+8>>2];z=x[a+12>>2];while(1){if(d){b=x[g+16>>2];j=b>>>10&4194048;i=(((x[g+20>>2]&2147483647)<<1|b>>>31)&-2)+m|0;b=0;e=0;while(1){if((e|0)!=2){h=e+i|0;f=v[h|0];x[(g+8|0)+(e<<2)>>2]=((D(j,v[h+2|0]-f|0)|0)/16384|0)+(f<<8);e=e+1|0;continue}break}while(1){if((b|0)!=2){j=(g+8|0)+(b<<2)|0;f=x[j>>2];e=(g+24|0)+(b<<3)|0;i=x[e+8>>2];h=x[e+4>>2];x[e+8>>2]=h;l=f<<8;f=l;f=qoa(u,w,f,f>>31);k=kb;A=e;e=Vb(h,-16777216,16776704);h=qoa(s,t,e,e>>31);f=h+f|0;e=kb+k|0;e=f>>>0<h>>>0?e+1|0:e;k=f;f=Vb(i,-16777216,16776704);i=qoa(q,r,f,f>>31);f=k+i|0;e=kb+e|0;e=f>>>0<i>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Vc(f,e,24);x[A+4>>2]=e-(p&l);x[j>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[g+8>>2],o);x[c+4>>2]=x[c+4>>2]+D(n,x[g+12>>2]);Pb(g+16|0,y,z);c=c+8|0;d=d-1|0;continue}break}b=x[g+20>>2];x[a>>2]=x[g+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}ib=g+48|0}function rha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0;g=ib-48|0;ib=g;n=x[a+16>>2];k=ag(1,2);b=kb;o=b;Pb(a,k,b);b=0;while(1){if((b|0)!=2){e=b<<3;f=e+(g+24|0)|0;e=a+e|0;x[f+4>>2]=x[e+44>>2];x[f+8>>2]=x[e+48>>2];b=b+1|0;continue}break}p=x[a+24>>2];q=x[a+20>>2];b=x[a+4>>2];x[g+16>>2]=x[a>>2];x[g+20>>2]=b;r=x[a+72>>2];b=x[a+68>>2];s=b;t=b>>31;b=x[a+64>>2];u=b;v=b>>31;b=x[a+60>>2];y=b;z=b>>31;A=x[a+8>>2];B=x[a+12>>2];while(1){if(d){d=d-1|0;f=((((x[g+20>>2]&2147483647)<<1|x[g+16>>2]>>>31)&2147483646)<<1)+n|0;b=0;e=0;while(1){if((e|0)!=2){x[(g+8|0)+(e<<2)>>2]=w[f+(e<<1)>>1];e=e+1|0;continue}break}while(1){if((b|0)!=2){l=(g+8|0)+(b<<2)|0;f=x[l>>2];e=(g+24|0)+(b<<3)|0;i=x[e+8>>2];h=x[e+4>>2];x[e+8>>2]=h;m=f<<8;f=m;f=qoa(y,z,f,f>>31);j=kb;C=e;e=Vb(h,-16777216,16776704);h=qoa(u,v,e,e>>31);f=h+f|0;e=kb+j|0;e=f>>>0<h>>>0?e+1|0:e;j=f;f=Vb(i,-16777216,16776704);i=qoa(s,t,f,f>>31);f=j+i|0;e=kb+e|0;e=f>>>0<i>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Vc(f,e,24);x[C+4>>2]=e-(r&m);x[l>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[g+8>>2],q);x[c+4>>2]=x[c+4>>2]+D(p,x[g+12>>2]);Pb(g+16|0,A,B);c=c+8|0;continue}break}b=x[g+20>>2];x[a>>2]=x[g+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}sg(a,k,o);ib=g+48|0}function yj(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{if(!_d(x[a>>2],x[a+20>>2])){break a}Jk(a);b:{switch(an(z[a+34>>1])-1|0){case 1:e=ib+-64|0;ib=e;h=x[a+20>>2];c=x[a>>2];d=Md(z[a+34>>1]);f=h+(D(c,d)<<1)|0;while(1){c:{d:{if((g|0)!=16){i=D(d,g);j=D(d,g^-1);c=0;break d}g=f+(d<<5)|0;c=z[a+34>>1];if(c&2){i=x[a+8>>2];f=x[a+4>>2];Ab(e+32|0,b+1074312|0,33);QR(e+40|0,g,h+(D(d,f)<<1)|0,i-f|0,d,(c&4)>>>2|0,zb(x[x[e+32>>2]>>2],x[e+36>>2]));c=z[a+34>>1]}if(c&8){f=x[a+16>>2];a=x[a+12>>2];Ab(e+32|0,b+1074312|0,33);QR(e+8|0,g+(d<<7)|0,h+(D(a,d)<<1)|0,f-a|0,d,(c&16)>>>4|0,zb(x[x[e+32>>2]>>2],x[e+36>>2]))}ib=e- -64|0;break c}while(1){if((c|0)!=(d|0)){w[f+(c+i<<1)>>1]=z[f+(c-d<<1)>>1];w[h+(c+j<<1)>>1]=z[h+(c<<1)>>1];c=c+1|0;continue}break}g=g+1|0;continue}break};return;case 0:break b;default:break a}}e=ib+-64|0;ib=e;h=x[a+20>>2];c=x[a>>2];d=Md(z[a+34>>1]);f=h+D(c,d)|0;while(1){e:{f:{if((g|0)!=16){i=D(d,g);j=D(d,g^-1);c=0;break f}g=f+(d<<4)|0;c=z[a+34>>1];if(c&2){i=x[a+8>>2];f=x[a+4>>2];Ab(e+32|0,b+1074312|0,33);PR(e+40|0,g,h+D(d,f)|0,i-f|0,d,(c&4)>>>2|0,zb(x[x[e+32>>2]>>2],x[e+36>>2]));c=z[a+34>>1]}if(c&8){f=x[a+16>>2];a=x[a+12>>2];Ab(e+32|0,b+1074312|0,33);PR(e+8|0,g+(d<<6)|0,h+D(a,d)|0,f-a|0,d,(c&16)>>>4|0,zb(x[x[e+32>>2]>>2],x[e+36>>2]))}ib=e- -64|0;break e}while(1){if((c|0)!=(d|0)){v[f+(c+i|0)|0]=y[f+(c-d|0)|0];v[h+(c+j|0)|0]=y[c+h|0];c=c+1|0;continue}break}g=g+1|0;continue}break}}}function k2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=ib-384|0;ib=a;x[a+368>>2]=c;x[a+376>>2]=b;Rw(a+216|0,d,a+240|0,a+236|0,a+232|0);d=Kb(a+200|0);b=ad(d);x[27524]=0;R(60,d|0,b|0);b=x[27524];x[27524]=0;a:{b:{c:{if((b|0)!=1){c=Qc(d,0);x[a+196>>2]=c;x[a+28>>2]=a+32;x[a+24>>2]=0;v[a+23|0]=1;v[a+22|0]=69;h=x[a+232>>2];i=x[a+236>>2];while(1){d:{x[27524]=0;b=Q(1169,a+376|0,a+368|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break d}if(!b){break c}g=x[a+196>>2];b=Eb(d);if((g|0)==(b+c|0)){x[27524]=0;R(60,d|0,b<<1);c=x[27524];x[27524]=0;if((c|0)==1){break b}c=ad(d);x[27524]=0;R(60,d|0,c|0);c=x[27524];x[27524]=0;if((c|0)==1){break b}c=Qc(d,0);x[a+196>>2]=b+c}x[27524]=0;b=T(1171,x[a+376>>2])|0;g=x[27524];x[27524]=0;if((g|0)==1){break d}if(Qw(b,a+23|0,a+22|0,c,a+196|0,i,h,a+216|0,a+32|0,a+28|0,a+24|0,a+240|0)){break c}x[27524]=0;T(1173,a+376|0)|0;b=x[27524];x[27524]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Eb(a+216|0)|!y[a+23|0]){break e}b=x[a+28>>2];if((b-(a+32|0)|0)>159){break e}x[a+28>>2]=b+4;x[b>>2]=x[a+24>>2]}aH(a,c,x[a+196>>2],e);b=x[a>>2];c=x[a+4>>2];h=x[a+12>>2];x[f+8>>2]=x[a+8>>2];x[f+12>>2]=h;x[f>>2]=b;x[f+4>>2]=c;Of(a+216|0,a+32|0,x[a+28>>2],e);x[27524]=0;b=Q(1170,a+376|0,a+368|0)|0;c=x[27524];x[27524]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+376>>2];wb(d);wb(a+216|0);ib=a+384|0;break a}}b=P()|0;wb(d);wb(a+216|0);S(b|0);p()}return b|0}function t2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=ib-288|0;ib=a;x[a+272>>2]=c;x[a+280>>2]=b;Vw(a+224|0,d,a+240|0,a+239|0,a+238|0);d=Kb(a+208|0);b=ad(d);x[27524]=0;R(60,d|0,b|0);b=x[27524];x[27524]=0;a:{b:{c:{if((b|0)!=1){c=Qc(d,0);x[a+204>>2]=c;x[a+28>>2]=a+32;x[a+24>>2]=0;v[a+23|0]=1;v[a+22|0]=69;h=v[a+238|0];i=v[a+239|0];while(1){d:{x[27524]=0;b=Q(1153,a+280|0,a+272|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break d}if(!b){break c}g=x[a+204>>2];b=Eb(d);if((g|0)==(b+c|0)){x[27524]=0;R(60,d|0,b<<1);c=x[27524];x[27524]=0;if((c|0)==1){break b}c=ad(d);x[27524]=0;R(60,d|0,c|0);c=x[27524];x[27524]=0;if((c|0)==1){break b}c=Qc(d,0);x[a+204>>2]=b+c}x[27524]=0;b=T(1155,x[a+280>>2])|0;g=x[27524];x[27524]=0;if((g|0)==1){break d}if(Uw(b,a+23|0,a+22|0,c,a+204|0,i,h,a+224|0,a+32|0,a+28|0,a+24|0,a+240|0)){break c}x[27524]=0;T(1157,a+280|0)|0;b=x[27524];x[27524]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Eb(a+224|0)|!y[a+23|0]){break e}b=x[a+28>>2];if((b-(a+32|0)|0)>159){break e}x[a+28>>2]=b+4;x[b>>2]=x[a+24>>2]}aH(a,c,x[a+204>>2],e);b=x[a>>2];c=x[a+4>>2];h=x[a+12>>2];x[f+8>>2]=x[a+8>>2];x[f+12>>2]=h;x[f>>2]=b;x[f+4>>2]=c;Of(a+224|0,a+32|0,x[a+28>>2],e);x[27524]=0;b=Q(1154,a+280|0,a+272|0)|0;c=x[27524];x[27524]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+280>>2];wb(d);wb(a+224|0);ib=a+288|0;break a}}b=P()|0;wb(d);wb(a+224|0);S(b|0);p()}return b|0}function DY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=ib-32|0;ib=f;yc(c);while(1){a:{if(!Ob(x[c>>2],x[c+8>>2],3)){break a}d=f+24|0;fr(d,c);i=Lc(d);h=Ze(d);d=y[f+24|0];if(d>>>0>=A[a+12>>2]){break a}g=hd(x[a>>2],x[x[a+48>>2]+12>>2],d,b);d=y[i|0];if(d>>>0<=126){if(!(d|y[h|0])){v[g|0]=254;continue}v[g|0]=d+1;if(y[h|0]==255){continue}v[g+2|0]=1;v[g+4|0]=y[h|0];continue}b:{switch(d-127|0){case 1:v[g+1|0]=y[h|0]+1;continue;case 0:continue;default:break b}}e=v[h|0];v[f+23|0]=e;h=0;j=y[i|0];d=j&127;if(d>>>0<=23){h=y[d+26208|0]}c:{d:{e:{f:{g:{switch(d-2|0){case 0:case 8:case 9:if((e|0)>=0){break f}d=0-e&15;break e;case 1:v[f+16|0]=64;e=y[Ub(f+23|0,f+16|0)|0];if(y[g+2|0]>1){break d}v[g+4|0]=e;v[g+2|0]=1;continue;case 2:d=3;if((e|0)>=0){break c}d=0-e&127;break e;case 15:if(!e){continue}d=0-e|-16;if((e|0)<0){break e}d=e<<4|15;break e;case 16:case 20:if(!e){continue}d=(e|0)>=0;if(!d){e=0-e&15;v[f+23|0]=e;j=y[i|0]}d=d?3:2;e=((j|0)==22?-32:-16)|e;v[f+23|0]=e;break c;case 17:d=e&15|-48;break e;case 18:d=e&15|-64;break e;case 21:break g;default:break d}}d=164;if((e|0)==100){break e}x[f+16>>2]=e- -64;x[f+12>>2]=0;x[f+8>>2]=128;e=x[Oj(f+16|0,f+12|0,f+8|0)>>2];if(!y[g+3|0]){break d}h:{switch(y[g+2|0]){case 0:case 2:break h;default:continue}}v[g+2|0]=2;v[g+4|0]=(e&254)>>>1;continue}d=e<<4}e=d;v[f+23|0]=e}d=h;if(!d){continue}}v[g+5|0]=e;v[g+3|0]=d;continue}break}ib=f+32|0}function sha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0,B=0,C=0;g=ib-48|0;ib=g;n=x[a+16>>2];k=ag(1,2);b=kb;o=b;Pb(a,k,b);b=0;while(1){if((b|0)!=2){e=b<<3;f=e+(g+24|0)|0;e=a+e|0;x[f+4>>2]=x[e+44>>2];x[f+8>>2]=x[e+48>>2];b=b+1|0;continue}break}p=x[a+24>>2];q=x[a+20>>2];b=x[a+4>>2];x[g+16>>2]=x[a>>2];x[g+20>>2]=b;r=x[a+72>>2];b=x[a+68>>2];s=b;t=b>>31;b=x[a+64>>2];u=b;w=b>>31;b=x[a+60>>2];y=b;z=b>>31;A=x[a+8>>2];B=x[a+12>>2];while(1){if(d){d=d-1|0;f=(((x[g+20>>2]&2147483647)<<1|x[g+16>>2]>>>31)&-2)+n|0;b=0;e=0;while(1){if((e|0)!=2){x[(g+8|0)+(e<<2)>>2]=v[e+f|0]<<8;e=e+1|0;continue}break}while(1){if((b|0)!=2){l=(g+8|0)+(b<<2)|0;f=x[l>>2];e=(g+24|0)+(b<<3)|0;i=x[e+8>>2];h=x[e+4>>2];x[e+8>>2]=h;m=f<<8;f=m;f=qoa(y,z,f,f>>31);j=kb;C=e;e=Vb(h,-16777216,16776704);h=qoa(u,w,e,e>>31);f=h+f|0;e=kb+j|0;e=f>>>0<h>>>0?e+1|0:e;j=f;f=Vb(i,-16777216,16776704);i=qoa(s,t,f,f>>31);f=j+i|0;e=kb+e|0;e=f>>>0<i>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Vc(f,e,24);x[C+4>>2]=e-(r&m);x[l>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[g+8>>2],q);x[c+4>>2]=x[c+4>>2]+D(p,x[g+12>>2]);Pb(g+16|0,A,B);c=c+8|0;continue}break}b=x[g+20>>2];x[a>>2]=x[g+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}sg(a,k,o);ib=g+48|0}function S1(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;m=b;i=ib-432|0;ib=i;x[i+424>>2]=37;x[i+428>>2]=0;l=es(i+424|1,13874,x[c+4>>2]);x[i+380>>2]=i+384;a=Fd();a:{if(l){b=x[c+8>>2];j=i- -64|0;x[j>>2]=g;x[j+4>>2]=h;x[i+56>>2]=e;x[i+60>>2]=f;x[i+48>>2]=b;j=hh(i+384|0,30,a,i+424|0,i+48|0);break a}x[i+80>>2]=e;x[i+84>>2]=f;x[i+88>>2]=g;x[i+92>>2]=h;j=hh(i+384|0,30,a,i+424|0,i+80|0)}x[i+128>>2]=1151;k=xe(i+368|0,0,i+128|0);b=i+384|0;a=b;b:{c:{d:{e:{if((j|0)>=30){a=Fd();f:{if(l){j=x[c+8>>2];x[i+16>>2]=g;x[i+20>>2]=h;x[i+8>>2]=e;x[i+12>>2]=f;x[i>>2]=j;j=dj(i+380|0,a,i+424|0,i);break f}x[i+32>>2]=e;x[i+36>>2]=f;x[i+40>>2]=g;x[i+44>>2]=h;j=dj(i+380|0,a,i+424|0,i+32|0)}if((j|0)==-1){x[27524]=0;Z(1152);a=x[27524];x[27524]=0;if((a|0)==1){break d}break e}a=x[i+380>>2];cf(k,a)}f=a+j|0;g=ej(a,f,c);x[i+116>>2]=1151;e=xe(i+120|0,0,i+116|0);g:{h:{if((i+384|0)==(a|0)){j=i+128|0;break h}j=Gd(j<<3);if(!j){x[27524]=0;Z(1152);a=x[27524];x[27524]=0;if((a|0)!=1){break e}a=P()|0;break g}cf(e,j);b=a}a=i+104|0;ed(a,c);x[27524]=0;ia(1184,b|0,g|0,f|0,j|0,i+116|0,i+112|0,a|0);a=x[27524];x[27524]=0;i:{if((a|0)!=1){_b(i+104|0);x[27524]=0;a=ka(1185,m|0,j|0,x[i+116>>2],x[i+112>>2],c|0,d|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break i}Uc(e);Uc(k);ib=i+432|0;break b}a=P()|0;_b(i+104|0);break g}a=P()|0}Uc(e);break c}p()}a=P()|0}Uc(k);S(a|0);p()}return a|0}function a2(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;m=b;i=ib-256|0;ib=i;x[i+248>>2]=37;x[i+252>>2]=0;l=es(i+248|1,13874,x[c+4>>2]);x[i+204>>2]=i+208;a=Fd();a:{if(l){b=x[c+8>>2];j=i- -64|0;x[j>>2]=g;x[j+4>>2]=h;x[i+56>>2]=e;x[i+60>>2]=f;x[i+48>>2]=b;j=hh(i+208|0,30,a,i+248|0,i+48|0);break a}x[i+80>>2]=e;x[i+84>>2]=f;x[i+88>>2]=g;x[i+92>>2]=h;j=hh(i+208|0,30,a,i+248|0,i+80|0)}x[i+128>>2]=1151;k=xe(i+192|0,0,i+128|0);b=i+208|0;a=b;b:{c:{d:{e:{if((j|0)>=30){a=Fd();f:{if(l){j=x[c+8>>2];x[i+16>>2]=g;x[i+20>>2]=h;x[i+8>>2]=e;x[i+12>>2]=f;x[i>>2]=j;j=dj(i+204|0,a,i+248|0,i);break f}x[i+32>>2]=e;x[i+36>>2]=f;x[i+40>>2]=g;x[i+44>>2]=h;j=dj(i+204|0,a,i+248|0,i+32|0)}if((j|0)==-1){x[27524]=0;Z(1152);a=x[27524];x[27524]=0;if((a|0)==1){break d}break e}a=x[i+204>>2];cf(k,a)}f=a+j|0;g=ej(a,f,c);x[i+116>>2]=1151;e=xe(i+120|0,0,i+116|0);g:{h:{if((i+208|0)==(a|0)){j=i+128|0;break h}j=Gd(j<<1);if(!j){x[27524]=0;Z(1152);a=x[27524];x[27524]=0;if((a|0)!=1){break e}a=P()|0;break g}cf(e,j);b=a}a=i+104|0;ed(a,c);x[27524]=0;ia(1179,b|0,g|0,f|0,j|0,i+116|0,i+112|0,a|0);a=x[27524];x[27524]=0;i:{if((a|0)!=1){_b(i+104|0);x[27524]=0;a=ka(15,m|0,j|0,x[i+116>>2],x[i+112>>2],c|0,d|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break i}Uc(e);Uc(k);ib=i+256|0;break b}a=P()|0;_b(i+104|0);break g}a=P()|0}Uc(e);break c}p()}a=P()|0}Uc(k);S(a|0);p()}return a|0}
function Ufa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0;g=ib-16|0;ib=g;s=x[a+16>>2];t=qg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);n=x[a+128>>2];a:{if(!n){k=x[a+8>>2];l=x[a+12>>2];i=x[a>>2];e=x[a+4>>2];m=0;break a}k=x[a+8>>2];l=x[a+12>>2];o=rg(k,l,n);p=kb;b=x[a+76>>2];i=x[a>>2];e=x[a+4>>2];Zf(i,e,rf(k,l,d),kb);m=b>>>0<kb>>>0?d:0}h=a+112|0;f=x[a+48>>2];u=x[a+24>>2];v=x[a+20>>2];b=x[a+44>>2];x[g>>2]=i;x[g+4>>2]=e;b:while(1){c:{q=b;if(!d){break c}d=d-1|0;x[g+8>>2]=i;x[g+12>>2]=0;m=m-1|0;b=m;o=b?o:0;p=b?p:0;e=(e<<1)+s|0;b=n;while(1)if((b|0)<=0){Pb(h,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){Sd(h,w[e+(x[g+12>>2]<<1)>>1]/4<<16>>16);Rd(h,b);x[h>>2]=x[h>>2];x[h+4>>2]=0}i=x[a+72>>2];b=x[a+60>>2];e=b;j=b>>31;r=pg(h,t)<<8;b=r;b=qoa(e,j,b,b>>31);y=kb;e=b;b=x[a+64>>2];j=b;z=b>>31;b=Vb(q,-16777216,16776704);j=qoa(j,z,b,b>>31);e=e+j|0;b=kb+y|0;b=e>>>0<j>>>0?b+1|0:b;j=e;e=x[a+68>>2];f=Vb(f,-16777216,16776704);e=qoa(e,e>>31,f,f>>31);f=j+e|0;b=kb+b|0;b=e>>>0>f>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Vc(f,b,24);f=(b|0)/256|0;x[c>>2]=D(f,v)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(f,u);Pb(g,k,l);b=b-(i&r)|0;c=c+8|0;i=x[g>>2];e=x[g+4>>2];f=q;continue b}else{Sd(h,w[e+(x[g+12>>2]<<1)>>1]/4<<16>>16);Rd(h,4);Pb(g+8|0,o,p);b=b-1|0;continue}}break}x[a>>2]=i;x[a+4>>2]=e;x[a+48>>2]=f;x[a+44>>2]=q;ib=g+16|0}function NL(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=ib-80|0;ib=e;f=Nb(a);a=0;c=x[b+24>>2];g=xj(Tb(x[c+484360>>2],y[c+484376|0]));x[27524]=0;R(185,f|0,g|0);c=x[27524];x[27524]=0;a:{if((c|0)!=1){while(1){b:{if((a|0)!=(g|0)){c=x[b+24>>2];d=x[c+484344>>2];h=x[c+484348>>2];c=z[bc(x[Tb(x[c+484360>>2],y[c+484376|0])>>2],a)>>1];if(Sm(d,h,c)){x[27524]=0;R(1028,e+48|0,Xb(d,c)|0);c=x[27524];x[27524]=0;c:{d:{e:{if((c|0)!=1){c=x[b+24>>2];x[27524]=0;U(1015,e- -64|0,c|0,e+48|0);c=x[27524];x[27524]=0;if((c|0)==1){break e}x[27524]=0;R(187,f|0,e- -64|0);c=x[27524];x[27524]=0;if((c|0)==1){break d}wb(e- -64|0);wb(e+48|0);break b}a=P()|0;break a}a=P()|0;break c}a=P()|0;wb(e- -64|0)}wb(e+48|0);break a}f:{switch(c-65534|0){case 0:x[27524]=0;c=Q(55,e+32|0,9188)|0;d=x[27524];x[27524]=0;g:{if((d|0)!=1){x[27524]=0;R(187,f|0,c|0);d=x[27524];x[27524]=0;if((d|0)==1){break g}wb(c);break b}a=P()|0;break a}a=P()|0;wb(c);break a;case 1:x[27524]=0;c=Q(55,e+16|0,9150)|0;d=x[27524];x[27524]=0;h:{if((d|0)!=1){x[27524]=0;R(187,f|0,c|0);d=x[27524];x[27524]=0;if((d|0)==1){break h}wb(c);break b}a=P()|0;break a}a=P()|0;wb(c);break a;default:break f}}x[27524]=0;c=Q(55,e|0,14615)|0;d=x[27524];x[27524]=0;i:{if((d|0)!=1){x[27524]=0;R(187,f|0,c|0);d=x[27524];x[27524]=0;if((d|0)==1){break i}wb(c);break b}a=P()|0;break a}a=P()|0;wb(c);break a}ib=e+80|0;return}a=a+1|0;continue}}a=P()|0}ve(f);S(a|0);p()}function $q(a,b,c,d){var e=0,f=0;e=ib-16|0;ib=e;v[e+15|0]=c;a:{b:{c:{d:{switch(b-2|0){case 11:v[e+14|0]=64;fe(a,1,Ub(e+15|0,e+14|0));break a;case 0:if(!(c&3|c>>>0>223?d:1)){break c}v[e+14|0]=c>>>2;fe(a,12,e+14|0);break a;case 1:if(!(c&3|c>>>0>223?d:1)){break c}v[e+14|0]=c>>>2;fe(a,13,e+14|0);break a;case 2:if(c>>>0>=240){v[e+14|0]=9;fe(a,11,e+14|0);break a}b=0;while(1){if((b|0)==10){break c}f=y[b+43776|0];e:{if(d){if(c>>>0>f>>>0){break e}break b}if((c|0)==(f|0)){break b}}b=b+1|0;continue};case 3:f:{if(d){v[e+14|0]=c&15;v[e+13|0]=9;c=y[Ub(e+14|0,e+13|0)|0];break f}if(c>>>0>15|(c&14)>>>0>9){break c}}v[e+14|0]=c&15;fe(a,8,e+14|0);break a;case 24:g:{if(d){v[e+15|0]=0;break g}if(c){break c}}fe(a,8,e+15|0);break a;case 7:v[e+15|0]=(c|0)==255?64:c>>>2|0;fe(a,2,e+15|0);break a;case 9:if(!c){break c}b=c&15;if(!b){v[e+14|0]=c>>>4;fe(a,3,e+14|0);break a}d=c&240;if(!d){fe(a,4,e+15|0);break a}if((b|0)==15){v[e+14|0]=c>>>4;fe(a,5,e+14|0);break a}if((d|0)!=240){break c}v[e+14|0]=c&15;fe(a,6,e+14|0);break a;case 18:if((c&240)!=128){break c}v[e+14|0]=c<<2&60|2;fe(a,2,e+14|0);break a;case 17:break d;default:break c}}h:{switch((c>>>4|0)-8|0){case 0:v[e+14|0]=c<<2&60|2;fe(a,2,e+14|0);break a;case 2:v[e+14|0]=c&15;fe(a,5,e+14|0);break a;case 3:break h;default:break c}}v[e+14|0]=c&15;fe(a,6,e+14|0);break a}v[e+14|0]=0;fe(a,0,e+14|0);break a}v[e+14|0]=b;fe(a,11,e+14|0)}ib=e+16|0}function zga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0;h=ib-16|0;ib=h;a:{b:{c:{i=x[a+12>>2];j=x[a+8>>2];d:{if((i|0)<=1&j>>>0<=805306368|(i|0)<=0){if((i|0)>=-2&j>>>0>=3489660928|(i|0)>-2){break c}if((i|0)==-2&j>>>0>2147483647|(i|0)==-1){break d}break b}if((i|0)==1&j>>>0>2147483648|i>>>0>1){break b}}n=b+196648|0;break a}n=b+131112|0;break a}n=b+262184|0}o=x[a+16>>2];f=x[a+48>>2];p=x[a+24>>2];q=x[a+20>>2];b=x[a+44>>2];e=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=e;r=x[a+72>>2];e=x[a+68>>2];s=e;t=e>>31;e=x[a+64>>2];u=e;v=e>>31;e=x[a+60>>2];y=e;z=e>>31;while(1){e=b;if(d){b=Vb(e,-16777216,16776704);b=qoa(u,v,b,b>>31);k=kb;l=b;g=(x[h+12>>2]<<1)+o|0;b=(x[h+8>>2]>>>16&65520)+n|0;g=(((((((D(w[g-4>>1],w[b+2>>1])+D(w[g-6>>1],w[b>>1])|0)+D(w[g-2>>1],w[b+4>>1])|0)+D(w[g>>1],w[b+6>>1])|0)+D(w[g+2>>1],w[b+8>>1])|0)+D(w[g+4>>1],w[b+10>>1])|0)+D(w[g+6>>1],w[b+12>>1])|0)+D(w[g+8>>1],w[b+14>>1])|0)/32768<<8;b=g;b=qoa(b,b>>31,y,z);l=l+b|0;m=kb+k|0;m=b>>>0>l>>>0?m+1|0:m;b=Vb(f,-16777216,16776704);f=qoa(s,t,b,b>>31);k=f+l|0;b=kb+m|0;b=f>>>0>k>>>0?b+1|0:b;f=k+8388608|0;b=f>>>0<8388608?b+1|0:b;f=Vc(f,b,24);b=(f|0)/256|0;x[c>>2]=D(b,q)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(b,p);Pb(h+8|0,j,i);b=f-(g&r)|0;c=c+8|0;d=d-1|0;f=e;continue}break}b=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=b;x[a+48>>2]=f;x[a+44>>2]=e;ib=h+16|0}function j2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=ib-352|0;ib=a;x[a+336>>2]=c;x[a+344>>2]=b;h=Kb(a+208|0);b=a+16|0;ed(b,d);x[27524]=0;b=T(1164,b|0)|0;c=x[27524];x[27524]=0;a:{b:{c:{d:{if((c|0)==1){break d}x[27524]=0;X(1176,b|0,98224,98250,a+224|0);b=x[27524];x[27524]=0;if((b|0)==1){break d}_b(a+16|0);c=Kb(a+192|0);b=ad(c);x[27524]=0;R(60,c|0,b|0);b=x[27524];x[27524]=0;if((b|0)==1){break b}b=Qc(c,0);x[a+188>>2]=b;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){e:{x[27524]=0;d=Q(1169,a+344|0,a+336|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break e}if(!d){break c}g=x[a+188>>2];d=Eb(c);if((g|0)==(d+b|0)){x[27524]=0;R(60,c|0,d<<1);b=x[27524];x[27524]=0;if((b|0)==1){break b}b=ad(c);x[27524]=0;R(60,c|0,b|0);b=x[27524];x[27524]=0;if((b|0)==1){break b}b=Qc(c,0);x[a+188>>2]=d+b}x[27524]=0;d=T(1171,x[a+344>>2])|0;g=x[27524];x[27524]=0;if((g|0)==1){break e}if(Cn(d,16,b,a+188|0,a+8|0,0,h,a+16|0,a+12|0,a+224|0)){break c}x[27524]=0;T(1173,a+344|0)|0;d=x[27524];x[27524]=0;if((d|0)!=1){continue}}break}break b}b=P()|0;_b(a+16|0);break a}x[27524]=0;R(60,c|0,x[a+188>>2]-b|0);b=x[27524];x[27524]=0;f:{if((b|0)==1){break f}b=Jc(c);d=Fd();x[a>>2]=f;if(($G(b,d,a)|0)!=1){x[e>>2]=4}x[27524]=0;b=Q(1170,a+344|0,a+336|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break f}if(b){x[e>>2]=x[e>>2]|2}b=x[a+344>>2];wb(c);wb(h);ib=a+352|0;return b|0}}b=P()|0;wb(c)}wb(h);S(b|0);p()}function Iha(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=ib-48|0;ib=e;w[e+46>>1]=254;c=xj(a);f=e+32|0;x[f>>2]=0;x[f+4>>2]=0;sc(f+8|0);if(c){sq(f,c);UC(f,c)}a:{b:{while(1){c:{if((b|0)==(c|0)){if(!(d&65535)){break a}c=Cb(x[a>>2]);d=Cb(x[a+4>>2]);b=ib-16|0;ib=b;c=NA(c,d,z[e+46>>1]);x[b+8>>2]=c;if(Mb(c,d)){x[b>>2]=c;while(1){c=x[Ye(b)>>2];if(Mb(c,d)){c=z[c>>1];if((c|0)==z[e+46>>1]){continue}w[x[b+8>>2]>>1]=c;Ye(b+8|0);continue}break}c=x[b+8>>2]}ib=b+16|0;b=Wb(e+24|0,c);c=x[Wb(e+16|0,Cb(x[a+4>>2]))>>2];d=x[b>>2];b=x[a>>2];b=(Do(d,Cb(b))<<1)+b|0;if(Mb(d,c)){Od(a,ji(b+(Do(c,d)<<1)|0,x[a+4>>2],b))}Cb(b);k=e,l=Cb(x[a>>2]),x[k+8>>2]=l;d=Cb(x[a+4>>2]);break c}k=bc(x[f>>2],b),l=b-d|0,w[k>>1]=l;g=x[a+4>>2];h=x[a>>2];x[27524]=0;g=W(754,h|0,g|0,b|0)|0;h=x[27524];x[27524]=0;if((h|0)==1){break b}b=b+1|0;d=(z[g>>1]==254)+d|0;continue}break}while(1){b=x[e+8>>2];if(Mb(b,d)){d:{c=x[a+24>>2];g=x[c+484344>>2];b=z[b>>1];if(!Ce(g,x[c+484348>>2],b)){break d}b=Xb(g,b);k=e,l=Cb(x[b>>2]),x[k>>2]=l;g=Cb(x[b+4>>2]);h=x[f+4>>2];c=x[f>>2];while(1){b=x[e>>2];if(!Mb(b,g)){break d}e:{if(y[b+3|0]!=12){break e}j=Oc(c,h);i=y[b+5|0];if(j>>>0<=i>>>0){break e}k=b,l=y[bc(c,i)|0],v[k+5|0]=l}Hk(e);continue}}Ye(e+8|0);continue}else{b=x[f>>2];d=Oc(b,x[f+4>>2]);c=z[a+28>>1];if(d>>>0<=c>>>0){break a}k=a,l=z[bc(b,c)>>1],w[k+28>>1]=l;break a}}}a=P()|0;jd(f);S(a|0);p()}jd(f);ib=e+48|0}function s2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=ib-272|0;ib=a;x[a+256>>2]=c;x[a+264>>2]=b;h=Kb(a+208|0);b=a+16|0;ed(b,d);x[27524]=0;b=T(19,b|0)|0;c=x[27524];x[27524]=0;a:{b:{c:{d:{if((c|0)==1){break d}x[27524]=0;X(1162,b|0,98224,98250,a+224|0);b=x[27524];x[27524]=0;if((b|0)==1){break d}_b(a+16|0);c=Kb(a+192|0);b=ad(c);x[27524]=0;R(60,c|0,b|0);b=x[27524];x[27524]=0;if((b|0)==1){break b}b=Qc(c,0);x[a+188>>2]=b;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){e:{x[27524]=0;d=Q(1153,a+264|0,a+256|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break e}if(!d){break c}g=x[a+188>>2];d=Eb(c);if((g|0)==(d+b|0)){x[27524]=0;R(60,c|0,d<<1);b=x[27524];x[27524]=0;if((b|0)==1){break b}b=ad(c);x[27524]=0;R(60,c|0,b|0);b=x[27524];x[27524]=0;if((b|0)==1){break b}b=Qc(c,0);x[a+188>>2]=d+b}x[27524]=0;d=T(1155,x[a+264>>2])|0;g=x[27524];x[27524]=0;if((g|0)==1){break e}if(Dn(d,16,b,a+188|0,a+8|0,0,h,a+16|0,a+12|0,a+224|0)){break c}x[27524]=0;T(1157,a+264|0)|0;d=x[27524];x[27524]=0;if((d|0)!=1){continue}}break}break b}b=P()|0;_b(a+16|0);break a}x[27524]=0;R(60,c|0,x[a+188>>2]-b|0);b=x[27524];x[27524]=0;f:{if((b|0)==1){break f}b=Jc(c);d=Fd();x[a>>2]=f;if(($G(b,d,a)|0)!=1){x[e>>2]=4}x[27524]=0;b=Q(1154,a+264|0,a+256|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break f}if(b){x[e>>2]=x[e>>2]|2}b=x[a+264>>2];wb(c);wb(h);ib=a+272|0;return b|0}}b=P()|0;wb(c)}wb(h);S(b|0);p()}function gQ(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=ib-32|0;ib=e;f=x[b+64>>2];a:{b:{h=x[b+60>>2];g=z[b+68>>1];if(!((h|0)==-1&(g|0)==65535)){c:{d:{if((f|0)==-1){break d}f=a+1074312|0;Ab(e+24|0,f,68);if(zb(x[x[e+24>>2]>>2],x[e+28>>2])){break d}Ab(e+16|0,f,103);if(i=zb(x[x[e+16>>2]>>2],x[e+20>>2]),j=0,k=(g|0)!=65535,k?i:j){break c}Ab(e+8|0,f,49);if(i=zb(x[x[e+8>>2]>>2],x[e+12>>2]),j=0,k=(g|0)!=65535,k?i:j){break c}f=x[b+64>>2];break b}if((g|0)!=65535){break c}w[b+68>>1]=z[b+72>>1]+1}if((h|0)==-1){x[b+60>>2]=0}g=Oc(x[c>>2],x[c+4>>2]);f=z[b+68>>1];if(g>>>0<=f>>>0){f=z[c+28>>1];w[b+68>>1]=f}e:{if(z[b+72>>1]==(f&65535)){break e}c=a+1074312|0;Ab(e+24|0,c,26);if(zb(x[x[e+24>>2]>>2],x[e+28>>2])){break e}Ab(e+16|0,c,68);if(zb(x[x[e+16>>2]>>2],x[e+20>>2])|x[a+480180>>2]==1){break e}c=z[a+480188>>1];f=0;while(1){if((c|0)==(f|0)){break e}v[(D(f,872)+b|0)+1457|0]=0;f=f+1|0;continue}}x[b+52>>2]=x[b+60>>2];if(d){c=1;if(y[a+480208|0]&32){break a}}w[b+74>>1]=z[b+68>>1];c=1;break a}if((f|0)!=-1){break b}c=0;break a}x[b+52>>2]=f;w[b+74>>1]=z[b+72>>1];f:{if(!x[b+20>>2]){break f}c=x[a+480180>>2];if((c|0)==32){Ab(e+24|0,a+1074312|0,103);if(zb(x[x[e+24>>2]>>2],x[e+28>>2])){break f}c=x[a+480180>>2]}if((c|0)==2){break f}x[b+52>>2]=x[b+52>>2]+1}c=0;if(A[b+64>>2]<A[Xb(x[a+484344>>2],z[b+70>>1])+12>>2]){break a}x[b+52>>2]=0;w[b+74>>1]=z[b+74>>1]+1;c=0}ib=e+32|0;return c}function az(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;h=89;i=92;j=91;k=85;l=84;m=83;n=5;o=118;p=113;q=111;r=107;s=106;t=96;c=88;u=82;v=80;w=78;x=79;y=77;z=57;A=47;d=10;e=8;f=7;a=rr(a);a:{b:{c:{d:{switch(b-1|0){default:c=(b|0)==16777216;if(!c&(b|0)!=32){break c}Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(a,0,1),7,1),8,1),9,1),10,1),11,1),12,1),13,1),14,1),15,1),16,1),17,1),18,1),19,1),20,1),21,1),22,1),23,1),24,1),25,1),26,1),27,1),28,1),29,1),30,1),31,1),32,1),33,1),34,1),35,1),36,1),37,1),38,1),39,1),40,1),41,1),42,1),43,1),44,1),45,1),46,1),47,1),48,1),103,1),50,1),87,1),88,1),100,1),102,1),104,1),115,1);if(!c){break a}d=111;e=105;f=99;break b;case 3:Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(a,0,1),4,1),8,1),9,1),10,1),17,1),40,1),51,1),52,1),53,1),54,1),55,1),56,1),57,1),58,1),59,1),60,1),61,1),62,1),63,1),64,1),65,1),66,1);o=112;p=98;q=93;r=90;s=89;t=88;c=86;u=76;v=75;w=74;x=73;y=72;z=71;A=70;d=69;e=68;g=67;case 1:Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(a,g,1),e,1),d,1),A,1),z,1),y,1),x,1),w,1),v,1);n=u;m=c;l=t;k=s;j=r;i=q;c=p;h=o;break;case 2:break c;case 0:break d}}Lb(Lb(Lb(Lb(a,n,1),m,1),l,1),k,1);g=j;f=i;e=c;d=h}Lb(a,g,1)}Lb(Lb(Lb(a,f,1),e,1),d,1)}}function _S(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;j=ib-16|0;ib=j;a:{if((b|0)==(c|0)){break a}x[j+12>>2]=-1953789045;AA(b,c,j+12|0);c=c-b|0;e=c>>2;x[j+8>>2]=e;f=tc(x[a>>2],x[a+4>>2]);g=11;b:{if(c>>>0>2488){break b}g=7;if(c>>>0>268){break b}g=5;if(c>>>0>152){break b}g=3;if(c>>>0>24){break b}g=e-1>>>1|0}c=f+1|0;x[j+4>>2]=c;n=x[Yc(j+4|0,j+8|0)>>2];k=e-g>>>1|0;d=(k<<2)+b|0;h=x[d>>2];i=D(gu(h^(x[b>>2]^x[((e<<2)+b|0)-4>>2])),1664525);x[d>>2]=i+h;g=g+k|0;d=(g<<2)+b|0;f=f+i|0;x[d>>2]=f+x[d>>2];x[b>>2]=f;i=x[a>>2];a=1;while(1)if((a|0)==(c|0)){while(1)if(c>>>0>=n>>>0){c=n;while(1){if(e+n>>>0<=c>>>0){break a}d=((c+k>>>0)%(e>>>0)<<2)+b|0;h=x[d>>2];f=(c>>>0)%(e>>>0)|0;i=(f<<2)+b|0;a=D(gu(x[((c-1>>>0)%(e>>>0)<<2)+b>>2]+(h+x[i>>2]|0)|0),1566083941);x[d>>2]=a^h;d=((c+g>>>0)%(e>>>0)<<2)+b|0;a=a-f|0;x[d>>2]=a^x[d>>2];x[i>>2]=a;c=c+1|0;continue}}else{d=((c+k>>>0)%(e>>>0)<<2)+b|0;h=x[d>>2];f=(c>>>0)%(e>>>0)|0;i=(f<<2)+b|0;a=D(gu(h^(x[i>>2]^x[((c-1>>>0)%(e>>>0)<<2)+b>>2])),1664525);x[d>>2]=a+h;d=((c+g>>>0)%(e>>>0)<<2)+b|0;a=a+f|0;x[d>>2]=a+x[d>>2];x[i>>2]=a;c=c+1|0;continue}}else{l=((a+k>>>0)%(e>>>0)<<2)+b|0;m=x[l>>2];d=(a>>>0)%(e>>>0)|0;h=(d<<2)+b|0;o=a-1|0;f=D(gu(m^(x[h>>2]^x[((o>>>0)%(e>>>0)<<2)+b>>2])),1664525);x[l>>2]=f+m;l=((a+g>>>0)%(e>>>0)<<2)+b|0;m=x[l>>2];f=x[Bb(i,o)>>2]+(f+d|0)|0;x[l>>2]=f+m;x[h>>2]=f;a=a+1|0;continue}}ib=j+16|0}function N$(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;n=ib-16|0;ib=n;b=c;while(1){a:{if((b|0)==(d|0)){b=d;break a}if(!x[b>>2]){break a}b=b+4|0;continue}break}x[h>>2]=f;x[e>>2]=c;while(1){b:{c:{if(!((c|0)==(d|0)|(f|0)==(g|0))){q=1;r=ib-16|0;ib=r;s=qi(r+8|0,x[a+8>>2]);i=f;j=g-f|0;m=0;o=ib-16|0;ib=o;k=x[e>>2];p=b-c>>2;d:{if(!k|!p){break d}j=i?j:0;while(1){l=tx(j>>>0<4?o+12|0:i,x[k>>2]);if((l|0)==-1){m=-1;break d}if(i){if(j>>>0<=3){if(j>>>0<l>>>0){break d}rc(i,o+12|0,l)}j=j-l|0;i=i+l|0}else{i=0}if(!x[k>>2]){k=0;break d}m=m+l|0;k=k+4|0;p=p-1|0;if(p){continue}break}}if(i){x[e>>2]=k}ib=o+16|0;pi(s);ib=r+16|0;e:{f:{g:{h:{switch(m+1|0){case 0:x[h>>2]=f;while(1){i:{if(x[e>>2]==(c|0)){break i}b=Lw(f,x[c>>2],x[a+8>>2]);if((b|0)==-1){break i}f=b+x[h>>2]|0;x[h>>2]=f;c=c+4|0;continue}break};x[e>>2]=c;break g;case 1:break c;default:break h}}f=m+x[h>>2]|0;x[h>>2]=f;if((f|0)==(g|0)){break e}if((b|0)==(d|0)){c=x[e>>2];b=d;continue}b=Lw(n+12|0,0,x[a+8>>2]);if((b|0)!=-1){break f}}q=2;break c}c=n+12|0;if(g-x[h>>2]>>>0<b>>>0){break c}while(1){if(b){f=y[c|0];i=x[h>>2];x[h>>2]=i+1;v[i|0]=f;b=b-1|0;c=c+1|0;continue}break}c=x[e>>2]+4|0;x[e>>2]=c;b=c;while(1){if((b|0)==(d|0)){b=d;break b}if(!x[b>>2]){break b}b=b+4|0;continue}}c=x[e>>2]}q=(c|0)!=(d|0)}ib=n+16|0;return q|0}f=x[h>>2];continue}}function Aga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0;h=ib-16|0;ib=h;a:{b:{c:{i=x[a+12>>2];k=x[a+8>>2];d:{if((i|0)<=1&k>>>0<=805306368|(i|0)<=0){if((i|0)>=-2&k>>>0>=3489660928|(i|0)>-2){break c}if((i|0)==-2&k>>>0>2147483647|(i|0)==-1){break d}break b}if((i|0)==1&k>>>0>2147483648|i>>>0>1){break b}}l=b+196648|0;break a}l=b+131112|0;break a}l=b+262184|0}m=x[a+16>>2];b=x[a+48>>2];n=x[a+24>>2];o=x[a+20>>2];e=x[a+44>>2];f=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=f;p=x[a+72>>2];f=x[a+68>>2];q=f;r=f>>31;f=x[a+64>>2];s=f;t=f>>31;f=x[a+60>>2];u=f;y=f>>31;while(1){f=e;if(d){e=Vb(f,-16777216,16776704);e=qoa(s,t,e,e>>31);g=kb;j=e;b=Vb(b,-16777216,16776704);e=qoa(q,r,b,b>>31);j=j+e|0;b=kb+g|0;b=e>>>0>j>>>0?b+1|0:b;g=x[h+12>>2]+m|0;e=(x[h+8>>2]>>>16&65520)+l|0;g=(((((((D(v[g-2|0],w[e+2>>1])+D(v[g-3|0],w[e>>1])|0)+D(v[g-1|0],w[e+4>>1])|0)+D(v[g|0],w[e+6>>1])|0)+D(v[g+1|0],w[e+8>>1])|0)+D(v[g+2|0],w[e+10>>1])|0)+D(v[g+3|0],w[e+12>>1])|0)+D(v[g+4|0],w[e+14>>1])<<8)/32768<<8;e=g;e=qoa(e,e>>31,u,y);j=e+j|0;b=kb+b|0;b=e>>>0>j>>>0?b+1|0:b;e=j+8388608|0;b=e>>>0<8388608?b+1|0:b;e=Vc(e,b,24);b=(e|0)/256|0;x[c>>2]=D(b,o)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(b,n);Pb(h+8|0,k,i);e=e-(g&p)|0;c=c+8|0;d=d-1|0;b=f;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+48>>2]=b;x[a+44>>2]=f;ib=h+16|0}function Vfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0;g=ib-16|0;ib=g;s=x[a+16>>2];t=qg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);n=x[a+128>>2];a:{if(!n){k=x[a+8>>2];l=x[a+12>>2];i=x[a>>2];e=x[a+4>>2];m=0;break a}k=x[a+8>>2];l=x[a+12>>2];o=rg(k,l,n);p=kb;b=x[a+76>>2];i=x[a>>2];e=x[a+4>>2];Zf(i,e,rf(k,l,d),kb);m=b>>>0<kb>>>0?d:0}h=a+112|0;f=x[a+48>>2];u=x[a+24>>2];w=x[a+20>>2];b=x[a+44>>2];x[g>>2]=i;x[g+4>>2]=e;b:while(1){c:{q=b;if(!d){break c}d=d-1|0;x[g+8>>2]=i;x[g+12>>2]=0;m=m-1|0;b=m;o=b?o:0;p=b?p:0;e=e+s|0;b=n;while(1)if((b|0)<=0){Pb(h,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){Sd(h,v[e+x[g+12>>2]|0]<<6);Rd(h,b);x[h>>2]=x[h>>2];x[h+4>>2]=0}i=x[a+72>>2];b=x[a+60>>2];e=b;j=b>>31;r=pg(h,t)<<8;b=r;b=qoa(e,j,b,b>>31);y=kb;e=b;b=x[a+64>>2];j=b;z=b>>31;b=Vb(q,-16777216,16776704);j=qoa(j,z,b,b>>31);e=e+j|0;b=kb+y|0;b=e>>>0<j>>>0?b+1|0:b;j=e;e=x[a+68>>2];f=Vb(f,-16777216,16776704);e=qoa(e,e>>31,f,f>>31);f=j+e|0;b=kb+b|0;b=e>>>0>f>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Vc(f,b,24);f=(b|0)/256|0;x[c>>2]=D(f,w)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(f,u);Pb(g,k,l);b=b-(i&r)|0;c=c+8|0;i=x[g>>2];e=x[g+4>>2];f=q;continue b}else{Sd(h,v[e+x[g+12>>2]|0]<<6);Rd(h,4);Pb(g+8|0,o,p);b=b-1|0;continue}}break}x[a>>2]=i;x[a+4>>2]=e;x[a+48>>2]=f;x[a+44>>2]=q;ib=g+16|0}function Hz(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=ib-16|0;ib=h;f=x[c+656>>2];a:{if(!Aj(f)){i=x[c+704>>2];f=ib-16|0;ib=f;x[f+12>>2]=d;g=0;b:{if(!d){break b}j=x[b+480180>>2];if(j&20){e=b+1074312|0;Ab(f,e,73);d=zb(x[x[f>>2]>>2],x[f+4>>2])?d&65535:d;if(y[b+480208|0]&16){Ab(f,e,73);e=zb(x[x[f>>2]>>2],x[f+4>>2])?14-((9983-d>>>0)/768|0)&31:((d>>>0)/768|0)+2|0;g=x[((d>>>0)%768<<2)+33952>>2]<<6>>>e|0;break b}g=229079296/((d?d:1)>>>0)|0;break b}g=227001280/(d>>>0)|0;if(Nm(j)){break b}g=(d+i<<4)-133808|0;if((j|0)==64){break b}wc(f+12|0,16777215);if(j&17408){g=Ec(soa(qoa(i?i:8363,0,3506176,0),kb,(x[f+12>>2]<<8)+e|0,0),kb);break b}if(sj(b)){d=x[f+12>>2];i=d>>>24|0;j=d<<8;d=j+e|0;e=i+(e>>31)|0;g=((d>>>0<j>>>0?e+1|0:e)&15)<<28|d>>>4;break b}if(y[b+480208|0]&16){g=Ec(soa(qoa(i?i:8363,0,7012352,0),kb,(x[f+12>>2]<<8)+e|0,0),kb);break b}g=Ec(soa(-1485242368,13,(x[f+12>>2]<<8)+e|0,0),kb)}e=g;ib=f+16|0;f=x[c+656>>2];break a}e=x[c+700>>2]}x[h+12>>2]=e;c=w[c+774>>1];c:{if(!c){break c}c=f?D(v[f+33|0],c):c;if(!c){break c}e=Xe(ki(+(c|0)/393216)*+(e>>>0));x[h+12>>2]=e}d:{if(!f){break d}c=x[f+40>>2];if(!c){break d}d=(c|0)/2|0;f=x[b+1074420>>2];e=qoa(f,f>>31,e,e>>31);f=d+e|0;d=kb+(d>>31)|0;k=h,l=Dc(roa(f,e>>>0>f>>>0?d+1|0:d,c,c>>31),kb),x[k+12>>2]=l}wc(h+12|0,2147483647);c=x[h+12>>2];b=ag(c,x[b+24620>>2]<<4);x[a+8>>2]=c;x[a>>2]=b;x[a+4>>2]=kb;ib=h+16|0}function sia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,B=0;i=ib-16|0;ib=i;md(d,32);g=i+8|0;HS(g,y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24),y[a+28|0]|y[a+29|0]<<8|(y[a+30|0]<<16|y[a+31|0]<<24),x[b>>2]);g=gc(g);HS(i,y[a+40|0]|y[a+41|0]<<8|(y[a+42|0]<<16|y[a+43|0]<<24),y[a+44|0]|y[a+45|0]<<8|(y[a+46|0]<<16|y[a+47|0]<<24),x[c>>2]);a=0;g=x[g>>2];if(g-838861>>>0>=4294128436){a=x[gc(i)>>2];x[d>>2]=D(g,320);w[d+34>>1]=1;a:{m=Xg(d);if(!m){break a}l=g<<2;e=+(l>>>0);q=+(a>>>0)/e;r=+(g>>>0)/e;s=1/+A[d>>2];t=+A[i>>2];u=+A[i+8>>2];g=0;b:while(1){if((g|0)==(l|0)){break a}n=+(g>>>0);o=0;p=0;a=x[b+20>>2];if(_d(x[b>>2],a)){e=n*r+u;c:{if(e<4294967296&e>=0){f=~~e>>>0;break c}f=0}k=z[b+34>>1];j=Md(k);h=D(f,j);e=e-+(f>>>0);d:{if(k&1){f=z[a+(h<<1)>>1];a=z[a+(h+j<<1)>>1];break d}f=y[a+h|0]<<8;a=y[a+(h+j|0)|0]<<8}p=+(f<<16>>16)*(1-e)+e*+(a<<16>>16)}a=x[c+20>>2];if(_d(x[c>>2],a)){e=n*q+t;e:{if(e<4294967296&e>=0){f=~~e>>>0;break e}f=0}k=z[c+34>>1];j=Md(k);h=D(f,j);e=e-+(f>>>0);f:{if(k&1){f=z[a+(h<<1)>>1];a=z[a+(h+j<<1)>>1];break f}f=y[a+h|0]<<8;a=y[a+(h+j|0)|0]<<8}o=+(f<<16>>16)*(1-e)+e*+(a<<16>>16)}f=0;a=g;while(1)if((f|0)==80){g=g+1|0;continue b}else{e=s*+(a>>>0);v=x[d+20>>2]+(a<<1)|0,B=wA(p*(1-e)+o*e),w[v>>1]=B;a=a+l|0;f=f+1|0;continue}}}a=(m|0)!=0}ib=i+16|0;return a|0}function p_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=Kb(a);a=y[b+11|0];g=x[b+4>>2];x[27524]=0;k=Ik(g,a);R(119,h|0,k|0);a=x[27524];x[27524]=0;a:{b:{if((a|0)!=1){g=0;a=0;while(1){c:{if((a|0)==(k|0)){a=!f;if(!(l?a&(m^-1):a)){break c}return}e=y[nd(b)+a|0];d:{e:{f:{g:{switch(f+1|0){case 1:f=1;h:{switch(e-123|0){case 2:break h;case 0:break d;default:break f}}f=3;break d;case 2:i:{switch(e-123|0){case 2:m=1;e=g+1|0;f=0;if(d>>>0<=g>>>0){g=e;break d}x[27524]=0;Q(120,h|0,Cd(c,g)|0)|0;j=x[27524];x[27524]=0;g=e;if((j|0)!=1){break d}a=P()|0;break b;case 0:break f;default:break i}}f=-1;e=e-48|0;if((e&255)>>>0>9){break d}l=1;f=2;i=e;break d;case 3:f=-1;j:{switch(e-123|0){case 2:f=0;if(d>>>0<=i>>>0){break d}x[27524]=0;Q(120,h|0,Cd(c,i)|0)|0;e=x[27524];x[27524]=0;if((e|0)!=1){break d}a=P()|0;break b;case 0:break d;default:break j}}if((e-48&255)>>>0>9){break d}i=(D(i,10)+e|0)-48|0;l=1;f=2;break d;case 4:break g;case 0:break e;default:break d}}j=(e|0)!=125;f=-1;e=125;if(j){break d}}f=0;x[27524]=0;Q(121,h|0,e|0)|0;e=x[27524];x[27524]=0;if((e|0)!=1){break d}a=P()|0;break b}f=-1}a=a+1|0;continue}break}b=ba(8)|0;x[27524]=0;a=T(122,b|0)|0;c=x[27524];x[27524]=0;if((c|0)!=1){x[27524]=0;U(123,a|0,41828,25);a=x[27524];x[27524]=0;if((a|0)!=1){break a}a=P()|0;break b}a=P()|0;ca(b|0);break b}a=P()|0}xb(h);S(a|0)}p()}function PE(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=ib-96|0;ib=c;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if(!b){xc(a,9688);break j}d=b>>>24|0;if(!(b&65535)){e=ib-16|0;ib=e;f=xc(e,4402);$c(c+80|0,f);xb(f);ib=e+16|0;x[27524]=0;x[c+24>>2]=d;R(113,c- -64|0,c+24|0);d=x[27524];x[27524]=0;k:{l:{m:{n:{if((d|0)!=1){x[27524]=0;x[c+8>>2]=b>>>16&255;R(114,c+48|0,c+8|0);b=x[27524];x[27524]=0;if((b|0)==1){break n}x[27524]=0;X(115,a|0,c+80|0,c- -64|0,c+48|0);a=x[27524];x[27524]=0;if((a|0)==1){break m}xb(c+48|0);xb(c- -64|0);$b(c+80|0);break j}b=P()|0;break k}b=P()|0;break l}b=P()|0;xb(c+48|0)}xb(c- -64|0)}break a}e=ib-16|0;ib=e;f=xc(e,4126);$c(c+80|0,f);xb(f);ib=e+16|0;x[27524]=0;x[c+44>>2]=d;R(113,c- -64|0,c+44|0);d=x[27524];x[27524]=0;if((d|0)==1){break i}x[27524]=0;x[c+40>>2]=b>>>16&255;R(114,c+48|0,c+40|0);d=x[27524];x[27524]=0;if((d|0)==1){break h}x[27524]=0;x[c+20>>2]=b>>>8&255;R(114,c+24|0,c+20|0);d=x[27524];x[27524]=0;if((d|0)==1){break g}x[27524]=0;x[c+4>>2]=b&255;R(114,c+8|0,c+4|0);b=x[27524];x[27524]=0;if((b|0)==1){break f}x[27524]=0;ma(116,a|0,c+80|0,c- -64|0,c+48|0,c+24|0,c+8|0);a=x[27524];x[27524]=0;if((a|0)==1){break e}xb(c+8|0);xb(c+24|0);xb(c+48|0);xb(c- -64|0);$b(c+80|0)}ib=c+96|0;return}b=P()|0;break a}b=P()|0;break b}b=P()|0;break c}b=P()|0;break d}b=P()|0;xb(c+8|0)}xb(c+24|0)}xb(c+48|0)}xb(c- -64|0)}$b(c+80|0);S(b|0);p()}function yka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=ib-16|0;ib=e;a:{if((c|0)!=4){g=b+236|0;h=b+108|0;while(1){if((d|0)==120){break a}f=(d<<2)+a|0;i=Jb(h,d),j=y[f+4|0]+1|0,v[i|0]=j;i=bc(g,d),j=(y[f+6|0]|y[f+7|0]<<8)+1|0,w[i>>1]=j;d=d+1|0;continue}}f=b+236|0;while(1){if((d|0)==96){break a}g=(d<<2)+a|0;i=bc(f,d+12|0),j=(y[g+6|0]|y[g+7|0]<<8)+1|0,w[i>>1]=j;d=d+1|0;continue}}ZA(a+484|0,b+48|0,0);ZA(a+590|0,b+68|0,0);ZA(a+696|0,b+88|0,5);x[b>>2]=y[a+806|0]|y[a+807|0]<<8;d=v[a+808|0];b:{if((d|0)<0){v[b+34|0]=d-127;break b}if(d>>>0>16){break b}if(v[a|0]&1){v[b+31|0]=d+1;break b}if(!d){break b}v[b+31|0]=d+1}if(y[b+31|0]){c:{d:{if((c|0)==4){d=y[a+810|0];break d}d=v[a+809|0];if((d|0)>=0){w[b+28>>1]=(d&255)+1}d=v[a+810|0];if((d|0)<0){break c}}v[b+30|0]=d+1}v[b+33|0]=y[a+811|0]}if((c|0)==32){v[e+15|0]=y[a+812|0];v[e+14|0]=128;i=b,j=y[Ub(e+15|0,e+14|0)|0]>>>1|0,x[i+4>>2]=j}c=y[a+813|0]|y[a+814|0]<<8;if(c>>>0<=256){x[b+8>>2]=c;v[b+15|0]=y[b+15|0]|1}v[b+16|0]=y[a+815|0];v[b+26|0]=y[a+816|0];v[b+27|0]=y[a+817|0];v[b+17|0]=y[a+818|0];v[b+18|0]=y[a+819|0];w[e+12>>1]=y[a+820|0]|y[a+821|0]<<8;w[e+10>>1]=100;i=b,j=y[Tc(e+12|0,e+10|0)|0],v[i+20|0]=j;w[e+8>>1]=y[a+822|0]|y[a+823|0]<<8;w[e+6>>1]=256;i=b,j=z[Tc(e+8|0,e+6|0)>>1]>>>2|0,v[i+19|0]=j;c=y[a+824|0];Tj(b,c&127,c>>>7|0);a=y[a+825|0];Sj(b,a&127,a>>>7|0);ib=e+16|0}function EB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;j=ib-16|0;ib=j;a:{if(b&4){break a}c=y[a+14|0];b:{if(c>>>0>=y[a+15|0]){break b}d=y[a+12|0];if(!(d&2)){break b}v[a+12|0]=d&251}if(!(y[a+12|0]&2)|c>>>0<=y[a+13|0]){break a}e=x[a>>2];d=x[a+4>>2];if($d(e,d)>>>0<=c>>>0){break a}e=z[Mc(e,d,c)>>1];d=Mc(x[a>>2],x[a+4>>2],y[a+14|0]-1|0);c=y[a+14|0];if(z[d>>1]<(e-1|0)){c=z[Mc(x[a>>2],x[a+4>>2],c)>>1]-1&65535;e=kq(a,c,64,64);d=Wb(j+8|0,Dm(Cb(x[a>>2]),y[a+14|0]));k=Bl(j,c,e&255);m=ib-32|0;ib=m;c=x[d>>2];d=x[a>>2];c=(vu(c,Cb(d))<<2)+d|0;h=x[a+4>>2];c:{d:{if(h>>>0<A[Db(a)>>2]){if((c|0)!=(h|0)){break d}gV(a,k);break c}d=Db(a);f=cg(m+8|0,wg(a,tc(x[a>>2],h)+1|0),c-x[a>>2]>>2,d);x[27524]=0;R(756,f|0,k|0);d=x[27524];x[27524]=0;if((d|0)!=1){d=x[f+4>>2];i=f+4|0;nq(x[a>>2],c,i);e=x[a+4>>2];g=f+8|0;while(1){if((c|0)!=(e|0)){Lm(x[g>>2],z[c>>1]|z[c+2>>1]<<16);x[g>>2]=x[g>>2]+4;c=c+4|0;continue}break}oc(a,i);oc(a+4|0,g);oc(Db(a),zc(f));x[f>>2]=x[f+4>>2];c=d;bg(f);break c}a=P()|0;bg(f);S(a|0);p()}f=ib-16|0;ib=f;i=x[a+4>>2];d=(i-(c+4|0)|0)+c|0;g=Fh(f,a,h-d>>2);l=x[g+4>>2];e=d;while(1){if(e>>>0>=h>>>0){ic(g);Mq(c,d,i);ib=f+16|0}else{Lm(l,z[e>>1]|z[e+2>>1]<<16);l=l+4|0;x[g+4>>2]=l;e=e+4|0;continue}break}v[c+2|0]=y[k+2|0];w[c>>1]=z[k>>1]}Cb(c);ib=m+32|0;break a}v[a+14|0]=c-1}if((b|0)!=16777216){v[a+17|0]=255}ib=j+16|0}function qG(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0;a=ib-16|0;ib=a;x[a+12>>2]=c;x[a+8>>2]=f;x[a+12>>2]=c;x[a+8>>2]=f;a:{b:{c:{while(1){c=x[a+12>>2];if(!(c>>>0>=d>>>0|f>>>0>=g>>>0)){i=v[c|0];j=i&255;d:{if((i|0)>=0){w[f>>1]=j;b=c+1|0;break d}b=2;if(i>>>0<4294967234){break b}if(i>>>0<=4294967263){if((d-c|0)<2){break c}i=y[c+1|0];if((i&192)!=128){break a}w[f>>1]=i&63|j<<6&1984;b=c+2|0;break d}if(i>>>0<=4294967279){if((d-c|0)<3){break c}k=y[c+2|0];i=y[c+1|0];e:{f:{if((j|0)!=237){if((j|0)!=224){break f}if((i&224)==160){break e}break a}if((i&224)==128){break e}break a}if((i&192)!=128){break a}}if((k&192)!=128){break a}w[f>>1]=k&63|((i&63)<<6|j<<12);b=c+3|0;break d}if(i>>>0>4294967284){break b}b=1;if((d-c|0)<4){break a}k=y[c+3|0];i=y[c+2|0];c=y[c+1|0];g:{h:{switch(j-240|0){case 0:if((c+112&255)>>>0>=48){break b}break g;case 4:if((c&240)!=128){break b}break g;default:break h}}if((c&192)!=128){break b}}if((i&192)!=128|(k&192)!=128){break b}if((g-f|0)<4){break a}b=2;j=j&7;if((c<<12&196608|j<<18)>>>0>1114111){break a}b=c<<2;w[f>>1]=(i>>>4&3|(b&192|j<<8|b&60))+16320|55296;x[a+8>>2]=f+2;w[f+2>>1]=i<<6&960|k&63|56320;b=x[a+12>>2]+4|0}x[a+12>>2]=b;f=x[a+8>>2]+2|0;x[a+8>>2]=f;continue}break}b=c>>>0<d>>>0;break a}b=1;break a}b=2}x[e>>2]=x[a+12>>2];x[h>>2]=x[a+8>>2];ib=a+16|0;return b|0}function Zz(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a:{e=a;b:{c:{h=a+62|0;f=Jb(h,b);a=v[f|0];if((a|0)==-1){break c}if((a|0)>=0){break b}a=a&127;d=bc(e+26|0,a);g=z[d>>1];if((g|0)!=65535&(b|0)!=(g|0)){break c}w[d>>1]=b;v[f|0]=a;break b}l=e+8|0;i=e+26|0;d=255;a=0;g=255;while(1){if((a|0)!=18){j=bc(i,a);k=z[j>>1];if((k|0)==65535){w[j>>1]=b;v[f|0]=a;break b}else{if(!(y[Jb(l,a)|0]&32)){g=v[Jb(h,k)|0]<0?a:g;d=a}a=a+1|0;continue}}break}if((d&255)!=255){a=(g&255)==255?d:g;d=bc(i,a&255);m=Jb(h,z[d>>1]),n=255,v[m|0]=n;w[d>>1]=b;v[f|0]=a}a=sl(e,b)}g=a&255;if((g|0)==255){break a}if(qk(x[e>>2])){break a}d=Cd(e+318|0,g);a=y[c+8|0]|y[c+9|0]<<8|(y[c+10|0]<<16|y[c+11|0]<<24);v[d+8|0]=a;v[d+9|0]=a>>>8;v[d+10|0]=a>>>16;v[d+11|0]=a>>>24;a=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);f=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[d|0]=f;v[d+1|0]=f>>>8;v[d+2|0]=f>>>16;v[d+3|0]=f>>>24;v[d+4|0]=a;v[d+5|0]=a>>>8;v[d+6|0]=a>>>16;v[d+7|0]=a>>>24;f=oR(g);h=f+3|0;a=0;while(1){if((a|0)==2){ph(x[e>>2],x[e+4>>2],b,Qt(g)|192,y[Jb(c,10)|0])}else{d=a?h:f;ph(x[e>>2],x[e+4>>2],b,d|32,y[Jb(c,a)|0]);ph(x[e>>2],x[e+4>>2],b,d|64,y[Jb(c,a+2|0)|0]);ph(x[e>>2],x[e+4>>2],b,d|96,y[Jb(c,a+4|0)|0]);ph(x[e>>2],x[e+4>>2],b,d|128,y[Jb(c,a+6|0)|0]);ph(x[e>>2],x[e+4>>2],b,d|224,y[Jb(c,a+8|0)|0]);a=a+1|0;continue}break}}}function Qia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=ib-48|0;ib=e;md(b,2);f=e+16|0;Bk(f,2,a+1|0);d=e+32|0;Fc(d,f);Fe(b+43|0,d);wb(d);a:{b:{c:{d:{switch(y[a|0]){case 0:f=x[b+4>>2];d=x[b+8>>2];break c;case 2:break b;case 1:break d;default:break a}}d=y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24);x[b>>2]=d;x[e+32>>2]=y[a+20|0]|y[a+21|0]<<8|(y[a+22|0]<<16|y[a+23|0]<<24);x[e+16>>2]=d-1;d=e+32|0;f=x[Hb(d,e+16|0)>>2];x[b+4>>2]=f;x[e+32>>2]=y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24);d=x[Hb(d,b)>>2];x[b+8>>2]=d;w[b+34>>1]=z[b+34>>1]&65533|y[a+31|0]<<1&2}if(d>>>0>f>>>0&d>>>0>=2){break a}w[b+34>>1]=0;x[b+4>>2]=0;x[b+8>>2]=0;break a}f=e+16|0;Ph(f,a+16|0);d=x[e+16>>2];x[e+32>>2]=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);Ph(f,a+20|0);d=x[e+16>>2];x[e+36>>2]=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);Ph(f,a+24|0);d=x[e+16>>2];d=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);x[e+40>>2]=d;x[e+8>>2]=d;d=x[e+36>>2];x[e>>2]=x[e+32>>2];x[e+4>>2]=d;Rm(b,1,e)}v[e+32|0]=y[a+28|0];v[e+16|0]=64;g=b,h=y[Ub(e+32|0,e+16|0)|0]<<2,w[g+30>>1]=h;d=y[a+32|0]|y[a+33|0]<<8|(y[a+34|0]<<16|y[a+35|0]<<24);x[b+24>>2]=d;b=b+24|0;e:{if(!c){break e}if(y[a|0]==2){d=d&65535;x[b>>2]=d;break e}if(A[b>>2]>=65536){x[b>>2]=65535}d=x[b>>2]}f:{g:{if(!d){a=8363;break g}a=1024;if(d>>>0>1023){break f}}x[b>>2]=a}ib=e+48|0}function qK(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=ib-16|0;ib=h;g=x[a+32>>2];f=Ip(g);if(!f){f=Hp(g)}a:{b:{c:{if(b>>>0>=f>>>0){b=ba(8)|0;x[27524]=0;c=Q(55,h|0,6003)|0;a=x[27524];x[27524]=0;if((a|0)==1){break c}lc(b,c);x[27524]=0;U(123,b|0,50060,962);a=x[27524];x[27524]=0;if((a|0)!=1){break a}a=P()|0;wb(c);break b}if(c>>>0>=120){b=ba(8)|0;x[27524]=0;c=Q(55,h|0,11214)|0;a=x[27524];x[27524]=0;if((a|0)!=1){lc(b,c);x[27524]=0;U(123,b|0,50060,962);a=x[27524];x[27524]=0;if((a|0)!=1){break a}a=P()|0;wb(c);break b}a=P()|0;ca(b|0);break b}f=oz(g,65535);j=(f|0)==65535?255:f;w[h>>1]=j;f=g+D(j,872)|0;i=f+1074992|0;io(i,g,65535,1024);c=c+1|0;v[f+1075794|0]=c;v[f+1075791|0]=c;w[f+1075778>>1]=0;ym(i);cq(x[a+32>>2],i,b+1|0,0,1,1);x[f+1075688>>2]=65536;Gt(x[a+32>>2],i,c,0,1,1,65535);l=f+1075684|0,m=Al(Pu(e*128,-128,128)+128),x[l>>2]=m;l=f+1075680|0,m=Al(Pu(d*256,0,256)),x[l>>2]=m;c=x[a+32>>2];i=c+1074478|0;b=i;c=b+(z[c+480212>>1]<<1)|0;g=z[h>>1];f=g;while(1){d:{e:{if((b|0)!=(c|0)){if((f|0)!=z[b>>1]){break e}}else{b=c}break d}b=b+2|0;continue}break}f:{if((b|0)==(c|0)){break f}f=b;while(1){f=f+2|0;if((f|0)==(c|0)){c=b;break f}k=z[f>>1];if((k|0)==(g|0)){continue}w[b>>1]=k;b=b+2|0;g=z[h>>1];continue}}l=x[a+32>>2],m=Oz(i,c),w[l+480212>>1]=m;ib=h+16|0;return j|0}a=P()|0;ca(b|0)}S(a|0)}p()}function ala(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=x[a>>2];b=yu(c,x[a+4>>2]);if(b>>>0<=63){g=ib-32|0;ib=g;f=64-b|0;c=x[Db(a)>>2];d=x[a+4>>2];a:{if(f>>>0<=(c-d|0)/33>>>0){b=ib-16|0;ib=b;x[b>>2]=a;a=x[a+4>>2];x[b+4>>2]=a;x[b+8>>2]=a+D(f,33);a=x[b+4>>2];c=x[b+8>>2];while(1){if((a|0)==(c|0)){ic(b);ib=b+16|0}else{fV(a);a=a+33|0;x[b+4>>2]=a;continue}break}break a}i=Db(a);c=g+8|0;h=yu(x[a>>2],d)+f|0;d=ib-16|0;ib=d;x[d+12>>2]=h;e=ib-16|0;ib=e;x[e+12>>2]=130150524;x[e+8>>2]=2147483647;b=x[Hb(e+12|0,e+8|0)>>2];ib=e+16|0;b:{if(b>>>0>=h>>>0){e=kV(a);if(e>>>0<b>>>1>>>0){x[d+8>>2]=e<<1;b=x[Yc(d+8|0,d+12|0)>>2]}ib=d+16|0;break b}_c();p()}e=yu(x[a>>2],x[a+4>>2]);tg(c+12|0,i);if(b){if(b>>>0>=130150525){Vg();p()}d=mc(D(b,33))}else{d=0}x[c>>2]=d;e=d+D(e,33)|0;x[c+8>>2]=e;x[c+4>>2]=e;j=zc(c),k=d+D(b,33)|0,x[j>>2]=k;b=ib-16|0;ib=b;x[b>>2]=x[c+8>>2];d=x[c+8>>2];x[b+8>>2]=c+8;x[b+4>>2]=d+D(f,33);d=x[b>>2];while(1){if(x[b+4>>2]!=(d|0)){fV(d);d=x[b>>2]+33|0;x[b>>2]=d;continue}break}Vd(b);ib=b+16|0;b=c+4|0;f=x[a>>2];d=x[a+4>>2]-f|0;e=x[b>>2]+D((d|0)/-33|0,33)|0;x[b>>2]=e;if((d|0)>0){rc(e,f,d)}oc(a,b);oc(a+4|0,c+8|0);oc(Db(a),zc(c));x[c>>2]=x[c+4>>2];b=x[c+4>>2];a=x[c+8>>2];while(1){if((a|0)!=(b|0)){a=a-33|0;x[c+8>>2]=a;continue}break}a=x[c>>2];if(a){zc(c);Ib(a)}}ib=g+32|0;return}if((b|0)!=64){Od(a,c+2112|0)}}function m2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=E(0);a=ib-368|0;ib=a;x[a+352>>2]=c;x[a+360>>2]=b;Rw(a+200|0,d,a+224|0,a+220|0,a+216|0);d=Kb(a+184|0);b=ad(d);x[27524]=0;R(60,d|0,b|0);b=x[27524];x[27524]=0;a:{b:{c:{if((b|0)!=1){c=Qc(d,0);x[a+180>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;v[a+7|0]=1;v[a+6|0]=69;h=x[a+216>>2];i=x[a+220>>2];while(1){d:{x[27524]=0;b=Q(1169,a+360|0,a+352|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break d}if(!b){break c}g=x[a+180>>2];b=Eb(d);if((g|0)==(b+c|0)){x[27524]=0;R(60,d|0,b<<1);c=x[27524];x[27524]=0;if((c|0)==1){break b}c=ad(d);x[27524]=0;R(60,d|0,c|0);c=x[27524];x[27524]=0;if((c|0)==1){break b}c=Qc(d,0);x[a+180>>2]=b+c}x[27524]=0;b=T(1171,x[a+360>>2])|0;g=x[27524];x[27524]=0;if((g|0)==1){break d}if(Qw(b,a+7|0,a+6|0,c,a+180|0,i,h,a+200|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}x[27524]=0;T(1173,a+360|0)|0;b=x[27524];x[27524]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Eb(a+200|0)|!y[a+7|0]){break e}b=x[a+12>>2];if((b-(a+16|0)|0)>159){break e}x[a+12>>2]=b+4;x[b>>2]=x[a+8>>2]}j=f,k=dH(c,x[a+180>>2],e),B[j>>2]=k;Of(a+200|0,a+16|0,x[a+12>>2],e);x[27524]=0;b=Q(1170,a+360|0,a+352|0)|0;c=x[27524];x[27524]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+360>>2];wb(d);wb(a+200|0);ib=a+368|0;break a}}b=P()|0;wb(d);wb(a+200|0);S(b|0);p()}return b|0}function Tna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=Kb(a);k=Eb(b);x[27524]=0;R(301,h|0,k|0);a=x[27524];x[27524]=0;a:{b:{if((a|0)!=1){a=0;while(1){c:{if((a|0)==(k|0)){a=!f;if(!(l?a&(m^-1):a)){break c}return}e=v[ng(b,a)|0];g=e&255;d:{e:{f:{g:{switch(f+1|0){case 1:f=1;h:{switch(g-123|0){case 2:break h;case 0:break d;default:break f}}f=3;break d;case 2:i:{switch(g-123|0){case 2:m=1;e=i+1|0;f=0;if(d>>>0<=i>>>0){i=e;break d}x[27524]=0;Q(302,h|0,Cd(c,i)|0)|0;g=x[27524];x[27524]=0;i=e;if((g|0)!=1){break d}a=P()|0;break b;case 0:break f;default:break i}}f=-1;e=e-48|0;if((e&255)>>>0>9){break d}l=1;f=2;j=e;break d;case 3:f=-1;j:{switch(g-123|0){case 2:f=0;if(d>>>0<=j>>>0){break d}x[27524]=0;Q(302,h|0,Cd(c,j)|0)|0;e=x[27524];x[27524]=0;if((e|0)!=1){break d}a=P()|0;break b;case 0:break d;default:break j}}if((e-48&255)>>>0>9){break d}j=(D(j,10)+e|0)-48|0;l=1;f=2;break d;case 4:break g;case 0:break e;default:break d}}g=(e|0)!=125;f=-1;e=125;if(g){break d}}f=0;x[27524]=0;Q(303,h|0,e|0)|0;e=x[27524];x[27524]=0;if((e|0)!=1){break d}a=P()|0;break b}f=-1}a=a+1|0;continue}break}b=ba(8)|0;x[27524]=0;a=T(122,b|0)|0;c=x[27524];x[27524]=0;if((c|0)!=1){x[27524]=0;U(123,a|0,41828,25);a=x[27524];x[27524]=0;if((a|0)!=1){break a}a=P()|0;break b}a=P()|0;ca(b|0);break b}a=P()|0}wb(h);S(a|0)}p()}function v2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=E(0);a=ib-272|0;ib=a;x[a+256>>2]=c;x[a+264>>2]=b;Vw(a+208|0,d,a+224|0,a+223|0,a+222|0);d=Kb(a+192|0);b=ad(d);x[27524]=0;R(60,d|0,b|0);b=x[27524];x[27524]=0;a:{b:{c:{if((b|0)!=1){c=Qc(d,0);x[a+188>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;v[a+7|0]=1;v[a+6|0]=69;h=v[a+222|0];i=v[a+223|0];while(1){d:{x[27524]=0;b=Q(1153,a+264|0,a+256|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break d}if(!b){break c}g=x[a+188>>2];b=Eb(d);if((g|0)==(b+c|0)){x[27524]=0;R(60,d|0,b<<1);c=x[27524];x[27524]=0;if((c|0)==1){break b}c=ad(d);x[27524]=0;R(60,d|0,c|0);c=x[27524];x[27524]=0;if((c|0)==1){break b}c=Qc(d,0);x[a+188>>2]=b+c}x[27524]=0;b=T(1155,x[a+264>>2])|0;g=x[27524];x[27524]=0;if((g|0)==1){break d}if(Uw(b,a+7|0,a+6|0,c,a+188|0,i,h,a+208|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}x[27524]=0;T(1157,a+264|0)|0;b=x[27524];x[27524]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Eb(a+208|0)|!y[a+7|0]){break e}b=x[a+12>>2];if((b-(a+16|0)|0)>159){break e}x[a+12>>2]=b+4;x[b>>2]=x[a+8>>2]}j=f,k=dH(c,x[a+188>>2],e),B[j>>2]=k;Of(a+208|0,a+16|0,x[a+12>>2],e);x[27524]=0;b=Q(1154,a+264|0,a+256|0)|0;c=x[27524];x[27524]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+264>>2];wb(d);wb(a+208|0);ib=a+272|0;break a}}b=P()|0;wb(d);wb(a+208|0);S(b|0);p()}return b|0}function l2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=ib-368|0;ib=a;x[a+352>>2]=c;x[a+360>>2]=b;Rw(a+200|0,d,a+224|0,a+220|0,a+216|0);d=Kb(a+184|0);b=ad(d);x[27524]=0;R(60,d|0,b|0);b=x[27524];x[27524]=0;a:{b:{c:{if((b|0)!=1){c=Qc(d,0);x[a+180>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;v[a+7|0]=1;v[a+6|0]=69;h=x[a+216>>2];i=x[a+220>>2];while(1){d:{x[27524]=0;b=Q(1169,a+360|0,a+352|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break d}if(!b){break c}g=x[a+180>>2];b=Eb(d);if((g|0)==(b+c|0)){x[27524]=0;R(60,d|0,b<<1);c=x[27524];x[27524]=0;if((c|0)==1){break b}c=ad(d);x[27524]=0;R(60,d|0,c|0);c=x[27524];x[27524]=0;if((c|0)==1){break b}c=Qc(d,0);x[a+180>>2]=b+c}x[27524]=0;b=T(1171,x[a+360>>2])|0;g=x[27524];x[27524]=0;if((g|0)==1){break d}if(Qw(b,a+7|0,a+6|0,c,a+180|0,i,h,a+200|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}x[27524]=0;T(1173,a+360|0)|0;b=x[27524];x[27524]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Eb(a+200|0)|!y[a+7|0]){break e}b=x[a+12>>2];if((b-(a+16|0)|0)>159){break e}x[a+12>>2]=b+4;x[b>>2]=x[a+8>>2]}j=f,k=bH(c,x[a+180>>2],e),C[j>>3]=k;Of(a+200|0,a+16|0,x[a+12>>2],e);x[27524]=0;b=Q(1170,a+360|0,a+352|0)|0;c=x[27524];x[27524]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+360>>2];wb(d);wb(a+200|0);ib=a+368|0;break a}}b=P()|0;wb(d);wb(a+200|0);S(b|0);p()}return b|0}function UI(a){var b=0,c=0,d=0,e=0;Ge(x[a+80>>2],x[a+20>>2]);while(1){c=x[a+28>>2];if((b|0)<x[a+24>>2]){Ge(x[a+80>>2],x[c+(b<<2)>>2]);b=b+1|0;continue}break}Ge(x[a+80>>2],c);a:{if(!x[a+396>>2]){break a}c=0;while(1){if(x[a+264>>2]<=(c|0)){break a}e=x[a+396>>2]+D(c,24)|0;d=x[e+16>>2];if(d){b=0;while(1){if((b|0)<x[(x[a+124>>2]+D(y[e+13|0],2096)|0)+4>>2]){Ge(x[a+80>>2],x[(b<<2)+d>>2]);b=b+1|0;d=x[e+16>>2];continue}break}Ge(x[a+80>>2],d)}Ge(x[a+80>>2],x[e+20>>2]);c=c+1|0;continue}}d=x[a+124>>2];if(d){c=0;while(1){if((c|0)<x[a+120>>2]){b=D(c,2096)+d|0;Ge(x[a+80>>2],x[b+8>>2]);Ge(x[a+80>>2],x[b+28>>2]);Ge(x[a+80>>2],x[b+32>>2]);Ge(x[a+80>>2],x[b+2084>>2]);b=x[b+2088>>2];Ge(x[a+80>>2],b?b-4|0:0);c=c+1|0;d=x[a+124>>2];continue}break}Ge(x[a+80>>2],d)}Ge(x[a+80>>2],x[a+260>>2]);Ge(x[a+80>>2],x[a+396>>2]);c=x[a+404>>2];if(c){b=0;while(1){if((b|0)<x[a+400>>2]){Ge(x[a+80>>2],x[(D(b,40)+c|0)+4>>2]);b=b+1|0;c=x[a+404>>2];continue}break}Ge(x[a+80>>2],c)}c=0;b=0;while(1){if(!(x[a+4>>2]<=(b|0)|b>>>0>15)){d=(b<<2)+a|0;Ge(x[a+80>>2],x[d+800>>2]);Ge(x[a+80>>2],x[d+928>>2]);Ge(x[a+80>>2],x[d+996>>2]);b=b+1|0;continue}break}while(1){if((c|0)!=2){b=(c<<2)+a|0;Ge(x[a+80>>2],x[b+1068>>2]);Ge(x[a+80>>2],x[b+1076>>2]);Ge(x[a+80>>2],x[b+1084>>2]);Ge(x[a+80>>2],x[b+1092>>2]);Ge(x[a+80>>2],x[b+1100>>2]);c=c+1|0;continue}break}}function u2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=ib-272|0;ib=a;x[a+256>>2]=c;x[a+264>>2]=b;Vw(a+208|0,d,a+224|0,a+223|0,a+222|0);d=Kb(a+192|0);b=ad(d);x[27524]=0;R(60,d|0,b|0);b=x[27524];x[27524]=0;a:{b:{c:{if((b|0)!=1){c=Qc(d,0);x[a+188>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;v[a+7|0]=1;v[a+6|0]=69;h=v[a+222|0];i=v[a+223|0];while(1){d:{x[27524]=0;b=Q(1153,a+264|0,a+256|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break d}if(!b){break c}g=x[a+188>>2];b=Eb(d);if((g|0)==(b+c|0)){x[27524]=0;R(60,d|0,b<<1);c=x[27524];x[27524]=0;if((c|0)==1){break b}c=ad(d);x[27524]=0;R(60,d|0,c|0);c=x[27524];x[27524]=0;if((c|0)==1){break b}c=Qc(d,0);x[a+188>>2]=b+c}x[27524]=0;b=T(1155,x[a+264>>2])|0;g=x[27524];x[27524]=0;if((g|0)==1){break d}if(Uw(b,a+7|0,a+6|0,c,a+188|0,i,h,a+208|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}x[27524]=0;T(1157,a+264|0)|0;b=x[27524];x[27524]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Eb(a+208|0)|!y[a+7|0]){break e}b=x[a+12>>2];if((b-(a+16|0)|0)>159){break e}x[a+12>>2]=b+4;x[b>>2]=x[a+8>>2]}j=f,k=bH(c,x[a+188>>2],e),C[j>>3]=k;Of(a+208|0,a+16|0,x[a+12>>2],e);x[27524]=0;b=Q(1154,a+264|0,a+256|0)|0;c=x[27524];x[27524]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+264>>2];wb(d);wb(a+208|0);ib=a+272|0;break a}}b=P()|0;wb(d);wb(a+208|0);S(b|0);p()}return b|0}function qR(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;h=ib-16|0;ib=h;c=x[a>>2];a:{if(qk(c)){i=ib-16|0;ib=i;e=mc(3848);d=e+808|0;c=e+16|0;while(1){x[c+16>>2]=0;x[c+20>>2]=0;x[c+36>>2]=0;v[c+42|0]=1;w[c+40>>1]=257;x[c+24>>2]=0;x[c+28>>2]=0;w[c+32>>1]=0;c=c+44|0;if((c|0)!=(d|0)){continue}break}c=e+3832|0;while(1){x[d>>2]=0;x[d+4>>2]=0;x[d+68>>2]=0;x[d+72>>2]=0;x[d+24>>2]=0;x[d+28>>2]=0;w[d+20>>1]=511;x[d+16>>2]=-1;w[d+14>>1]=1;w[d+6>>1]=0;w[d+8>>1]=0;w[d+10>>1]=0;w[d+12>>1]=0;v[d+73|0]=0;v[d+74|0]=0;v[d+75|0]=0;v[d+76|0]=0;v[d+77|0]=0;v[d+78|0]=0;v[d+79|0]=0;v[d+80|0]=0;d=d+84|0;if((c|0)!=(d|0)){continue}break}x[e+3832>>2]=0;x[e+3836>>2]=0;c=e+3837|0;v[c|0]=0;v[c+1|0]=0;v[c+2|0]=0;v[c+3|0]=0;v[c+4|0]=0;v[c+5|0]=0;v[c+6|0]=0;v[c+7|0]=0;while(1){if((g|0)==36){while(1){if((f|0)==18){b:{f=0;g=0;while(1)if((f|0)==18){while(1){if((g|0)==36){break b}ho((e+D(g,84)|0)+808|0);g=g+1|0;continue}}else{d=(e+D(f,44)|0)+16|0;c=x[(f<<2)+28928>>2];c:{if(!(!(1<<f&3591)|f>>>0>11)){c=e+D(c,84)|0;wR(d,c+808|0,c+1060|0,c+1312|0,c+1564|0);break c}c=e+D(c,84)|0;wR(d,c+808|0,c+1060|0,0,0)}f=f+1|0;continue}}}else{x[(e+D(f,44)|0)+32>>2]=e;f=f+1|0;continue}break}vR(e,b)}else{td((e+D(g,84)|0)+808|0,e);g=g+1|0;continue}break}b=x[uf(i+8|0,e)>>2];ib=i+16|0;x[h+8>>2]=b;b=h+8|0;LA(a,b);Cj(b);break a}vR(c,b)}pR(a);ib=h+16|0}function mma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=ib-80|0;ib=d;b=b&4095;w[d+78>>1]=b;a:{b:{c:{d:{if(b>>>0>=81){e=ib-16|0;ib=e;f=xc(e,4454);$c(d- -64|0,f);xb(f);ib=e+16|0;x[27524]=0;e=((b|0)==4095?c:b-80|0)+734016|0;c=qoa(e,e>>31,1e4,0)+14780|0;b=kb;b=roa(c,c>>>0<14780?b+1|0:b,3652425,0);c=(((e+((b|0)/-4|0)|0)+D(b,-365)|0)+((b|0)/100|0)|0)+((b|0)/-400|0)|0;if((c|0)<0){b=b-1|0;c=(((e+((b|0)/-4|0)|0)+D(b,-365)|0)+((b|0)/100|0)|0)+((b|0)/-400|0)|0}g=b;b=(D(c,100)+52|0)/3060|0;e=b+2|0;f=(e|0)/12|0;x[d+44>>2]=g+f;R(98,d+48|0,d+44|0);g=x[27524];x[27524]=0;e:{f:{g:{h:{i:{j:{if((g|0)!=1){x[27524]=0;x[d+28>>2]=(e+D(f,-12)|0)+1;R(101,d+32|0,d+28|0);e=x[27524];x[27524]=0;if((e|0)==1){break j}x[27524]=0;x[d+12>>2]=(((D(b,306)+5|0)/-10|0)+c|0)+1;R(101,d+16|0,d+12|0);b=x[27524];x[27524]=0;if((b|0)==1){break i}x[27524]=0;ea(407,a|0,d- -64|0,d+48|0,d+32|0,d+16|0);a=x[27524];x[27524]=0;if((a|0)==1){break h}xb(d+16|0);xb(d+32|0);break d}b=P()|0;break e}b=P()|0;break f}b=P()|0;break g}b=P()|0;xb(d+16|0)}xb(d+32|0)}xb(d+48|0)}break a}_f(d- -64|0,4434);x[27524]=0;R(408,d+48|0,d+78|0);b=x[27524];x[27524]=0;if((b|0)==1){break c}x[27524]=0;U(149,a|0,d- -64|0,d+48|0);a=x[27524];x[27524]=0;if((a|0)==1){break b}}xb(d+48|0);$b(d- -64|0);ib=d+80|0;return}b=P()|0;break a}b=P()|0;xb(d+48|0)}$b(d- -64|0);S(b|0);p()}function bo(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=ib-16|0;ib=d;g=a+1074312|0;Ab(d+8|0,g,96);i=b,j=(k=0,l=x[b+660>>2],m=zb(x[x[d+8>>2]>>2],x[d+12>>2]),m?k:l)+c|0,x[i+660>>2]=j;f=x[a+480180>>2];e=x[b+84>>2];if(!(!(f&18)|e>>>0>c>>>0|(!(y[b+88|0]&2)|!e))){h=c;c=x[b+80>>2];c=((h-c>>>0)%(e-c>>>0)|0)+c|0}c=c>>>(x[b+88>>2]&1&(f|0)==16384)|0;a:{b:{if(!Wc(y[b+788|0])){Ab(d+8|0,g,114);if(!zb(x[x[d+8>>2]>>2],x[d+12>>2])){break b}}e=x[b+656>>2];c:{if(!e){break c}f=y[b+788|0];if(!Wc(f)){break c}e=z[bc(e+236|0,f-1|0)>>1];if(!e|e>>>0>z[a+480190>>1]){break a}}if(y[a+480210|0]&32){e=c;c=x[b+660>>2];x[b+660>>2]=e+c}x[b>>2]=0;x[b+4>>2]=c;if((!(y[b+88|0]&2)|A[b+84>>2]>c>>>0)&A[b+76>>2]>c>>>0){break a}Ab(d+8|0,g,57);d:{if(!zb(x[x[d+8>>2]>>2],x[d+12>>2])){c=x[a+480180>>2];if((c|0)!=16){break d}}x[b+700>>2]=0;x[b+88>>2]=x[b+88>>2]|2097152;break a}if(!(c&1048581)){Ab(d+8|0,g,27);if(zb(x[x[d+8>>2]>>2],x[d+12>>2])){if(y[a+480208|0]&4){c=x[b+76>>2];x[b>>2]=0;x[b+4>>2]=c;break a}x[b>>2]=0;x[b+4>>2]=0;break a}c=x[b+80>>2];x[b>>2]=0;x[b+4>>2]=c;if(!(y[a+480208|0]&4)){break a}a=x[b+76>>2];if(a>>>0<5){break a}x[b>>2]=0;x[b+4>>2]=a-2;break a}if(!(y[b+88|0]&2)|(c|0)!=1){break a}a=x[b+80>>2];x[b>>2]=0;x[b+4>>2]=a;break a}if(!(x[a+480180>>2]&268582928)|A[b+76>>2]<=c>>>0){break a}x[b>>2]=0;x[b+4>>2]=c}ib=d+16|0}function jA(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=ib-32|0;ib=e;if(b&5){if((b|0)==1){d=qoa(x[a+24>>2],0,8363,0)+4136|0;c=kb;h=a,i=Ec(soa(d,d>>>0<4136?c+1|0:c,8272,0),kb),x[h+24>>2]=i}d=ib-16|0;ib=d;g=d+8|0;c=ib-16|0;ib=c;f=x[a+24>>2];a:{if(!f){Mo(g);break a}gC(c+8|0,Vb(Al(xp(+(f>>>0)*.00011957431543704412)*2215.9795828054475),-16384,16383),128);f=x[c+8>>2];v[c+7|0]=x[c+12>>2];fe(g,f,c+7|0)}ib=c+16|0;ZB(d,a+36|0,a+37|0);YB(d,g);ib=d+16|0}if(b&3){w[a+38>>1]=0;w[a+40>>1]=0;v[a+36|0]=0;w[a+34>>1]=z[a+34>>1]&65499}if(b&7){w[a+32>>1]=64;c=z[a+34>>1];if(c&8){d=x[a+16>>2];x[a+4>>2]=x[a+12>>2];x[a+8>>2]=d;c=c&16?c|6:c&65529|2}x[a+12>>2]=0;x[a+16>>2]=0;w[a+34>>1]=c&65511}b:{if(!(b&4)){break b}c=z[a+34>>1];if(!(c&32)){w[a+28>>1]=128;w[a+34>>1]=c|32}Ff(a+40|0,15);Ff(a+41|0,63);if(!y[a+41|0]){break b}d=y[a+40|0];if(!d){break b}c=y[a+39|0];if(c){c=Nl(Ec(((d<<8|c>>>1)>>>0)/(c>>>0)|0,0))}else{c=255}v[a+39|0]=c}c:{d:{if((b|0)!=4){if((b|0)==16777216){break c}if((b|0)!=32|y[a+38|0]!=2){break d}v[a+38|0]=3;break d}if(y[a+38|0]!=4){break d}v[a+38|0]=0}w[a+34>>1]=z[a+34>>1]&49151}e:{if(!(!(y[a+35|0]&2)|b&16777218)){x[e+24>>2]=0;x[e+8>>2]=0;x[e+16>>2]=0;x[e+20>>2]=0;x[e>>2]=0;x[e+4>>2]=0;Rm(a,0,e);break e}if(!(y[a+35|0]&2)|(b|0)!=2){break e}a=a+68|0;b=Jb(a,8);v[b|0]=y[b|0]&3;a=Jb(a,9);v[a|0]=y[a|0]&3}ib=e+32|0}function Xfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=ib-16|0;ib=f;s=x[a+16>>2];t=qg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);n=x[a+128>>2];a:{if(!n){k=x[a+8>>2];l=x[a+12>>2];e=x[a>>2];b=x[a+4>>2];m=0;break a}k=x[a+8>>2];l=x[a+12>>2];o=rg(k,l,n);p=kb;g=x[a+76>>2];e=x[a>>2];b=x[a+4>>2];Zf(e,b,rf(k,l,d),kb);m=g>>>0<kb>>>0?d:0}h=a+112|0;i=x[a+40>>2];j=x[a+36>>2];x[f>>2]=e;x[f+4>>2]=b;while(1){if(d){d=d-1|0;x[f+8>>2]=e;x[f+12>>2]=0;m=m-1|0;g=m;o=g?o:0;p=g?p:0;r=(((b&2147483647)<<1|e>>>31)&-2)+s|0;g=n;b:{c:while(1){d:{if((g|0)<=0){Pb(h,x[a+120>>2],x[a+124>>2]);g=x[a+116>>2];if(!g){break b}q=((x[f+12>>2]&2147483647)<<1|x[f+8>>2]>>>31)&-2;e=0;b=0;break d}q=((x[f+12>>2]&2147483647)<<1|x[f+8>>2]>>>31)&-2;b=0;e=0;while(1)if((b|0)==2){Sd(h,(e|0)/8<<16>>16);Rd(h,4);Pb(f+8|0,o,p);g=g-1|0;continue c}else{e=(v[(b+q|0)+r|0]<<8)+e|0;b=b+1|0;continue}}break}while(1){if((b|0)!=2){e=(v[(b+q|0)+r|0]<<8)+e|0;b=b+1|0;continue}break}Sd(h,(e|0)/8<<16>>16);Rd(h,g);x[h>>2]=x[h>>2];x[h+4>>2]=0}b=x[a+32>>2];j=x[a+28>>2]+j|0;g=pg(h,t);x[c>>2]=D(j>>12,g)+x[c>>2];i=b+i|0;x[c+4>>2]=x[c+4>>2]+D(g,i>>12);Pb(f,k,l);c=c+8|0;e=x[f>>2];b=x[f+4>>2];continue}break}x[a>>2]=e;x[a+4>>2]=b;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+24>>2]=i>>12;ib=f+16|0}function _R(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=ib-240|0;ib=e;if(!y[110256]){if(!y[110132]){c=ib-16|0;ib=c;Kb(110108);x[27530]=0;v[110124]=0;x[27532]=0;x[27524]=0;b=ga(29)|0;a=x[27524];x[27524]=0;a:{b:{c:{d:{e:{f:{if((a|0)!=1){x[c+8>>2]=b;b=c+8|0;$A(110120,ce(b));Cj(b);v[110124]=0;break f}a=Ba(108196,108780)|0;b=jb;if((da(108196)|0)==(b|0)){_(a|0)|0;x[27524]=0;Z(30);c=x[27524];x[27524]=0;if((c|0)==1){break d}p()}if((da(108780)|0)!=(b|0)){break c}_(a|0)|0;x[27524]=0;v[110124]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)==1){a=P()|0;break c}if(y[110124]){break e}}x[27524]=0;Y(31,110104);b=x[27524];x[27524]=0;if((b|0)!=1){break e}a=P()|0;break c}ib=c+16|0;break a}a=P()|0;x[27524]=0;Z(18);c=x[27524];x[27524]=0;if((c|0)==1){break b}}Cj(110128);Cj(110120);wb(110108);S(a|0);p()}V(0)|0;Sb();p()}v[110132]=1}c=ib+-64|0;ib=c;b=c+16|0;g=ib-16|0;ib=g;h=JR(g+8|0);j=e+120|0;while(1){if((i|0)==12){ib=g+16|0}else{f=ib-48|0;ib=f;a=x[h+4>>2];d=x[h>>2];g:{if((a|0)==(d|0)){break g}a=(a-d|0)+1|0;if(!a){a=yR(DR(f+8|0,32));break g}d=G(a);d=DR(f+8|0,(a<<d+1?32:31)-d|0);while(1){k=yR(d);if(a>>>0<=k>>>0){continue}break}a=x[h>>2]+k|0}ib=f+48|0;l=Bb(b,i),m=a,x[l>>2]=m;i=i+1|0;continue}break}b=UR(c,b,ZR(b));RR(j,b);Km(b);ib=c- -64|0;rc(110136,rc(e,j,120),116);v[110256]=1}ib=e+240|0}function p2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;a=ib-352|0;ib=a;x[a+336>>2]=c;x[a+344>>2]=b;b=ij(d);i=vp(d,a+224|0);up(a+208|0,d,a+332|0);d=Kb(a+192|0);c=ad(d);x[27524]=0;R(60,d|0,c|0);c=x[27524];x[27524]=0;a:{b:{c:{if((c|0)!=1){c=Qc(d,0);x[a+188>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;j=x[a+332>>2];while(1){d:{x[27524]=0;g=Q(1169,a+344|0,a+336|0)|0;h=x[27524];x[27524]=0;if((h|0)==1){break d}if(!g){break c}h=x[a+188>>2];g=Eb(d);if((h|0)==(g+c|0)){x[27524]=0;R(60,d|0,g<<1);c=x[27524];x[27524]=0;if((c|0)==1){break b}c=ad(d);x[27524]=0;R(60,d|0,c|0);c=x[27524];x[27524]=0;if((c|0)==1){break b}c=Qc(d,0);x[a+188>>2]=g+c}x[27524]=0;g=T(1171,x[a+344>>2])|0;h=x[27524];x[27524]=0;if((h|0)==1){break d}if(Cn(g,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,i)){break c}x[27524]=0;T(1173,a+344|0)|0;g=x[27524];x[27524]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Eb(a+208|0)){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}k=f,l=iH(c,x[a+188>>2],e,b),x[k>>2]=l;x[f+4>>2]=kb;Of(a+208|0,a+16|0,x[a+12>>2],e);x[27524]=0;b=Q(1170,a+344|0,a+336|0)|0;c=x[27524];x[27524]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+344>>2];wb(d);wb(a+208|0);ib=a+352|0;break a}}b=P()|0;wb(d);wb(a+208|0);S(b|0);p()}return b|0}function n2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;a=ib-352|0;ib=a;x[a+336>>2]=c;x[a+344>>2]=b;b=ij(d);i=vp(d,a+224|0);up(a+208|0,d,a+332|0);d=Kb(a+192|0);c=ad(d);x[27524]=0;R(60,d|0,c|0);c=x[27524];x[27524]=0;a:{b:{c:{if((c|0)!=1){c=Qc(d,0);x[a+188>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;j=x[a+332>>2];while(1){d:{x[27524]=0;g=Q(1169,a+344|0,a+336|0)|0;h=x[27524];x[27524]=0;if((h|0)==1){break d}if(!g){break c}h=x[a+188>>2];g=Eb(d);if((h|0)==(g+c|0)){x[27524]=0;R(60,d|0,g<<1);c=x[27524];x[27524]=0;if((c|0)==1){break b}c=ad(d);x[27524]=0;R(60,d|0,c|0);c=x[27524];x[27524]=0;if((c|0)==1){break b}c=Qc(d,0);x[a+188>>2]=g+c}x[27524]=0;g=T(1171,x[a+344>>2])|0;h=x[27524];x[27524]=0;if((h|0)==1){break d}if(Cn(g,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,i)){break c}x[27524]=0;T(1173,a+344|0)|0;g=x[27524];x[27524]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Eb(a+208|0)){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}k=f,l=eH(c,x[a+188>>2],e,b),x[k>>2]=l;x[f+4>>2]=kb;Of(a+208|0,a+16|0,x[a+12>>2],e);x[27524]=0;b=Q(1170,a+344|0,a+336|0)|0;c=x[27524];x[27524]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+344>>2];wb(d);wb(a+208|0);ib=a+352|0;break a}}b=P()|0;wb(d);wb(a+208|0);S(b|0);p()}return b|0}function RL(a){a=a|0;var b=0,c=0,d=0,e=0;e=ib-160|0;ib=e;d=Kc(e,11496);x[27524]=0;b=d+12|0;Q(55,b|0,10914)|0;c=x[27524];x[27524]=0;a:{if((c|0)==1){break a}x[27524]=0;b=d+24|0;Q(55,b|0,11326)|0;c=x[27524];x[27524]=0;if((c|0)==1){break a}x[27524]=0;b=d+36|0;Q(55,b|0,10906)|0;c=x[27524];x[27524]=0;if((c|0)==1){break a}x[27524]=0;b=d+48|0;Q(55,b|0,8191)|0;c=x[27524];x[27524]=0;if((c|0)==1){break a}x[27524]=0;b=d+60|0;Q(55,b|0,10891)|0;c=x[27524];x[27524]=0;if((c|0)==1){break a}x[27524]=0;b=d+72|0;Q(55,b|0,8257)|0;c=x[27524];x[27524]=0;if((c|0)==1){break a}x[27524]=0;b=d+84|0;Q(55,b|0,5623)|0;c=x[27524];x[27524]=0;if((c|0)==1){break a}x[27524]=0;b=d+96|0;Q(55,b|0,11900)|0;c=x[27524];x[27524]=0;if((c|0)==1){break a}x[27524]=0;b=d+108|0;Q(55,b|0,11269)|0;c=x[27524];x[27524]=0;if((c|0)==1){break a}x[27524]=0;b=d+120|0;Q(55,b|0,12169)|0;c=x[27524];x[27524]=0;if((c|0)==1){break a}x[27524]=0;b=d+132|0;Q(55,b|0,5475)|0;c=x[27524];x[27524]=0;if((c|0)==1){break a}x[27524]=0;b=d+144|0;Q(55,b|0,7283)|0;c=x[27524];x[27524]=0;if((c|0)==1){break a}x[27524]=0;W(1025,a|0,d|0,13)|0;a=x[27524];x[27524]=0;if((a|0)!=1){b=d+156|0;while(1){b=wb(b-12|0);if((d|0)!=(b|0)){continue}break}ib=e+160|0;return}b=d+156|0}a=P()|0;while(1){b=wb(b-12|0);if((d|0)!=(b|0)){continue}break}S(a|0);p()}function Hha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;d=ib-48|0;ib=d;l=a+480190|0;c=z[l>>1];v[d+32|0]=0;WQ(b,c+1|0,d+32|0);j=a+480192|0;if(z[j>>1]){h=Nb(d+32|0);q=d,r=Cb(x[a+484344>>2]),x[q+24>>2]=r;o=Cb(x[a+484348>>2]);m=a+480188|0;while(1){i=x[d+24>>2];if(Mb(i,o)){a:{if(!Mb(x[i>>2],x[i+4>>2])){break a}c=z[m>>1];x[27524]=0;v[d+8|0]=0;U(755,h|0,c|0,d+8|0);c=x[27524];x[27524]=0;if((c|0)!=1){q=d,r=Cb(x[i>>2]),x[q+16>>2]=r;k=0;b:while(1){f=0;if(A[i+12>>2]<=k>>>0){break a}while(1)if(z[m>>1]<=f>>>0){k=k+1|0;continue b}else{c:{c=x[d+16>>2];if(!Wc(y[c|0])){break c}d:{e:{c=y[c+1|0];if(c){g=z[j>>1];break e}g=z[j>>1];c=y[Jb(x[h>>2],f)|0];if(c){break e}c=1;break d}q=Jb(x[h>>2],f),r=c,v[q|0]=r;g=g&65535;e=g>>>0<c>>>0;g=e?g:c;c=e?1:c}while(1){e=c&65535;if(e>>>0>(g&65535)>>>0){break c}e=x[((e<<2)+a|0)+900380>>2];f:{if(!e){break f}e=z[bc(e+236|0,y[x[d+16>>2]]-1|0)>>1];if(e>>>0>z[l>>1]){break f}n=d+8|0;Ab(n,x[b>>2],e);bf(n,1)}c=c+1|0;continue}}f=f+1|0;MA(d+16|0);continue}}}a=P()|0;ec(h);S(a|0);p()}ou(d+24|0);continue}else{c=z[a+480190>>1];while(1){if(c){Ab(d+8|0,x[b>>2],c);if(!zb(x[x[d+8>>2]>>2],x[d+12>>2])){e=f;f=D(c,104)+a|0;f=e+_d(x[f+484380>>2],x[f+484400>>2])|0}c=c-1|0;continue}else{ec(h)}break}}break}}ib=d+48|0;return f&65535}function rG(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;a=ib-16|0;ib=a;x[a+12>>2]=c;x[a+8>>2]=f;x[a+12>>2]=c;x[a+8>>2]=f;c=x[a+12>>2];a:{while(1){if(c>>>0>=d>>>0){f=0;break a}b:{b=z[c>>1];c:{if(b>>>0<=127){f=1;c=x[a+8>>2];if((g-c|0)<=0){break a}x[a+8>>2]=c+1;v[c|0]=b;break c}if(b>>>0<=2047){c=x[a+8>>2];if((g-c|0)<2){break b}x[a+8>>2]=c+1;v[c|0]=b>>>6|192;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b&63|128;break c}if(b>>>0<=55295){c=x[a+8>>2];if((g-c|0)<3){break b}x[a+8>>2]=c+1;v[c|0]=b>>>12|224;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b>>>6&63|128;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b&63|128;break c}d:{e:{if(b>>>0<=56319){f=1;if((d-c|0)<4){break a}i=z[c+2>>1];if((i&64512)!=56320){break e}if((g-x[a+8>>2]|0)<4){break a}x[a+12>>2]=c+2;c=x[a+8>>2];x[a+8>>2]=c+1;f=c;c=(b>>>6&15)+1|0;v[f|0]=c>>>2|240;f=x[a+8>>2];x[a+8>>2]=f+1;v[f|0]=c<<4&48|b>>>2&15|128;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=i>>>6&15|b<<4&48|128;b=x[a+8>>2];x[a+8>>2]=b+1;v[b|0]=i&63|128;break c}if(b>>>0>=57344){break d}}f=2;break a}c=x[a+8>>2];if((g-c|0)<3){break b}x[a+8>>2]=c+1;v[c|0]=b>>>12|224;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b>>>6&63|128;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b&63|128}c=x[a+12>>2]+2|0;x[a+12>>2]=c;continue}break}f=1}x[e>>2]=x[a+12>>2];x[h>>2]=x[a+8>>2];ib=a+16|0;return f|0}function q2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;a=ib-352|0;ib=a;x[a+336>>2]=c;x[a+344>>2]=b;b=ij(d);i=vp(d,a+224|0);up(a+208|0,d,a+332|0);d=Kb(a+192|0);c=ad(d);x[27524]=0;R(60,d|0,c|0);c=x[27524];x[27524]=0;a:{b:{c:{if((c|0)!=1){c=Qc(d,0);x[a+188>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;j=x[a+332>>2];while(1){d:{x[27524]=0;g=Q(1169,a+344|0,a+336|0)|0;h=x[27524];x[27524]=0;if((h|0)==1){break d}if(!g){break c}h=x[a+188>>2];g=Eb(d);if((h|0)==(g+c|0)){x[27524]=0;R(60,d|0,g<<1);c=x[27524];x[27524]=0;if((c|0)==1){break b}c=ad(d);x[27524]=0;R(60,d|0,c|0);c=x[27524];x[27524]=0;if((c|0)==1){break b}c=Qc(d,0);x[a+188>>2]=g+c}x[27524]=0;g=T(1171,x[a+344>>2])|0;h=x[27524];x[27524]=0;if((h|0)==1){break d}if(Cn(g,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,i)){break c}x[27524]=0;T(1173,a+344|0)|0;g=x[27524];x[27524]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Eb(a+208|0)){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}k=f,l=kH(c,x[a+188>>2],e,b),x[k>>2]=l;Of(a+208|0,a+16|0,x[a+12>>2],e);x[27524]=0;b=Q(1170,a+344|0,a+336|0)|0;c=x[27524];x[27524]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+344>>2];wb(d);wb(a+208|0);ib=a+352|0;break a}}b=P()|0;wb(d);wb(a+208|0);S(b|0);p()}return b|0}function o2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;a=ib-352|0;ib=a;x[a+336>>2]=c;x[a+344>>2]=b;b=ij(d);i=vp(d,a+224|0);up(a+208|0,d,a+332|0);d=Kb(a+192|0);c=ad(d);x[27524]=0;R(60,d|0,c|0);c=x[27524];x[27524]=0;a:{b:{c:{if((c|0)!=1){c=Qc(d,0);x[a+188>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;j=x[a+332>>2];while(1){d:{x[27524]=0;g=Q(1169,a+344|0,a+336|0)|0;h=x[27524];x[27524]=0;if((h|0)==1){break d}if(!g){break c}h=x[a+188>>2];g=Eb(d);if((h|0)==(g+c|0)){x[27524]=0;R(60,d|0,g<<1);c=x[27524];x[27524]=0;if((c|0)==1){break b}c=ad(d);x[27524]=0;R(60,d|0,c|0);c=x[27524];x[27524]=0;if((c|0)==1){break b}c=Qc(d,0);x[a+188>>2]=g+c}x[27524]=0;g=T(1171,x[a+344>>2])|0;h=x[27524];x[27524]=0;if((h|0)==1){break d}if(Cn(g,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,i)){break c}x[27524]=0;T(1173,a+344|0)|0;g=x[27524];x[27524]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Eb(a+208|0)){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}k=f,l=hH(c,x[a+188>>2],e,b),w[k>>1]=l;Of(a+208|0,a+16|0,x[a+12>>2],e);x[27524]=0;b=Q(1170,a+344|0,a+336|0)|0;c=x[27524];x[27524]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+344>>2];wb(d);wb(a+208|0);ib=a+352|0;break a}}b=P()|0;wb(d);wb(a+208|0);S(b|0);p()}return b|0}function ZG(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;a=ib-352|0;ib=a;x[a+336>>2]=c;x[a+344>>2]=b;b=ij(d);i=vp(d,a+224|0);up(a+208|0,d,a+332|0);d=Kb(a+192|0);c=ad(d);x[27524]=0;R(60,d|0,c|0);c=x[27524];x[27524]=0;a:{b:{c:{if((c|0)!=1){c=Qc(d,0);x[a+188>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;j=x[a+332>>2];while(1){d:{x[27524]=0;g=Q(1169,a+344|0,a+336|0)|0;h=x[27524];x[27524]=0;if((h|0)==1){break d}if(!g){break c}h=x[a+188>>2];g=Eb(d);if((h|0)==(g+c|0)){x[27524]=0;R(60,d|0,g<<1);c=x[27524];x[27524]=0;if((c|0)==1){break b}c=ad(d);x[27524]=0;R(60,d|0,c|0);c=x[27524];x[27524]=0;if((c|0)==1){break b}c=Qc(d,0);x[a+188>>2]=g+c}x[27524]=0;g=T(1171,x[a+344>>2])|0;h=x[27524];x[27524]=0;if((h|0)==1){break d}if(Cn(g,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,i)){break c}x[27524]=0;T(1173,a+344|0)|0;g=x[27524];x[27524]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Eb(a+208|0)){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}k=f,l=fH(c,x[a+188>>2],e,b),x[k>>2]=l;Of(a+208|0,a+16|0,x[a+12>>2],e);x[27524]=0;b=Q(1170,a+344|0,a+336|0)|0;c=x[27524];x[27524]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+344>>2];wb(d);wb(a+208|0);ib=a+352|0;break a}}b=P()|0;wb(d);wb(a+208|0);S(b|0);p()}return b|0}function hja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if(x[a+4>>2]!=x[Db(a)>>2]){c=ib-16|0;ib=c;x[c>>2]=a;a=x[a+4>>2];x[c+4>>2]=a;x[c+8>>2]=a+56;a=x[c+4>>2];x[27524]=0;R(662,a|0,b|0);a=x[27524];x[27524]=0;a:{if((a|0)!=1){x[c+4>>2]=x[c+4>>2]+56;ic(c);ib=c+16|0;break a}a=P()|0;ic(c);S(a|0);p()}return}h=ib-32|0;ib=h;i=Db(a);f=h+8|0;g=rq(x[a>>2],x[a+4>>2])+1|0;d=ib-16|0;ib=d;x[d+12>>2]=g;e=ib-16|0;ib=e;x[e+12>>2]=76695844;x[e+8>>2]=2147483647;c=x[Hb(e+12|0,e+8|0)>>2];ib=e+16|0;b:{if(c>>>0>=g>>>0){e=JT(a);if(e>>>0<c>>>1>>>0){x[d+8>>2]=e<<1;c=x[Yc(d+8|0,d+12|0)>>2]}ib=d+16|0;break b}_c();p()}e=rq(x[a>>2],x[a+4>>2]);tg(f+12|0,i);if(c){if(c>>>0>=76695845){Vg();p()}d=mc(D(c,56))}else{d=0}x[f>>2]=d;e=d+D(e,56)|0;x[f+8>>2]=e;x[f+4>>2]=e;j=zc(f),k=d+D(c,56)|0,x[j>>2]=k;c=x[f+8>>2];x[27524]=0;R(662,c|0,b|0);b=x[27524];x[27524]=0;c:{if((b|0)!=1){x[f+8>>2]=x[f+8>>2]+56;e=x[a>>2];b=x[a+4>>2];d=f+4|0;while(1){if((b|0)!=(e|0)){b=b-56|0;c=xl(x[d>>2]-56|0,b);xl(c+12|0,b+12|0);EA(c+24|0,b+24|0);w[c+52>>1]=z[b+52>>1];g=x[b+48>>2];x[c+44>>2]=x[b+44>>2];x[c+48>>2]=g;g=x[b+40>>2];x[c+36>>2]=x[b+36>>2];x[c+40>>2]=g;x[d>>2]=x[d>>2]-56;continue}break}oc(a,d);oc(a+4|0,f+8|0);oc(Db(a),zc(f));x[f>>2]=x[f+4>>2];IT(f);ib=h+32|0;break c}a=P()|0;IT(f);S(a|0);p()}}function y2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=ib-240|0;ib=a;x[a+224>>2]=c;x[a+232>>2]=b;b=ij(d);wp(a+208|0,d,a+223|0);d=Kb(a+192|0);c=ad(d);x[27524]=0;R(60,d|0,c|0);c=x[27524];x[27524]=0;a:{b:{c:{if((c|0)!=1){c=Qc(d,0);x[a+188>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;i=v[a+223|0];while(1){d:{x[27524]=0;g=Q(1153,a+232|0,a+224|0)|0;h=x[27524];x[27524]=0;if((h|0)==1){break d}if(!g){break c}h=x[a+188>>2];g=Eb(d);if((h|0)==(g+c|0)){x[27524]=0;R(60,d|0,g<<1);c=x[27524];x[27524]=0;if((c|0)==1){break b}c=ad(d);x[27524]=0;R(60,d|0,c|0);c=x[27524];x[27524]=0;if((c|0)==1){break b}c=Qc(d,0);x[a+188>>2]=g+c}x[27524]=0;g=T(1155,x[a+232>>2])|0;h=x[27524];x[27524]=0;if((h|0)==1){break d}if(Dn(g,b,c,a+188|0,a+8|0,i,a+208|0,a+16|0,a+12|0,98224)){break c}x[27524]=0;T(1157,a+232|0)|0;g=x[27524];x[27524]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Eb(a+208|0)){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}j=f,k=iH(c,x[a+188>>2],e,b),x[j>>2]=k;x[f+4>>2]=kb;Of(a+208|0,a+16|0,x[a+12>>2],e);x[27524]=0;b=Q(1154,a+232|0,a+224|0)|0;c=x[27524];x[27524]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+232>>2];wb(d);wb(a+208|0);ib=a+240|0;break a}}b=P()|0;wb(d);wb(a+208|0);S(b|0);p()}return b|0}function w2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=ib-240|0;ib=a;x[a+224>>2]=c;x[a+232>>2]=b;b=ij(d);wp(a+208|0,d,a+223|0);d=Kb(a+192|0);c=ad(d);x[27524]=0;R(60,d|0,c|0);c=x[27524];x[27524]=0;a:{b:{c:{if((c|0)!=1){c=Qc(d,0);x[a+188>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;i=v[a+223|0];while(1){d:{x[27524]=0;g=Q(1153,a+232|0,a+224|0)|0;h=x[27524];x[27524]=0;if((h|0)==1){break d}if(!g){break c}h=x[a+188>>2];g=Eb(d);if((h|0)==(g+c|0)){x[27524]=0;R(60,d|0,g<<1);c=x[27524];x[27524]=0;if((c|0)==1){break b}c=ad(d);x[27524]=0;R(60,d|0,c|0);c=x[27524];x[27524]=0;if((c|0)==1){break b}c=Qc(d,0);x[a+188>>2]=g+c}x[27524]=0;g=T(1155,x[a+232>>2])|0;h=x[27524];x[27524]=0;if((h|0)==1){break d}if(Dn(g,b,c,a+188|0,a+8|0,i,a+208|0,a+16|0,a+12|0,98224)){break c}x[27524]=0;T(1157,a+232|0)|0;g=x[27524];x[27524]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Eb(a+208|0)){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}j=f,k=eH(c,x[a+188>>2],e,b),x[j>>2]=k;x[f+4>>2]=kb;Of(a+208|0,a+16|0,x[a+12>>2],e);x[27524]=0;b=Q(1154,a+232|0,a+224|0)|0;c=x[27524];x[27524]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+232>>2];wb(d);wb(a+208|0);ib=a+240|0;break a}}b=P()|0;wb(d);wb(a+208|0);S(b|0);p()}return b|0}function fga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0;h=ib-16|0;ib=h;f=x[a+48>>2];i=x[a+40>>2];j=x[a+36>>2];e=x[a+44>>2];l=x[a+16>>2];g=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=g;m=b+24|0;n=x[a+32>>2];o=x[a+28>>2];p=x[a+72>>2];b=x[a+68>>2];q=b;r=b>>31;b=x[a+64>>2];s=b;t=b>>31;b=x[a+60>>2];u=b;v=b>>31;y=x[a+8>>2];z=x[a+12>>2];while(1){b=e;if(d){e=Vb(b,-16777216,16776704);e=qoa(s,t,e,e>>31);g=kb;f=Vb(f,-16777216,16776704);k=qoa(q,r,f,f>>31);e=k+e|0;f=kb+g|0;f=e>>>0<k>>>0?f+1|0:f;A=e;e=(x[h+12>>2]<<1)+l|0;g=(((x[h+8>>2]>>>16|0)+4&131064)<<1)+m|0;g=(((((D(w[e+4>>1],w[g+10>>1])+D(w[e+2>>1],w[g+8>>1])|0)+D(w[e+6>>1],w[g+12>>1])|0)+D(w[e+8>>1],w[g+14>>1])|0)/2|0)+((((D(w[e-4>>1],w[g+2>>1])+D(w[e-6>>1],w[g>>1])|0)+D(w[e-2>>1],w[g+4>>1])|0)+D(w[e>>1],w[g+6>>1])|0)/2|0)|0)/16384<<8;e=g;k=qoa(e,e>>31,u,v);e=A+k|0;f=kb+f|0;f=e>>>0<k>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Vc(e,f,24);e=(f|0)/256|0;j=j+o|0;x[c>>2]=D(e,j>>12)+x[c>>2];i=i+n|0;x[c+4>>2]=x[c+4>>2]+D(i>>12,e);Pb(h+8|0,y,z);e=f-(g&p)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=f;x[a+44>>2]=b;x[a+24>>2]=i>>12;ib=h+16|0}function ze(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=E(0),k=0;f=(q(b),j(2));d=_F(f);a:{b:{c:{d:{c=(q(a),j(2));e:{if(c-2139095040>>>0>=2164260864){if(d){break e}break c}if(!d){break d}}i=E(1);if((c|0)==1065353216){break b}e=f<<1;if(!e){break b}d=e>>>0<4278190081;e=c<<1;a=E(a+b);if(!(d&e>>>0<=4278190080)){break a}if((e|0)==2130706432){break b}a=e>>>0>2130706431^(f|0)>=0?E(0):E(b*b);break a}if(_F(c)){i=E(a*a);if((c|0)<0){i=(ZF(f)|0)==1?E(-i):i}if((f|0)>=0){break b}a=ow(E(E(1)/i));break a}if((c|0)<0){e=ZF(f);if(!e){a=YE(a);break a}c=c&2147483647;e=((e|0)==1)<<16}if(c>>>0>8388607){break c}c=((q(E(a*E(8388608))),j(2))&2147483647)-192937984|0}f=c-1060306944|0;d=f>>>15&240;g=+(l(2,c-(f&-8388608)|0),r())*C[d+108824>>3]+-1;h=g*g;h=((g*.288457581109214+-.36092606229713164)*(h*h)+((g*.480898481472577+-.7213474675006291)*h+(g*1.4426950408774342+(C[d+108832>>3]+ +(f>>23)))))*+b;o(+h);d=j(1)|0;j(0)|0;f:{d=d&2147450880;if((d|0)==1079967744|d>>>0<1079967744){break f}if(h>127.99999995700433){a=rE(e);break a}if(!(h<=-150)){break f}a=QD(e);break a}k=h;g=C[160];h=g+h;g=k-(h-g);k=(C[161]*g+C[162])*(g*g)+(C[163]*g+1);o(+h);j(1)|0;c=j(0)|0;f=e+c|0;f=f<<15;d=((c&31)<<3)+1024|0;e=x[d>>2];c=e;d=x[d+4>>2]+f|0;l(0,c|0);l(1,(c>>>0<c>>>0?d+1|0:d)|0);i=E(k*+n())}a=i}return a}function Bla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=ib-16|0;ib=e;h=Af(a,c);Pd(e,x[a+36>>2]);i=a;a:{if(!h){Pc(e,a+32|0,5);c=0;if(zb(x[x[e>>2]>>2],x[e+4>>2])){break a}}d=ib-160|0;ib=d;f=bm(d+48|0,x[a+36>>2]);x[27524]=0;a=Q(453,d+32|0,43843)|0;c=x[27524];x[27524]=0;b:{c:{d:{e:{if((c|0)!=1){x[27524]=0;x[d+16>>2]=19988503;x[d+20>>2]=0;U(454,f|0,a|0,d+16|0);c=x[27524];x[27524]=0;if((c|0)==1){break e}Zb(a);if(!Rk(y[f|0])){break d}break b}c=P()|0;break c}c=P()|0;Zb(a);break c}k=d,l=Jf(x[b>>2],x[b+4>>2]),w[k+30>>1]=l;w[d+28>>1]=65535;x[27524]=0;a=Q(453,d+16|0,10043)|0;c=x[27524];x[27524]=0;f:{if((c|0)!=1){x[27524]=0;c=W(483,f|0,d+28|0,a|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break f}Zb(a);if(c){w[d+30>>1]=z[d+28>>1]}Mf(d+30|0,4e3);a=z[d+30>>1];g:{if(Jf(x[b>>2],x[b+4>>2])>>>0>=a>>>0){break g}x[27524]=0;R(229,b|0,a|0);c=x[27524];x[27524]=0;if((c|0)!=1){break g}c=P()|0;break c}c=0;h:{while(1){if((a|0)==(c|0)){break b}g=x[b>>2];x[27524]=0;R(484,d|0,c|0);j=x[27524];x[27524]=0;if((j|0)!=1){x[27524]=0;X(485,f|0,Xb(g,c)|0,d|0,486);g=x[27524];x[27524]=0;if((g|0)==1){break h}c=c+1|0;Zb(d);continue}break}c=P()|0;break c}c=P()|0;Zb(d);break c}c=P()|0;break c}c=P()|0;Zb(a)}rh(f);S(c|0);p()}rh(f);ib=d+160|0;c=h}af(i,c);ib=e+16|0}function nh(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;f=ib-16|0;ib=f;x[f+12>>2]=d;e=0;a:{if(b-251>>>0<4294967046){break a}e=b-1|0;g=x[a+480180>>2];if(!Nm(g)){if(g&17408){a=((e&255)>>>0)/12|0;e=z[((D(a,-12)+e&255)<<1)+33264>>1]<<4>>>a|0;break a}if(!d){x[f+12>>2]=8363;d=8363}if(sj(a)){a=((e&255)>>>0)/12|0;b=qoa(x[(D(a,-12)+e<<6&960)+37152>>2]<<a,0,d,0);a=kb;c=a>>>21|0;h=f,i=Ec((a&2097151)<<11|b>>>21,c),x[h>>2]=i;wc(f,2147483647);e=x[f>>2];break a}if(y[a+480208|0]&16){a=e&255;e=z[((a>>>0)%12<<1)+33264>>1]<<5>>>(a>>>0)/12|0;break a}a=((e&255)>>>0)/12|0;wc(f+12|0,-1>>>a|0);e=Ec(soa(qoa(z[((D(a,-12)+e&255)<<1)+33264>>1],0,267616,0),kb,x[f+12>>2]<<a,0),kb);break a}if(g&20){d=e>>>0>12;if((g|0)==16){b=c<<4}else{Ab(f,a+1074312|0,76);b=zb(x[x[f>>2]>>2],x[f+4>>2])?c&-8:c}c=d?e:12;if(y[a+480208|0]&16){a=(((b|0)/-2|0)-(c<<6)|0)+8448|0;e=(a|0)<=1?1:a;break a}a=c-12|0;c=((a&255)>>>0)/12|0;d=((b|0)/16|0)+(D(c,-12)+a<<3&248)|0;x[f>>2]=d+8;re(f,0,103);a=b>>31;b=(a^b)-a&15;a=d+(a|1)|0;a=(a|0)<=-8?-8:a;e=D(b,z[(((a|0)>=95?95:a)<<1)+33760>>1])+D(z[(x[f>>2]<<1)+33744>>1],16-b|0)<<1>>>c|0;break a}if(!((c&255)>>>0<16&b-25>>>0<=83)){a=((e&255)>>>0)/12|0;e=z[(D((c&240)>>>4|0,12)+(D(a,-12)+e&255)<<1)+32864>>1]<<5>>>a|0;break a}e=z[(b<<1)+32638>>1]<<2}ib=f+16|0;return e}function JI(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=E(0),k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=E(0);d=(b<<2)+a|0;h=d+1068|0;k=c<<1&-4;p=h,q=ie(a,k),x[p>>2]=q;g=d+1076|0;p=g,q=ie(a,k),x[p>>2]=q;i=ie(a,c&-4);x[d+1084>>2]=i;a:{h=x[h>>2];if(!h){break a}g=x[g>>2];if(!g|!i){break a}d=c>>2;o=(d|0)>0?d:0;j=E(c|0);d=0;while(1){if((e|0)==(o|0)){d=0;e=c>>3;h=(e|0)>0?e:0;e=0;while(1){if((d|0)!=(h|0)){g=e|1;f=+E(E(E(g<<1)*E(3.1415927410125732))/j);p=i+(e<<2)|0,r=E(gf(f)),B[p>>2]=r;p=i+(g<<2)|0,r=E(-E(Ki(f))),B[p>>2]=r;e=e+2|0;d=d+1|0;continue}break}}else{l=d<<2;f=+E(E(E(e<<2)*E(3.1415927410125732))/j);p=h+l|0,r=E(gf(f)),B[p>>2]=r;m=d|1;n=m<<2;p=h+n|0,r=E(-E(Ki(f))),B[p>>2]=r;f=+E(E(E(E(m|0)*E(3.1415927410125732))/j)*E(.5));p=g+l|0,r=E(E(gf(f))*E(.5)),B[p>>2]=r;p=g+n|0,r=E(E(Ki(f))*E(.5)),B[p>>2]=r;d=d+2|0;e=e+1|0;continue}break}i=(b<<2)+a|0;d=ie(a,k);x[i+1092>>2]=d;if(!d){break a}b=0;e=c>>1;k=(e|0)>0?e:0;f=+(e|0);while(1){if((b|0)!=(k|0)){j=E(Ki((+(b|0)+.5)/f*.5*3.1415927410125732));p=d+(b<<2)|0,r=E(Ki(+E(j*j)*1.5707963705062866)),B[p>>2]=r;b=b+1|0;continue}break}b=ie(a,c>>2&-2);x[i+1100>>2]=b;if(!b){break a}a=0;d=c>>3;d=(d|0)>0?d:0;c=36-mm(c)|0;while(1){if((a|0)!=(d|0)){p=b+(a<<1)|0,q=km(a)>>>c<<2,w[p>>1]=q;a=a+1|0;continue}break}return 1}fc(a,3);return 0}function gga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0;h=ib-16|0;ib=h;f=x[a+48>>2];i=x[a+40>>2];j=x[a+36>>2];e=x[a+44>>2];l=x[a+16>>2];g=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=g;m=b+24|0;n=x[a+32>>2];o=x[a+28>>2];p=x[a+72>>2];b=x[a+68>>2];q=b;r=b>>31;b=x[a+64>>2];s=b;t=b>>31;b=x[a+60>>2];u=b;y=b>>31;z=x[a+8>>2];A=x[a+12>>2];while(1){b=e;if(d){e=Vb(b,-16777216,16776704);e=qoa(s,t,e,e>>31);g=kb;f=Vb(f,-16777216,16776704);k=qoa(q,r,f,f>>31);e=k+e|0;f=kb+g|0;f=e>>>0<k>>>0?f+1|0:f;B=e;e=x[h+12>>2]+l|0;g=(((x[h+8>>2]>>>16|0)+4&131064)<<1)+m|0;g=(((((D(v[e+2|0],w[g+10>>1])+D(v[e+1|0],w[g+8>>1])|0)+D(v[e+3|0],w[g+12>>1])|0)+D(v[e+4|0],w[g+14>>1])<<8)/2|0)+((((D(v[e-2|0],w[g+2>>1])+D(v[e-3|0],w[g>>1])|0)+D(v[e-1|0],w[g+4>>1])|0)+D(v[e|0],w[g+6>>1])<<8)/2|0)|0)/16384<<8;e=g;k=qoa(e,e>>31,u,y);e=B+k|0;f=kb+f|0;f=e>>>0<k>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Vc(e,f,24);e=(f|0)/256|0;j=j+o|0;x[c>>2]=D(e,j>>12)+x[c>>2];i=i+n|0;x[c+4>>2]=x[c+4>>2]+D(i>>12,e);Pb(h+8|0,z,A);e=f-(g&p)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=f;x[a+44>>2]=b;x[a+24>>2]=i>>12;ib=h+16|0}function z2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=ib-240|0;ib=a;x[a+224>>2]=c;x[a+232>>2]=b;b=ij(d);wp(a+208|0,d,a+223|0);d=Kb(a+192|0);c=ad(d);x[27524]=0;R(60,d|0,c|0);c=x[27524];x[27524]=0;a:{b:{c:{if((c|0)!=1){c=Qc(d,0);x[a+188>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;i=v[a+223|0];while(1){d:{x[27524]=0;g=Q(1153,a+232|0,a+224|0)|0;h=x[27524];x[27524]=0;if((h|0)==1){break d}if(!g){break c}h=x[a+188>>2];g=Eb(d);if((h|0)==(g+c|0)){x[27524]=0;R(60,d|0,g<<1);c=x[27524];x[27524]=0;if((c|0)==1){break b}c=ad(d);x[27524]=0;R(60,d|0,c|0);c=x[27524];x[27524]=0;if((c|0)==1){break b}c=Qc(d,0);x[a+188>>2]=g+c}x[27524]=0;g=T(1155,x[a+232>>2])|0;h=x[27524];x[27524]=0;if((h|0)==1){break d}if(Dn(g,b,c,a+188|0,a+8|0,i,a+208|0,a+16|0,a+12|0,98224)){break c}x[27524]=0;T(1157,a+232|0)|0;g=x[27524];x[27524]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Eb(a+208|0)){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}j=f,k=kH(c,x[a+188>>2],e,b),x[j>>2]=k;Of(a+208|0,a+16|0,x[a+12>>2],e);x[27524]=0;b=Q(1154,a+232|0,a+224|0)|0;c=x[27524];x[27524]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+232>>2];wb(d);wb(a+208|0);ib=a+240|0;break a}}b=P()|0;wb(d);wb(a+208|0);S(b|0);p()}return b|0}function x2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=ib-240|0;ib=a;x[a+224>>2]=c;x[a+232>>2]=b;b=ij(d);wp(a+208|0,d,a+223|0);d=Kb(a+192|0);c=ad(d);x[27524]=0;R(60,d|0,c|0);c=x[27524];x[27524]=0;a:{b:{c:{if((c|0)!=1){c=Qc(d,0);x[a+188>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;i=v[a+223|0];while(1){d:{x[27524]=0;g=Q(1153,a+232|0,a+224|0)|0;h=x[27524];x[27524]=0;if((h|0)==1){break d}if(!g){break c}h=x[a+188>>2];g=Eb(d);if((h|0)==(g+c|0)){x[27524]=0;R(60,d|0,g<<1);c=x[27524];x[27524]=0;if((c|0)==1){break b}c=ad(d);x[27524]=0;R(60,d|0,c|0);c=x[27524];x[27524]=0;if((c|0)==1){break b}c=Qc(d,0);x[a+188>>2]=g+c}x[27524]=0;g=T(1155,x[a+232>>2])|0;h=x[27524];x[27524]=0;if((h|0)==1){break d}if(Dn(g,b,c,a+188|0,a+8|0,i,a+208|0,a+16|0,a+12|0,98224)){break c}x[27524]=0;T(1157,a+232|0)|0;g=x[27524];x[27524]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Eb(a+208|0)){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}j=f,k=hH(c,x[a+188>>2],e,b),w[j>>1]=k;Of(a+208|0,a+16|0,x[a+12>>2],e);x[27524]=0;b=Q(1154,a+232|0,a+224|0)|0;c=x[27524];x[27524]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+232>>2];wb(d);wb(a+208|0);ib=a+240|0;break a}}b=P()|0;wb(d);wb(a+208|0);S(b|0);p()}return b|0}function gH(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=ib-240|0;ib=a;x[a+224>>2]=c;x[a+232>>2]=b;b=ij(d);wp(a+208|0,d,a+223|0);d=Kb(a+192|0);c=ad(d);x[27524]=0;R(60,d|0,c|0);c=x[27524];x[27524]=0;a:{b:{c:{if((c|0)!=1){c=Qc(d,0);x[a+188>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;i=v[a+223|0];while(1){d:{x[27524]=0;g=Q(1153,a+232|0,a+224|0)|0;h=x[27524];x[27524]=0;if((h|0)==1){break d}if(!g){break c}h=x[a+188>>2];g=Eb(d);if((h|0)==(g+c|0)){x[27524]=0;R(60,d|0,g<<1);c=x[27524];x[27524]=0;if((c|0)==1){break b}c=ad(d);x[27524]=0;R(60,d|0,c|0);c=x[27524];x[27524]=0;if((c|0)==1){break b}c=Qc(d,0);x[a+188>>2]=g+c}x[27524]=0;g=T(1155,x[a+232>>2])|0;h=x[27524];x[27524]=0;if((h|0)==1){break d}if(Dn(g,b,c,a+188|0,a+8|0,i,a+208|0,a+16|0,a+12|0,98224)){break c}x[27524]=0;T(1157,a+232|0)|0;g=x[27524];x[27524]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Eb(a+208|0)){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}j=f,k=fH(c,x[a+188>>2],e,b),x[j>>2]=k;Of(a+208|0,a+16|0,x[a+12>>2],e);x[27524]=0;b=Q(1154,a+232|0,a+224|0)|0;c=x[27524];x[27524]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+232>>2];wb(d);wb(a+208|0);ib=a+240|0;break a}}b=P()|0;wb(d);wb(a+208|0);S(b|0);p()}return b|0}function Y1(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=ib-16|0;ib=k;l=ix(g);g=Tw(g);ih(k,g);a:{b:{if(Qe(k)){x[27524]=0;X(1176,l|0,a|0,c|0,d|0);g=x[27524];x[27524]=0;if((g|0)==1){break b}g=(c-a<<2)+d|0;x[f>>2]=g;break a}x[f>>2]=d;c:{d:{j=a;h=y[j|0];switch(h-43|0){case 0:case 2:break d;default:break c}}x[27524]=0;j=Q(1182,l|0,h<<24>>24)|0;h=x[27524];x[27524]=0;if((h|0)==1){break b}h=x[f>>2];x[f>>2]=h+4;x[h>>2]=j;j=a+1|0}if(!(y[j|0]!=48|(c-j|0)<2|(y[j+1|0]|32)!=120)){x[27524]=0;h=Q(1182,l|0,48)|0;i=x[27524];x[27524]=0;if((i|0)==1){break b}i=x[f>>2];x[f>>2]=i+4;x[i>>2]=h;h=v[j+1|0];x[27524]=0;h=Q(1182,l|0,h|0)|0;i=x[27524];x[27524]=0;if((i|0)==1){break b}i=x[f>>2];x[f>>2]=i+4;x[i>>2]=h;j=j+2|0}dm(j,c);i=0;x[27524]=0;o=T(1174,g|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break b}h=0;g=j;while(1){if(c>>>0<=g>>>0){hs((j-a<<2)+d|0,x[f>>2]);g=x[f>>2];break a}e:{if(!y[Qc(k,h)|0]){break e}if(v[Qc(k,h)|0]!=(i|0)){break e}i=x[f>>2];x[f>>2]=i+4;x[i>>2]=o;h=(Eb(k)-1>>>0>h>>>0)+h|0;i=0}n=v[g|0];x[27524]=0;n=Q(1182,l|0,n|0)|0;m=x[27524];x[27524]=0;if((m|0)!=1){m=x[f>>2];x[f>>2]=m+4;x[m>>2]=n;g=g+1|0;i=i+1|0;continue}break}}a=P()|0;wb(k);S(a|0);p()}x[e>>2]=(b|0)==(c|0)?g:(b-a<<2)+d|0;wb(k);ib=k+16|0}function wJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0;c=ib+-64|0;ib=c;d=x[a>>2];a=x[d>>2];f=x[a+4>>2];x[c+40>>2]=x[a+20>>2];g=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=g;Qf(c+48|0,c+32|0,f);a=x[d+4>>2];f=x[a+8>>2];g=x[a+4>>2];d=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=d;d=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=d;x[c+8>>2]=x[a+8>>2];d=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=d;a=ib-32|0;ib=a;a:{b:{c:{d:{k=x[c+4>>2];if(k>>>0>=g>>>0){l=x[c+20>>2];if(l>>>0<g>>>0){break d}if(f>>>0>A[c+8>>2]){break c}m=x[c+28>>2];if(f>>>0>x[c+24>>2]-m>>>0){break b}n=b+12|0;o=x[c+16>>2];q=x[c>>2];e:while(1){if((f|0)==(h|0)){break a}r=D(h,k);s=D(h+m|0,l);d=0;while(1)if((d|0)==(g|0)){h=h+1|0;continue e}else{e=Bb(x[b>>2],d);i=Be(ug(C[(d+r<<3)+q>>3])*134217728);j=e;e=(x[e>>2]>>1)+Mm(i)|0;t=e;e=Ks(n)+e&-4096;x[j>>2]=t-e;C[a+24>>3]=+(e|0)*7.450580596923828e-9;x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;j=(d+s<<1)+o|0;i=Be(C[Qg(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(F(i)<2147483648){e=~~i;break f}e=-2147483648}u=j,v=dd(e),w[u>>1]=v;d=d+1|0;continue}}}aa(7192,8993,77,8673);p()}aa(7157,8993,78,8673);p()}aa(5900,8993,79,8673);p()}aa(5870,8993,80,8673);p()}ib=a+32|0;ib=c- -64|0}function CJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;c=ib+-64|0;ib=c;d=x[a>>2];a=x[d>>2];f=x[a+4>>2];x[c+40>>2]=x[a+20>>2];g=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=g;Qf(c+48|0,c+32|0,f);a=x[d+4>>2];f=x[a+8>>2];g=x[a+4>>2];d=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=d;d=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=d;x[c+8>>2]=x[a+8>>2];d=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=d;a=ib-32|0;ib=a;a:{b:{c:{d:{l=x[c+4>>2];if(l>>>0>=g>>>0){if(A[c+20>>2]<g>>>0){break d}if(f>>>0>A[c+8>>2]){break c}m=x[c+28>>2];if(f>>>0>x[c+24>>2]-m>>>0){break b}n=b+12|0;o=x[c+16>>2];q=x[c>>2];e:while(1){if((f|0)==(h|0)){break a}r=h+m|0;s=D(h,l);d=0;while(1)if((d|0)==(g|0)){h=h+1|0;continue e}else{e=Bb(x[b>>2],d);i=Be(ug(C[(d+s<<3)+q>>3])*134217728);j=e;e=(x[e>>2]>>1)+Mm(i)|0;k=e;e=Ks(n)+e&-4096;x[j>>2]=k-e;C[a+24>>3]=+(e|0)*7.450580596923828e-9;x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;j=r<<1;k=(d<<2)+o|0;i=Be(C[Qg(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(F(i)<2147483648){e=~~i;break f}e=-2147483648}t=j+x[k>>2]|0,u=dd(e),w[t>>1]=u;d=d+1|0;continue}}}aa(7192,8993,77,8673);p()}aa(7157,8993,78,8673);p()}aa(5900,8993,79,8673);p()}aa(5870,8993,80,8673);p()}ib=a+32|0;ib=c- -64|0}function NO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=ib-16|0;ib=d;f=a+484376|0;while(1){a:{c=Tb(x[a+484360>>2],y[f|0]);e=b&65535;if(Oc(x[c>>2],x[c+4>>2])>>>0>e>>>0){if(!Sq(c,e)){break a}c=Tb(x[a+484360>>2],y[a+484376|0])}if(Oc(x[c>>2],x[c+4>>2])>>>0>e>>>0){e=a+1074312|0;f=a+1298224|0;c=a+1074992|0;b:{while(1){c:{if((c|0)==(f|0)){MO(a);if(b&65535){break c}b=0;while(1){if((b|0)==256){eo(a+1298264|0,1);x[a+1074456>>2]=x[a+480200>>2];x[a+1074416>>2]=x[a+480196>>2];x[a+1074420>>2]=x[a+480204>>2];x[a+480208>>2]=x[a+480208>>2]&-769;Cz(a+1074376|0);w[a+1074450>>1]=0;x[a+1074392>>2]=-2;b=a+1074428|0;x[b>>2]=0;x[b+4>>2]=0;b=a+1074396|0;x[b>>2]=0;x[b+4>>2]=0;x[a+1074376>>2]=0;x[a+1074380>>2]=0}else{io((D(b,872)+a|0)+1074992|0,a,b&65535,134217728);b=b+1|0;continue}break}break b}v[c+797|0]=0;x[c+700>>2]=0;v[c+841|0]=0;v[c+805|0]=0;x[c+708>>2]=0;v[c+821|0]=0;x[c+764>>2]=0;v[c+819|0]=0;v[c+820|0]=0;Ab(d+8|0,e,23);if(zb(x[x[d+8>>2]>>2],x[d+12>>2])){v[c+807|0]=1;v[c+808|0]=0}v[c+839|0]=0;c=c+872|0;continue}break}w[a+1074450>>1]=b;w[a+1074446>>1]=0;b=a+1074424|0;x[b>>2]=0;x[b+4>>2]=0;x[a+1074392>>2]=-2;x[a+1074432>>2]=0;b=a+1074396|0;x[b>>2]=0;x[b+4>>2]=0;x[a+1074380>>2]=0}x[a+480208>>2]=x[a+480208>>2]&-769}ib=d+16|0;return}b=b+1|0;continue}}function BU(a,b){var c=0;a:{b:{c:{d:{if(qe(a,16704)){break d}if(qe(a,17473)){break d}if(qe(a,13534)){break d}if(qe(a,13689)){break d}if(!qe(a,14258)){break c}}w[b+10>>1]=4;x[b>>2]=11932;break b}e:{f:{if(qe(a,17468)){break f}if(qe(a,13544)){break f}if(!qe(a,16689)){break e}}v[b+12|0]=1;x[b>>2]=8339;w[b+10>>1]=4;return 1}g:{if(!qe(a,14304)){if(!qe(a,14309)){break g}}w[b+10>>1]=8;x[b>>2]=8117;break b}h:{if(!qe(a,15366)){if(!qe(a,15371)){break h}}x[b>>2]=17076;w[b+10>>1]=v[a+2|0]-48;break b}i:{if(!qe(a,26890)){if(!qe(a,26895)){break i}}x[b+4>>2]=1;x[b>>2]=16882;w[b+10>>1]=y[a|0]==56?8:4;return 1}if(!(Qb(a,15472,3)|(y[a+3|0]-52&255)>>>0>4)){x[b>>2]=8457;a=v[a+3|0];w[b+8>>1]=1088;w[b+10>>1]=a-48;break b}j:{if(Qb(a,13617,3)){if(Qb(a,13751,3)){break j}}if((y[a+3|0]-52&255)>>>0>5){break j}v[b+15|0]=1;v[b+13|0]=1;x[b>>2]=8216;w[b+10>>1]=v[a+3|0]-48;return 1}k:{if((y[a|0]-49&255)>>>0>8){break k}if(!Qb(a+1|0,13775,3)){v[b+14|0]=1;x[b>>2]=8521;w[b+10>>1]=v[a|0]-48;return 1}if((y[a+1|0]-48&255)>>>0>9){break k}c=a+2|0;if(Qb(c,14107,2)){if(Qb(c,13779,2)){break k}}v[b+14|0]=1;x[b>>2]=8521;w[b+10>>1]=(v[a+1|0]+D(v[a|0],10)|0)-528;return 1}c=0;if(Qb(a,13400,3)|(y[a+3|0]-49&255)>>>0>8){break a}x[b>>2]=8366;w[b+10>>1]=v[a+3|0]-48}c=1}return c}function rL(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=ib-80|0;ib=e;a:{b:{c:{d:{f=a+36|0;d=x[f>>2];c=x[a+40>>2];e:{if(Mb(d,c)){sc(e+72|0);break e}c=e+32|0;Nn(c,a);x[27524]=0;c=T(1018,c|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break d}x[e+72>>2]=c;nf(e+32|0);c=x[a+40>>2];d=x[a+36>>2]}c=(k=f,l=x[e+72>>2],m=Mb(d,c),m?k:l);f=x[a+8>>2];if((f|0)==-1){d=x[c+4>>2];f=d-24|0;g=x[c>>2];i=Xi(g,d);j=C[f>>3];d=0;while(1){if((d|0)==(i|0)){c=f;break c}c=sf(g,d);if(h+C[c>>3]>b){break c}d=d+1|0;h=h+j;continue}}c=sf(x[c>>2],f);break b}d=P()|0;nf(e+32|0);break a}b=b-h}f=z[c+12>>1];d=x[a+24>>2];x[27524]=0;R(1051,d|0,f|0);f=x[27524];x[27524]=0;if((f|0)!=1){f:{f=x[a+24>>2];d=y[a+64|0];c=FO(tU(e+32|0,b),y[c+16|0],z[c+12>>1],x[c+8>>2]);x[27524]=0;g=x[c+12>>2];x[e+16>>2]=x[c+8>>2];x[e+20>>2]=g;g=x[c+20>>2];x[e+24>>2]=x[c+16>>2];x[e+28>>2]=g;g=x[c+4>>2];x[e+8>>2]=x[c>>2];x[e+12>>2]=g;X(1052,e+56|0,f|0,(d?7:1)|0,e+8|0);c=x[27524];x[27524]=0;if((c|0)==1){break f}c=GO(x[e+60>>2]);f=v[c+26|0]&1;d=x[(f?c+8|0:c+12|0)>>2];f=z[(f?c+20|0:c+22|0)>>1];b=C[c>>3];Li(e+56|0);c=x[a+24>>2];w[c+1074450>>1]=f;w[c+1074448>>1]=f;x[c+1074428>>2]=d;x[c+1074392>>2]=-2;b=h+b;C[a+16>>3]=b;el(e+72|0);ib=e+80|0;return+b}}d=P()|0;el(e+72|0)}S(d|0);p()}function _Y(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;g=ib-1088|0;ib=g;e=Oh(a);Rb(e+20|0,0,1040);x[e+1064>>2]=0;x[e+1068>>2]=0;x[e+1060>>2]=c;v[e+1084|0]=d;a=e+1072|0;x[a>>2]=0;x[a+4>>2]=0;x[e+1080>>2]=0;i=e+1064|0;a=c;d=0;a:{b:{c:while(1){if(Md(z[a+34>>1])>>>0<=d>>>0){break a}x[e+1064>>2]=0;x[e+1068>>2]=0;a=0;while(1){d:{e:{f:{g:{h:{i:{j:{if(A[c>>2]<=a>>>0){break j}a=x[b+8>>2];f=x[b>>2];x[27524]=0;a=W(160,f|0,a|0,2)|0;f=x[27524];x[27524]=0;if((f|0)==1){break i}if(!a){break j}x[27524]=0;a=T(198,b|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break h}if(!a){break e}x[27524]=0;U(194,g|0,b|0,a|0);a=x[27524];x[27524]=0;if((a|0)==1){break g}a=zr(g+24|0,g);f=fd(e,a);rc(f+20|0,a+20|0,1040);yb(a);yb(g);x[e+1076>>2]=0;x[e+1080>>2]=0;h=x[e+1060>>2];a=x[h+20>>2];if(an(z[h+34>>1])>>>0>=2){x[27524]=0;R(199,f|0,a+(d<<1)|0);a=x[27524];x[27524]=0;if((a|0)!=1){break e}break f}x[27524]=0;R(200,f|0,a+d|0);a=x[27524];x[27524]=0;if((a|0)==1){break f}break e}d=d+1|0;a=x[e+1060>>2];continue c}a=P()|0;break b}a=P()|0;break b}a=P()|0;break b}a=V(30496)|0;if((jb|0)!=(da(30496)|0)){break b}_(a|0)|0;x[27524]=0;Z(18);a=x[27524];x[27524]=0;if((a|0)==1){break d}}a=x[i>>2];continue}break}break}a=P()|0}yb(e);S(a|0);p()}ib=g+1088|0;return e|0}function GQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=ib-48|0;ib=f;n=Uz(x[a+24>>2],y[a+32|0]);o=xj(n);a:{b:{while(1){c:{w[b>>1]=m;e=m&65535;if(e>>>0>=o>>>0){break c}if(Sq(n,e)){e=x[a>>2];d=wd(e,x[a+4>>2]);g=z[b>>1];if(d>>>0<=g>>>0){x[c>>2]=0;break a}l=Cd(e,g);wl(f+32|0,x[l>>2]);Im(f+24|0,x[l>>2],x[l+4>>2]);e=x[f+36>>2];x[f+8>>2]=x[f+32>>2];x[f+12>>2]=e;g=ib-32|0;ib=g;e=x[f+12>>2];i=e;d=x[f+8>>2];e=vl(x[f+24>>2],x[f+28>>2],d,e);x[g+8>>2]=d;x[g+12>>2]=i;x[g+24>>2]=d;x[g+28>>2]=i;i=f+40|0;j=ib-16|0;ib=j;x[j+12>>2]=e;d=x[g+12>>2];d:{if(d){h=32-d|0;x[j+8>>2]=h;k=-1<<d;d=x[Hb(j+8|0,j+12|0)>>2];k=k&-1>>>h-d;h=x[g+8>>2];k=k&x[h>>2];if(k){dc(i,h,poa(k));break d}if((e|0)==(d|0)){d=x[g+12>>2];x[i>>2]=x[g+8>>2];x[i+4>>2]=d;eS(i,e);break d}e=e-d|0;x[j+12>>2]=e;d=h+4|0}else{d=x[g+8>>2]}while(1){if(e>>>0>=32){h=x[d>>2];if(h){dc(i,d,poa(h));break d}else{e=e-32|0;x[j+12>>2]=e;d=d+4|0;continue}}break}if(!e){dc(i,d,0);break d}h=x[d>>2]&-1>>>32-e;if(!h){dc(i,d,e);break d}dc(i,d,poa(h))}ib=j+16|0;ib=g+32|0;Im(f+16|0,x[l>>2],x[l+4>>2]);if(x[f+40>>2]==x[f+16>>2]&x[f+44>>2]==x[f+20>>2]){break b}}m=z[b>>1]+1|0;continue}break}w[b>>1]=65535;x[c>>2]=-1;break a}x[c>>2]=0}ib=f+48|0;return(m&65535)>>>0<o>>>0|0}function cN(a){var b=0,c=E(0),d=0,e=0,f=0,g=E(0),h=0,i=0,k=E(0),m=0,n=0,o=E(0);d=ib-16|0;ib=d;b=x[x[a+16>>2]+24620>>2];e=a+4208|0;n=a,o=ze(E(10),E(E(E(B[Bb(e,0)>>2]*E(120))+E(-60))/E(20))),B[n+4232>>2]=o;k=E(E(b>>>0)/E(1e3));n=a,o=ze(E(10),E(E(-1)/E(k*E(E(B[Bb(e,1)>>2]*E(499.989990234375))+E(.009999999776482582))))),B[n+4236>>2]=o;n=a,o=ze(E(10),E(E(-1)/E(k*E(E(B[Bb(e,2)>>2]*E(2950))+E(50))))),B[n+4240>>2]=o;x[d+12>>2]=1325400064;c=E(ze(E(10),E(E(E(B[Bb(e,3)>>2]*E(60))+E(-60))/E(20)))*E(2147483648));b=(q(c),j(2));g=E(0);a:{if((b|0)==1065353216){break a}b:{if(b-2139095040>>>0<=2164260863){f=b<<1;if(!f){g=E(ow(E(-1))/E(0));break a}if((b|0)==2139095040){break b}if(!(f>>>0<4278190080&(b|0)>=0)){g=YE(c);break a}b=(q(E(c*E(8388608))),j(2))-192937984|0}f=b-1060306944|0;h=f>>>15&240;i=+(l(2,b-(f&-8388608)|0),r())*C[h+3568>>3]+-1;m=i*i;c=E((C[479]*m+(C[480]*i+C[481]))*m+(+(f>>23)*C[478]+C[h+3576>>3]+i))}g=c}B[d+8>>2]=E(E(g*E(67108864))/E(.6931471824645996))+E(67108864);n=a,o=E(B[rm(d+12|0,d+8|0)>>2]*E(4.656612873077393e-10)),B[n+4244>>2]=o;n=a,o=E(E(E(-1)/E(E(B[Bb(e,4)>>2]*E(99))+E(1)))+E(1)),B[n+4248>>2]=o;c=E(E(E(B[Bb(e,5)>>2]*E(4))*k)+E(2));c:{if(E(F(c))<E(2147483648)){h=~~c;break c}h=-2147483648}x[a+4252>>2]=h;ib=d+16|0}function BH(a,b){var c=0,d=0,e=0,f=0,g=0;a:{b:{c:{d:{e:{f:{g:{c=x[a+4>>2];h:{if((c|0)!=x[a+104>>2]){x[a+4>>2]=c+1;c=y[c|0];break h}c=qd(a)}switch(c-43|0){case 0:case 2:break g;default:break f}}f=(c|0)==45;g=!b;c=x[a+4>>2];i:{if((c|0)!=x[a+104>>2]){x[a+4>>2]=c+1;c=y[c|0];break i}c=qd(a)}b=c-58|0;if(g|b>>>0>4294967285){break e}b=x[a+116>>2];if((b|0)>0|(b|0)>=0){break d}break a}b=c-58|0}if(b>>>0<4294967286){break c}b=c-48|0;if(b>>>0<10){while(1){e=(D(e,10)+c|0)-48|0;d=(e|0)<214748364;c=x[a+4>>2];j:{if((c|0)!=x[a+104>>2]){x[a+4>>2]=c+1;c=y[c|0];break j}c=qd(a)}b=c-48|0;if(d&b>>>0<=9){continue}break}d=e>>31}k:{if(b>>>0>=10){break k}while(1){b=qoa(e,d,10,0);c=b+c|0;d=kb;d=b>>>0>c>>>0?d+1|0:d;b=c;e=b-48|0;d=d-(b>>>0<48)|0;b=x[a+4>>2];l:{if((b|0)!=x[a+104>>2]){x[a+4>>2]=b+1;c=y[b|0];break l}c=qd(a)}b=c-48|0;if(b>>>0>9){break k}if(e>>>0<2061584302&(d|0)<=21474836|(d|0)<21474836){continue}break}}if(b>>>0<10){while(1){b=x[a+4>>2];m:{if((b|0)!=x[a+104>>2]){x[a+4>>2]=b+1;b=y[b|0];break m}b=qd(a)}if(b-48>>>0<10){continue}break}}b=x[a+116>>2];if((b|0)>0|(b|0)>=0){x[a+4>>2]=x[a+4>>2]-1}kb=f?0-(((e|0)!=0)+d|0)|0:d;return f?0-e|0:e}x[a+4>>2]=x[a+4>>2]-1;break b}if(x[a+116>>2]<0){break a}}x[a+4>>2]=x[a+4>>2]-1}kb=-2147483648;return 0}function g2(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=ib-16|0;ib=k;l=rv(g);g=Zw(g);ih(k,g);a:{b:{if(Qe(k)){x[27524]=0;X(1162,l|0,a|0,c|0,d|0);g=x[27524];x[27524]=0;if((g|0)==1){break b}g=(c-a|0)+d|0;x[f>>2]=g;break a}x[f>>2]=d;c:{d:{j=a;h=y[j|0];switch(h-43|0){case 0:case 2:break d;default:break c}}x[27524]=0;j=Q(20,l|0,h<<24>>24)|0;h=x[27524];x[27524]=0;if((h|0)==1){break b}h=x[f>>2];x[f>>2]=h+1;v[h|0]=j;j=a+1|0}if(!(y[j|0]!=48|(c-j|0)<2|(y[j+1|0]|32)!=120)){x[27524]=0;h=Q(20,l|0,48)|0;i=x[27524];x[27524]=0;if((i|0)==1){break b}i=x[f>>2];x[f>>2]=i+1;v[i|0]=h;h=v[j+1|0];x[27524]=0;h=Q(20,l|0,h|0)|0;i=x[27524];x[27524]=0;if((i|0)==1){break b}i=x[f>>2];x[f>>2]=i+1;v[i|0]=h;j=j+2|0}dm(j,c);i=0;x[27524]=0;o=T(1160,g|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break b}h=0;g=j;while(1){if(c>>>0<=g>>>0){dm((j-a|0)+d|0,x[f>>2]);g=x[f>>2];break a}e:{if(!y[Qc(k,h)|0]){break e}if(v[Qc(k,h)|0]!=(i|0)){break e}i=x[f>>2];x[f>>2]=i+1;v[i|0]=o;h=(Eb(k)-1>>>0>h>>>0)+h|0;i=0}n=v[g|0];x[27524]=0;n=Q(20,l|0,n|0)|0;m=x[27524];x[27524]=0;if((m|0)!=1){m=x[f>>2];x[f>>2]=m+1;v[m|0]=n;g=g+1|0;i=i+1|0;continue}break}}a=P()|0;wb(k);S(a|0);p()}x[e>>2]=(b|0)==(c|0)?g:(b-a|0)+d|0;wb(k);ib=k+16|0}function ofa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;l=ib-16|0;ib=l;k=ib-32|0;ib=k;h=k+28|0;f=k+24|0;g=ib-16|0;ib=g;a:{b:{if(!pc(b,x[Wb(g+8|0,eg(a))>>2])){e=z[c>>1];i=x[c+4>>2];j=ud(b);m=z[j>>1];j=x[j+4>>2];if(!ql(e,i,m,j)){break b}}x[g+8>>2]=b;e=Wb(g,Cb(x[a>>2]));c:{f=x[g+8>>2];if(!pc(f,x[e>>2])){f=x[Tz(g+8|0)>>2];e=ud(f);j=z[e>>1];m=x[e+4>>2];e=z[c>>1];i=x[c+4>>2];if(!ql(j,m,e,i)){break c}}if(!x[b>>2]){x[h>>2]=b;break a}x[h>>2]=f;b=f+4|0;break a}b=Sz(a,h,e,i);break a}if(ql(m,j,e,i)){d:{f=Rz(b);if(!pc(f,x[Wb(g+8|0,eg(a))>>2])){e=z[c>>1];i=x[c+4>>2];j=ud(f);if(!ql(e,i,z[j>>1],x[j+4>>2])){break d}}if(!x[b+4>>2]){x[h>>2]=b;b=b+4|0;break a}x[h>>2]=f;b=f;break a}b=Sz(a,h,e,i);break a}x[h>>2]=b;x[f>>2]=b;b=f}ib=g+16|0;f=b;b=x[b>>2];if(!b){b=ib-16|0;ib=b;g=gc(a);h=k+8|0;e=sh(h,mc(36),th(b+8|0,g));g=x[e>>2]+16|0;i=x[c+4>>2];x[g>>2]=x[c>>2];x[g+4>>2]=i;xl(g+8|0,d);o=gc(e),p=1,v[o+4|0]=p;ib=b+16|0;Tg(a,x[k+28>>2],f,x[k+8>>2]);b=ce(h);PQ(h);n=1}Sg(l,x[Wb(k+8|0,b)>>2],n);ib=k+32|0;if(!y[gc(l)|0]){a=ud(x[l>>2])+8|0;OQ(a);x[a>>2]=x[d>>2];x[a+4>>2]=x[d+4>>2];b=Db(d);o=Db(a),p=x[b>>2],x[o>>2]=p;x[b>>2]=0;x[d>>2]=0;x[d+4>>2]=0}a=x[Wb(l+8|0,x[l>>2])>>2];ib=l+16|0;return a|0}function h1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=ib-496|0;ib=a;g=a+488|0;ed(g,d);x[27524]=0;m=T(1164,g|0)|0;g=x[27524];x[27524]=0;a:{b:{c:{d:{e:{f:{g:{if((g|0)!=1){if(Eb(f)){g=x[Hi(f,0)>>2];x[27524]=0;h=Q(1182,m|0,45)|0;k=x[27524];x[27524]=0;if((k|0)==1){break g}n=(g|0)==(h|0)}k=Kb(a+456|0);g=Kb(a+440|0);h=Kb(a+424|0);x[27524]=0;na(1203,c|0,n|0,a+488|0,a+480|0,a+476|0,a+472|0,k|0,g|0,h|0,a+420|0);c=x[27524];x[27524]=0;if((c|0)==1){break f}x[a+4>>2]=1151;c=xe(a+8|0,0,a+4|0);j=Eb(f);l=x[a+420>>2];h:{if((j|0)>(l|0)){i=((Eb(h)+(j-l<<1)|0)+Eb(g)|0)+1|0;break h}i=(Eb(h)+Eb(g)|0)+2|0}j=a+16|0;i=i+l|0;if(i>>>0<101){break e}cf(c,Gd(i<<2));j=x[c>>2];if(j){break e}x[27524]=0;Z(1152);b=x[27524];x[27524]=0;if((b|0)==1){break d}p()}f=P()|0;break b}f=P()|0;break b}f=P()|0;break c}o=x[d+4>>2];i=vc(f);f=Eb(f);x[27524]=0;pa(1204,j|0,a+4|0,a|0,o|0,i|0,i+(f<<2)|0,m|0,n|0,a+480|0,x[a+476>>2],x[a+472>>2],k|0,g|0,h|0,l|0);f=x[27524];x[27524]=0;if((f|0)!=1){x[27524]=0;b=ka(1185,b|0,j|0,x[a+4>>2],x[a>>2],d|0,e|0)|0;d=x[27524];x[27524]=0;if((d|0)!=1){break a}}}f=P()|0;Uc(c)}Gc(h);Gc(g);wb(k)}_b(a+488|0);S(f|0);p()}Uc(c);Gc(h);Gc(g);wb(k);_b(a+488|0);ib=a+496|0;return b|0}function Bga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0;f=ib-16|0;ib=f;a:{b:{c:{g=x[a+12>>2];i=x[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|(g|0)==-1){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}l=x[a+16>>2];j=x[a+40>>2];k=x[a+36>>2];e=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=e;m=x[a+32>>2];n=x[a+28>>2];while(1){if(d){h=x[f+8>>2];o=((((x[f+12>>2]&2147483647)<<1|h>>>31)&2147483646)<<1)+l|0;e=(h>>>16&65520)+b|0;p=w[e+14>>1];q=w[e+12>>1];r=w[e+10>>1];s=w[e+8>>1];t=w[e+6>>1];u=w[e+4>>1];v=w[e+2>>1];y=w[e>>1];h=0;while(1){if((h|0)!=2){e=(h<<1)+o|0;x[(h<<2)+f>>2]=(((((((D(w[e-8>>1],v)+D(w[e-12>>1],y)|0)+D(w[e-4>>1],u)|0)+D(w[e>>1],t)|0)+D(w[e+4>>1],s)|0)+D(w[e+8>>1],r)|0)+D(w[e+12>>1],q)|0)+D(w[e+16>>1],p)|0)/32768;h=h+1|0;continue}break}k=k+n|0;x[c>>2]=x[c>>2]+D(x[f>>2],k>>12);j=j+m|0;x[c+4>>2]=x[c+4>>2]+D(x[f+4>>2],j>>12);Pb(f+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;x[a+40>>2]=j;x[a+20>>2]=k>>12;x[a+36>>2]=k;x[a+24>>2]=j>>12;ib=f+16|0}function $fa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=ib-16|0;ib=e;q=x[a+16>>2];r=qg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);l=x[a+128>>2];a:{if(!l){j=x[a+8>>2];k=x[a+12>>2];f=x[a>>2];g=x[a+4>>2];i=0;break a}j=x[a+8>>2];k=x[a+12>>2];m=rg(j,k,l);n=kb;b=x[a+76>>2];f=x[a>>2];g=x[a+4>>2];Zf(f,g,rf(j,k,d),kb);i=b>>>0<kb>>>0?d:0}h=a+112|0;s=x[a+24>>2];t=x[a+20>>2];x[e>>2]=f;x[e+4>>2]=g;while(1){if(d){b=x[e+4>>2];f=x[e>>2];x[e+8>>2]=f;x[e+12>>2]=0;i=i-1|0;m=i?m:0;n=i?n:0;d=d-1|0;p=(((b&2147483647)<<1|f>>>31)&-2)+q|0;f=l;b:{c:while(1){d:{if((f|0)<=0){Pb(h,x[a+120>>2],x[a+124>>2]);f=x[a+116>>2];if(!f){break b}o=((x[e+12>>2]&2147483647)<<1|x[e+8>>2]>>>31)&-2;g=0;b=0;break d}o=((x[e+12>>2]&2147483647)<<1|x[e+8>>2]>>>31)&-2;b=0;g=0;while(1)if((b|0)==2){Sd(h,(g|0)/8<<16>>16);Rd(h,4);Pb(e+8|0,m,n);f=f-1|0;continue c}else{g=(v[(b+o|0)+p|0]<<8)+g|0;b=b+1|0;continue}}break}while(1){if((b|0)!=2){g=(v[(b+o|0)+p|0]<<8)+g|0;b=b+1|0;continue}break}Sd(h,(g|0)/8<<16>>16);Rd(h,f);x[h>>2]=x[h>>2];x[h+4>>2]=0}f=x[c>>2];b=pg(h,r);x[c>>2]=f+D(b,t);x[c+4>>2]=x[c+4>>2]+D(b,s);Pb(e,j,k);c=c+8|0;continue}break}b=x[e+4>>2];x[a>>2]=x[e>>2];x[a+4>>2]=b;ib=e+16|0}function wea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;i=ib-16|0;ib=i;d=x[b+1298304>>2];if(!Ed(d)){e=ib-16|0;ib=e;c=mc(12);x[27524]=0;d=T(913,c|0)|0;f=x[27524];x[27524]=0;a:{if((f|0)!=1){c=x[uf(e+8|0,d)>>2];ib=e+16|0;break a}a=P()|0;Ib(c);S(a|0);p()}x[i+8>>2]=c;c=b+1298304|0;e=i+8|0;aP(c,ce(e));hz(e);d=x[c>>2]}f=ib-48|0;ib=f;c=f+16|0;QO(c,a);x[27524]=0;U(8,f+32|0,0,c|0);c=x[27524];x[27524]=0;b:{c:{if((c|0)!=1){xb(f+16|0);m=f,n=Cb(x[d>>2]),x[m+8>>2]=n;l=Cb(x[d+4>>2]);c=0;d=0;while(1){d:{h=x[f+8>>2];if(!Mb(h,l)){e:{if(!d){break e}c=x[d+4>>2];if(!c){break e}x[27524]=0;a=W(c|0,d|0,b|0,a|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break d}if(!a){break e}b=x[d>>2];x[a+4>>2]=b;if(b){x[b+8>>2]=a}x[d>>2]=a}wb(f+32|0);ib=f+48|0;break b}j=0;e=x[h>>2];if(x[e+32>>2]==x[a+16>>2]){j=x[e+36>>2]==x[a+20>>2]}x[27524]=0;R(914,f+16|0,e+8|0);e=x[27524];x[27524]=0;if((e|0)!=1){g=ib-16|0;ib=g;k=f+16|0;ye(g+8|0,k);ye(g,f+32|0);e=wO(x[g+8>>2],x[g+12>>2],x[g>>2],x[g+4>>2]);ib=g+16|0;wb(k);f:{if(!(!j|(e|0)!=0)){d=x[h>>2];c=3;break f}if((c|0)<2&j){d=x[h>>2];c=2;break f}e=!e&(c|0)<=0;d=e?x[h>>2]:d;c=e?1:c}Pe(f+8|0);continue}}break}d=P()|0;wb(f+32|0);break c}d=P()|0;xb(f+16|0)}S(d|0);p()}ib=i+16|0}function W_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;if(gh(a,x[b+8>>2],e)){Iw(b,c,d);return}a:{if(gh(a,x[b>>2],e)){if(!(x[b+16>>2]!=(c|0)&x[b+20>>2]!=(c|0))){if((d|0)!=1){break a}x[b+32>>2]=1;return}x[b+32>>2]=d;if(x[b+44>>2]!=4){f=a+16|0;h=f+(x[a+12>>2]<<3)|0;d=0;b:{c:{while(1){d:{if(f>>>0>=h>>>0){break d}w[b+52>>1]=0;Fw(x[f>>2],x[f+4>>2],b,c,c,1,e);if(y[b+54|0]){break d}e:{if(!y[b+53|0]){break e}if(y[b+52|0]){d=1;if(x[b+24>>2]==1){break c}g=1;if(y[a+8|0]&2){break e}break c}g=1;if(!(v[a+8|0]&1)){break c}}f=f+8|0;continue}break}a=4;if(!g){break b}}a=3}x[b+44>>2]=a;if(d&1){break a}}x[b+20>>2]=c;x[b+40>>2]=x[b+40>>2]+1;if(x[b+36>>2]!=1|x[b+24>>2]!=2){break a}v[b+54|0]=1;return}g=x[a+12>>2];h=a+16|0;Zr(x[h>>2],x[a+20>>2],b,c,d,e);f=a+24|0;g=h+(g<<3)|0;if(f>>>0>=g>>>0){break a}a=x[a+8>>2];if(!(!(a&2)&x[b+36>>2]!=1)){while(1){if(y[b+54|0]){break a}Zr(x[f>>2],x[f+4>>2],b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break}break a}if(!(a&1)){while(1){if(y[b+54|0]|x[b+36>>2]==1){break a}Zr(x[f>>2],x[f+4>>2],b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break a}}while(1){if(y[b+54|0]|x[b+36>>2]==1&x[b+24>>2]==1){break a}Zr(x[f>>2],x[f+4>>2],b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break}}}function l1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=ib-192|0;ib=a;g=a+184|0;ed(g,d);x[27524]=0;m=T(19,g|0)|0;g=x[27524];x[27524]=0;a:{b:{c:{d:{e:{f:{g:{if((g|0)!=1){if(Eb(f)){g=y[ng(f,0)|0];x[27524]=0;h=Q(20,m|0,45)|0;k=x[27524];x[27524]=0;if((k|0)==1){break g}n=(g|0)==(h&255)}k=Kb(a+160|0);g=Kb(a+144|0);h=Kb(a+128|0);x[27524]=0;na(1201,c|0,n|0,a+184|0,a+176|0,a+175|0,a+174|0,k|0,g|0,h|0,a+124|0);c=x[27524];x[27524]=0;if((c|0)==1){break f}x[a+4>>2]=1151;c=xe(a+8|0,0,a+4|0);j=Eb(f);l=x[a+124>>2];h:{if((j|0)>(l|0)){i=((Eb(h)+(j-l<<1)|0)+Eb(g)|0)+1|0;break h}i=(Eb(h)+Eb(g)|0)+2|0}j=a+16|0;i=i+l|0;if(i>>>0<101){break e}cf(c,Gd(i));j=x[c>>2];if(j){break e}x[27524]=0;Z(1152);b=x[27524];x[27524]=0;if((b|0)==1){break d}p()}f=P()|0;break b}f=P()|0;break b}f=P()|0;break c}o=x[d+4>>2];i=Jc(f);f=Eb(f);x[27524]=0;pa(1202,j|0,a+4|0,a|0,o|0,i|0,f+i|0,m|0,n|0,a+176|0,v[a+175|0],v[a+174|0],k|0,g|0,h|0,l|0);f=x[27524];x[27524]=0;if((f|0)!=1){x[27524]=0;b=ka(15,b|0,j|0,x[a+4>>2],x[a>>2],d|0,e|0)|0;d=x[27524];x[27524]=0;if((d|0)!=1){break a}}}f=P()|0;Uc(c)}wb(h);wb(g);wb(k)}_b(a+184|0);S(f|0);p()}Uc(c);wb(h);wb(g);wb(k);_b(a+184|0);ib=a+192|0;return b|0}function Mr(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a:{e=ib-96|0;ib=e;i=x[c>>2];g=ib-32|0;ib=g;f=e- -64|0;j=Kb(f+16|0);x[f>>2]=x[c>>2];x[f+4>>2]=x[c+4>>2];x[f+8>>2]=x[c+8>>2];x[f+12>>2]=x[c+12>>2];x[27524]=0;c=Q(54,g|0,c+16|0)|0;h=x[27524];x[27524]=0;b:{c:{d:{if((h|0)!=1){x[27524]=0;R(58,g+16|0,c|0);h=x[27524];x[27524]=0;if((h|0)==1){break d}f=g+16|0;Ac(j,f);wb(f);wb(c);ib=g+32|0;break b}a=P()|0;break c}a=P()|0;wb(c)}nm(f);S(a|0);p()}x[27524]=0;U(d|0,e|0,b|0,(i&2?16:10)|0);b=x[27524];x[27524]=0;e:{f:{g:{h:{i:{j:{if((b|0)!=1){c=e+16|0;b=ib-16|0;ib=b;k:{if(!(x[e+64>>2]&32)){break k}k=b,l=ke(e),x[k+8>>2]=l;k=b,l=Eh(e),x[k>>2]=l;while(1){if(!Fi(b+8|0,b)){break k}d=x[b+8>>2];f=y[d|0];if((f-97&255)>>>0<=25){v[d|0]=f-32}Ie(b+8|0);continue}}$c(c,e);ib=b+16|0;x[27524]=0;X(75,e+32|0,c|0,x[e+64>>2],x[e+68>>2]);b=x[27524];x[27524]=0;if((b|0)==1){break j}x[27524]=0;U(76,e+48|0,e+32|0,e- -64|0);b=x[27524];x[27524]=0;if((b|0)==1){break i}x[27524]=0;R(58,a|0,e+48|0);a=x[27524];x[27524]=0;if((a|0)==1){break h}wb(e+48|0);wb(e+32|0);wb(e+16|0);wb(e);nm(e- -64|0);ib=e+96|0;break a}a=P()|0;break e}a=P()|0;break f}a=P()|0;break g}a=P()|0;wb(e+48|0)}wb(e+32|0)}wb(e+16|0);wb(e)}nm(e- -64|0);S(a|0);p()}}function Wfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=ib-16|0;ib=f;q=x[a+16>>2];r=qg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);n=x[a+128>>2];a:{if(!n){l=x[a+8>>2];m=x[a+12>>2];e=x[a>>2];b=x[a+4>>2];h=0;break a}l=x[a+8>>2];m=x[a+12>>2];o=rg(l,m,n);p=kb;h=x[a+76>>2];e=x[a>>2];b=x[a+4>>2];Zf(e,b,rf(l,m,d),kb);h=h>>>0<kb>>>0?d:0}g=a+112|0;i=x[a+40>>2];j=x[a+36>>2];x[f>>2]=e;x[f+4>>2]=b;b:while(1){if(d){d=d-1|0;x[f+8>>2]=e;x[f+12>>2]=0;h=h-1|0;o=h?o:0;p=h?p:0;e=((((b&2147483647)<<1|e>>>31)&2147483646)<<1)+q|0;b=n;while(1)if((b|0)<=0){Pb(g,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){k=(x[f+12>>2]&2147483647)<<1|x[f+8>>2]>>>31;Sd(g,(w[(k<<1|2)+e>>1]+w[e+((k&2147483646)<<1)>>1]|0)/8<<16>>16);Rd(g,b);x[g>>2]=x[g>>2];x[g+4>>2]=0}b=x[a+32>>2];j=x[a+28>>2]+j|0;e=pg(g,r);x[c>>2]=D(j>>12,e)+x[c>>2];i=b+i|0;x[c+4>>2]=x[c+4>>2]+D(e,i>>12);Pb(f,l,m);c=c+8|0;e=x[f>>2];b=x[f+4>>2];continue b}else{k=(x[f+12>>2]&2147483647)<<1|x[f+8>>2]>>>31;Sd(g,(w[(k<<1|2)+e>>1]+w[e+((k&2147483646)<<1)>>1]|0)/8<<16>>16);Rd(g,4);Pb(f+8|0,o,p);b=b-1|0;continue}}break}x[a>>2]=e;x[a+4>>2]=b;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+24>>2]=i>>12;ib=f+16|0}function o5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;c=ib+-64|0;ib=c;d=x[a>>2];a=x[d>>2];e=x[a+4>>2];x[c+40>>2]=x[a+20>>2];f=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=f;Qf(c+48|0,c+32|0,e);a=x[d+4>>2];e=x[a+8>>2];f=x[a+4>>2];d=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=d;d=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=d;x[c+8>>2]=x[a+8>>2];d=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=d;a=ib-32|0;ib=a;a:{b:{c:{d:{g=x[c+4>>2];if(f>>>0<=g>>>0){if(f>>>0>A[c+20>>2]){break d}if(A[c+8>>2]<e>>>0){break c}h=x[c+28>>2];if(x[c+24>>2]-h>>>0<e>>>0){break b}k=b+12|0;l=x[c+16>>2];m=x[c>>2];b=0;e:while(1){if((b|0)==(e|0)){break a}n=b+h|0;o=D(b,g);d=0;while(1)if((d|0)==(f|0)){b=b+1|0;continue e}else{s=a,t=+(Mm(Be(ug(C[(d+o<<3)+m>>3])*134217728))+kd(Js(k),21)|0)*7.450580596923828e-9,C[s+24>>3]=t;x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;q=n<<1;r=(d<<2)+l|0;i=Be(C[Qg(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(F(i)<2147483648){j=~~i;break f}j=-2147483648}s=x[r>>2]+q|0,u=dd(j),w[s>>1]=u;d=d+1|0;continue}}}aa(7192,8993,77,8673);p()}aa(7157,8993,78,8673);p()}aa(5900,8993,79,8673);p()}aa(5870,8993,80,8673);p()}ib=a+32|0;ib=c- -64|0}function U1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;k=b;f=ib-384|0;ib=f;x[f+376>>2]=37;x[f+380>>2]=0;h=es(f+376|1,21631,x[c+4>>2]);x[f+332>>2]=f+336;a=Fd();a:{if(h){b=x[c+8>>2];C[f+40>>3]=e;x[f+32>>2]=b;g=hh(f+336|0,30,a,f+376|0,f+32|0);break a}C[f+48>>3]=e;g=hh(f+336|0,30,a,f+376|0,f+48|0)}x[f+80>>2]=1151;i=xe(f+320|0,0,f+80|0);b=f+336|0;a=b;b:{c:{d:{e:{if((g|0)>=30){a=Fd();f:{if(h){g=x[c+8>>2];C[f+8>>3]=e;x[f>>2]=g;g=dj(f+332|0,a,f+376|0,f);break f}C[f+16>>3]=e;g=dj(f+332|0,a,f+376|0,f+16|0)}if((g|0)==-1){x[27524]=0;Z(1152);a=x[27524];x[27524]=0;if((a|0)==1){break d}break e}a=x[f+332>>2];cf(i,a)}j=a+g|0;l=ej(a,j,c);x[f+68>>2]=1151;h=xe(f+72|0,0,f+68|0);g:{h:{if((f+336|0)==(a|0)){g=f+80|0;break h}g=Gd(g<<3);if(!g){x[27524]=0;Z(1152);a=x[27524];x[27524]=0;if((a|0)!=1){break e}a=P()|0;break g}cf(h,g);b=a}a=f+56|0;ed(a,c);x[27524]=0;ia(1184,b|0,l|0,j|0,g|0,f+68|0,f- -64|0,a|0);a=x[27524];x[27524]=0;i:{if((a|0)!=1){_b(f+56|0);x[27524]=0;a=ka(1185,k|0,g|0,x[f+68>>2],x[f+64>>2],c|0,d|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break i}Uc(h);Uc(i);ib=f+384|0;break b}a=P()|0;_b(f+56|0);break g}a=P()|0}Uc(h);break c}p()}a=P()|0}Uc(i);S(a|0);p()}return a|0}function e5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;c=ib+-64|0;ib=c;d=x[a>>2];a=x[d>>2];e=x[a+4>>2];x[c+40>>2]=x[a+20>>2];f=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=f;Qf(c+48|0,c+32|0,e);a=x[d+4>>2];e=x[a+8>>2];f=x[a+4>>2];d=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=d;d=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=d;x[c+8>>2]=x[a+8>>2];d=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=d;a=ib-32|0;ib=a;a:{b:{c:{d:{g=x[c+4>>2];if(f>>>0<=g>>>0){h=x[c+20>>2];if(f>>>0>h>>>0){break d}if(A[c+8>>2]<e>>>0){break c}i=x[c+28>>2];if(x[c+24>>2]-i>>>0<e>>>0){break b}l=b+12|0;m=x[c+16>>2];n=x[c>>2];b=0;e:while(1){if((b|0)==(e|0)){break a}o=D(b,g);q=D(b+i|0,h);d=0;while(1)if((d|0)==(f|0)){b=b+1|0;continue e}else{s=a,t=+(Mm(Be(ug(C[(d+o<<3)+n>>3])*134217728))+kd(Js(l),21)|0)*7.450580596923828e-9,C[s+24>>3]=t;x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;r=(d+q<<1)+m|0;j=Be(C[Qg(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(F(j)<2147483648){k=~~j;break f}k=-2147483648}s=r,u=dd(k),w[s>>1]=u;d=d+1|0;continue}}}aa(7192,8993,77,8673);p()}aa(7157,8993,78,8673);p()}aa(5900,8993,79,8673);p()}aa(5870,8993,80,8673);p()}ib=a+32|0;ib=c- -64|0}function c2(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;k=b;f=ib-208|0;ib=f;x[f+200>>2]=37;x[f+204>>2]=0;h=es(f+200|1,21631,x[c+4>>2]);x[f+156>>2]=f+160;a=Fd();a:{if(h){b=x[c+8>>2];C[f+40>>3]=e;x[f+32>>2]=b;g=hh(f+160|0,30,a,f+200|0,f+32|0);break a}C[f+48>>3]=e;g=hh(f+160|0,30,a,f+200|0,f+48|0)}x[f+80>>2]=1151;i=xe(f+144|0,0,f+80|0);b=f+160|0;a=b;b:{c:{d:{e:{if((g|0)>=30){a=Fd();f:{if(h){g=x[c+8>>2];C[f+8>>3]=e;x[f>>2]=g;g=dj(f+156|0,a,f+200|0,f);break f}C[f+16>>3]=e;g=dj(f+156|0,a,f+200|0,f+16|0)}if((g|0)==-1){x[27524]=0;Z(1152);a=x[27524];x[27524]=0;if((a|0)==1){break d}break e}a=x[f+156>>2];cf(i,a)}j=a+g|0;l=ej(a,j,c);x[f+68>>2]=1151;h=xe(f+72|0,0,f+68|0);g:{h:{if((f+160|0)==(a|0)){g=f+80|0;break h}g=Gd(g<<1);if(!g){x[27524]=0;Z(1152);a=x[27524];x[27524]=0;if((a|0)!=1){break e}a=P()|0;break g}cf(h,g);b=a}a=f+56|0;ed(a,c);x[27524]=0;ia(1179,b|0,l|0,j|0,g|0,f+68|0,f- -64|0,a|0);a=x[27524];x[27524]=0;i:{if((a|0)!=1){_b(f+56|0);x[27524]=0;a=ka(15,k|0,g|0,x[f+68>>2],x[f+64>>2],c|0,d|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break i}Uc(h);Uc(i);ib=f+208|0;break b}a=P()|0;_b(f+56|0);break g}a=P()|0}Uc(h);break c}p()}a=P()|0}Uc(i);S(a|0);p()}return a|0}function Af(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=ib-96|0;ib=c;d=x[a+36>>2];$f(x[x[d>>2]-12>>2]+d|0,0);d=a+32|0;Pc(c+56|0,d,4);if(!zb(x[x[c+56>>2]>>2],x[c+60>>2])){rw(a)}a:{if(!x[a+8>>2]){break a}Pc(c+56|0,d,6);if(zb(x[x[c+56>>2]>>2],x[c+60>>2])){break a}Pc(c+88|0,d,7);if(zb(x[x[c+88>>2]>>2],x[c+92>>2])){break a}h=x[a+36>>2];e=x[a+92>>2];g=D(x[a+28>>2],x[a+8>>2]);f=g+x[a+88>>2]|0;e=Nf(c+72|0,f,f>>>0<g>>>0?e+1|0:e);f=x[e+12>>2];x[c+32>>2]=x[e+8>>2];x[c+36>>2]=f;f=x[e+4>>2];x[c+24>>2]=x[e>>2];x[c+28>>2]=f;eh(h,c+24|0)}Pc(c+56|0,d,5);e=0;b:{if(!zb(x[x[c+56>>2]>>2],x[c+60>>2])){break b}f=Xi(x[a+52>>2],x[a+56>>2]);d=0;while(1){if((d|0)==(f|0)){break b}h=(x[a+108>>2]+d>>>0)%(f>>>0)|0;i=sf(x[a+52>>2],h);g=x[i>>2];c:{j=x[a+40>>2];if(cd(j,x[a+44>>2])>>>0<=g>>>0){break c}g=Tk(c+56|0,Jb(j,g),z[i+20>>1]);i=Bw(b,g);Zb(g);if(!i){break c}x[a+108>>2]=(h+1>>>0)%(f>>>0);e=sf(x[a+52>>2],h);d=e;b=x[d+12>>2];d=x[d+8>>2];if(!(b|d)){break b}e=x[a+36>>2];b=x[a+20>>2]+b|0;f=x[a+16>>2];d=f+d|0;b=Nf(c+40|0,d,d>>>0<f>>>0?b+1|0:b);d=x[b+12>>2];x[c+16>>2]=x[b+8>>2];x[c+20>>2]=d;d=x[b+4>>2];x[c+8>>2]=x[b>>2];x[c+12>>2]=d;eh(e,c+8|0);e=sf(x[a+52>>2],h);break b}d=d+1|0;continue}}ib=c+96|0;return e}function Cga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0;f=ib-16|0;ib=f;a:{b:{c:{g=x[a+12>>2];i=x[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|(g|0)==-1){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}l=x[a+16>>2];j=x[a+40>>2];k=x[a+36>>2];e=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=e;m=x[a+32>>2];n=x[a+28>>2];while(1){if(d){h=x[f+8>>2];o=(((x[f+12>>2]&2147483647)<<1|h>>>31)&-2)+l|0;e=(h>>>16&65520)+b|0;p=w[e+14>>1];q=w[e+12>>1];r=w[e+10>>1];s=w[e+8>>1];t=w[e+6>>1];u=w[e+4>>1];y=w[e+2>>1];z=w[e>>1];h=0;while(1){if((h|0)!=2){e=h+o|0;x[(h<<2)+f>>2]=(((((((D(v[e-4|0],y)+D(v[e-6|0],z)|0)+D(v[e-2|0],u)|0)+D(v[e|0],t)|0)+D(v[e+2|0],s)|0)+D(v[e+4|0],r)|0)+D(v[e+6|0],q)|0)+D(v[e+8|0],p)<<8)/32768;h=h+1|0;continue}break}k=k+n|0;x[c>>2]=x[c>>2]+D(x[f>>2],k>>12);j=j+m|0;x[c+4>>2]=x[c+4>>2]+D(x[f+4>>2],j>>12);Pb(f+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;x[a+40>>2]=j;x[a+20>>2]=k>>12;x[a+36>>2]=k;x[a+24>>2]=j>>12;ib=f+16|0}function tG(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;a=ib-16|0;ib=a;x[a+12>>2]=c;x[a+8>>2]=f;x[a+12>>2]=c;x[a+8>>2]=f;a:{b:{while(1){j=x[a+12>>2];if(!(j>>>0>=d>>>0|f>>>0>=g>>>0)){i=v[j|0];c=i&255;c:{if((i|0)>=0){i=1;break c}b=2;if(i>>>0<4294967234){break a}if(i>>>0<=4294967263){if((d-j|0)<2){break b}i=y[j+1|0];if((i&192)!=128){break a}c=i&63|c<<6&1984;i=2;break c}if(i>>>0<=4294967279){if((d-j|0)<3){break b}k=y[j+2|0];i=y[j+1|0];d:{e:{if((c|0)!=237){if((c|0)!=224){break e}if((i&224)==160){break d}break a}if((i&224)==128){break d}break a}if((i&192)!=128){break a}}if((k&192)!=128){break a}c=k&63|(c<<12&61440|(i&63)<<6);i=3;break c}if(i>>>0>4294967284){break a}if((d-j|0)<4){break b}l=y[j+3|0];m=y[j+2|0];k=y[j+1|0];f:{g:{switch(c-240|0){case 0:if((k+112&255)>>>0<48){break f}break a;case 4:if((k&240)==128){break f}break a;default:break g}}if((k&192)!=128){break a}}if((m&192)!=128|(l&192)!=128){break a}i=4;c=l&63|(m<<6&4032|(c<<18&1835008|(k&63)<<12));if(c>>>0>1114111){break a}}x[f>>2]=c;x[a+12>>2]=i+j;f=x[a+8>>2]+4|0;x[a+8>>2]=f;continue}break}b=d>>>0>j>>>0;break a}b=1}x[e>>2]=x[a+12>>2];x[h>>2]=x[a+8>>2];ib=a+16|0;return b|0}function Hea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;l=ib-16|0;ib=l;x[l+8>>2]=b;q=Gf(a);while(1){if(Rg(b,c)){b=x[Wb(l,q)>>2];k=ud(x[l+8>>2]);o=ib-16|0;ib=o;p=0;m=ib-16|0;ib=m;i=ib-32|0;ib=i;g=i+28|0;d=i+24|0;e=ib-16|0;ib=e;a:{b:{if(!pc(b,x[Wb(e+8|0,eg(a))>>2])){f=y[k|0];j=x[k+4>>2];h=ud(b);n=y[h|0];h=x[h+4>>2];if(!Un(f,j,n,h)){break b}}x[e+8>>2]=b;f=Wb(e,Cb(x[a>>2]));c:{d=x[e+8>>2];if(!pc(d,x[f>>2])){d=x[Tz(e+8|0)>>2];f=ud(d);h=y[f|0];n=x[f+4>>2];f=y[k|0];j=x[k+4>>2];if(!Un(h,n,f,j)){break c}}if(!x[b>>2]){x[g>>2]=b;break a}x[g>>2]=d;b=d+4|0;break a}b=pz(a,g,f,j);break a}if(Un(n,h,f,j)){d:{d=Rz(b);if(!pc(d,x[Wb(e+8|0,eg(a))>>2])){f=y[k|0];j=x[k+4>>2];h=ud(d);if(!Un(f,j,y[h|0],x[h+4>>2])){break d}}if(!x[b+4>>2]){x[g>>2]=b;b=b+4|0;break a}x[g>>2]=d;b=d;break a}b=pz(a,g,f,j);break a}x[g>>2]=b;x[d>>2]=b;b=d}ib=e+16|0;d=b;b=x[b>>2];if(!b){b=ib-16|0;ib=b;e=gc(a);g=i+8|0;e=sh(g,mc(28),th(b+8|0,e));zA(x[e>>2]+16|0,k);r=gc(e),s=1,v[r+4|0]=s;ib=b+16|0;Tg(a,x[i+28>>2],d,x[i+8>>2]);b=ce(g);zk(g);p=1}Sg(m+8|0,x[Wb(i+8|0,b)>>2],p);ib=i+32|0;ib=m+16|0;Wb(o+8|0,x[m+8>>2]);ib=o+16|0;b=x[Ug(l+8|0)>>2];continue}else{ib=l+16|0}break}}function wka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=ib-16|0;ib=e;md(b,0);Ro(b);f=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);a:{if(c&34){if(d){x[b+24>>2]=f;break a}g=b,h=Xe(ki(+(f+1408|0)/1536)*8363),x[g+24>>2]=h;break a}v[b+37|0]=(c|0)==16?f:f^128;v[b+36|0]=y[a+4|0]}v[e+15|0]=y[a+5|0];v[e+14|0]=64;g=b,h=y[Ub(e+15|0,e+14|0)|0]<<2,w[g+30>>1]=h;d=y[a+6|0]|y[a+7|0]<<8;if(d>>>0<=256){w[b+28>>1]=d;w[b+34>>1]=z[b+34>>1]|32}x[b>>2]=y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24);x[b+4>>2]=y[a+12|0]|y[a+13|0]<<8|(y[a+14|0]<<16|y[a+15|0]<<24);x[b+8>>2]=y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24);d=y[a+20|0]|y[a+21|0]<<8;if(d&16){w[b+34>>1]=z[b+34>>1]|2;d=y[a+20|0]|y[a+21|0]<<8}if(d&32){w[b+34>>1]=z[b+34>>1]|4;d=y[a+20|0]|y[a+21|0]<<8}if(d&256){w[b+34>>1]=z[b+34>>1]|8;d=y[a+20|0]|y[a+21|0]<<8}if(d&512){w[b+34>>1]=z[b+34>>1]|16}v[b+38|0]=y[(y[a+22|0]&7)+39712|0];v[b+39|0]=y[a+23|0];v[b+40|0]=y[a+24|0];v[b+41|0]=y[a+25|0];if((c|0)==32){v[e+13|0]=y[a+26|0];v[e+12|0]=64;g=b,h=y[Ub(e+13|0,e+12|0)|0],w[g+32>>1]=h}x[b+12>>2]=y[a+27|0]|y[a+28|0]<<8|(y[a+29|0]<<16|y[a+30|0]<<24);x[b+16>>2]=y[a+31|0]|y[a+32|0]<<8|(y[a+33|0]<<16|y[a+34|0]<<24);ib=e+16|0}function ena(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;f=ib-288|0;ib=f;Vf(b);a:{if(!Ob(x[a>>2],x[a+8>>2],1)){break a}while(1){d=f+32|0;yn(f+8|0,d,Kq(d));k=x[a>>2];g=x[a+8>>2];d=ib-32|0;ib=d;lg(d+16|0,x[f+8>>2],x[f+12>>2]);e=x[x[k>>2]+28>>2];l=x[d+20>>2];x[d+8>>2]=x[d+16>>2];x[d+12>>2]=l;lb[e|0](d+24|0,k,g,d+8|0);lg(f+16|0,x[d+24>>2],x[d+28>>2]);ib=d+32|0;x[f+28>>2]=x[f+20>>2];o=f,q=c-Eb(b)|0,x[o+4>>2]=q;d=x[Hb(f+28|0,f+4|0)>>2];if(!d){break a}v[f+16|0]=0;k=f+32|0;m=k+d|0;d=f+16|0;l=Bi(k,m,d);o=f,q=Eh(b),x[o+16>>2]=q;e=x[pj(f,d)>>2];g=ib-32|0;ib=g;x[g+24>>2]=e;o=g,q=ke(b),x[o+8>>2]=q;h=Rn(g+24|0,g+8|0);b:{c:{d=k;i=Xh(d,l);if(!i){break c}if(!jt(b,d)){e=Eb(b);j=ad(b);d:{if(i>>>0<=j-e>>>0){j=vc(b);if((e|0)==(h|0)){break d}n=h+j|0;ai(i+n|0,n,e-h|0);break d}tm(b,j,(e+i|0)-j|0,e,h,0,i);j=x[b>>2]}e=e+i|0;Wh(b,e);v[g+8|0]=0;oe(e+j|0,g+8|0);e=h+j|0;while(1){if((d|0)==(l|0)){break c}oe(e,d);d=d+1|0;e=e+1|0;continue}}d=Zh(g+8|0,d,l);h=Jc(d);i=Eb(d);x[27524]=0;fa(360,b|0,e|0,h|0,h+i|0)|0;e=x[27524];x[27524]=0;if((e|0)!=1){wb(d);break b}a=P()|0;wb(d);S(a|0);p()}ke(b)}ib=g+32|0;Yb(a,l-k|0);if(l>>>0>=m>>>0){continue}break}Yb(a,1)}ib=f+288|0}function zd(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=ib-80|0;ib=e;x[a+480180>>2]=b;b=Iq(a);Hq(e+8|0,b);d=x[e+20>>2];c=a+1074320|0;x[c>>2]=x[e+16>>2];x[c+4>>2]=d;c=x[e+12>>2];x[a+1074312>>2]=x[e+8>>2];x[a+1074316>>2]=c;qt(a+8|0,b);b=1;while(1){c=b&65535;if(c>>>0>z[a+480192>>1]){x[a+480184>>2]=0;x[a+480188>>2]=0;x[a+480236>>2]=65536;x[a+480228>>2]=48;x[a+480232>>2]=48;v[a+480268|0]=5;x[a+480260>>2]=16;x[a+480264>>2]=32767;x[a+480204>>2]=125e4;x[a+480208>>2]=0;x[a+480196>>2]=6;x[a+480200>>2]=256;x[a+1074304>>2]=0;x[a+1074308>>2]=0;w[a+480192>>1]=0;bz(a,4);d=ib+-64|0;ib=d;b=a+484344|0;st(b);f=Fk(x[b>>2],x[b+4>>2]);c=Ey(d+8|0,b);x[27524]=0;U(820,b|0,f|0,c|0);b=x[27524];x[27524]=0;a:{if((b|0)!=1){ll(c);ib=d- -64|0;break a}a=P()|0;ll(c);S(a|0);p()}FR(a+484360|0);Vf(a+1298308|0);YA(a+1298320|0);Vf(a+1298332|0);b=e+8|0;Rb(b,0,68);b=iP(b);c=Gb(a+1298344|0,b);Gb(c+12|0,b+12|0);Gb(c+24|0,b+24|0);Gb(c+36|0,b+36|0);Gb(c+48|0,b+48|0);d=x[b+64>>2];x[c+60>>2]=x[b+60>>2];x[c+64>>2]=d;iz(b);Ic(a+1298412|0);Ic(a+480248|0);if(x[a+480180>>2]&738230281){x[a+480208>>2]=x[a+480208>>2]|8388608}ib=e+80|0;return}c=((c<<2)+a|0)+900380|0;d=x[c>>2];if(d){Ib(wu(d))}x[c>>2]=0;b=b+1|0;continue}}function PS(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=x[a>>2];e=Gh(c,x[a+4>>2]);if(e>>>0<b>>>0){g=ib-32|0;ib=g;f=b-e|0;b=x[Db(a)>>2];c=x[a+4>>2];a:{if(f>>>0<=b-c>>8>>>0){b=ib-16|0;ib=b;x[b>>2]=a;a=x[a+4>>2];x[b+4>>2]=a;x[b+8>>2]=a+(f<<8);a=x[b+4>>2];e=x[b+8>>2];while(1){if((a|0)==(e|0)){ic(b);ib=b+16|0}else{yS(a);a=a+256|0;x[b+4>>2]=a;continue}break}break a}i=Db(a);b=g+8|0;e=a;h=Gh(x[a>>2],c)+f|0;c=ib-16|0;ib=c;x[c+12>>2]=h;d=ib-16|0;ib=d;x[d+12>>2]=16777215;x[d+8>>2]=2147483647;a=x[Hb(d+12|0,d+8|0)>>2];ib=d+16|0;b:{if(a>>>0>=h>>>0){d=yA(e);if(d>>>0<a>>>1>>>0){x[c+8>>2]=d<<1;a=x[Yc(c+8|0,c+12|0)>>2]}ib=c+16|0;break b}_c();p()}d=Gh(x[e>>2],x[e+4>>2]);tg(b+12|0,i);if(a){if(a>>>0>=16777216){Vg();p()}c=mc(a<<8)}else{c=0}x[b>>2]=c;d=c+(d<<8)|0;x[b+8>>2]=d;x[b+4>>2]=d;j=zc(b),k=c+(a<<8)|0,x[j>>2]=k;a=ib-16|0;ib=a;x[a>>2]=x[b+8>>2];c=x[b+8>>2];x[a+8>>2]=b+8;x[a+4>>2]=c+(f<<8);c=x[a>>2];while(1){if(x[a+4>>2]!=(c|0)){yS(c);c=x[a>>2]+256|0;x[a>>2]=c;continue}break}Vd(a);ib=a+16|0;Dd(e,b);e=x[b+4>>2];a=x[b+8>>2];while(1){if((a|0)!=(e|0)){a=a-256|0;x[b+8>>2]=a;continue}break}a=x[b>>2];if(a){zc(b);Ib(a)}}ib=g+32|0;return}if(b>>>0<e>>>0){Od(a,c+(b<<8)|0)}}function dba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=E(0),q=E(0),r=0,s=0,t=0,u=E(0),v=0;i=ib-16|0;ib=i;if(fi(a+44|0)){n=x[a+44>>2];j=Hc(n,0);k=Hc(n,1);n=x[a+56>>2];t=Hc(n,0);n=Hc(n,1);u=B[Bb(a+4208|0,1)>>2];x[i+12>>2]=d;s=x[a+4220>>2];q=E(E(1)/E(s>>>0));v=x[a+4216>>2];o=d;f=n;g=t;while(1){if(o){h=x[a+4224>>2];a:{if(s>>>0>h>>>0){x[i+8>>2]=s-h;r=x[Hb(i+12|0,i+8|0)>>2];m=0;b:{if(u<E(1)){l=h+r|0;e=h>>>0>l>>>0?h:l;while(1){if((h|0)==(e|0)){break b}p=E(h>>>0);B[g>>2]=q*E(B[j>>2]*p);B[f>>2]=q*E(B[k>>2]*p);h=h+1|0;f=f+4|0;k=k+4|0;g=g+4|0;j=j+4|0;continue}}while(1){if((m|0)!=(r|0)){B[g>>2]=B[j>>2];B[f>>2]=B[k>>2];m=m+1|0;f=f+4|0;k=k+4|0;g=g+4|0;j=j+4|0;continue}break}l=h+r|0}o=o-r|0;x[i+12>>2]=o;break a}m=v-h|0;x[i+4>>2]=m;l=x[Hb(i+12|0,i+4|0)>>2];e=0;c:{if(u<E(1)){e=m-l|0;while(1){if(e>>>0>=m>>>0){break c}p=E(m>>>0);B[g>>2]=q*E(B[j>>2]*p);B[f>>2]=q*E(B[k>>2]*p);m=m-1|0;f=f+4|0;k=k+4|0;g=g+4|0;j=j+4|0;continue}}while(1){if((e|0)!=(l|0)){x[g>>2]=0;x[f>>2]=0;e=e+1|0;f=f+4|0;g=g+4|0;continue}break}e=l<<2;k=e+k|0;j=j+e|0}o=o-l|0;x[i+12>>2]=o;e=h+l|0;l=e>>>0<v>>>0?e:0}x[a+4224>>2]=l;continue}else{zi(a,b,c,t,n,d)}break}}ib=i+16|0}function j8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;b=ib-2160|0;ib=b;it(b+112|0);a:{b:{c:{f=x[c+4>>2];if(!f){a=ba(8)|0;x[27524]=0;b=Q(55,b+96|0,10391)|0;c=x[27524];x[27524]=0;if((c|0)==1){break c}lc(a,b);x[27524]=0;U(123,a|0,50060,962);a=x[27524];x[27524]=0;if((a|0)!=1){break a}c=P()|0;wb(b);break b}g=x[c>>2];d=x[c+12>>2];e=x[c+8>>2];x[b+88>>2]=e;x[b+92>>2]=d;c=x[b+92>>2];x[b+40>>2]=x[b+88>>2];x[b+44>>2]=c;x[b+84>>2]=f;x[b+80>>2]=g;c=x[b+84>>2];x[b+32>>2]=x[b+80>>2];x[b+36>>2]=c;h=sJ(b+32|0);if(h){c=b- -64|0;x[c>>2]=e;x[b+68>>2]=d;d=x[c+4>>2];x[b+24>>2]=x[c>>2];x[b+28>>2]=d;x[b+60>>2]=f;x[b+56>>2]=g;c=x[b+60>>2];x[b+16>>2]=x[b+56>>2];x[b+20>>2]=c;c=lJ(b+16|0)}else{c=0}x[b+72>>2]=c;x[b+76>>2]=0;d=0;c=2048;while(1){if(c){e=lb[f|0](g,(b+112|0)+d|0,c)|0;c=c-e|0;d=d+e|0;if(e){continue}}break}c=dc(b+48|0,b+112|0,d);d=x[c+4>>2];x[b+8>>2]=x[c>>2];x[b+12>>2]=d;a=pt(a,b+8|0,h?b+72|0:0);if(a+1>>>0>=3){a=ba(8)|0;x[27524]=0;b=Q(55,b+96|0,8005)|0;c=x[27524];x[27524]=0;if((c|0)!=1){lc(a,b);x[27524]=0;U(123,a|0,50060,962);a=x[27524];x[27524]=0;if((a|0)!=1){break a}c=P()|0;wb(b);break b}c=P()|0;ca(a|0);break b}ib=b+2160|0;return a|0}c=P()|0;ca(a|0)}S(c|0)}p()}function VY(a,b){a=a|0;b=b|0;var c=0,d=0;d=ib-32|0;ib=d;if(!Qb(a,13647,4)){md(b,32);Ro(b);di(d,1,a+4|0);c=d+16|0;Fc(c,d);Fe(b+43|0,c);wb(c);w[b+30>>1]=y[a+19|0]<<2;Mf(b+30|0,256);w[b+32>>1]=y[a+17|0];Mf(b+32|0,64);w[b+28>>1]=(y[a+47|0]&127)<<2;Mf(b+28|0,256);if(v[a+47|0]<0){w[b+34>>1]=z[b+34>>1]|32}c=y[a+18|0];if(c&16){w[b+34>>1]=z[b+34>>1]|2;c=y[a+18|0]}if(c&32){w[b+34>>1]=z[b+34>>1]|8;c=y[a+18|0]}if(c&64){w[b+34>>1]=z[b+34>>1]|4;c=y[a+18|0]}if(c<<24>>24<0){w[b+34>>1]=z[b+34>>1]|16}c=y[a+60|0]|y[a+61|0]<<8|(y[a+62|0]<<16|y[a+63|0]<<24);x[b+24>>2]=c?c>>>0<=256?256:c:8363;x[b>>2]=y[a+48|0]|y[a+49|0]<<8|(y[a+50|0]<<16|y[a+51|0]<<24);x[b+4>>2]=y[a+52|0]|y[a+53|0]<<8|(y[a+54|0]<<16|y[a+55|0]<<24);x[b+8>>2]=y[a+56|0]|y[a+57|0]<<8|(y[a+58|0]<<16|y[a+59|0]<<24);x[b+12>>2]=y[a+64|0]|y[a+65|0]<<8|(y[a+66|0]<<16|y[a+67|0]<<24);x[b+16>>2]=y[a+68|0]|y[a+69|0]<<8|(y[a+70|0]<<16|y[a+71|0]<<24);Jk(b);v[b+38|0]=y[(y[a+79|0]&7)+39712|0];v[b+41|0]=y[a+76|0];v[b+40|0]=y[a+77|0]&127;v[b+39|0]=y[a+78|0];c=y[a+46|0];a:{if((c|0)==64){c=512}else{if((c|0)!=128){break a}c=16384}w[b+34>>1]=c|z[b+34>>1]}c=y[a+72|0]|y[a+73|0]<<8|(y[a+74|0]<<16|y[a+75|0]<<24)}ib=d+32|0;return c|0}function mp(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;a:{e=ib-96|0;ib=e;i=x[c>>2];g=ib-32|0;ib=g;f=e- -64|0;j=Kb(f+16|0);x[f>>2]=x[c>>2];x[f+4>>2]=x[c+4>>2];x[f+8>>2]=x[c+8>>2];x[f+12>>2]=x[c+12>>2];x[27524]=0;c=Q(3,g|0,c+16|0)|0;h=x[27524];x[27524]=0;b:{c:{d:{if((h|0)!=1){x[27524]=0;R(71,g+16|0,c|0);h=x[27524];x[27524]=0;if((h|0)==1){break d}f=g+16|0;Gb(j,f);xb(f);xb(c);ib=g+32|0;break b}a=P()|0;break c}a=P()|0;xb(c)}Qj(f);S(a|0);p()}x[27524]=0;U(d|0,e|0,b|0,(i&2?16:10)|0);b=x[27524];x[27524]=0;e:{f:{g:{h:{i:{j:{if((b|0)!=1){d=e+16|0;c=ib-16|0;ib=c;k:{if(!(x[e+64>>2]&32)){break k}b=Ti(e);x[c+8>>2]=b;f=ir(e);while(1){if(!Mb(b,f)){break k}g=y[b|0];if((g-97&255)>>>0<=25){v[b|0]=g-32}b=x[Ie(c+8|0)>>2];continue}}$c(d,e);ib=c+16|0;x[27524]=0;X(82,e+32|0,d|0,x[e+64>>2],x[e+68>>2]);b=x[27524];x[27524]=0;if((b|0)==1){break j}x[27524]=0;U(83,e+48|0,e+32|0,e- -64|0);b=x[27524];x[27524]=0;if((b|0)==1){break i}x[27524]=0;R(71,a|0,e+48|0);a=x[27524];x[27524]=0;if((a|0)==1){break h}xb(e+48|0);xb(e+32|0);xb(e+16|0);xb(e);Qj(e- -64|0);ib=e+96|0;break a}a=P()|0;break e}a=P()|0;break f}a=P()|0;break g}a=P()|0;xb(e+48|0)}xb(e+32|0)}xb(e+16|0);xb(e)}Qj(e- -64|0);S(a|0);p()}}function Yha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=ib-48|0;ib=k;if(Jf(x[b>>2],x[b+4>>2])>>>0>c>>>0){while(1){i=m&65535;if(i>>>0<=c>>>0){g=hg(x[b>>2],i);e=x[g>>2];if(Mb(e,x[g+4>>2])){n=k+24|0;e=Cb(e);o=Cb(x[hg(x[b>>2],i)+4>>2]);f=oS(k,d);l=ib-16|0;ib=l;x[l+8>>2]=e;while(1){if(Mb(e,o)){j=ib-16|0;ib=j;if(!(y[e+5|0]|y[e+3|0]!=4)){g=j+8|0;Ab(g,x[f>>2],z[f+14>>1]);bf(g,0);v[e+3|0]=0}h=y[e+2|0];if(!(y[e+4|0]|(h|0)!=11)){g=j+8|0;Ab(g,x[f>>2],z[f+14>>1]);bf(g,0);v[e+2|0]=0;h=0}a:{b:{if(!y[e|0]){Ab(j+8|0,x[f>>2],z[f+14>>1]);if(zb(x[x[j+8>>2]>>2],x[j+12>>2])){break b}h=y[e+2|0]}i=y[e+3|0];g=j+8|0;Ab(g,x[f>>2],z[f+14>>1]);bf(g,(i|0)==4|(h|0)==11);h=y[e+3|0];break a}h=y[e+3|0];g=y[e+2|0];if(!(h|(g|0)==11)){v[e+5|0]=0;h=4;v[e+3|0]=4;break a}if(g|(h|0)==4){break a}v[e+4|0]=0;v[e+2|0]=11}c:{d:{e:{if(!(!y[f+16|0]|h)){v[e+3|0]=17;i=0;h=125;break e}i=0;f:{switch(h-16|0){case 1:break d;case 0:break f;default:break c}}if(y[e+5|0]){break c}i=1;h=6}v[e+5|0]=h}v[f+16|0]=i}w[f+14>>1]=(z[f+14>>1]+1>>>0)%z[f+12>>1];ib=j+16|0;e=x[Hk(l+8|0)>>2];continue}break}mS(n,f);ib=l+16|0;$e(n);$e(f)}m=m+1|0;continue}break}}mS(a,d);ib=k+48|0}function jga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0;h=ib-16|0;ib=h;f=x[a+48>>2];j=x[a+24>>2];k=x[a+20>>2];e=x[a+44>>2];l=x[a+16>>2];g=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=g;m=b+24|0;n=x[a+72>>2];b=x[a+68>>2];o=b;p=b>>31;b=x[a+64>>2];q=b;r=b>>31;b=x[a+60>>2];s=b;t=b>>31;u=x[a+8>>2];v=x[a+12>>2];while(1){b=e;if(d){e=Vb(b,-16777216,16776704);e=qoa(q,r,e,e>>31);g=kb;f=Vb(f,-16777216,16776704);i=qoa(o,p,f,f>>31);e=i+e|0;f=kb+g|0;f=e>>>0<i>>>0?f+1|0:f;y=e;e=(x[h+12>>2]<<1)+l|0;g=(((x[h+8>>2]>>>16|0)+4&131064)<<1)+m|0;g=(((((D(w[e+4>>1],w[g+10>>1])+D(w[e+2>>1],w[g+8>>1])|0)+D(w[e+6>>1],w[g+12>>1])|0)+D(w[e+8>>1],w[g+14>>1])|0)/2|0)+((((D(w[e-4>>1],w[g+2>>1])+D(w[e-6>>1],w[g>>1])|0)+D(w[e-2>>1],w[g+4>>1])|0)+D(w[e>>1],w[g+6>>1])|0)/2|0)|0)/16384<<8;e=g;i=qoa(e,e>>31,s,t);e=y+i|0;f=kb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Vc(e,f,24);e=(f|0)/256|0;x[c>>2]=D(e,k)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(e,j);Pb(h+8|0,u,v);e=f-(g&n)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+48>>2]=f;x[a+44>>2]=b;ib=h+16|0}function kga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0;h=ib-16|0;ib=h;f=x[a+48>>2];j=x[a+24>>2];k=x[a+20>>2];e=x[a+44>>2];l=x[a+16>>2];g=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=g;m=b+24|0;n=x[a+72>>2];b=x[a+68>>2];o=b;p=b>>31;b=x[a+64>>2];q=b;r=b>>31;b=x[a+60>>2];s=b;t=b>>31;u=x[a+8>>2];y=x[a+12>>2];while(1){b=e;if(d){e=Vb(b,-16777216,16776704);e=qoa(q,r,e,e>>31);g=kb;f=Vb(f,-16777216,16776704);i=qoa(o,p,f,f>>31);e=i+e|0;f=kb+g|0;f=e>>>0<i>>>0?f+1|0:f;z=e;e=x[h+12>>2]+l|0;g=(((x[h+8>>2]>>>16|0)+4&131064)<<1)+m|0;g=(((((D(v[e+2|0],w[g+10>>1])+D(v[e+1|0],w[g+8>>1])|0)+D(v[e+3|0],w[g+12>>1])|0)+D(v[e+4|0],w[g+14>>1])<<8)/2|0)+((((D(v[e-2|0],w[g+2>>1])+D(v[e-3|0],w[g>>1])|0)+D(v[e-1|0],w[g+4>>1])|0)+D(v[e|0],w[g+6>>1])<<8)/2|0)|0)/16384<<8;e=g;i=qoa(e,e>>31,s,t);e=z+i|0;f=kb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Vc(e,f,24);e=(f|0)/256|0;x[c>>2]=D(e,k)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(e,j);Pb(h+8|0,u,y);e=f-(g&n)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+48>>2]=f;x[a+44>>2]=b;ib=h+16|0}function Lga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0;h=ib-16|0;ib=h;f=x[a+48>>2];i=x[a+40>>2];j=x[a+36>>2];e=x[a+44>>2];n=x[a+16>>2];b=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=b;o=x[a+32>>2];p=x[a+28>>2];q=x[a+72>>2];b=x[a+68>>2];r=b;s=b>>31;b=x[a+64>>2];t=b;u=b>>31;b=x[a+60>>2];v=b;y=b>>31;z=x[a+8>>2];A=x[a+12>>2];while(1){b=e;if(d){e=Vb(b,-16777216,16776704);e=qoa(t,u,e,e>>31);k=kb;B=e;e=(x[h+12>>2]<<1)+n|0;g=x[h+8>>2]>>>21&2040;l=(((D(w[e>>1],w[g+39730>>1])+D(w[e-2>>1],w[g+39728>>1])|0)+D(w[e+2>>1],w[g+39732>>1])|0)+D(w[e+4>>1],w[g+39734>>1])|0)/16384<<8;e=l;m=qoa(e,e>>31,v,y);g=B+m|0;e=kb+k|0;e=g>>>0<m>>>0?e+1|0:e;f=Vb(f,-16777216,16776704);k=qoa(r,s,f,f>>31);g=k+g|0;f=kb+e|0;f=g>>>0<k>>>0?f+1|0:f;e=g+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Vc(e,f,24);e=(f|0)/256|0;j=j+p|0;x[c>>2]=D(e,j>>12)+x[c>>2];i=i+o|0;x[c+4>>2]=x[c+4>>2]+D(e,i>>12);Pb(h+8|0,z,A);e=f-(q&l)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=f;x[a+44>>2]=b;x[a+24>>2]=i>>12;ib=h+16|0}function Fca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=ib-16|0;ib=h;if(!y[a+4242|0]){qy(a);a:{if(!y[a+4240|0]){break a}e=Zy(x[a+16>>2]);if(e==C[a+4288>>3]){break a}C[a+4288>>3]=e;dt(a)}f=a+4256|0;b:{if(y[a+4244|0]){if(C[f>>3]>1){x[f>>2]=0;x[f+4>>2]=1072693248}break b}i=(x[a+4232>>2]&-2)!=4;e=C[f>>3];c:{if(F(e)<2147483648){g=~~e;break c}g=-2147483648}if(!(i|(g|0)<=0)){py(a);e=C[a+4256>>3]}C[f>>3]=e-+(g|0)}e=0;d:{e:{switch(x[a+4232>>2]){case 0:e=Ki(C[f>>3]*6.283185307179586);break d;case 1:e=F(C[f>>3]+-.5)*-4+1;break d;case 2:e=C[f>>3];e=e+e+-1;break d;case 3:e=C[f>>3]<.5?-1:1;break d;case 4:e=C[a+4272>>3];break d;case 5:break e;default:break d}}e=C[a+4256>>3];e=e*(e*e)*(e*(e*6+-15)+10);e=C[a+4280>>3]*e+C[a+4272>>3]*(1-e)}C[h+8>>3]=(y[a+4241|0]?-e:e)*+B[a+4220>>2]+ +B[a+4224>>2];uQ(h+8|0,1);g=oj(a);f:{if(!g){break f}f=x[a+4236>>2];if(y[a+4243|0]){k=g,l=(f>>>8&15|176)&191|(f&127)<<8|Ak(C[h+8>>3]*127)<<16,j=x[x[g>>2]+68>>2],lb[j](k|0,l|0)|0;break f}lb[x[x[g>>2]+44>>2]](g,f,E(C[h+8>>3]))}C[a+4256>>3]=C[a+4264>>3]*+(d>>>0)+C[a+4256>>3]}g=a;a=x[a+44>>2];zi(g,b,c,Hc(a,0),Hc(a,1),d);ib=h+16|0}function Cma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;md(b,32);xo(b);f=b,g=se((y[a+50|0]|y[a+51|0]<<8)<<16>>16)>>>2|0,w[f+32>>1]=g;if((se((y[a+32|0]|y[a+33|0]<<8)<<16>>16)|0)>0){w[b+34>>1]=z[b+34>>1]|32;c=se((y[a+32|0]|y[a+33|0]<<8)<<16>>16);e=c>>>24|0;d=(c<<8&-256)+2047|0;c=e&255;f=b,g=Ec(soa(d,d>>>0<2047?c+1|0:c,4095,0),kb),w[f+28>>1]=g}c=ac(y[a+38|0]|y[a+39|0]<<8|(y[a+40|0]<<16|y[a+41|0]<<24));x[b>>2]=c;d=ac(y[a+42|0]|y[a+43|0]<<8|(y[a+44|0]<<16|y[a+45|0]<<24));x[b+4>>2]=d;e=ac(y[a+42|0]|y[a+43|0]<<8|(y[a+44|0]<<16|y[a+45|0]<<24))+ac(y[a+46|0]|y[a+47|0]<<8|(y[a+48|0]<<16|y[a+49|0]<<24))|0;x[b+8>>2]=e;if((Fb(y[a+34|0]|y[a+35|0]<<8)|0)==16){x[b+8>>2]=e>>>1;x[b+4>>2]=d>>>1;x[b>>2]=c>>>1}a:{b:{if(ac(y[a+42|0]|y[a+43|0]<<8|(y[a+44|0]<<16|y[a+45|0]<<24))){c=z[b+34>>1];break b}c=z[b+34>>1];if(ac(y[a+46|0]|y[a+47|0]<<8|(y[a+48|0]<<16|y[a+49|0]<<24))>>>0>=3){break b}c=c&-3;break a}c=c|2}w[b+34>>1]=c;f=b,g=c&65531|Fb(y[a+30|0]|y[a+31|0]<<8)<<1&4,w[f+34>>1]=g;f=b,g=Fb(y[a+36|0]|y[a+37|0]<<8)<<1,x[f+24>>2]=g;c=se((y[a+52|0]|y[a+53|0]<<8)<<16>>16);if(c){Cl(b,+(c|0)/96);c=se((y[a+52|0]|y[a+53|0]<<8)<<16>>16)}v[b+37|0]=c<<4}function jV(a,b,c){var d=0,e=0,f=0,g=0;d=ib-16|0;ib=d;v[d+15|0]=c;a:{if(b>>>0>=22){v[d+14|0]=0;fe(a,0,d+14|0);break a}e=y[b+26688|0];b:{c:{switch(b-8|0){case 0:v[d+15|0]=c<<1;break b;case 4:v[d+15|0]=c+1>>>1;break b;case 5:v[d+15|0]=D(c>>>4|0,10)+(c&15);break b;case 6:d:{switch((c>>>4|0)-1|0){default:e=0;break b;case 0:v[d+13|0]=c&15;v[d+12|0]=14;f=d,g=y[Ub(d+13|0,d+12|0)|0]<<4|15,v[f+15|0]=g;e=29;break b;case 1:v[d+11|0]=c&15;v[d+10|0]=14;f=d,g=y[Ub(d+11|0,d+10|0)|0]|240,v[f+15|0]=g;e=29;break b;case 3:v[d+15|0]=c&15|48;break b;case 4:v[d+15|0]=c<<4^128;e=35;break b;case 5:v[d+15|0]=c&15|176;break b;case 6:v[d+15|0]=c&15|64;break b;case 8:e=15;v[d+15|0]=c&15;break b;case 9:v[d+15|0]=(c<<3&120)+8&240;e=24;break b;case 10:v[d+15|0]=(c&15)+1>>>1;e=24;break b;case 14:break d;case 11:case 12:case 13:break b}}e=10;break b;case 8:if(c>>>0<=223){b=c>>>2|0;v[d+15|0]=(b>>>0>=15?15:b)<<4;break b}if(c>>>0<=239){v[d+15|0]=c<<2&48|15;break b}v[d+15|0]=c<<4|15;break b;case 9:break c;default:break b}}if(c>>>0<=223){b=c>>>2|0;v[d+15|0]=b>>>0>=15?15:b;break b}if(c>>>0>239){break b}v[d+15|0]=c>>>2&3|240}fe(a,e,d+15|0)}ib=d+16|0}function Mga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0;g=ib-16|0;ib=g;f=x[a+48>>2];i=x[a+40>>2];j=x[a+36>>2];e=x[a+44>>2];l=x[a+16>>2];b=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=b;m=x[a+32>>2];n=x[a+28>>2];o=x[a+72>>2];b=x[a+68>>2];p=b;q=b>>31;b=x[a+64>>2];r=b;s=b>>31;b=x[a+60>>2];t=b;u=b>>31;y=x[a+8>>2];z=x[a+12>>2];while(1){b=e;if(d){e=Vb(b,-16777216,16776704);e=qoa(r,s,e,e>>31);h=kb;f=Vb(f,-16777216,16776704);k=qoa(p,q,f,f>>31);e=k+e|0;f=kb+h|0;f=e>>>0<k>>>0?f+1|0:f;A=e;e=x[g+12>>2]+l|0;h=x[g+8>>2]>>>21&2040;h=(((D(v[e|0],w[h+39730>>1])+D(v[e-1|0],w[h+39728>>1])|0)+D(v[e+1|0],w[h+39732>>1])|0)+D(v[e+2|0],w[h+39734>>1])<<8)/16384<<8;e=h;k=qoa(e,e>>31,t,u);e=A+k|0;f=kb+f|0;f=e>>>0<k>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Vc(e,f,24);e=(f|0)/256|0;j=j+n|0;x[c>>2]=D(e,j>>12)+x[c>>2];i=i+m|0;x[c+4>>2]=x[c+4>>2]+D(i>>12,e);Pb(g+8|0,y,z);e=f-(h&o)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=f;x[a+44>>2]=b;x[a+24>>2]=i>>12;ib=g+16|0}function _fa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=ib-16|0;ib=e;o=x[a+16>>2];p=qg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);l=x[a+128>>2];a:{if(!l){j=x[a+8>>2];k=x[a+12>>2];f=x[a>>2];g=x[a+4>>2];i=0;break a}j=x[a+8>>2];k=x[a+12>>2];m=rg(j,k,l);n=kb;b=x[a+76>>2];f=x[a>>2];g=x[a+4>>2];Zf(f,g,rf(j,k,d),kb);i=b>>>0<kb>>>0?d:0}h=a+112|0;q=x[a+24>>2];r=x[a+20>>2];x[e>>2]=f;x[e+4>>2]=g;b:while(1){if(d){b=x[e+4>>2];f=x[e>>2];x[e+8>>2]=f;x[e+12>>2]=0;i=i-1|0;m=i?m:0;n=i?n:0;d=d-1|0;f=((((b&2147483647)<<1|f>>>31)&2147483646)<<1)+o|0;b=l;while(1)if((b|0)<=0){Pb(h,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){g=(x[e+12>>2]&2147483647)<<1|x[e+8>>2]>>>31;Sd(h,(w[(g<<1|2)+f>>1]+w[((g&2147483646)<<1)+f>>1]|0)/8<<16>>16);Rd(h,b);x[h>>2]=x[h>>2];x[h+4>>2]=0}f=x[c>>2];b=pg(h,p);x[c>>2]=f+D(b,r);x[c+4>>2]=x[c+4>>2]+D(b,q);Pb(e,j,k);c=c+8|0;continue b}else{g=(x[e+12>>2]&2147483647)<<1|x[e+8>>2]>>>31;Sd(h,(w[(g<<1|2)+f>>1]+w[((g&2147483646)<<1)+f>>1]|0)/8<<16>>16);Rd(h,4);Pb(e+8|0,m,n);b=b-1|0;continue}}break}b=x[e+4>>2];x[a>>2]=x[e>>2];x[a+4>>2]=b;ib=e+16|0}function rH(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;k=ib-16|0;ib=k;f=y[a|0];a:{if(!f){g=a;break a}g=a;b:{while(1){if(!_k(f<<24>>24)){break b}f=y[g+1|0];g=g+1|0;if(f){continue}break}break a}c:{f=f&255;switch(f-43|0){case 0:case 2:break c;default:break a}}m=(f|0)==45?-1:0;g=g+1|0}d:{if(!((c|16)!=16|y[g|0]!=48)){n=1;if((y[g+1|0]&223)==88){g=g+2|0;l=16;break d}g=g+1|0;l=c?c:8;break d}l=c?c:10}c=0;while(1){e:{f=-48;i=v[g|0];f:{if((i-48&255)>>>0<10){break f}f=-87;if((i-97&255)>>>0<26){break f}f=-55;if((i-65&255)>>>0>25){break e}}i=f+i|0;if((i|0)>=(l|0)){break e}Ef(k,l,0,0,0,j,h,0,0);f=1;g:{if(x[k+8>>2]|x[k+12>>2]){break g}o=qoa(j,h,l,0);p=kb;if((p|0)==-1&(i^-1)>>>0<o>>>0){break g}h=p;f=i+o|0;h=f>>>0<i>>>0?h+1|0:h;j=f;n=1;f=c}g=g+1|0;c=f;continue}break}if(b){x[b>>2]=n?g:a}h:{i:{j:{if(c){x[12e4]=68;a=d&1;m=a?0:m;j=d;h=e;break j}if((e|0)==(h|0)&d>>>0>j>>>0|e>>>0>h>>>0){break i}a=d&1}if(!(a|m)){x[12e4]=68;a=d;d=a-1|0;e=e-!a|0;break h}if((e|0)==(h|0)&d>>>0>=j>>>0|e>>>0>h>>>0){break i}x[12e4]=68;break h}a=m;b=a^j;d=b-a|0;c=a>>31;e=(c^h)-((a>>>0>b>>>0)+c|0)|0}ib=k+16|0;kb=e;return d}function p5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0;b=ib+-64|0;ib=b;c=x[a>>2];a=x[c>>2];d=x[a+4>>2];x[b+40>>2]=x[a+20>>2];e=x[a+16>>2];x[b+32>>2]=x[a+12>>2];x[b+36>>2]=e;Qf(b+48|0,b+32|0,d);a=x[c+4>>2];d=x[a+8>>2];e=x[a+4>>2];c=x[b+60>>2];x[b+24>>2]=x[b+56>>2];x[b+28>>2]=c;c=x[b+52>>2];x[b+16>>2]=x[b+48>>2];x[b+20>>2]=c;x[b+8>>2]=x[a+8>>2];c=x[a+4>>2];x[b>>2]=x[a>>2];x[b+4>>2]=c;a=ib-32|0;ib=a;a:{b:{c:{d:{g=x[b+4>>2];if(g>>>0>=e>>>0){if(A[b+20>>2]<e>>>0){break d}if(d>>>0>A[b+8>>2]){break c}h=x[b+28>>2];if(d>>>0>x[b+24>>2]-h>>>0){break b}k=x[b+16>>2];l=x[b>>2];e:while(1){if((d|0)==(f|0)){break a}m=f+h|0;n=D(f,g);c=0;while(1)if((c|0)==(e|0)){f=f+1|0;continue e}else{C[a+24>>3]=C[(c+n<<3)+l>>3];x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;o=m<<1;q=(c<<2)+k|0;i=Be(C[Qg(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(F(i)<2147483648){j=~~i;break f}j=-2147483648}r=x[q>>2]+o|0,s=dd(j),w[r>>1]=s;c=c+1|0;continue}}}aa(7192,8993,77,8673);p()}aa(7157,8993,78,8673);p()}aa(5900,8993,79,8673);p()}aa(5870,8993,80,8673);p()}ib=a+32|0;ib=b- -64|0}function f5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0;b=ib+-64|0;ib=b;c=x[a>>2];a=x[c>>2];d=x[a+4>>2];x[b+40>>2]=x[a+20>>2];e=x[a+16>>2];x[b+32>>2]=x[a+12>>2];x[b+36>>2]=e;Qf(b+48|0,b+32|0,d);a=x[c+4>>2];d=x[a+8>>2];e=x[a+4>>2];c=x[b+60>>2];x[b+24>>2]=x[b+56>>2];x[b+28>>2]=c;c=x[b+52>>2];x[b+16>>2]=x[b+48>>2];x[b+20>>2]=c;x[b+8>>2]=x[a+8>>2];c=x[a+4>>2];x[b>>2]=x[a>>2];x[b+4>>2]=c;a=ib-32|0;ib=a;a:{b:{c:{d:{g=x[b+4>>2];if(g>>>0>=e>>>0){h=x[b+20>>2];if(h>>>0<e>>>0){break d}if(d>>>0>A[b+8>>2]){break c}i=x[b+28>>2];if(d>>>0>x[b+24>>2]-i>>>0){break b}l=x[b+16>>2];m=x[b>>2];e:while(1){if((d|0)==(f|0)){break a}n=D(f,g);o=D(f+i|0,h);c=0;while(1)if((c|0)==(e|0)){f=f+1|0;continue e}else{C[a+24>>3]=C[(c+n<<3)+m>>3];x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;q=(c+o<<1)+l|0;j=Be(C[Qg(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(F(j)<2147483648){k=~~j;break f}k=-2147483648}r=q,s=dd(k),w[r>>1]=s;c=c+1|0;continue}}}aa(7192,8993,77,8673);p()}aa(7157,8993,78,8673);p()}aa(5900,8993,79,8673);p()}aa(5870,8993,80,8673);p()}ib=a+32|0;ib=b- -64|0}function jJ(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;e=ib-16|0;ib=e;d=e+8|0;Pw(d,a);b=ib-96|0;ib=b;a=x[d+4>>2];$f(x[x[a>>2]-12>>2]+a|0,0);Pd(b+80|0,x[d+4>>2]);a:{b:{a=x[d+4>>2];if(!jh(x[(x[x[a>>2]-12>>2]+a|0)+16>>2])){if(!gp(b+80|0,Nf(b- -64|0,-1,-1))){break b}}$f(a+x[x[a>>2]-12>>2]|0,0);break a}kt(a,0,0);a=x[d+4>>2];c=x[x[a>>2]-12>>2]+a|0;if(jh(x[c+16>>2])){$f(c,0);a=x[d+4>>2];c=x[b+92>>2];x[b+8>>2]=x[b+88>>2];x[b+12>>2]=c;c=x[b+84>>2];x[b>>2]=x[b+80>>2];x[b+4>>2]=c;eh(a,b);a=x[d+4>>2];$f(x[x[a>>2]-12>>2]+a|0,0);break a}kt(a,0,2);a=x[d+4>>2];c=x[x[a>>2]-12>>2]+a|0;if(jh(x[c+16>>2])){$f(c,0);a=x[d+4>>2];c=x[b+92>>2];x[b+24>>2]=x[b+88>>2];x[b+28>>2]=c;c=x[b+84>>2];x[b+16>>2]=x[b+80>>2];x[b+20>>2]=c;eh(a,b+16|0);a=x[d+4>>2];$f(x[x[a>>2]-12>>2]+a|0,0);break a}Pd(b- -64|0,a);a=x[d+4>>2];c:{if(!jh(x[(a+x[x[a>>2]-12>>2]|0)+16>>2])){f=1;if(!gp(b- -64|0,Nf(b+48|0,-1,-1))){break c}}$f(x[x[a>>2]-12>>2]+a|0,0);a=x[d+4>>2];f=0}c=x[b+92>>2];x[b+40>>2]=x[b+88>>2];x[b+44>>2]=c;c=x[b+84>>2];x[b+32>>2]=x[b+80>>2];x[b+36>>2]=c;eh(a,b+32|0);a=x[d+4>>2];$f(x[x[a>>2]-12>>2]+a|0,0)}ib=b+96|0;ib=e+16|0;return f|0}function Fga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=ib-16|0;ib=f;a:{b:{c:{g=x[a+12>>2];i=x[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|(g|0)==-1){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}j=x[a+16>>2];k=x[a+24>>2];l=x[a+20>>2];e=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=e;while(1){if(d){h=x[f+8>>2];m=((((x[f+12>>2]&2147483647)<<1|h>>>31)&2147483646)<<1)+j|0;e=(h>>>16&65520)+b|0;n=w[e+14>>1];o=w[e+12>>1];p=w[e+10>>1];q=w[e+8>>1];r=w[e+6>>1];s=w[e+4>>1];t=w[e+2>>1];u=w[e>>1];h=0;while(1){if((h|0)!=2){e=(h<<1)+m|0;x[(h<<2)+f>>2]=(((((((D(w[e-8>>1],t)+D(w[e-12>>1],u)|0)+D(w[e-4>>1],s)|0)+D(w[e>>1],r)|0)+D(w[e+4>>1],q)|0)+D(w[e+8>>1],p)|0)+D(w[e+12>>1],o)|0)+D(w[e+16>>1],n)|0)/32768;h=h+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f>>2],l);x[c+4>>2]=x[c+4>>2]+D(x[f+4>>2],k);Pb(f+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;ib=f+16|0}function Iea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;i=ib-16|0;ib=i;x[i+8>>2]=b;o=Gf(a);while(1){if(Rg(b,c)){b=x[Wb(i,o)>>2];j=ud(x[i+8>>2]);m=ib-16|0;ib=m;n=0;k=ib-16|0;ib=k;h=ib-32|0;ib=h;f=h+28|0;d=h+24|0;e=ib-16|0;ib=e;a:{b:{if(!pc(b,x[Wb(e+8|0,eg(a))>>2])){g=y[j|0];l=y[ud(b)|0];if(!Vn(g,l)){break b}}x[e+8>>2]=b;g=Wb(e,Cb(x[a>>2]));c:{d=x[e+8>>2];if(!pc(d,x[g>>2])){d=x[Tz(e+8|0)>>2];l=y[ud(d)|0];g=y[j|0];if(!Vn(l,g)){break c}}if(!x[b>>2]){x[f>>2]=b;break a}x[f>>2]=d;b=d+4|0;break a}b=qz(a,f,g);break a}if(Vn(l,g)){d:{d=Rz(b);if(!pc(d,x[Wb(e+8|0,eg(a))>>2])){g=y[j|0];if(!Vn(g,y[ud(d)|0])){break d}}if(!x[b+4>>2]){x[f>>2]=b;b=b+4|0;break a}x[f>>2]=d;b=d;break a}b=qz(a,f,g);break a}x[f>>2]=b;x[d>>2]=b;b=d}ib=e+16|0;d=b;b=x[b>>2];if(!b){b=ib-16|0;ib=b;e=gc(a);f=h+8|0;e=sh(f,mc(24),th(b+8|0,e));EP(x[e>>2]+16|0,x[j>>2],x[j+4>>2]);p=gc(e),q=1,v[p+4|0]=q;ib=b+16|0;Tg(a,x[h+28>>2],d,x[h+8>>2]);b=ce(f);zk(f);n=1}Sg(k+8|0,x[Wb(h+8|0,b)>>2],n);ib=h+32|0;ib=k+16|0;Wb(m+8|0,x[k+8>>2]);ib=m+16|0;b=x[Ug(i+8|0)>>2];continue}else{ib=i+16|0}break}}function ooa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=ib-32|0;ib=g;v[g+12|0]=0;m=Io(g+16|0,d,g+12|0);f=x[m>>2];x[g+12>>2]=d;h=d;while(1){if(!(!b|!h)){a:{i=b-1|0;k=y[a|0];if(!(!i|(k|0)!=(e&255))){x[g+8>>2]=y[a+1|0];i=a+2|0;j=Hb(g+8|0,g+12|0);b:{k=b-2|0;if(!k){break b}j=x[j>>2];if(!(j&255)){break b}i=y[i|0];while(1){if(!(j&255)){break a}v[f|0]=i;h=x[g+12>>2]-1|0;x[g+12>>2]=h;f=f+1|0;j=j-1|0;continue}}v[f|0]=e;h=x[g+12>>2]-1|0;x[g+12>>2]=h;f=f+1|0;b=k;a=i;continue}a=a+1|0;v[f|0]=k;h=x[g+12>>2]-1|0;x[g+12>>2]=h;f=f+1|0;b=i;continue}b=b-3|0;a=a+3|0;continue}break}e=d-h|0;a=x[m>>2];k=0;f=128;b=0;i=0;c:while(1){if((e|0)==(i|0)){while(1){if(e){d=k<<24>>24;b=v[c|0];a=128;d:{if((b|0)==-128){break d}a=b;if((b|0)>=0){break d}a=0-(b&127)|0}k=d-(a&255)|0;v[c|0]=k;e=e-1|0;c=c+1|0;continue}break}ec(m);ib=g+32|0;return}n=y[a|0];h=0;j=0;while(1)if((j&65535)>>>0>=8){f=f&65535;f=(f<<8|f)>>>h&255;i=i+1|0;a=a+1|0;continue c}else{l=b+c|0;v[l|0]=y[l|0]|D(f&n,257)>>>(h-j&7);l=b+1|0;b=d>>>0>l>>>0?l:0;j=j+1|0;h=(d>>>0<=l>>>0)+h|0;f=(f<<8|f)>>>1&255;continue}}}function HU(a,b,c,d,e){var f=0,g=0;f=ib-16|0;ib=f;a:{if((d&255)>>>0<=4){while(1){d=z[c>>1]<<1;w[c>>1]=d;v[b|0]=(d&65534)>>>0>255;d=y[c|0];w[c>>1]=d;if(!d){if(!vf(a,f+15|0)){break a}d=y[f+15|0];w[c>>1]=d<<1|1;v[b|0]=d>>>7;w[c>>1]=y[c|0]}w[e>>1]=v[b|0]+(z[e>>1]<<1);d=z[c>>1]<<1;w[c>>1]=d;v[b|0]=(d&65534)>>>0>255;d=y[c|0];w[c>>1]=d;if(!d){if(!vf(a,f+14|0)){break a}d=y[f+14|0];w[c>>1]=d<<1|1;v[b|0]=d>>>7;w[c>>1]=y[c|0]}w[e>>1]=v[b|0]+(z[e>>1]<<1);d=z[c>>1]<<1;w[c>>1]=d;v[b|0]=(d&65534)>>>0>255;d=y[c|0];w[c>>1]=d;if(!d){d=vf(a,f+13|0);if(d){g=y[f+13|0];w[c>>1]=g<<1|1;v[b|0]=g>>>7;w[c>>1]=y[c|0]}if(!d){break a}if(y[b|0]){continue}break a}if(y[b|0]){continue}break a}}while(1){d=z[c>>1]<<1;w[c>>1]=d;v[b|0]=(d&65534)>>>0>255;d=y[c|0];w[c>>1]=d;if(!d){if(!vf(a,f+12|0)){break a}d=y[f+12|0];w[c>>1]=d<<1|1;v[b|0]=d>>>7;w[c>>1]=y[c|0]}w[e>>1]=v[b|0]+(z[e>>1]<<1);d=z[c>>1]<<1;w[c>>1]=d;v[b|0]=(d&65534)>>>0>255;d=y[c|0];w[c>>1]=d;if(!d){d=vf(a,f+11|0);if(d){g=y[f+11|0];w[c>>1]=g<<1|1;v[b|0]=g>>>7;w[c>>1]=y[c|0]}if(!d){break a}if(y[b|0]){continue}break a}if(y[b|0]){continue}break}}ib=f+16|0}function r1(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;a=ib-448|0;ib=a;x[a+432>>2]=c;x[a+440>>2]=b;x[a+20>>2]=1186;b=xe(a+24|0,a+32|0,a+20|0);h=a+16|0;ed(h,e);x[27524]=0;h=T(1164,h|0)|0;i=x[27524];x[27524]=0;if((i|0)!=1){a:{v[a+15|0]=0;e=x[e+4>>2];x[27524]=0;c=qa(1194,a+440|0,c|0,d|0,a+16|0,e|0,f|0,a+15|0,h|0,b|0,a+20|0,a+432|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break a}b:{c:{if(!c){break c}d:{if(kf(g)){td(x[g>>2],0);vd(g,0);break d}td(g,0);ee(g,0)}if(y[a+15|0]){x[27524]=0;c=Q(1182,h|0,45)|0;d=x[27524];x[27524]=0;if((d|0)==1){break a}x[27524]=0;R(49,g|0,c|0);c=x[27524];x[27524]=0;if((c|0)==1){break a}}x[27524]=0;d=Q(1182,h|0,48)|0;c=x[27524];x[27524]=0;if((c|0)==1){break b}e=x[a+20>>2];h=e-4|0;c=x[b>>2];while(1){if(!((d|0)!=x[c>>2]|c>>>0>=h>>>0)){c=c+4|0;continue}break}x[27524]=0;W(1199,g|0,c|0,e|0)|0;c=x[27524];x[27524]=0;if((c|0)!=1){break c}break a}x[27524]=0;c=Q(1170,a+440|0,a+432|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break a}if(c){x[f>>2]=x[f>>2]|2}c=x[a+440>>2];_b(a+16|0);Uc(b);ib=a+448|0;return c|0}}}c=P()|0;_b(a+16|0);Uc(b);S(c|0);p()}function d4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;m=ib-32|0;ib=m;i=wf(m+16|0,1,0);a:{b:{while(1){d=vc(i);o=d+Eb(i)|0;e=x[b>>2];g=x[b+4>>2];if(!((g|0)>0|(g|0)>=0|(d|0)==(o|0))){v[d|0]=45;d=d+1|0;e=pM(e,g);g=kb}n=m+8|0;c:{if((c|0)==10){kM(n,d,o,e,g);break c}j=e;h=g;k=D(c,c);r=D(k,c);q=D(k,k);f=0;d:{while(1){l=f|1;if(!h&c>>>0>j>>>0){break d}l=f|2;if(!h&j>>>0<k>>>0){break d}l=f|3;if(!h&j>>>0<r>>>0){break d}if(!h&j>>>0<q>>>0){l=f+4|0}else{f=f+4|0;j=soa(j,h,q,0);h=kb;continue}break}}f=l;if((f|0)>(o-d|0)){x[n+4>>2]=61;x[n>>2]=o;break c}j=d+f|0;d=j;while(1){k=soa(e,g,c,0);f=kb;h=qoa(k,f,c,0);d=d-1|0;v[d|0]=y[(e-h|0)+4898|0];h=!g&c>>>0<=e>>>0|(g|0)!=0;e=k;g=f;if(h){continue}break}x[n+4>>2]=0;x[n>>2]=j}if(!x[m+12>>2]){break b}e=Og(Eb(i));x[27524]=0;R(59,i|0,e|0);e=x[27524];x[27524]=0;if((e|0)!=1){continue}break}break a}c=x[m+8>>2];b=vc(i);x[27524]=0;R(60,i|0,c-b|0);b=x[27524];x[27524]=0;e:{if((b|0)!=1){x[27524]=0;R(72,a|0,i|0);a=x[27524];x[27524]=0;if((a|0)!=1){break e}break a}break a}wb(i);ib=m+32|0;return}a=P()|0;wb(i);S(a|0);p()}function Lda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;j=ib-32|0;ib=j;e=b;b=x[a>>2];f=D(mt(e,Cb(b)),6)+b|0;a:{if(!c){break a}b=x[Db(a)>>2];g=x[a+4>>2];if((b-g|0)/6>>>0>=c>>>0){b=c;e=(g-f|0)/6|0;if(e>>>0<c>>>0){uB(a,c-e|0,d);b=e;if((f|0)==(g|0)){break a}}k=ib-16|0;ib=k;m=x[a+4>>2];h=D((m-(D(c,6)+f|0)|0)/6|0,6)+f|0;l=Rq(k,a,(g-h|0)/6|0);i=x[l+4>>2];e=h;while(1){if(e>>>0>=g>>>0){ic(l);if((f|0)!=(h|0)){e=h-f|0;Wi(m+D((e|0)/-6|0,6)|0,f,e)}ib=k+16|0}else{Du(i,e);i=i+6|0;x[l+4>>2]=i;e=e+6|0;continue}break}e=f;a=D(e>>>0<=d>>>0?A[a+4>>2]>d>>>0?c:0:0,6)+d|0;while(1){if(b){c=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);v[e|0]=c;v[e+1|0]=c>>>8;v[e+2|0]=c>>>16;v[e+3|0]=c>>>24;c=y[a+4|0]|y[a+5|0]<<8;v[e+4|0]=c;v[e+5|0]=c>>>8;b=b-1|0;e=e+6|0;continue}break}break a}b=Db(a);e=BV(j+8|0,pB(a,xk(x[a>>2],g)+c|0),(f-x[a>>2]|0)/6|0,b);AV(e,c,d);b=x[e+4>>2];d=e+4|0;yV(x[a>>2],f,d);h=x[a+4>>2];c=e+8|0;while(1){if((f|0)!=(h|0)){Du(x[c>>2],f);x[c>>2]=x[c>>2]+6;f=f+6|0;continue}break}oc(a,d);oc(a+4|0,c);oc(Db(a),zc(e));x[e>>2]=x[e+4>>2];f=b;zV(e)}Cb(f);ib=j+32|0}function qna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;d=ib-1072|0;ib=d;x[d+1068>>2]=c;o=d,q=Re(b),v[o+8|0]=q;v[d+4|0]=1;c=d+8|0;g=y[mf(c,d+4|0)|0];f=eC(c,b);l=Pq(f);x[27524]=0;c=T(206,b|0)|0;e=x[27524];x[27524]=0;a:{if((e|0)!=1){x[d+4>>2]=c;x[d>>2]=536870911;wc(d+1068|0,x[Hb(d+4|0,d)>>2]<<3);x[27524]=0;m=x[d+1068>>2];k=Q(339,a|0,m|0)|0;a=x[27524];x[27524]=0;if((a|0)!=1){x[27524]=0;c=8;h=Q(168,f|0,8)|0;a=x[27524];x[27524]=0;b:{if((a|0)!=1){c:{o=Jb(x[k>>2],0),q=h,v[o|0]=q;i=1;a=g;while(1){c=c&255;n=c>>>0<=9?9:c;e=a;d:{e:{while(1){if(i>>>0>=m>>>0){break d}x[27524]=0;j=Q(168,f|0,c|0)|0;a=x[27524];x[27524]=0;if((a|0)!=1){if(j){break e}if((c|0)==(n|0)){break d}c=c+1|0;e=g;continue}break}break c}a=j>>>1|0;h=(j&1?0-a|0:a)+h|0;o=Jb(x[k>>2],i),q=h,v[o|0]=q;i=i+1|0;a=g;if(j>>>c-1|0){continue}a=e-1|0;e=a&255;a=e?a:g;c=c-(!e&(c&255)>>>0>1)|0;continue}break}a=Pq(f);x[27524]=0;Q(159,b|0,((a-l|0)+3&-4)+l|0)|0;a=x[27524];x[27524]=0;if((a|0)!=1){break b}}}c=P()|0;ec(k);break a}yb(f);ib=d+1072|0;return}c=P()|0;break a}c=P()|0}yb(f);S(c|0);p()}function aca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=E(0),g=0,h=0,i=0,j=0,k=0,l=0,m=E(0),n=0,o=0,p=E(0),q=E(0),r=E(0),s=E(0),t=E(0),u=0,v=0,w=0,z=E(0);i=x[a+44>>2];h=Hc(i,0);i=Hc(i,1);j=x[a+56>>2];n=Hc(j,0);j=Hc(j,1);k=a+4208|0;g=tc(x[k>>2],x[a+4212>>2]);o=D(x[x[a+16>>2]+1074404>>2],y[a+4233|0]);e=o<<1;if(g>>>0<e>>>0){kk(k,e)}l=y[a+4232|0];a:{if(l){e=x[a+4220>>2];k=x[a+4208>>2];u=l-1|0;l=0;while(1){if((d|0)==(l|0)){break a}r=B[i>>2];e=e>>>0<o>>>0?e:0;g=e-o|0;g=((g|0)<0?e:g)<<1;v=Bb(k,g);f=B[Bb(k,g|1)>>2];s=B[h>>2];t=B[v>>2];p=E(s+t);B[n>>2]=p;q=E(r+f);B[j>>2]=q;f=E(0);m=E(0);b:{c:{switch(u|0){case 0:f=B[a+4224>>2];m=E(q*f);f=E(p*f);break b;case 1:case 2:f=B[a+4224>>2];m=E(p*f);f=E(q*f);break b;case 3:break c;default:break b}}f=E(E(E(E(s+r)*E(.5))+t)*B[a+4224>>2]);m=f}j=j+4|0;n=n+4|0;i=i+4|0;h=h+4|0;g=e<<1;w=Bb(k,g),z=E(F(f))<E(10000000195414814e-40)?E(0):f,B[w>>2]=z;w=Bb(k,g|1),z=E(F(m))<E(10000000195414814e-40)?E(0):m,B[w>>2]=z;e=e+1|0;x[a+4220>>2]=e;l=l+1|0;continue}}e=h;h=d<<2;wh(e,e+h|0,n);wh(i,i+h|0,j)}h=a;a=x[a+56>>2];zi(h,b,c,Hc(a,0),Hc(a,1),d)}function Gga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=ib-16|0;ib=f;a:{b:{c:{g=x[a+12>>2];i=x[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|(g|0)==-1){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}j=x[a+16>>2];k=x[a+24>>2];l=x[a+20>>2];e=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=e;while(1){if(d){h=x[f+8>>2];m=(((x[f+12>>2]&2147483647)<<1|h>>>31)&-2)+j|0;e=(h>>>16&65520)+b|0;n=w[e+14>>1];o=w[e+12>>1];p=w[e+10>>1];q=w[e+8>>1];r=w[e+6>>1];s=w[e+4>>1];t=w[e+2>>1];u=w[e>>1];h=0;while(1){if((h|0)!=2){e=h+m|0;x[(h<<2)+f>>2]=(((((((D(v[e-4|0],t)+D(v[e-6|0],u)|0)+D(v[e-2|0],s)|0)+D(v[e|0],r)|0)+D(v[e+2|0],q)|0)+D(v[e+4|0],p)|0)+D(v[e+6|0],o)|0)+D(v[e+8|0],n)<<8)/32768;h=h+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f>>2],l);x[c+4>>2]=x[c+4>>2]+D(x[f+4>>2],k);Pb(f+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;ib=f+16|0}function Nn(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=ib-80|0;ib=c;g=Nb(a);a=x[b+24>>2];a:{b:{if(wj(x[a+484360>>2],x[a+484364>>2])){c:{d:{e:while(1){if(wj(x[a+484360>>2],x[a+484364>>2])>>>0<=f>>>0){break d}d=FO(uU(c+40|0,1),f&255,0,0);x[27524]=0;e=x[d+12>>2];x[c+16>>2]=x[d+8>>2];x[c+20>>2]=e;e=x[d+20>>2];x[c+24>>2]=x[d+16>>2];x[c+28>>2]=e;e=x[d+4>>2];x[c+8>>2]=x[d>>2];x[c+12>>2]=e;X(1052,c- -64|0,a|0,0,c+8|0);a=x[27524];x[27524]=0;if((a|0)==1){break c}j=c,k=Cb(x[c+64>>2]),x[j+32>>2]=k;d=Cb(x[c+68>>2]);while(1){a=x[c+32>>2];if(!Mb(a,d)){f=f+1|0;Li(c- -64|0);a=x[b+24>>2];continue e}h=C[a>>3];e=x[a+16>>2];i=z[a+24>>1];a=c+40|0;x[a+16>>2]=f;x[a+12>>2]=i;x[a+8>>2]=e;C[a>>3]=h;x[27524]=0;R(1085,g|0,a|0);a=x[27524];x[27524]=0;if((a|0)!=1){gA(c+32|0);continue}break}break}a=P()|0;Li(c- -64|0);break b}ib=c+80|0;return}a=P()|0;break b}b=ba(8)|0;x[27524]=0;d=Q(55,c+40|0,7258)|0;a=x[27524];x[27524]=0;if((a|0)!=1){lc(b,d);x[27524]=0;U(123,b|0,50060,962);a=x[27524];x[27524]=0;if((a|0)!=1){break a}a=P()|0;wb(d);break b}a=P()|0;ca(b|0)}nf(g);S(a|0)}p()}function zB(a,b,c,d){v[a+5|0]=c;a:{b:{switch((b|64)+-64|0){case 0:v[a+3|0]=c?37:0;return;case 1:v[a+3|0]=16;return;case 2:v[a+3|0]=12;return;case 3:v[a+3|0]=14;if(d){break a}v[a+5|0]=D(c>>>4|0,10)+(c&15);return;case 4:v[a+3|0]=11;return;case 5:v[a+3|0]=3;return;case 6:v[a+3|0]=2;return;case 7:v[a+3|0]=4;return;case 8:v[a+3|0]=5;return;case 9:v[a+3|0]=18;return;case 10:v[a+3|0]=1;return;case 11:v[a+3|0]=7;return;case 12:v[a+3|0]=6;return;case 13:v[a+3|0]=21;return;case 14:v[a+3|0]=22;return;case 15:v[a+3|0]=10;return;case 16:v[a+3|0]=29;return;case 17:v[a+3|0]=15;return;case 18:v[a+3|0]=8;return;case 19:v[a+3|0]=20;return;case 20:v[a+3|0]=17;return;case 21:v[a+3|0]=26;return;case 22:v[a+3|0]=23;return;case 23:v[a+3|0]=24;return;case 24:v[a+3|0]=9;return;case 25:v[a+3|0]=27;return;case 26:v[a+3|0]=31;return;case 28:v[a+3|0]=d?32:31;return;case 29:v[a+3|0]=d?33:0;return;case 27:v[a+3|0]=d?34:0;return;case 30:v[a+3|0]=d?35:0;return;case 31:v[a+3|0]=d?36:0;return;case 50:v[a+3|0]=d?25:0;return;case 51:v[a+3|0]=d?30:0;return;default:break b}}v[a+3|0]=0}}function Gba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=E(0),f=0,g=E(0),h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=E(0),t=0,u=0,v=0,w=0,y=0,z=E(0);a:{j=x[a+4272>>2];if(!j){break a}if(!fi(a+44|0)){break a}f=x[a+44>>2];l=Hc(f,0);m=Hc(f,1);u=x[a+4252>>2]-1|0;i=x[a+4268>>2];k=x[a+4256>>2];n=d;f=x[a+56>>2];q=Hc(f,0);o=q;r=Hc(f,1);p=r;while(1){if(n){e=B[m>>2];f=i<<1;h=Bb(k,f);g=B[l>>2];B[h>>2]=g;y=Bb(k,f|1),z=e,B[y>>2]=z;s=B[a+4276>>2];e=E(E(F(bN(E(E(E(F(g))+E(F(e)))*E(536870912)),31,5)))*E(4.656612873077393e-10));e=E(E(E(s-e)*B[(e>=s?4236:4240)+a>>2])+e);B[a+4276>>2]=e;g=B[a+4244>>2];e=E(E(E(E(g-(e<g?g:e))*B[a+4248>>2])+E(.9999998807907104))*E(2147483648));b:{if(e<E(4294967296)&e>=E(0)){f=~~e>>>0;break b}f=0}t=((((i<<12)+u|0)+j|0)/4096|0)%(j|0)<<1;g=B[Bb(k,t)>>2];h=f<<5;v=h;w=h|-2147483648;h=f>>>0<67108864;e=E(B[a+4232>>2]*E(E((h?v:w)>>>(h?31:32-(f>>>26|0)|0)>>>0)*E(4.656612873077393e-10)));B[o>>2]=g*e;y=p,z=E(B[Bb(k,t|1)>>2]*e),B[y>>2]=z;i=((i?0:j)+i|0)-1|0;x[a+4268>>2]=i;n=n-1|0;p=p+4|0;o=o+4|0;m=m+4|0;l=l+4|0;continue}else{zi(a,b,c,q,r,d)}break}}}function oca(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0;b=ib+-64|0;ib=b;g=Nb(a);x[27524]=0;Y(915,g|0);a=x[27524];x[27524]=0;a:{if((a|0)!=1){a=44608;b:{c:{d:{e:{f:{g:{h:{i:{j:{while(1){if((a|0)==44920){ib=b- -64|0;return g|0}k:{h=ot(44);if(h){d=x[a>>2];e=x[a+4>>2];x[27524]=0;e=Q(55,b+32|0,e|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break k}x[27524]=0;R(916,b+48|0,e|0);c=x[27524];x[27524]=0;if((c|0)==1){break j}c=x[a+8>>2];x[27524]=0;c=Q(55,b|0,c|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break i}x[27524]=0;R(916,b+16|0,c|0);f=x[27524];x[27524]=0;if((f|0)==1){break h}x[27524]=0;d=fa(917,h|0,d|0,b+48|0,b+16|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break g}$b(b+16|0);wb(c);$b(b+48|0);wb(e);x[b+60>>2]=d;x[27524]=0;R(918,g|0,b+60|0);e=x[27524];x[27524]=0;if((e|0)==1){break b}x[d+32>>2]=x[a+12>>2];x[d+36>>2]=x[a+16>>2];v[d+40|0]=y[a+20|0];v[d+41|0]=y[d+41|0]&253|y[a+21|0]<<1}a=a+24|0;continue}break}a=P()|0;break c}a=P()|0;break d}a=P()|0;break e}a=P()|0;break f}a=P()|0;$b(b+16|0)}wb(c)}$b(b+48|0)}wb(e)}Ib(h);break a}a=P()|0;break a}a=P()|0}uc(g);S(a|0);p()}function PI(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0,n=0,o=E(0),q=0;a:{if(y[b+21|0]){q=D(d,g);j=x[e>>2];l=x[f>>2];m=x[b>>2];b:{while(1){if((h|0)>0){if(x[a+1396>>2]<=9){dl(a)}g=x[a+1392>>2];k=w[(((g&1023)<<1)+b|0)+36>>1];c:{if((k|0)>=0){i=g;k=k&65535;g=y[k+x[b+8>>2]|0];x[a+1392>>2]=i>>>g;g=x[a+1396>>2]-g|0;x[a+1396>>2]=(g|0)>0?g:0;k=(g|0)<0?-1:k;break c}k=lm(a,b)}if((k|0)>=x[b+2092>>2]?y[b+23|0]:0){break a}if((k|0)<0){if(!y[a+1376|0]){b=0;if(x[a+1384>>2]){break b}}fc(a,21);return 0}else{g=0;n=D(d,l);m=((m+n|0)+j|0)>(q|0)?(q-n|0)+j|0:m;n=(m|0)>0?m:0;k=D(k,x[b>>2]);o=E(0);d:{if(y[b+22|0]){while(1){if((g|0)==(n|0)){break d}o=E(o+B[x[b+28>>2]+(g+k<<2)>>2]);i=x[(j<<2)+c>>2];if(i){i=i+(l<<2)|0;B[i>>2]=o+B[i>>2]}j=j+1|0;i=(j|0)==(d|0);j=i?0:j;g=g+1|0;l=i+l|0;continue}}while(1){if((g|0)==(n|0)){break d}i=x[(j<<2)+c>>2];if(i){i=i+(l<<2)|0;B[i>>2]=B[i>>2]+E(B[x[b+28>>2]+(g+k<<2)>>2]+E(0))}j=j+1|0;i=(j|0)==(d|0);j=i?0:j;g=g+1|0;l=i+l|0;continue}}h=h-m|0;continue}}break}x[e>>2]=j;x[f>>2]=l;b=1}return b}fc(a,21);return 0}aa(7500,13154,1887,6554);p()}function soa(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=c;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if(b){if(!g){break k}if(!d){break j}c=G(d)-G(b)|0;if(c>>>0<=31){break i}break c}if((d|0)==1|d>>>0>1){break c}a=(a>>>0)/(g>>>0)|0;kb=0;break a}if(!a){break h}if(!d){break g}if(d-1&d){break g}a=b>>>poa(d)|0;kb=0;break a}if(!(g-1&g)){break f}h=(G(g)+33|0)-G(b)|0;e=0-h|0;break d}h=c+1|0;e=63-c|0;break d}a=(b>>>0)/(d>>>0)|0;kb=0;break a}c=G(d)-G(b)|0;if(c>>>0<31){break e}break c}if((g|0)==1){break b}c=poa(g);d=c&31;if((c&63)>>>0>=32){c=0;a=b>>>d|0}else{c=b>>>d|0;a=((1<<d)-1&b)<<32-d|a>>>d}kb=c;break a}h=c+1|0;e=63-c|0}c=h&63;f=c&31;if(c>>>0>=32){c=0;i=b>>>f|0}else{c=b>>>f|0;i=((1<<f)-1&b)<<32-f|a>>>f}f=c;c=e&63;e=c&31;if(c>>>0>=32){c=a<<e;a=0}else{c=(1<<e)-1&a>>>32-e|b<<e;a=a<<e}b=c;if(h){c=d-1|0;e=g-1|0;m=(e|0)!=-1?c+1|0:c;while(1){c=i<<1|b>>>31;f=f<<1|i>>>31;j=m-(f+(c>>>0>e>>>0)|0)>>31;k=g&j;i=c-k|0;f=f-((d&j)+(c>>>0<k>>>0)|0)|0;b=b<<1|a>>>31;a=l|a<<1;l=j&1;h=h-1|0;if(h){continue}break}}kb=b<<1|a>>>31;a=l|a<<1;break a}a=0;b=0}kb=b}return a}function bP(a){var b=0,c=0,d=0,e=0,f=0,g=0;while(1){if((f|0)!=4e3){g=ib-32|0;ib=g;b=Rt(g);d=y[b+4|0]|y[b+5|0]<<8|(y[b+6|0]<<16|y[b+7|0]<<24);c=(f<<5)+a|0;e=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);v[c|0]=e;v[c+1|0]=e>>>8;v[c+2|0]=e>>>16;v[c+3|0]=e>>>24;v[c+4|0]=d;v[c+5|0]=d>>>8;v[c+6|0]=d>>>16;v[c+7|0]=d>>>24;d=y[b+28|0]|y[b+29|0]<<8|(y[b+30|0]<<16|y[b+31|0]<<24);e=y[b+24|0]|y[b+25|0]<<8|(y[b+26|0]<<16|y[b+27|0]<<24);v[c+24|0]=e;v[c+25|0]=e>>>8;v[c+26|0]=e>>>16;v[c+27|0]=e>>>24;v[c+28|0]=d;v[c+29|0]=d>>>8;v[c+30|0]=d>>>16;v[c+31|0]=d>>>24;d=y[b+20|0]|y[b+21|0]<<8|(y[b+22|0]<<16|y[b+23|0]<<24);e=y[b+16|0]|y[b+17|0]<<8|(y[b+18|0]<<16|y[b+19|0]<<24);v[c+16|0]=e;v[c+17|0]=e>>>8;v[c+18|0]=e>>>16;v[c+19|0]=e>>>24;v[c+20|0]=d;v[c+21|0]=d>>>8;v[c+22|0]=d>>>16;v[c+23|0]=d>>>24;d=y[b+12|0]|y[b+13|0]<<8|(y[b+14|0]<<16|y[b+15|0]<<24);b=y[b+8|0]|y[b+9|0]<<8|(y[b+10|0]<<16|y[b+11|0]<<24);v[c+8|0]=b;v[c+9|0]=b>>>8;v[c+10|0]=b>>>16;v[c+11|0]=b>>>24;v[c+12|0]=d;v[c+13|0]=d>>>8;v[c+14|0]=d>>>16;v[c+15|0]=d>>>24;ib=g+32|0;f=f+1|0;continue}break}}function aha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0;g=ib-16|0;ib=g;f=x[a+48>>2];j=x[a+40>>2];k=x[a+36>>2];e=x[a+44>>2];l=x[a+16>>2];b=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=b;m=x[a+32>>2];n=x[a+28>>2];o=x[a+72>>2];b=x[a+68>>2];p=b;q=b>>31;b=x[a+64>>2];r=b;s=b>>31;b=x[a+60>>2];t=b;u=b>>31;w=x[a+8>>2];y=x[a+12>>2];while(1){b=e;if(d){e=Vb(b,-16777216,16776704);e=qoa(r,s,e,e>>31);i=kb;f=Vb(f,-16777216,16776704);h=qoa(p,q,f,f>>31);e=h+e|0;f=kb+i|0;f=e>>>0<h>>>0?f+1|0:f;i=e;h=x[g+12>>2]+l|0;e=v[h|0];z=i;i=((D(v[h+1|0]-e|0,x[g+8>>2]>>>10&4194048)|0)/16384|0)+(e<<8)<<8;e=i;h=qoa(e,e>>31,t,u);e=z+h|0;f=kb+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Vc(e,f,24);e=(f|0)/256|0;k=k+n|0;x[c>>2]=D(e,k>>12)+x[c>>2];j=j+m|0;x[c+4>>2]=x[c+4>>2]+D(j>>12,e);Pb(g+8|0,w,y);e=f-(i&o)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+40>>2]=j;x[a+20>>2]=k>>12;x[a+36>>2]=k;x[a+48>>2]=f;x[a+44>>2]=b;x[a+24>>2]=j>>12;ib=g+16|0}function $la(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=ib-48|0;ib=d;i=a+484344|0;j=a+480280|0;k=a+906300|0;while(1){a:{if(Ob(x[b>>2],x[b+8>>2],9)){e=d+44|0;so(b,e);c=Jg(b);b:{if(!Qb(e,13995,4)){break b}if(!Qb(d+44|0,13647,4)){break b}if(!Qb(d+44|0,13823,4)){break b}if(!Qb(d+44|0,13828,4)){break b}if(Ob(x[b>>2],x[b+8>>2],c)){break a}}Gg(b,8)}ib=d+48|0;return l|0}ae(d,b,c);e=hc(d+24|0,d);yb(d);c=j;c:{d:{e:{if(!Qb(d+44|0,13513,4)){while(1){if((c|0)==(i|0)){break c}x[27524]=0;f=T(161,e|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break e}v[c+8|0]=f;c=c+32|0;continue}}if(y[d+44|0]!=70){break d}f=y[d+45|0];h=(f|0)==88;f:{if(!h){if((f-48&255)>>>0>9){break d}c=v[d+46|0];if((c|0)>47){break f}break d}c=v[d+46|0];if((c|0)<48){break d}}if(c>>>0>57){break d}g=v[d+47|0];if((g|0)<48|(g|0)>57){break d}c=(g+(h?-16:D(f,100)+48|0)|0)+D(c,10)&255;if(c>>>0>249){break c}x[27524]=0;R(443,e|0,Nd(k,c)|0);c=x[27524];x[27524]=0;if((c|0)!=1){break c}}a=P()|0;yb(e);S(a|0);p()}if(Qb(d+44|0,13529,4)){break c}x[a+1074308>>2]=0;l=1}yb(e);continue}}function vda(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=E(0),m=0,n=0,o=E(0);h=w[d>>1];j=w[d+2>>1];a:{if((h|0)>(j|0)){break a}k=x[b>>2];g=tc(k,x[b+4>>2]);if(!g){break a}i=w[e>>1];if((i|0)<(h|0)|(i|0)>(j|0)|(g-1&65535)>>>0>(j-i&65535)>>>0|A[a+36>>2]>65535){break a}b:{while(1){if((f|0)==(g|0)){break b}i=Bb(k,f);f=f+1|0;if(!(B[i>>2]<E(0))){continue}break}return 0}i=(f|0)!=(g|0);f=0;if(i){break a}l=B[c>>2];if(l<=E(0)){break a}w[a+28>>1]=h;w[a>>1]=1;m=a,n=XN(g),w[m+30>>1]=n;B[a+32>>2]=F(l);kk(a+4|0,(j-h|0)+1|0);wh(Cb(x[b>>2]),Cb(x[b+4>>2]),Dm(Cb(x[a+4>>2]),w[e>>1]-w[d>>1]|0));c=x[a+4>>2];g=w[a+30>>1];h=w[a+28>>1];b=w[e>>1];f=b;while(1){if((b&65535)!=32768&(f|0)>(h|0)){f=f-1|0;b=f-h|0;j=Bb(c,b+g|0);m=Bb(c,b),o=E(B[j>>2]/B[a+32>>2]),B[m>>2]=o;b=w[e>>1];continue}else{c=w[a+30>>1];e=w[a+28>>1];h=c+e|0;f=g;g=b<<16>>16;f=f+g|0;b=x[a+4>>2];d=w[d+2>>1];c=(g|0)<=(32767-c|0);while(1){if(c&(d|0)>=(f|0)){g=Bb(b,f-h|0);m=Bb(b,f-e|0),o=E(B[a+32>>2]*B[g>>2]),B[m>>2]=o;f=f+1|0;continue}else{Qp(a)}break}}break}f=1}return f|0}function mQ(a,b){var c=0,d=0,e=0,f=0;d=ib-16|0;ib=d;a:{b:{switch(y[a+480224|0]-1|0){default:c=x[a+24620>>2];x[d+12>>2]=1;x[d+8>>2]=x[b+44>>2]<<1;c=qoa(c,c>>31,5e4,0);e=kb;b=x[Yc(d+12|0,d+8|0)>>2];c=Dc(roa(c,e,b,b>>31),kb);break a;case 0:c=x[a+24620>>2];x[d+12>>2]=1;x[d+8>>2]=x[b+44>>2];c=qoa(c,c>>31,1e4,0);e=kb;b=x[Yc(d+12|0,d+8|0)>>2];c=Dc(roa(c,e,b,b>>31),kb);break a;case 1:break b}}f=60/(+A[b+44>>2]/1e4*(+(qoa(x[b+32>>2],0,x[b+40>>2],0)>>>0)+ +(kb>>>0)*4294967296))*+A[a+24620>>2];c:{d:{c=x[a+484344>>2];e=z[b+70>>1];if(!Ce(c,x[a+484348>>2],e)){break d}c=Xb(c,e);if(!Mb(x[c+24>>2],x[c+28>>2])){break d}c=c+24|0;break c}c=a+480248|0}e=x[c>>2];c=x[c+4>>2];if(!pc(e,c)){f=f*+A[Bb(e,A[b+48>>2]%(tc(e,c)>>>0)|0)>>2]*5.960464477539063e-8}e:{if(F(f)<2147483648){c=~~f;break e}c=-2147483648}f=C[b+8>>3]+(f-+(c>>>0));C[b+8>>3]=f;if(f>=1){C[b+8>>3]=f+-1;c=c+1|0;break a}if(!(C[a+1074384>>3]<=-1)){break a}C[b+8>>3]=f+1;c=c-1|0}b=qoa(x[a+480244>>2],0,c,0)+32768|0;a=kb;a=b>>>0<32768?a+1|0:a;a=Ec((a&65535)<<16|b>>>16,a>>>16|0);ib=d+16|0;return a?a:1}function $ga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0;g=ib-16|0;ib=g;f=x[a+48>>2];j=x[a+40>>2];k=x[a+36>>2];e=x[a+44>>2];l=x[a+16>>2];b=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=b;m=x[a+32>>2];n=x[a+28>>2];o=x[a+72>>2];b=x[a+68>>2];p=b;q=b>>31;b=x[a+64>>2];r=b;s=b>>31;b=x[a+60>>2];t=b;u=b>>31;v=x[a+8>>2];y=x[a+12>>2];while(1){b=e;if(d){e=Vb(b,-16777216,16776704);e=qoa(r,s,e,e>>31);i=kb;f=Vb(f,-16777216,16776704);h=qoa(p,q,f,f>>31);e=h+e|0;f=kb+i|0;f=e>>>0<h>>>0?f+1|0:f;i=e;h=(x[g+12>>2]<<1)+l|0;e=w[h>>1];z=i;i=e+((D(w[h+2>>1]-e|0,x[g+8>>2]>>>18|0)|0)/16384|0)<<8;e=i;h=qoa(e,e>>31,t,u);e=z+h|0;f=kb+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Vc(e,f,24);e=(f|0)/256|0;k=k+n|0;x[c>>2]=D(e,k>>12)+x[c>>2];j=j+m|0;x[c+4>>2]=x[c+4>>2]+D(j>>12,e);Pb(g+8|0,v,y);e=f-(i&o)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+40>>2]=j;x[a+20>>2]=k>>12;x[a+36>>2]=k;x[a+48>>2]=f;x[a+44>>2]=b;x[a+24>>2]=j>>12;ib=g+16|0}function Ez(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=ib-16|0;ib=e;f=a+1074312|0;Ab(e+8|0,f,77);a:{if(j=zb(x[x[e+8>>2]>>2],x[e+12>>2]),k=0,l=x[c+88>>2]&134218752,l?j:k){break a}b:{c:{if(d){g=y[c+841|0];if(!g){break c}d=g-1|0;v[c+841|0]=d;if(d&255){break b}Ab(e+8|0,f,16);if(!zb(x[x[e+8>>2]>>2],x[e+12>>2])&x[a+480180>>2]!=2){break a}a=x[b+48>>2]+1|0}else{a=x[b+48>>2]}x[c+764>>2]=a;break a}Ab(e+8|0,f,17);d:{if(zb(x[x[e+8>>2]>>2],x[e+12>>2])|x[a+480180>>2]&3){break d}g=b+616|0;i=z[a+480188>>1];while(1){if((h&65535)>>>0>=i>>>0){break d}if(y[g+841|0]?(c|0)!=(g|0):0){break a}g=g+872|0;h=h+1|0;continue}}v[c+841|0]=d}d=x[c+764>>2];x[b+56>>2]=d;e:{if((d|0)==-1){break e}f:{if(x[b+60>>2]==-1){break f}Ab(e+8|0,f,68);if(!zb(x[x[e+8>>2]>>2],x[e+12>>2])){break f}x[b+60>>2]=d}x[b+64>>2]=d;Ab(e+8|0,f,103);if(!zb(x[x[e+8>>2]>>2],x[e+12>>2])){break e}w[b+68>>1]=65535}if(x[a+480180>>2]!=2){break a}d=z[a+480188>>1];a=0;while(1){if((a|0)==(d|0)){break a}f=D(a,872)+b|0;x[f+1380>>2]=x[c+764>>2];v[f+1457|0]=y[c+841|0];a=a+1|0;continue}}ib=e+16|0}function KI(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=ib-208|0;ib=d;x[d+8>>2]=1;x[d+12>>2]=0;h=b<<2;a:{if(!h){break a}x[d+16>>2]=4;x[d+20>>2]=4;b=4;f=4;e=2;while(1){g=b;b=(b+f|0)+4|0;x[(d+16|0)+(e<<2)>>2]=b;e=e+1|0;f=g;if(b>>>0<h>>>0){continue}break}f=(a+h|0)-4|0;b:{if(f>>>0<=a>>>0){f=0;e=1;h=0;b=1;g=0;break b}e=1;b=1;while(1){c:{if((e&3)==3){xx(a,c,b,d+16|0);Bs(d+8|0,2);b=b+2|0;break c}g=b-1|0;d:{if(A[(d+16|0)+(g<<2)>>2]>=f-a>>>0){As(a,c,e,x[d+12>>2],b,0,d+16|0);break d}xx(a,c,b,d+16|0)}if((b|0)==1){zs(d+8|0,1);b=0;break c}zs(d+8|0,g);b=1}g=x[d+8>>2];e=g|1;x[d+8>>2]=e;a=a+4|0;if(f>>>0>a>>>0){continue}break}h=g>>>0>1;f=x[d+12>>2];g=(f|0)!=0}As(a,c,e,f,b,0,d+16|0);if(!(g|((b|0)!=1|h))){break a}while(1){e:{if((b|0)<=1){g=DI(e,f);Bs(d+8|0,g);f=x[d+12>>2];e=x[d+8>>2];b=b+g|0;break e}e=d+8|0;zs(e,2);x[d+8>>2]=x[d+8>>2]^7;Bs(e,1);f=a-4|0;h=d+16|0;g=b-2|0;As(f-x[h+(g<<2)>>2]|0,c,x[d+8>>2],x[d+12>>2],b-1|0,1,h);zs(e,1);e=x[d+8>>2]|1;x[d+8>>2]=e;b=f;f=x[d+12>>2];As(b,c,e,f,g,1,h);b=g}a=a-4|0;if((b|0)!=1|(e|0)!=1|f){continue}break}}ib=d+208|0}function x1(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;a=ib-160|0;ib=a;x[a+144>>2]=c;x[a+152>>2]=b;x[a+20>>2]=1186;b=xe(a+24|0,a+32|0,a+20|0);h=a+16|0;ed(h,e);x[27524]=0;h=T(19,h|0)|0;i=x[27524];x[27524]=0;if((i|0)!=1){a:{v[a+15|0]=0;e=x[e+4>>2];x[27524]=0;c=qa(1187,a+152|0,c|0,d|0,a+16|0,e|0,f|0,a+15|0,h|0,b|0,a+20|0,a+132|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break a}b:{c:{if(!c){break c}Vf(g);if(y[a+15|0]){x[27524]=0;c=Q(20,h|0,45)|0;d=x[27524];x[27524]=0;if((d|0)==1){break a}x[27524]=0;R(47,g|0,c|0);c=x[27524];x[27524]=0;if((c|0)==1){break a}}x[27524]=0;d=Q(20,h|0,48)|0;c=x[27524];x[27524]=0;if((c|0)==1){break b}e=x[a+20>>2];h=e-1|0;c=x[b>>2];d=d&255;while(1){if(!((d|0)!=y[c|0]|c>>>0>=h>>>0)){c=c+1|0;continue}break}x[27524]=0;W(1193,g|0,c|0,e|0)|0;c=x[27524];x[27524]=0;if((c|0)!=1){break c}break a}x[27524]=0;c=Q(1154,a+152|0,a+144|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break a}if(c){x[f>>2]=x[f>>2]|2}c=x[a+152>>2];_b(a+16|0);Uc(b);ib=a+160|0;return c|0}}}c=P()|0;_b(a+16|0);Uc(b);S(c|0);p()}function sca(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=E(0),h=0,i=0;c=ib-32|0;ib=c;a:{d=x[a+20>>2];b:{if(!d){break b}x[d+148>>2]=-1;h=c,i=lb[x[x[a>>2]+40>>2]](a)|0,x[h+16>>2]=i;x[c+8>>2]=1073741822;f=x[Hb(c+16|0,c+8|0)>>2];b=f<<2;if(!b){break b}e=x[a+20>>2];d=0;x[27524]=0;R(289,e+4|0,b+4|0);b=x[27524];x[27524]=0;c:{d:{if((b|0)!=1){b=x[a+20>>2];he(c+8|0,x[b+4>>2],x[b+8>>2]);x[c>>2]=0;x[c+4>>2]=0;e=x[c+12>>2];b=c+16|0;x[b>>2]=x[c+8>>2];x[b+4>>2]=e;e=x[c+4>>2];x[b+8>>2]=x[c>>2];x[b+12>>2]=e;e=ib-16|0;ib=e;x[e+8>>2]=0;uN(b,e+8|0);ib=e+16|0;b=x[x[a>>2]+184>>2];x[27524]=0;R(b|0,a|0,-1);b=x[27524];x[27524]=0;if((b|0)==1){break d}while(1){if((d|0)==(f|0)){d=x[x[a>>2]+188>>2];x[27524]=0;Y(d|0,a|0);d=x[27524];x[27524]=0;if((d|0)!=1){break b}break d}b=x[x[a>>2]+48>>2];x[27524]=0;g=E(Za(b|0,a|0,d|0));b=x[27524];x[27524]=0;if((b|0)!=1){B[c+8>>2]=g;d=d+1|0;uN(c+16|0,c+8|0);continue}break}d=V(108196)|0;break c}d=V(108196)|0;break c}d=V(108196)|0}if((jb|0)!=(da(108196)|0)){break a}_(d|0)|0;Ic(x[a+20>>2]+4|0);$()}ib=c+32|0;return}S(d|0);p()}function io(a,b,c,d){var e=0;e=ib-16|0;ib=e;v[a+841|0]=0;x[a+708>>2]=0;v[a+797|0]=0;x[a+764>>2]=0;x[a+800>>2]=0;x[a+696>>2]=0;x[a+668>>2]=0;w[a+804>>1]=0;x[a+88>>2]=x[a+88>>2]|6144;Ab(e+8|0,b+1074312|0,23);if(zb(x[x[e+8>>2]>>2],x[e+12>>2])){v[a+807|0]=1;v[a+808|0]=0}v[a+846|0]=0;v[a+839|0]=0;w[a+774>>1]=0;v[a+850|0]=255;x[a+660>>2]=0;v[a+851|0]=y[a+851|0]&224;mo(a+788|0);x[a+84>>2]=0;x[a+76>>2]=0;x[a+80>>2]=0;x[a+700>>2]=0;x[a+656>>2]=0;x[a+104>>2]=0;x[a+92>>2]=0;x[a+96>>2]=0;x[a>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;v[a+845|0]=0;v[a+838|0]=0;v[a+821|0]=0;x[a+688>>2]=0;x[a+672>>2]=0;x[a+676>>2]=0;w[a+836>>1]=32512;v[a+819|0]=0;v[a+820|0]=0;w[a+842>>1]=0;x[a+28>>2]=0;x[a+32>>2]=0;x[a+20>>2]=0;x[a+24>>2]=0;x[a+852>>2]=0;x[a+856>>2]=0;v[a+851|0]=y[a+851|0]&159;a:{if(c>>>0<=126){b=(c<<5)+b|0;c=x[b+480280>>2];x[a+88>>2]=c;x[a+692>>2]=z[b+480284>>1];x[a+748>>2]=z[b+480286>>1];if(!(c&1024)){break a}x[a+88>>2]=c&-1025|d;break a}x[a+748>>2]=64;x[a+692>>2]=128;x[a+88>>2]=0}w[a+784>>1]=0;v[a+795|0]=0;v[a+796|0]=0;ib=e+16|0}function pha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0;g=ib-16|0;ib=g;o=x[a+16>>2];l=ag(1,2);b=kb;p=b;Pb(a,l,b);f=x[a+48>>2];i=x[a+40>>2];j=x[a+36>>2];e=x[a+44>>2];b=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=b;q=x[a+32>>2];r=x[a+28>>2];s=x[a+72>>2];b=x[a+68>>2];t=b;u=b>>31;b=x[a+64>>2];v=b;y=b>>31;b=x[a+60>>2];z=b;A=b>>31;B=x[a+8>>2];C=x[a+12>>2];while(1){b=e;if(d){m=w[(x[g+12>>2]<<1)+o>>1]<<8;e=m;e=qoa(e,e>>31,z,A);k=kb;h=e;e=Vb(b,-16777216,16776704);n=qoa(v,y,e,e>>31);h=h+n|0;e=kb+k|0;e=h>>>0<n>>>0?e+1|0:e;f=Vb(f,-16777216,16776704);k=qoa(t,u,f,f>>31);h=k+h|0;f=kb+e|0;f=h>>>0<k>>>0?f+1|0:f;e=h+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Vc(e,f,24);e=(f|0)/256|0;j=j+r|0;x[c>>2]=D(e,j>>12)+x[c>>2];i=i+q|0;x[c+4>>2]=x[c+4>>2]+D(i>>12,e);Pb(g+8|0,B,C);e=f-(s&m)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=f;x[a+44>>2]=b;x[a+24>>2]=i>>12;sg(a,l,p);ib=g+16|0}function qha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0,B=0,C=0;g=ib-16|0;ib=g;o=x[a+16>>2];l=ag(1,2);b=kb;p=b;Pb(a,l,b);f=x[a+48>>2];i=x[a+40>>2];j=x[a+36>>2];e=x[a+44>>2];b=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=b;q=x[a+32>>2];r=x[a+28>>2];s=x[a+72>>2];b=x[a+68>>2];t=b;u=b>>31;b=x[a+64>>2];w=b;y=b>>31;b=x[a+60>>2];z=b;A=b>>31;B=x[a+8>>2];C=x[a+12>>2];while(1){b=e;if(d){m=v[x[g+12>>2]+o|0]<<16;e=m;e=qoa(e,e>>31,z,A);k=kb;h=e;e=Vb(b,-16777216,16776704);n=qoa(w,y,e,e>>31);h=h+n|0;e=kb+k|0;e=h>>>0<n>>>0?e+1|0:e;f=Vb(f,-16777216,16776704);k=qoa(t,u,f,f>>31);h=k+h|0;f=kb+e|0;f=h>>>0<k>>>0?f+1|0:f;e=h+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Vc(e,f,24);e=(f|0)/256|0;j=j+r|0;x[c>>2]=D(e,j>>12)+x[c>>2];i=i+q|0;x[c+4>>2]=x[c+4>>2]+D(i>>12,e);Pb(g+8|0,B,C);e=f-(s&m)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=f;x[a+44>>2]=b;x[a+24>>2]=i>>12;sg(a,l,p);ib=g+16|0}function vT(a){a=a|0;var b=0,c=0,d=0,e=0;c=ib-80|0;ib=c;x[c+72>>2]=0;x[c+76>>2]=0;b=c- -64|0;x[b>>2]=0;x[b+4>>2]=0;x[c+56>>2]=0;x[c+60>>2]=0;x[c+48>>2]=0;x[c+52>>2]=0;nA(a,oA(a),c+48|0);b=qc(c+40|0,14188);pf(De(a,0),x[b>>2],x[b+4>>2]);b=qc(c+32|0,14292);pf(De(a,1),x[b>>2],x[b+4>>2]);b=qc(c+24|0,5499);pf(De(a,3),x[b>>2],x[b+4>>2]);b=qc(c+16|0,15683);pf(De(a,4),x[b>>2],x[b+4>>2]);b=qc(c+8|0,9213);pf(De(a,8),x[b>>2],x[b+4>>2]);e=De(a+288|0,0);b=ib-16|0;ib=b;d=e;e=qc(b+8|0,4935);pf(d,x[e>>2],x[e+4>>2]);ib=b+16|0;e=a+800|0;b=0;a=ib-80|0;ib=a;a:{b:{while(1){if((b|0)==128){break a}x[a+76>>2]=b<<3;c:{d:{if(b>>>0<=15){bv(a+32|0,4087);x[27524]=0;R(291,a+16|0,a+76|0);d=x[27524];x[27524]=0;if((d|0)==1){break c}x[27524]=0;U(292,a+48|0,a+32|0,a+16|0);d=x[27524];x[27524]=0;if((d|0)!=1){d=a+48|0;ye(a- -64|0,d);pf(De(e,b),x[a+64>>2],x[a+68>>2]);wb(d);wb(a+16|0);Zb(a+32|0);break d}b=P()|0;wb(a+16|0);break b}d=qc(a+8|0,21631);pf(De(e,b),x[d>>2],x[a+12>>2])}b=b+1|0;continue}break}b=P()|0}Zb(a+32|0);S(b|0);p()}ib=a+80|0;ib=c+80|0}function Yfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=ib-16|0;ib=e;p=x[a+16>>2];q=qg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);l=x[a+128>>2];a:{if(!l){k=x[a+8>>2];m=x[a+12>>2];f=x[a>>2];b=x[a+4>>2];h=0;break a}b=x[a+12>>2];m=b;k=x[a+8>>2];n=rg(k,b,l);o=kb;h=x[a+76>>2];f=x[a>>2];b=x[a+4>>2];Zf(f,b,rf(k,m,d),kb);h=h>>>0<kb>>>0?d:0}g=a+112|0;i=x[a+40>>2];j=x[a+36>>2];x[e>>2]=f;x[e+4>>2]=b;b:while(1){if(d){d=d-1|0;x[e+8>>2]=f;x[e+12>>2]=0;h=h-1|0;n=h?n:0;o=h?o:0;f=(b<<1)+p|0;b=l;while(1)if((b|0)<=0){Pb(g,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){Sd(g,w[f+(x[e+12>>2]<<1)>>1]/4<<16>>16);Rd(g,b);x[g>>2]=x[g>>2];x[g+4>>2]=0}b=x[a+32>>2];j=x[a+28>>2]+j|0;f=pg(g,q);x[c>>2]=D(j>>12,f)+x[c>>2];i=b+i|0;x[c+4>>2]=x[c+4>>2]+D(f,i>>12);Pb(e,k,m);c=c+8|0;f=x[e>>2];b=x[e+4>>2];continue b}else{Sd(g,w[f+(x[e+12>>2]<<1)>>1]/4<<16>>16);Rd(g,4);Pb(e+8|0,n,o);b=b-1|0;continue}}break}x[a>>2]=f;x[a+4>>2]=b;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+24>>2]=i>>12;ib=e+16|0}function WR(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=E(0),m=0,n=0;i=ib-16|0;ib=i;if(Aj(x[a+656>>2])){e=y[a+797|0];g=Wc(e);f=y[a+799|0];Ab(i+8|0,d+1074312|0,34);d=g?e:f;a:{if(!zb(x[x[i+8>>2]>>2],x[i+12>>2])){break a}e=d&255;if(!e|e>>>0>120){break a}d=y[Jb(x[a+656>>2]+108|0,e-1|0)|0]}l=E(E(x[a+704>>2])*b);e=x[x[a+656>>2]+44>>2];f=((d&255)+c<<16)-3997696>>16;b:{c:{c=x[a+852>>2]+w[a+772>>1]|0;if(c){h=x[e+36>>2];if(h){break c}}b=vm(e,c+f<<16>>16);break b}k=h+1|0;j=yy(c,k);d=zy(c,k);b=E(1);g=w[e+28>>1];c=f+j<<16>>16;d:{if((g|0)>(c|0)){break d}f=x[e+4>>2];if((c|0)>(tc(f,x[e+8>>2])+g<<16)-65536>>16){break d}if(!d){b=B[Bb(f,c-g|0)>>2];break b}e:{f:{g:{switch(z[e>>1]-1|0){case 2:h=x[e+16>>2];if(!tc(h,x[e+20>>2])){break f}b=B[Bb(h,d-1|0)>>2];break e;case 0:break g;default:break f}}j=x[e+16>>2];if(!tc(j,x[e+20>>2])){break f}b=B[Bb(j,(d+D(h,By(c,z[e+30>>1])<<16>>16)|0)-1|0)>>2];break e}b=ze(E(vm(e,(c<<16)+65536>>16)/vm(e,c)),E(E(d|0)/E(k|0)))}b=E(b*B[Bb(f,c-g|0)>>2])}}m=a,n=rk(E(E(l*b)*E(16))),x[m+700>>2]=n}ib=i+16|0}function Pda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=ib-16|0;ib=d;md(c,0);w[d+14>>1]=y[a+36|0]|y[a+37|0]<<8;w[d+12>>1]=32767;g=c,h=(z[Tc(d+14|0,d+12|0)>>1]<<8>>>0)/32767|0,w[g+28>>1]=h;w[d+10>>1]=y[a+38|0]|y[a+39|0]<<8;w[d+8>>1]=32767;g=c,h=(z[Tc(d+10|0,d+8|0)>>1]<<8>>>0)/32767|0,w[g+30>>1]=h;w[c+32>>1]=64;x[c>>2]=y[a+44|0]|y[a+45|0]<<8|(y[a+46|0]<<16|y[a+47|0]<<24);x[c+4>>2]=y[a+48|0]|y[a+49|0]<<8|(y[a+50|0]<<16|y[a+51|0]<<24);x[c+8>>2]=y[a+52|0]|y[a+53|0]<<8|(y[a+54|0]<<16|y[a+55|0]<<24);x[c+24>>2]=y[a+56|0]|y[a+57|0]<<8|(y[a+58|0]<<16|y[a+59|0]<<24);e=y[b+166|0];if(e>>>0<=4){v[c+38|0]=y[e+42746|0]}e=y[b+167|0]|y[b+168|0]<<8;v[c+39|0]=e;f=(y[b+171|0]|y[b+172|0]<<8)>>>4|0;v[c+41|0]=f;b=(y[b+169|0]|y[b+170|0]<<8)>>>2|0;v[c+40|0]=b;if((b|f)&255){v[c+39|0]=e^-1}b=y[a+40|0]|y[a+41|0]<<8;if(b&4){w[c+34>>1]=z[c+34>>1]|1;b=y[a+40|0]|y[a+41|0]<<8}if(b&8){w[c+34>>1]=z[c+34>>1]|2;b=y[a+40|0]|y[a+41|0]<<8}if(b&16){w[c+34>>1]=z[c+34>>1]|4;b=y[a+40|0]|y[a+41|0]<<8}if(b&32){w[c+34>>1]=z[c+34>>1]|32}ib=d+16|0}function vJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;c=ib+-64|0;ib=c;f=x[a>>2];a=x[f>>2];g=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;Qf(c+48|0,c+32|0,g);a=x[f+4>>2];f=x[a+8>>2];g=x[a+4>>2];e=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=e;e=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=e;x[c+8>>2]=x[a+8>>2];e=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=e;a:{b:{c:{d:{e=x[c+4>>2];if(g>>>0<=e>>>0){i=x[c+20>>2];if(g>>>0>i>>>0){break d}if(f>>>0>A[c+8>>2]){break c}j=x[c+28>>2];if(f>>>0>x[c+24>>2]-j>>>0){break b}k=b+12|0;l=x[c+16>>2];m=x[c>>2];e:while(1){if((f|0)==(h|0)){break a}n=D(e,h);o=D(h+j|0,i);a=0;while(1)if((a|0)==(g|0)){h=h+1|0;continue e}else{d=Bb(x[b>>2],a);q=d;d=x[(a+n<<2)+m>>2]+(x[d>>2]>>1)|0;r=d;d=Ks(k)+d&-4096;x[q>>2]=r-d;d=kd(d|2048,12);d=(d|0)>=32767?32767:d;w[(a+o<<1)+l>>1]=(d|0)<=-32768?-32768:d;a=a+1|0;continue}}}aa(7192,8993,33,8706);p()}aa(7157,8993,34,8706);p()}aa(5900,8993,35,8706);p()}aa(5870,8993,36,8706);p()}ib=c- -64|0}function _na(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;h=ib-32|0;ib=h;e=b;b=x[a>>2];b=(Do(e,Cb(b))<<1)+b|0;a:{b:{f=x[a+4>>2];if(f>>>0<A[Db(a)>>2]){if((b|0)!=(f|0)){break b}d=ib-16|0;ib=d;a=ei(d,a,1);Rj(x[a+4>>2],y[c|0]|y[c+1|0]<<8);x[a+4>>2]=x[a+4>>2]+2;ic(a);ib=d+16|0;break a}d=Db(a);d=Uj(h+8|0,Vj(a,Oc(x[a>>2],f)+1|0),b-x[a>>2]>>1,d);x[27524]=0;R(296,d|0,c|0);c=x[27524];x[27524]=0;if((c|0)!=1){c=x[d+4>>2];f=d+4|0;nq(x[a>>2],b,f);g=x[a+4>>2];e=d+8|0;while(1){if((b|0)!=(g|0)){Rj(x[e>>2],y[b|0]|y[b+1|0]<<8);x[e>>2]=x[e>>2]+2;b=b+2|0;continue}break}oc(a,f);oc(a+4|0,e);oc(Db(a),zc(d));x[d>>2]=x[d+4>>2];b=c;Ui(d);break a}a=P()|0;Ui(d);S(a|0);p()}i=ib-16|0;ib=i;j=x[a+4>>2];e=(j-(b+2|0)|0)+b|0;k=ei(i,a,f-e>>1);g=x[k+4>>2];d=e;while(1){if(d>>>0>=f>>>0){ic(k);while(1){if((b|0)!=(e|0)){e=e-2|0;j=LX(j-2|0,e);continue}break}ib=i+16|0}else{Rj(g,y[d|0]|y[d+1|0]<<8);g=g+2|0;x[k+4>>2]=g;d=d+2|0;continue}break}a=((b>>>0<=c>>>0&A[a+4>>2]>c>>>0)<<1)+c|0;c=y[a|0];v[b+1|0]=y[a+1|0];v[b|0]=c}Cb(b);ib=h+32|0}function T9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;x[27524]=0;Y(983,a|0);e=x[27524];x[27524]=0;a:{b:{c:{d:{e:{if((e|0)==1){break e}x[27524]=0;Y(959,b|0);e=x[27524];x[27524]=0;if((e|0)==1){break e}e=0;x[27524]=0;Y(984,c|0);f=x[27524];x[27524]=0;if((f|0)==1){break e}a=Rb(c,0,d);if(!y[b|0]){break b}if(Ei(b,48928)|(d|0)!=8){break d}x[a+4>>2]=985;x[a>>2]=986;break c}_(V(0)|0)|0;x[27524]=0;X(945,12240,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)==1){break a}$();return 0}if(!(Ei(b,48940)|(d|0)!=64)){x[a+60>>2]=987;x[a+56>>2]=988;x[a+52>>2]=989;x[a+48>>2]=990;x[a+44>>2]=991;x[a+40>>2]=992;x[a+36>>2]=993;x[a+32>>2]=994;x[a+28>>2]=995;x[a+24>>2]=996;x[a+20>>2]=997;x[a+16>>2]=998;x[a+12>>2]=999;x[a+8>>2]=1e3;x[a+4>>2]=1001;x[a>>2]=1002;break c}if(!(Ei(b,48952)|(d|0)!=24)){x[a+20>>2]=1003;x[a+16>>2]=1004;x[a+12>>2]=1005;x[a+8>>2]=1006;x[a+4>>2]=1007;x[a>>2]=1008;break c}if(Ei(b,48965)|(d|0)!=4){break b}x[a>>2]=1009}e=1}return e|0}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function BJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;c=ib+-64|0;ib=c;f=x[a>>2];a=x[f>>2];g=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;Qf(c+48|0,c+32|0,g);a=x[f+4>>2];f=x[a+8>>2];g=x[a+4>>2];e=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=e;e=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=e;x[c+8>>2]=x[a+8>>2];e=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=e;a:{b:{c:{d:{e=x[c+4>>2];if(g>>>0<=e>>>0){if(g>>>0>A[c+20>>2]){break d}if(f>>>0>A[c+8>>2]){break c}j=x[c+28>>2];if(f>>>0>x[c+24>>2]-j>>>0){break b}k=b+12|0;l=x[c+16>>2];m=x[c>>2];e:while(1){if((f|0)==(h|0)){break a}n=h+j|0;o=D(e,h);a=0;while(1)if((a|0)==(g|0)){h=h+1|0;continue e}else{d=Bb(x[b>>2],a);i=d;d=x[(a+o<<2)+m>>2]+(x[d>>2]>>1)|0;q=d;d=Ks(k)+d&-4096;x[i>>2]=q-d;i=x[(a<<2)+l>>2]+(n<<1)|0;d=kd(d|2048,12);d=(d|0)>=32767?32767:d;w[i>>1]=(d|0)<=-32768?-32768:d;a=a+1|0;continue}}}aa(7192,8993,33,8706);p()}aa(7157,8993,34,8706);p()}aa(5900,8993,35,8706);p()}aa(5870,8993,36,8706);p()}ib=c- -64|0}function t4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=ib-32|0;ib=f;l=x[d>>2];i=x[d+4>>2];x[f+28>>2]=i;o=b+36|0;d=l;while(1){a:{if(!i){break a}h=0;e=ib-32|0;ib=e;k=b+36|0;g=b+228|0;j=c&-4096;b:{c:{while(1){if((h|0)==16){break c}i=x[Bb(g,h)>>2];m=Cd(k,i);if(!((j|0)==x[m>>2]?y[m+8|0]:0)){h=h+1|0;continue}break}h=g+(h<<2)|0;Mq(g,h,h+4|0);p=Bb(g,0),q=i,x[p>>2]=q;break b}i=x[Bb(g,15)>>2];Mq(g,b+288|0,b+292|0);p=Bb(g,0),q=i,x[p>>2]=q;g=Cd(k,i);x[g>>2]=j;Kx(e+16|0,x[b+24>>2],i);h=x[x[b>>2]+44>>2];k=x[e+20>>2];x[e+8>>2]=x[e+16>>2];x[e+12>>2]=k;lb[h|0](e+24|0,b,j,e+8|0);x[g+4>>2]=x[e+28>>2];v[g+8|0]=1}ib=e+32|0;e=Cd(o,i);g=c-x[e>>2]|0;x[f+8>>2]=4096-g;h=f+8|0;p=f,q=x[Hb(h,f+28|0)>>2],x[p+24>>2]=q;e=x[e+4>>2];j=e-g|0;x[f+20>>2]=e>>>0>=j>>>0?j:0;e=x[Hb(f+24|0,f+20|0)>>2];Kx(h,x[b+24>>2],i);h=x[f+8>>2];Kx(f,x[b+24>>2],i);ji(g+h|0,e+(g+x[f>>2]|0)|0,d);i=x[f+28>>2]-e|0;x[f+28>>2]=i;n=e+n|0;if(e>>>0<A[f+24>>2]){break a}c=c+e|0;d=d+e|0;continue}break}cc(a,l,n);ib=f+32|0}function k_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=ib-32|0;ib=d;f=Nb(a);a=0;a:{b:{c:{d:{e:{while(1){if((nw(b,c,a)|0)==-1){break b}e=nw(b,c,a);x[27524]=0;X(126,d|0,b|0,a|0,e-a|0);e=x[27524];x[27524]=0;if((e|0)!=1){x[27524]=0;R(127,d+16|0,d|0);e=x[27524];x[27524]=0;if((e|0)==1){break e}x[27524]=0;R(128,f|0,d+16|0);e=x[27524];x[27524]=0;if((e|0)==1){break d}xb(d+16|0);xb(d);a=nw(b,c,a)+Ik(x[c+4>>2],y[c+11|0])|0;continue}break}a=P()|0;break a}a=P()|0;break c}a=P()|0;xb(d+16|0)}xb(d);break a}f:{g:{h:{i:{j:{k:{if(pc(x[f>>2],x[f+4>>2])){x[27524]=0;X(126,d+16|0,b|0,a|0,-1);c=x[27524];x[27524]=0;if((c|0)==1){break j}c=Ik(x[d+20>>2],y[d+27|0]);xb(d+16|0);if(!c){break k}}x[27524]=0;X(126,d|0,b|0,a|0,-1);a=x[27524];x[27524]=0;if((a|0)==1){break i}x[27524]=0;R(127,d+16|0,d|0);a=x[27524];x[27524]=0;if((a|0)==1){break h}x[27524]=0;R(128,f|0,d+16|0);a=x[27524];x[27524]=0;if((a|0)==1){break g}xb(d+16|0);xb(d)}ib=d+32|0;return}a=P()|0;break a}a=P()|0;break a}a=P()|0;break f}a=P()|0;xb(d+16|0)}xb(d)}Wl(f);S(a|0);p()}function OI(a,b,c,d,e){var f=E(0),g=0,h=E(0),i=0,j=E(0),k=E(0);if(!(a&3)){c=(c<<2)+b|0;d=c+(d<<2)|0;a=a>>2;while(1){if((a|0)>0){b=d-4|0;h=B[b>>2];j=B[c>>2];k=B[d>>2];B[c>>2]=j+k;g=c-4|0;f=B[g>>2];B[g>>2]=f+B[b>>2];j=E(j-k);f=E(f-h);B[d>>2]=E(j*B[e>>2])-E(B[e+4>>2]*f);B[b>>2]=E(f*B[e>>2])+E(j*B[e+4>>2]);b=d-12|0;j=B[b>>2];g=c-8|0;f=B[g>>2];i=g;g=d-8|0;k=B[g>>2];B[i>>2]=f+k;i=c-12|0;h=B[i>>2];B[i>>2]=h+B[b>>2];f=E(f-k);h=E(h-j);B[g>>2]=E(f*B[e+32>>2])-E(B[e+36>>2]*h);B[b>>2]=E(h*B[e+32>>2])+E(f*B[e+36>>2]);b=d-20|0;j=B[b>>2];g=c-16|0;f=B[g>>2];i=g;g=d-16|0;k=B[g>>2];B[i>>2]=f+k;i=c-20|0;h=B[i>>2];B[i>>2]=h+B[b>>2];f=E(f-k);h=E(h-j);B[g>>2]=E(f*B[e+64>>2])-E(B[e+68>>2]*h);B[b>>2]=E(h*B[e+64>>2])+E(f*B[e+68>>2]);b=d-28|0;j=B[b>>2];g=c-24|0;f=B[g>>2];i=g;g=d-24|0;k=B[g>>2];B[i>>2]=f+k;i=c-28|0;h=B[i>>2];B[i>>2]=h+B[b>>2];f=E(f-k);h=E(h-j);B[g>>2]=E(f*B[e+96>>2])-E(B[e+100>>2]*h);B[b>>2]=E(h*B[e+96>>2])+E(f*B[e+100>>2]);a=a-1|0;d=d-32|0;c=c-32|0;e=e+128|0;continue}break}return}aa(15772,13154,2423,9159);p()}function Dga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=ib-16|0;ib=f;a:{b:{c:{g=x[a+12>>2];i=x[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|(g|0)==-1){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}l=x[a+16>>2];j=x[a+40>>2];k=x[a+36>>2];e=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=e;m=x[a+32>>2];n=x[a+28>>2];while(1){if(d){e=(x[f+12>>2]<<1)+l|0;h=(x[f+8>>2]>>>16&65520)+b|0;e=(((((((D(w[e-4>>1],w[h+2>>1])+D(w[e-6>>1],w[h>>1])|0)+D(w[e-2>>1],w[h+4>>1])|0)+D(w[e>>1],w[h+6>>1])|0)+D(w[e+2>>1],w[h+8>>1])|0)+D(w[e+4>>1],w[h+10>>1])|0)+D(w[e+6>>1],w[h+12>>1])|0)+D(w[e+8>>1],w[h+14>>1])|0)/32768|0;k=k+n|0;x[c>>2]=x[c>>2]+D(e,k>>12);j=j+m|0;x[c+4>>2]=x[c+4>>2]+D(e,j>>12);Pb(f+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;x[a+40>>2]=j;x[a+20>>2]=k>>12;x[a+36>>2]=k;x[a+24>>2]=j>>12;ib=f+16|0}function Pga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0;h=ib-16|0;ib=h;f=x[a+48>>2];l=x[a+24>>2];m=x[a+20>>2];e=x[a+44>>2];n=x[a+16>>2];b=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=b;o=x[a+72>>2];b=x[a+68>>2];p=b;q=b>>31;b=x[a+64>>2];r=b;s=b>>31;b=x[a+60>>2];t=b;u=b>>31;v=x[a+8>>2];y=x[a+12>>2];while(1){b=e;if(d){e=Vb(b,-16777216,16776704);e=qoa(r,s,e,e>>31);i=kb;z=e;e=(x[h+12>>2]<<1)+n|0;g=x[h+8>>2]>>>21&2040;j=(((D(w[e>>1],w[g+39730>>1])+D(w[e-2>>1],w[g+39728>>1])|0)+D(w[e+2>>1],w[g+39732>>1])|0)+D(w[e+4>>1],w[g+39734>>1])|0)/16384<<8;e=j;k=qoa(e,e>>31,t,u);g=z+k|0;e=kb+i|0;e=g>>>0<k>>>0?e+1|0:e;f=Vb(f,-16777216,16776704);i=qoa(p,q,f,f>>31);g=i+g|0;f=kb+e|0;f=g>>>0<i>>>0?f+1|0:f;e=g+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Vc(e,f,24);e=(f|0)/256|0;x[c>>2]=D(e,m)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(e,l);Pb(h+8|0,v,y);e=f-(o&j)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+48>>2]=f;x[a+44>>2]=b;ib=h+16|0}function uma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=ib-16|0;ib=e;d=Mh(b,c);n=e,o=Fb(y[a|0]|y[a+1|0]<<8),w[n+14>>1]=o;w[e+12>>1]=64;Zg(d,z[Tc(e+14|0,e+12|0)>>1]);n=d,o=Fb(y[a+14|0]|y[a+15|0]<<8),v[n+13|0]=o;n=d,o=Fb(y[a+16|0]|y[a+17|0]<<8),v[n+14|0]=o;n=d,o=Fb(y[a+20|0]|y[a+21|0]<<8),v[n+15|0]=o;n=d,o=Fb(y[a+22|0]|y[a+23|0]<<8),v[n+16|0]=o;h=x[d>>2];j=x[d+4>>2];b=y[d+12|0]&-2|pc(h,j)^1;v[d+12|0]=b;b=Fb(y[a+12|0]|y[a+13|0]<<8)>>>3&2|b&-3;v[d+12|0]=b;n=d,o=Fb(y[a+12|0]|y[a+13|0]<<8)>>>3&4|b&251,v[n+12|0]=o;b=4096;a:{b:{switch(c-1|0){case 0:i=-128;b=127;break a;case 1:break b;default:break a}}i=-1616;b=1616}b=b-i|0;l=b;c=b>>>1|0;b=0;while(1){if($d(h,j)>>>0<=b>>>0){ib=e+16|0}else{d=Bb(h,b);w[d>>1]=k;m=d;g=(b<<2)+a|0;f=se((y[g+28|0]|y[g+29|0]<<8)<<16>>16)+i|0;d=f>>31;d=d<<6|f>>>26;f=c+(f<<6)|0;d=f>>>0<c>>>0?d+1|0:d;n=m,o=Ag(Dc(roa(f,d,l,0),kb)),v[n+2|0]=o;n=e,o=Fb(y[g+26|0]|y[g+27|0]<<8),w[n+10>>1]=o;w[e+8>>1]=1;b=b+1|0;k=z[pe(e+10|0,e+8|0)>>1]+k|0;continue}break}}function nA(a,b,c){var d=0,e=0;b=b-a>>5;while(1){if((b|0)>0){d=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);e=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[a|0]=e;v[a+1|0]=e>>>8;v[a+2|0]=e>>>16;v[a+3|0]=e>>>24;v[a+4|0]=d;v[a+5|0]=d>>>8;v[a+6|0]=d>>>16;v[a+7|0]=d>>>24;d=y[c+28|0]|y[c+29|0]<<8|(y[c+30|0]<<16|y[c+31|0]<<24);e=y[c+24|0]|y[c+25|0]<<8|(y[c+26|0]<<16|y[c+27|0]<<24);v[a+24|0]=e;v[a+25|0]=e>>>8;v[a+26|0]=e>>>16;v[a+27|0]=e>>>24;v[a+28|0]=d;v[a+29|0]=d>>>8;v[a+30|0]=d>>>16;v[a+31|0]=d>>>24;d=y[c+20|0]|y[c+21|0]<<8|(y[c+22|0]<<16|y[c+23|0]<<24);e=y[c+16|0]|y[c+17|0]<<8|(y[c+18|0]<<16|y[c+19|0]<<24);v[a+16|0]=e;v[a+17|0]=e>>>8;v[a+18|0]=e>>>16;v[a+19|0]=e>>>24;v[a+20|0]=d;v[a+21|0]=d>>>8;v[a+22|0]=d>>>16;v[a+23|0]=d>>>24;d=y[c+12|0]|y[c+13|0]<<8|(y[c+14|0]<<16|y[c+15|0]<<24);e=y[c+8|0]|y[c+9|0]<<8|(y[c+10|0]<<16|y[c+11|0]<<24);v[a+8|0]=e;v[a+9|0]=e>>>8;v[a+10|0]=e>>>16;v[a+11|0]=e>>>24;v[a+12|0]=d;v[a+13|0]=d>>>8;v[a+14|0]=d>>>16;v[a+15|0]=d>>>24;b=b-1|0;a=a+32|0;continue}break}}function Ega(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=ib-16|0;ib=f;a:{b:{c:{g=x[a+12>>2];i=x[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|(g|0)==-1){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}l=x[a+16>>2];j=x[a+40>>2];k=x[a+36>>2];e=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=e;m=x[a+32>>2];n=x[a+28>>2];while(1){if(d){e=x[f+12>>2]+l|0;h=(x[f+8>>2]>>>16&65520)+b|0;e=(((((((D(v[e-2|0],w[h+2>>1])+D(v[e-3|0],w[h>>1])|0)+D(v[e-1|0],w[h+4>>1])|0)+D(v[e|0],w[h+6>>1])|0)+D(v[e+1|0],w[h+8>>1])|0)+D(v[e+2|0],w[h+10>>1])|0)+D(v[e+3|0],w[h+12>>1])|0)+D(v[e+4|0],w[h+14>>1])<<8)/32768|0;k=k+n|0;x[c>>2]=x[c>>2]+D(e,k>>12);j=j+m|0;x[c+4>>2]=x[c+4>>2]+D(e,j>>12);Pb(f+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;x[a+40>>2]=j;x[a+20>>2]=k>>12;x[a+36>>2]=k;x[a+24>>2]=j>>12;ib=f+16|0}function zz(a,b,c,d,e){var f=0,g=0,h=0,i=0;g=ib-16|0;ib=g;h=D(c,872)+b|0;a:{if(d){Ab(g+8|0,a+1074312|0,90);if(!zb(x[x[g+8>>2]>>2],x[g+12>>2])){v[(D(c,872)+b|0)+1427|0]=d}v[(D(c,872)+b|0)+1428|0]=d;break a}d=y[h+1428|0]}f=x[a+480180>>2];if(!e){i=wt(f)}h=h+616|0;b:{c:{if((f|0)!=268435456){if((f|0)!=16777216){break c}f=x[(D(c,872)+b|0)+1272>>2];if(!f|!x[f+44>>2]){break c}a=d&255;if(!(a>>>0<240|e)){MP(b,c,240-a|0);break b}if(!(a>>>0<224|e)){LP(h,224-a|0);break b}KP(h,0-a|0);break b}x[(D(c,872)+b|0)+1324>>2]=65535}e=d&255;d:{if(!(e>>>0>223&i)){break d}e:{f=e&15;if(!f){break e}d=d&240;if((d|0)!=224){if((d|0)!=240){break e}wz(a,h,f);break b}if(x[a+480180>>2]==524288){break d}vz(a,h,f);break b}if(x[a+480180>>2]!=524288){break b}}f:{if(!(v[(D(c,872)+b|0)+1467|0]&1)){break f}if(x[a+1074416>>2]==1){Ab(g+8|0,a+1074312|0,6);if(zb(x[x[g+8>>2]>>2],x[g+12>>2])){break f}}d=x[a+480180>>2];if(d&32832){break f}if(!(x[a+480208>>2]&2)|(d|0)!=8){break b}}mk(a,h,(D(c,872)+b|0)+1316|0,0-(e<<2)|0,0)}ib=g+16|0}function Qga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0;g=ib-16|0;ib=g;f=x[a+48>>2];j=x[a+24>>2];k=x[a+20>>2];e=x[a+44>>2];l=x[a+16>>2];b=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=b;m=x[a+72>>2];b=x[a+68>>2];n=b;o=b>>31;b=x[a+64>>2];p=b;q=b>>31;b=x[a+60>>2];r=b;s=b>>31;t=x[a+8>>2];u=x[a+12>>2];while(1){b=e;if(d){e=Vb(b,-16777216,16776704);e=qoa(p,q,e,e>>31);h=kb;f=Vb(f,-16777216,16776704);i=qoa(n,o,f,f>>31);e=i+e|0;f=kb+h|0;f=e>>>0<i>>>0?f+1|0:f;y=e;e=x[g+12>>2]+l|0;h=x[g+8>>2]>>>21&2040;h=(((D(v[e|0],w[h+39730>>1])+D(v[e-1|0],w[h+39728>>1])|0)+D(v[e+1|0],w[h+39732>>1])|0)+D(v[e+2|0],w[h+39734>>1])<<8)/16384<<8;e=h;i=qoa(e,e>>31,r,s);e=y+i|0;f=kb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Vc(e,f,24);e=(f|0)/256|0;x[c>>2]=D(e,k)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(e,j);Pb(g+8|0,t,u);e=f-(h&m)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+48>>2]=f;x[a+44>>2]=b;ib=g+16|0}function GB(a,b,c){var d=0,e=0,f=0,g=0;d=ib-16|0;ib=d;v[d+15|0]=c;e=a;a:{b:{c:{switch(b-14|0){case 0:b=14;if(!c){break b}d:{if((c|0)!=15){if((c|0)!=240){break d}v[d+15|0]=239;break b}v[d+15|0]=254;break b}if(c>>>0>=16){v[d+15|0]=c|15;break b}v[d+15|0]=c|240;break b;case 1:v[d+15|0]=c^128;b=15;break b;case 6:case 7:if(c>>>0>=16){v[d+15|0]=c>>>4|240;break b}v[d+15|0]=c|224;break b;case 8:v[d+15|0]=((c^-1)&254)>>>1;b=22;break b;case 9:v[d+15|0]=c&15|128;b=23;break b;case 17:f=d,g=Ag(c<<1),v[f+15|0]=g;b=31;break b;case 19:a=32;b=33;e:{f:{switch(c>>>4|0){default:b=0;break b;case 8:a=64;break e;case 10:a=176;break e;case 11:a=224;break e;case 12:case 13:b=c?33:0;break b;case 14:g:{switch(c&15){case 0:v[d+15|0]=119;break b;case 1:v[d+15|0]=119;break b;case 2:v[d+15|0]=121;break b;case 3:break g;default:break b}}v[d+15|0]=123;break b;case 3:break e;case 5:break f;case 0:break b}}a=48}v[d+15|0]=c&15|a;break b;default:break c}}a=0;if(b>>>0>35){break a}}a=y[b+26624|0]}fe(e,a,d+15|0);ib=d+16|0}function QH(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;q=a;i=ib-1040|0;ib=i;r=x[12e4];a:{b:{a=i+16|0;l=z[((b>>>0<=149?b:0)<<1)+107088>>1]+105264|0;c=x[x[120026]+20>>2];if(c){j=x[c+4>>2];c=x[c>>2];e=x[c>>2]+1794895138|0;h=gm(x[c+8>>2],e);f=gm(x[c+12>>2],e);d=gm(x[c+16>>2],e);c:{if(j>>>2>>>0<=h>>>0){break c}k=j-(h<<2)|0;if((d|f)&3|(k>>>0<=f>>>0|d>>>0>=k>>>0)){break c}s=d>>>2|0;t=f>>>2|0;f=0;while(1){k=h>>>1|0;m=k+f|0;n=m<<1;d=c+(n+t<<2)|0;o=gm(x[d>>2],e);d=gm(x[d+4>>2],e);if(d>>>0>=j>>>0|j-d>>>0<=o>>>0|y[c+(d+o|0)|0]){break c}d=Ei(l,c+d|0);if(!d){f=c+(s+n<<2)|0;h=gm(x[f>>2],e);e=gm(x[f+4>>2],e);if(e>>>0>=j>>>0|h>>>0>=j-e>>>0){break c}g=y[c+(e+h|0)|0]?0:c+e|0;break c}if((h|0)==1){break c}d=(d|0)<0;h=d?k:h-k|0;f=d?f:m;continue}}}g=g?g:l;c=xf(g);d:{if(c>>>0>=1024){rc(a,g,1023);v[a+1023|0]=0;g=68;break d}rc(a,g,c+1|0);g=0}if(g){if((g|0)!=28){break b}a=21631}break a}xa();p()}if(!y[a|0]){x[i>>2]=b;a=i+16|0;ax(a,1024,12971,i)}x[12e4]=r;Kc(q,a);ib=i+1040|0}function boa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=ib-144|0;ib=f;x[27524]=0;l=T(275,a|0)|0;e=x[27524];x[27524]=0;if((e|0)!=1){m=c+480192|0;while(1){a:{if((j&65535)>>>0>=l>>>0){yb(a);ib=f+144|0;return}x[27524]=0;R(294,a|0,f+8|0);e=x[27524];x[27524]=0;if((e|0)!=1){b:{e=Fb(z[f+8>>1]);if(!e|e>>>0>z[m>>1]){break b}e=x[((e<<2)+c|0)+900380>>2];if(!e){break b}e=Mh(e,b);g=y[f+11|0];c:{if(!g){break c}h=y[f+10|0];if(h&1){v[e+12|0]=y[e+12|0]|1}if(h&2){v[e+12|0]=y[e+12|0]|4}if(!(h&4)){break c}v[e+12|0]=y[e+12|0]|2}v[f+4|0]=g;v[f+7|0]=31;h=y[Ub(f+4|0,f+7|0)|0];x[27524]=0;h=h+1&255;R(295,e|0,h|0);g=x[27524];x[27524]=0;if((g|0)==1){break a}v[e+13|0]=y[f+13|0];v[e+14|0]=y[f+14|0];g=y[f+12|0];v[e+15|0]=g;v[e+16|0]=g;g=x[e>>2];e=0;while(1){if((e|0)==(h|0)){break b}i=(f+8|0)+(e<<2)|0;n=Fb(z[i+8>>1]);k=Bb(g,e);w[k>>1]=n;i=Fb(z[i+10>>1]);w[f+4>>1]=d?i+128>>>2|0:i;Mf(f+4|0,64);v[k+2|0]=y[f+4|0];e=e+1|0;continue}}j=j+1|0;continue}}break}}b=P()|0;yb(a);S(b|0);p()}function Zfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=ib-16|0;ib=e;p=x[a+16>>2];q=qg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);l=x[a+128>>2];a:{if(!l){k=x[a+8>>2];m=x[a+12>>2];f=x[a>>2];b=x[a+4>>2];h=0;break a}b=x[a+12>>2];m=b;k=x[a+8>>2];n=rg(k,b,l);o=kb;h=x[a+76>>2];f=x[a>>2];b=x[a+4>>2];Zf(f,b,rf(k,m,d),kb);h=h>>>0<kb>>>0?d:0}g=a+112|0;i=x[a+40>>2];j=x[a+36>>2];x[e>>2]=f;x[e+4>>2]=b;b:while(1){if(d){d=d-1|0;x[e+8>>2]=f;x[e+12>>2]=0;h=h-1|0;n=h?n:0;o=h?o:0;f=b+p|0;b=l;while(1)if((b|0)<=0){Pb(g,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){Sd(g,v[f+x[e+12>>2]|0]<<6);Rd(g,b);x[g>>2]=x[g>>2];x[g+4>>2]=0}b=x[a+32>>2];j=x[a+28>>2]+j|0;f=pg(g,q);x[c>>2]=D(j>>12,f)+x[c>>2];i=b+i|0;x[c+4>>2]=x[c+4>>2]+D(f,i>>12);Pb(e,k,m);c=c+8|0;f=x[e>>2];b=x[e+4>>2];continue b}else{Sd(g,v[f+x[e+12>>2]|0]<<6);Rd(g,4);Pb(e+8|0,n,o);b=b-1|0;continue}}break}x[a>>2]=f;x[a+4>>2]=b;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+24>>2]=i>>12;ib=e+16|0}function fk(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0;i=ib-32|0;ib=i;x[i+16>>2]=c;x[i+24>>2]=b;b=i+8|0;ed(b,d);c=0;x[27524]=0;j=T(19,b|0)|0;b=x[27524];x[27524]=0;if((b|0)!=1){_b(i+8|0);x[e>>2]=0;a:{while(1){if((g|0)==(h|0)|c){break a}b:{if(jj(i+24|0,i+16|0)){break b}c:{if((An(j,v[g|0])|0)==37){c=g+1|0;if((h|0)==(c|0)){break b}d:{e:{b=An(j,v[c|0]);if((b|0)==69){break e}k=0;if((b&255)==48){break e}c=g;break d}if((g+2|0)==(h|0)){break b}k=b;b=An(j,v[g+2|0])}l=i,m=lb[x[x[a>>2]+36>>2]](a,x[i+24>>2],x[i+16>>2],d,e,f,b,k)|0,x[l+24>>2]=m;g=c+2|0;break c}b=x[j+8>>2];if(Bh(b,1,v[g|0])){while(1){f:{g=g+1|0;if((h|0)==(g|0)){g=h;break f}if(Bh(b,1,v[g|0])){continue}}break}while(1){if(!yp(i+24|0,i+16|0)){break c}b=bl(x[i+24>>2]);if(!Bh(x[j+8>>2],1,b)){break c}im(i+24|0);continue}}if((Xw(j,bl(x[i+24>>2]))|0)==(Xw(j,v[g|0])|0)){g=g+1|0;im(i+24|0);break c}x[e>>2]=4}c=x[e>>2];continue}break}x[e>>2]=4}if(jj(i+24|0,i+16|0)){x[e>>2]=x[e>>2]|2}ib=i+32|0;return x[i+24>>2]}a=P()|0;_b(i+8|0);S(a|0);p()}function mw(a,b,c,d){var e=0,f=0,g=0,h=0;g=ib-32|0;ib=g;e=d&2147483647;h=e;f=e-1006698496|0;e=e-1140785152|0;a:{if((f|0)==(e|0)&0|e>>>0>f>>>0){e=d<<4|c>>>28;f=c<<4|b>>>28;c=e;b=b&268435455;if((b|0)==134217728&(a|0)!=0|b>>>0>134217728){e=c+1073741824|0;a=f+1|0;e=a?e:e+1|0;f=a;break a}e=c+1073741824|0;if(a|(b|0)!=134217728){break a}b=f&1;a=b+f|0;e=a>>>0<b>>>0?e+1|0:e;f=a;break a}if(!(!c&(h|0)==2147418112?!(a|b):h>>>0<2147418112)){e=c;c=d<<4|e>>>28;f=e<<4|b>>>28;e=c&524287|2146959360;break a}f=0;e=2146435072;if(h>>>0>1140785151){break a}e=0;h=h>>>16|0;if(h>>>0<15249){break a}e=d&65535|65536;Sf(g+16|0,a,b,c,e,h-15233|0);xm(g,a,b,c,e,15361-h|0);e=x[g+4>>2];h=e;a=x[g+8>>2];c=x[g+12>>2]<<4|a>>>28;f=a<<4|e>>>28;e=c;a=h&268435455;b=x[g>>2]|(x[g+16>>2]|x[g+24>>2]|(x[g+20>>2]|x[g+28>>2]))!=0;if((a|0)==134217728&(b|0)!=0|a>>>0>134217728){a=f+1|0;e=a?e:e+1|0;f=a;break a}if(b|(a|0)!=134217728){break a}a=f+(f&1)|0;e=a>>>0<f>>>0?e+1|0:e;f=a}ib=g+32|0;l(0,f|0);l(1,d&-2147483648|e);return+n()}function lga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0;e=ib-16|0;ib=e;g=x[a+40>>2];h=x[a+36>>2];i=x[a+16>>2];f=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=f;j=b+24|0;k=x[a+32>>2];l=x[a+28>>2];m=x[a+8>>2];n=x[a+12>>2];while(1){if(d){f=x[e+8>>2];o=((((x[e+12>>2]&2147483647)<<1|f>>>31)&2147483646)<<1)+i|0;b=(((f>>>16|0)+4&131064)<<1)+j|0;p=w[b+14>>1];q=w[b+12>>1];r=w[b+10>>1];s=w[b+8>>1];t=w[b+6>>1];u=w[b+4>>1];v=w[b+2>>1];y=w[b>>1];f=0;while(1){if((f|0)!=2){b=(f<<1)+o|0;x[(f<<2)+e>>2]=(((((D(w[b+8>>1],r)+D(w[b+4>>1],s)|0)+D(w[b+12>>1],q)|0)+D(w[b+16>>1],p)|0)/2|0)+((((D(w[b-8>>1],v)+D(w[b-12>>1],y)|0)+D(w[b-4>>1],u)|0)+D(w[b>>1],t)|0)/2|0)|0)/16384;f=f+1|0;continue}break}h=h+l|0;x[c>>2]=x[c>>2]+D(x[e>>2],h>>12);g=g+k|0;x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],g>>12);Pb(e+8|0,m,n);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;x[a+40>>2]=g;x[a+20>>2]=h>>12;x[a+36>>2]=h;x[a+24>>2]=g>>12;ib=e+16|0}function Az(a,b,c,d,e){var f=0,g=0,h=0,i=0;g=ib-16|0;ib=g;h=D(c,872)+b|0;a:{if(d){Ab(g+8|0,a+1074312|0,90);if(!zb(x[x[g+8>>2]>>2],x[g+12>>2])){v[(D(c,872)+b|0)+1428|0]=d}v[(D(c,872)+b|0)+1427|0]=d;break a}d=y[h+1427|0]}f=x[a+480180>>2];if(!e){i=wt(f)}h=h+616|0;b:{c:{if((f|0)!=268435456){if((f|0)!=16777216){break c}f=x[(D(c,872)+b|0)+1272>>2];if(!f|!x[f+44>>2]){break c}a=d&255;if(!(a>>>0<240|e)){MP(b,c,a-240|0);break b}if(!(a>>>0<224|e)){LP(h,a-224|0);break b}KP(h,a);break b}x[(D(c,872)+b|0)+1324>>2]=1}e=d&255;d:{if(!(e>>>0>223&i)){break d}e:{f=e&15;if(!f){break e}d=d&240;if((d|0)!=224){if((d|0)!=240){break e}xz(a,h,f);break b}if(x[a+480180>>2]==524288){break d}yz(a,h,f);break b}if(x[a+480180>>2]!=524288){break b}}f:{if(!(v[(D(c,872)+b|0)+1467|0]&1)){break f}if(x[a+1074416>>2]==1){Ab(g+8|0,a+1074312|0,6);if(zb(x[x[g+8>>2]>>2],x[g+12>>2])){break f}}d=x[a+480180>>2];if(d&32832){break f}if(!(x[a+480208>>2]&2)|(d|0)!=8){break b}}mk(a,h,(D(c,872)+b|0)+1316|0,e<<2,0)}ib=g+16|0}function ki(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=$i(a)&2047;c=$i(5551115123125783e-32);d=e-c|0;a:{if(d>>>0>=$i(512)-c>>>0){if((d|0)<0){return a+1}o(+a);c=j(1)|0;d=j(0)|0;b:{if($i(1024)>>>0>e>>>0){break b}b=0;if(!d&(c|0)==-1048576){break a}if($i(O)>>>0<=e>>>0){return a+1}if((c|0)>0|(c|0)>=0){return Yr(3105036184601418e216)}if(c>>>0<3230714880){break b}return Yr(12882297539194267e-247)}c=c<<1|d>>>31;e=!(d<<1)&(c|0)==-2129002496|c>>>0<2165964800?e:0}b=C[177];f=b+a;a=a-(f-b);b=a*a;g=b*b*(a*C[182]+C[181]);b=b*(a*C[180]+C[179]);a=a*C[178];o(+f);j(1)|0;i=j(0)|0;d=i<<4&2032;a=g+(b+(a+C[d+1464>>3]));d=d+1472|0;h=x[d>>2];c=x[d+4>>2];d=h;h=0;d=d+h|0;c=(i<<13)+c|0;c=d>>>0<h>>>0?c+1|0:c;if(!e){c:{if(!(i&-2147483648)){l(0,d|0);l(1,c+-1048576|0);b=+n();a=b*a+b;a=a+a;break c}l(0,d|0);l(1,c+1071644672|0);b=+n();f=b*a;a=f+b;if(a<1){$E(WF()*22250738585072014e-324);g=a+1;a=g+(f+(b-a)+(a+(1-g)))+-1;a=a==0?0:a}a=a*22250738585072014e-324}return a}l(0,d|0);l(1,c|0);b=+n();b=b*a+b}return b}function ina(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=ib-16|0;ib=e;md(b,32);g=b,h=ac(y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24)),x[g>>2]=h;f=ac(y[a+10|0]|y[a+11|0]<<8|(y[a+12|0]<<16|y[a+13|0]<<24));x[b+4>>2]=f;g=b,h=ac(y[a+14|0]|y[a+15|0]<<8|(y[a+16|0]<<16|y[a+17|0]<<24))+f|0,x[g+8>>2]=h;if(!(d?0:c)){c=ac(y[a+46|0]|y[a+47|0]<<8|(y[a+48|0]<<16|y[a+49|0]<<24))}x[b+24>>2]=c;c=y[a+8|0]<<28>>24;a:{if((d|0)!=841887798){break a}d=Fb(y[a+42|0]|y[a+43|0]<<8);if(!d|(d|0)==48){break a}c=(c-(d<<7)|0)+6144|0}Cl(b,+(c|0)*.0006510416666666666);v[e+15|0]=y[a+9|0];v[e+14|0]=64;g=b,h=y[Ub(e+15|0,e+14|0)|0]<<2,w[g+30>>1]=h;if(v[a+40|0]&1){w[b+34>>1]=z[b+34>>1]|64;x[b>>2]=x[b>>2]>>>1;x[b+4>>2]=x[b+4>>2]>>>1;x[b+8>>2]=x[b+8>>2]>>>1}b:{if(y[a+41|0]<=8){a=x[b+4>>2];c=x[b+8>>2];break b}w[b+34>>1]=z[b+34>>1]|1;x[b>>2]=x[b>>2]>>>1;a=x[b+4>>2]>>>1|0;x[b+4>>2]=a;c=x[b+8>>2]>>>1|0;x[b+8>>2]=c}c:{if(a+1>>>0<c>>>0){w[b+34>>1]=z[b+34>>1]|2;break c}x[b+4>>2]=0;x[b+8>>2]=0}ib=e+16|0}function _9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;g=ib-16|0;ib=g;e=ib-160|0;ib=e;d=e+24|0;f=d+56|0;c=Xs(f);x[d>>2]=93204;x[c>>2]=93224;x[d+56>>2]=93264;x[d>>2]=93244;h=f;f=d+4|0;On(h,f);x[d>>2]=93204;x[c>>2]=93224;c=Ts(f);x[c>>2]=92688;Kb(c+32|0);x[c+44>>2]=0;x[c+48>>2]=16;c=x[x[d>>2]-12>>2];x[27524]=0;f=ga(62)|0;h=x[27524];x[27524]=0;a:{b:{c:{d:{e:{f:{if((h|0)==1){break f}x[27524]=0;U(63,e+16|0,c+d|0,f|0);c=x[27524];x[27524]=0;if((c|0)==1){break f}_b(e+16|0);c=ib-16|0;ib=c;x[c+8>>2]=17;ib=c+16|0;pm(x[x[d>>2]-12>>2]+d|0,x[c+8>>2]);i=C[b>>3];x[27524]=0;b=_a(64,d|0,+i)|0;c=x[27524];x[27524]=0;if((c|0)==1){break e}x[27524]=0;R(65,e|0,b|0);c=x[27524];x[27524]=0;if((c|0)==1){break d}x[27524]=0;R(61,g|0,e|0);c=x[27524];x[27524]=0;if((c|0)==1){break c}wb(e);Jp(b);ib=e+160|0;break a}a=P()|0;break b}a=P()|0;break b}a=P()|0;break b}a=P()|0;wb(e)}Jp(d);S(a|0);p()}x[27524]=0;R(58,a|0,g|0);a=x[27524];x[27524]=0;if((a|0)!=1){wb(g);ib=g+16|0;return}a=P()|0;wb(g);S(a|0);p()}function ay(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=ib-32|0;ib=d;a:{b:{c:{d:{e:{f:{g:{f=a+36|0;e=x[f>>2];c=x[a+40>>2];h:{if(Mb(e,c)){sc(d+24|0);break h}c=d+8|0;Nn(c,a);x[27524]=0;c=T(1018,c|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break g}x[d+24>>2]=c;nf(d+8|0);c=x[a+40>>2];e=x[a+36>>2]}e=(h=f,i=x[d+24>>2],j=Mb(e,c),j?h:i);if((b|0)==-1){f=x[e>>2];g=4194304;c=0;break e}if((b|0)>=0){c=b;f=x[e>>2];if((Xi(f,x[e+4>>2])|0)>(b|0)){break e}}b=ba(8)|0;x[27524]=0;c=Q(55,d+8|0,10875)|0;a=x[27524];x[27524]=0;if((a|0)==1){break f}lc(b,c);x[27524]=0;U(123,b|0,50060,962);a=x[27524];x[27524]=0;if((a|0)!=1){break b}a=P()|0;wb(c);break d}a=P()|0;nf(d+8|0);break c}a=P()|0;ca(b|0);break d}x[a+8>>2]=b;b=x[a+24>>2];x[b+480208>>2]=x[b+480208>>2]&-4194305|g;Lj(b+484360|0,y[sf(f,c)+16|0]);b=sf(x[e>>2],c);c=x[b+8>>2];b=x[b+12>>2];x[27524]=0;+ra(1049,a|0,b|0,c|0);b=x[27524];x[27524]=0;if((b|0)!=1){break a}a=P()|0}el(d+24|0)}S(a|0)}p()}x[a+16>>2]=0;x[a+20>>2]=0;el(d+24|0);ib=d+32|0}function ela(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=yu(c,d);d=b&63;if(e>>>0>d>>>0){c=lV(c,d);d=0;g=ib-16|0;ib=g;v[a+12|0]=0;Ic(a);e=ib-32|0;ib=e;a:{b:{if(_h(a)>>>0<=14){if(zh(1073741823)>>>0<=14){break b}f=Db(a);f=cg(e+8|0,15,tc(x[a>>2],x[a+4>>2]),f);Dd(a,f);bg(f)}ib=e+32|0;break a}_c();p()}h=0-y[c+1|0]|0;while(1){c:{if((d|0)==15){break c}e=c+(d<<1)|0;f=y[e+1|0];if(!f){break c}v[g+7|0]=64;h=f+(h<<16>>16)|0;f=Bl(g+8|0,h&65535,y[Ub(e+2|0,g+7|0)|0]);d:{if(A[a+4>>2]<A[Db(a)>>2]){gV(a,f);break d}i=ib-32|0;ib=i;e=Db(a);e=cg(i+8|0,wg(a,tc(x[a>>2],x[a+4>>2])+1|0),tc(x[a>>2],x[a+4>>2]),e);Lm(x[e+8>>2],z[f>>1]|z[f+2>>1]<<16);x[e+8>>2]=x[e+8>>2]+4;Dd(a,e);bg(e);ib=i+32|0}d=d+1|0;continue}break}d=y[c+32|0];v[a+14|0]=d>>>4;v[a+13|0]=d&15;c=y[c+31|0];d=c&15;v[a+15|0]=d;v[a+16|0]=d;if(c&16){v[a+12|0]=y[a+12|0]|4}if(c&32){v[a+12|0]=y[a+12|0]|2}ib=g+16|0}e:{if(b<<24>>24>=0){c=y[a+12|0]&-2;a=a+12|0;break e}c=y[a+12|0]&-2|pc(x[a>>2],x[a+4>>2])^1;a=a+12|0}v[a|0]=c}function m5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=ib+-64|0;ib=c;f=x[a>>2];a=x[f>>2];g=x[a+4>>2];x[c+40>>2]=x[a+20>>2];d=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=d;Qf(c+48|0,c+32|0,g);a=x[f+4>>2];f=x[a+8>>2];g=x[a+4>>2];d=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=d;d=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=d;x[c+8>>2]=x[a+8>>2];d=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=d;a:{b:{c:{d:{d=x[c+4>>2];if(g>>>0<=d>>>0){if(g>>>0>A[c+20>>2]){break d}if(f>>>0>A[c+8>>2]){break c}h=x[c+28>>2];if(f>>>0>x[c+24>>2]-h>>>0){break b}i=b+12|0;j=x[c+16>>2];k=x[c>>2];b=0;e:while(1){if((b|0)==(f|0)){break a}l=b+h|0;m=D(b,d);a=0;while(1)if((a|0)==(g|0)){b=b+1|0;continue e}else{e=x[(a+m<<2)+k>>2];n=Js(i);o=x[(a<<2)+j>>2]+(l<<1)|0;e=kd((kd(n,21)+e|0)+2048|0,12);e=(e|0)>=32767?32767:e;w[o>>1]=(e|0)<=-32768?-32768:e;a=a+1|0;continue}}}aa(7192,8993,33,8706);p()}aa(7157,8993,34,8706);p()}aa(5900,8993,35,8706);p()}aa(5870,8993,36,8706);p()}ib=c- -64|0}function Fc(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;a:{c=x[b>>2];e=ib-48|0;ib=e;f=x[b+4>>2];b=y[b+8|0];d=f-(((b|0)==1|(b|0)==4)&(f|0)!=0)|0;f=Kb(a);b:{c:{d:{e:{f:{g:{h:{if((b-1&255)>>>0<=1){v[e+32|0]=0;a=Bi(c,c+d|0,e+32|0);x[27524]=0;W(53,f|0,c|0,a|0)|0;a=x[27524];x[27524]=0;if((a|0)!=1){break h}a=P()|0;break b}if((b-3&255)>>>0>1){break h}x[27524]=0;b=W(53,f|0,c|0,c+d|0)|0;a=x[27524];x[27524]=0;if((a|0)==1){break g}c=ke(b);d=Eh(b);g=ke(b);a=ib-32|0;ib=a;x[a+16>>2]=d;x[a+24>>2]=c;x[a+8>>2]=g;while(1){if(Fi(a+24|0,a+16|0)){c=a+8|0;d=a+24|0;g=v[x[d>>2]];v[x[c>>2]]=g?g:32;Ie(d);Ie(c);continue}break}ib=a+32|0;x[27524]=0;c=Q(54,e+16|0,b|0)|0;a=x[27524];x[27524]=0;if((a|0)==1){break f}x[27524]=0;d=Q(55,e|0,17802)|0;a=x[27524];x[27524]=0;if((a|0)==1){break e}x[27524]=0;U(56,e+32|0,c|0,d|0);a=x[27524];x[27524]=0;if((a|0)==1){break d}a=e+32|0;Ac(b,a);wb(a);wb(d);wb(c)}ib=e+48|0;break a}a=P()|0;break b}a=P()|0;break b}a=P()|0;break c}a=P()|0;wb(d)}wb(c)}wb(f);S(a|0);p()}}function ek(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0;i=ib-32|0;ib=i;x[i+16>>2]=c;x[i+24>>2]=b;c=i+8|0;ed(c,d);b=0;x[27524]=0;j=T(1164,c|0)|0;c=x[27524];x[27524]=0;if((c|0)!=1){_b(i+8|0);x[e>>2]=0;a:{while(1){if((g|0)==(h|0)|b){break a}b:{if(gk(i+24|0,i+16|0)){break b}c:{if((zn(j,x[g>>2])|0)==37){b=g+4|0;if((h|0)==(b|0)){break b}d:{e:{c=zn(j,x[b>>2]);if((c|0)==69){break e}k=0;if((c&255)==48){break e}b=g;break d}if((g+8|0)==(h|0)){break b}k=c;c=zn(j,x[g+8>>2])}l=i,m=lb[x[x[a>>2]+36>>2]](a,x[i+24>>2],x[i+16>>2],d,e,f,c,k)|0,x[l+24>>2]=m;g=b+8|0;break c}if($k(j,1,x[g>>2])){while(1){f:{g=g+4|0;if((h|0)==(g|0)){g=h;break f}if($k(j,1,x[g>>2])){continue}}break}while(1){if(!ss(i+24|0,i+16|0)){break c}if(!$k(j,1,al(x[i+24>>2]))){break c}Gn(i+24|0);continue}}if((Jl(j,al(x[i+24>>2]))|0)==(Jl(j,x[g>>2])|0)){g=g+4|0;Gn(i+24|0);break c}x[e>>2]=4}b=x[e>>2];continue}break}x[e>>2]=4}if(gk(i+24|0,i+16|0)){x[e>>2]=x[e>>2]|2}ib=i+32|0;return x[i+24>>2]}a=P()|0;_b(i+8|0);S(a|0);p()}function Ap(a,b,c,d,e,f){var g=E(0),h=0,i=E(0),j=0,k=E(0),l=E(0);c=(c<<2)+b|0;d=c+(d<<2)|0;a=a>>2;b=f<<2;while(1){if((a|0)>0){f=d-4|0;i=B[f>>2];k=B[c>>2];l=B[d>>2];B[c>>2]=k+l;h=c-4|0;g=B[h>>2];B[h>>2]=g+B[f>>2];k=E(k-l);g=E(g-i);B[d>>2]=E(k*B[e>>2])-E(B[e+4>>2]*g);B[f>>2]=E(g*B[e>>2])+E(k*B[e+4>>2]);f=d-12|0;k=B[f>>2];h=c-8|0;g=B[h>>2];j=h;h=d-8|0;l=B[h>>2];B[j>>2]=g+l;j=c-12|0;i=B[j>>2];B[j>>2]=i+B[f>>2];g=E(g-l);e=b+e|0;i=E(i-k);B[h>>2]=E(g*B[e>>2])-E(B[e+4>>2]*i);B[f>>2]=E(i*B[e>>2])+E(g*B[e+4>>2]);f=d-20|0;k=B[f>>2];h=c-16|0;g=B[h>>2];j=h;h=d-16|0;l=B[h>>2];B[j>>2]=g+l;j=c-20|0;i=B[j>>2];B[j>>2]=i+B[f>>2];g=E(g-l);e=b+e|0;i=E(i-k);B[h>>2]=E(g*B[e>>2])-E(B[e+4>>2]*i);B[f>>2]=E(i*B[e>>2])+E(g*B[e+4>>2]);f=d-28|0;k=B[f>>2];h=c-24|0;g=B[h>>2];j=h;h=d-24|0;l=B[h>>2];B[j>>2]=g+l;j=c-28|0;i=B[j>>2];B[j>>2]=i+B[f>>2];g=E(g-l);e=b+e|0;i=E(i-k);B[h>>2]=E(g*B[e>>2])-E(B[e+4>>2]*i);B[f>>2]=E(i*B[e>>2])+E(g*B[e+4>>2]);e=b+e|0;a=a-1|0;d=d-32|0;c=c-32|0;continue}break}}function ty(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=E(0);c=ib-48|0;ib=c;a:{b=x[a+20>>2];b:{if(!b){break b}d=x[b+4>>2];b=x[b+8>>2];if(cd(d,b)>>>0<4){break b}he(c+16|0,d,b);b=Id(c+8|0);d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;d=ZW(c+24|0,x[c+16>>2],x[c+20>>2],c);x[27524]=0;b=T(161,d|0)|0;f=x[27524];x[27524]=0;c:{if((f|0)!=1){if(b){break c}b=x[x[a>>2]+40>>2];x[27524]=0;f=T(b|0,a|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break a}b=x[a+20>>2];if(cd(x[b+4>>2],x[b+8>>2])-4>>>0<f<<2>>>0){break c}e=x[x[a>>2]+176>>2];b=0;x[27524]=0;R(e|0,a|0,-1);e=x[27524];x[27524]=0;if((e|0)==1){break a}while(1){if((b|0)==(f|0)){b=x[x[a>>2]+180>>2];x[27524]=0;Y(b|0,a|0);a=x[27524];x[27524]=0;if((a|0)!=1){break c}break a}x[27524]=0;g=E(za(465,d|0));e=x[27524];x[27524]=0;d:{if((e|0)==1){break d}e=x[x[a>>2]+44>>2];x[27524]=0;ya(e|0,a|0,b|0,E(um(g)?g:E(0)));e=x[27524];x[27524]=0;if((e|0)==1){break d}b=b+1|0;continue}break}break a}break a}yb(d)}ib=c+48|0;return}a=P()|0;yb(d);S(a|0);p()}function Ana(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=ib-2608|0;ib=f;d=eC(f,a);x[d+1060>>2]=0;x[d+1064>>2]=0;e=d+2604|0;a=d+1068|0;while(1){v[a+4|0]=0;w[a>>1]=0;w[a+2>>1]=0;a=a+6|0;if((e|0)!=(a|0)){continue}break}x[27524]=0;Y(322,d|0);a=x[27524];x[27524]=0;a:{b:{if((a|0)!=1){if((w[d+1068>>1]|w[d+1070>>1])<0){break a}c:{while(1){if((c|0)==(g|0)){break a}x[27524]=0;j=Q(168,d|0,1)|0;a=x[27524];x[27524]=0;if((a|0)==1){break c}a=0;d:{while(1){x[27524]=0;k=Q(168,d|0,1)|0;e=x[27524];x[27524]=0;if((e|0)==1){break d}a=w[(d+D(a,6)|0)+(k?1070:1068)>>1];e:{if((a|0)>255){break e}e=d+D(a,6)|0;h=y[e+1072|0];if(w[e+1068>>1]<0){break e}if(w[e+1070>>1]>=0){continue}}break}h=(j?-1:0)^h;i=(i&255)+(h&255)|0;v[b+g|0]=i;g=g+1|0;continue}break}a=V(30496)|0;break b}a=V(30496)|0;break b}a=V(30496)|0}if((jb|0)==(da(30496)|0)){_(a|0)|0;x[27524]=0;Z(18);a=x[27524];x[27524]=0;if((a|0)!=1){break a}a=P()|0}yb(d);S(a|0);p()}a=Pq(d);yb(d);ib=f+2608|0;return a|0}function mga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0;e=ib-16|0;ib=e;g=x[a+40>>2];h=x[a+36>>2];i=x[a+16>>2];f=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=f;j=b+24|0;k=x[a+32>>2];l=x[a+28>>2];m=x[a+8>>2];n=x[a+12>>2];while(1){if(d){f=x[e+8>>2];o=(((x[e+12>>2]&2147483647)<<1|f>>>31)&-2)+i|0;b=(((f>>>16|0)+4&131064)<<1)+j|0;p=w[b+14>>1];q=w[b+12>>1];r=w[b+10>>1];s=w[b+8>>1];t=w[b+6>>1];u=w[b+4>>1];y=w[b+2>>1];z=w[b>>1];f=0;while(1){if((f|0)!=2){b=f+o|0;x[(f<<2)+e>>2]=(((((D(v[b+4|0],r)+D(v[b+2|0],s)|0)+D(v[b+6|0],q)|0)+D(v[b+8|0],p)<<8)/2|0)+((((D(v[b-4|0],y)+D(v[b-6|0],z)|0)+D(v[b-2|0],u)|0)+D(v[b|0],t)<<8)/2|0)|0)/16384;f=f+1|0;continue}break}h=h+l|0;x[c>>2]=x[c>>2]+D(x[e>>2],h>>12);g=g+k|0;x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],g>>12);Pb(e+8|0,m,n);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;x[a+40>>2]=g;x[a+20>>2]=h>>12;x[a+36>>2]=h;x[a+24>>2]=g>>12;ib=e+16|0}function r2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=ib-32|0;ib=g;x[g+24>>2]=b;a:{b:{if(!(x[d+4>>2]&1)){x[g>>2]=-1;b=lb[x[x[a>>2]+16>>2]](a,b,c,d,e,g)|0;c:{switch(x[g>>2]){case 1:v[f|0]=1;break a;case 0:break b;default:break c}}v[f|0]=1;x[e>>2]=4;break a}ed(g,d);x[27524]=0;b=T(1164,g|0)|0;a=x[27524];x[27524]=0;d:{e:{f:{g:{if((a|0)!=1){_b(g);ed(g,d);x[27524]=0;a=T(1165,g|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break g}_b(g);x[27524]=0;R(1166,g|0,a|0);d=x[27524];x[27524]=0;if((d|0)==1){b=P()|0;break d}x[27524]=0;R(1167,g|12,a|0);a=x[27524];x[27524]=0;if((a|0)==1){break f}x[27524]=0;d=g+24|0;a=va(1168,d|0,c|0,g|0,d|0,b|0,e|0,1)|0;b=x[27524];x[27524]=0;if((b|0)==1){break e}v[f|0]=(a|0)==(g|0);b=x[g+24>>2];while(1){d=Gc(d-12|0);if((g|0)!=(d|0)){continue}break}break a}b=P()|0;_b(g);break d}b=P()|0;_b(g);break d}b=P()|0;Gc(g);break d}b=P()|0;while(1){d=Gc(d-12|0);if((g|0)!=(d|0)){continue}break}}S(b|0);p()}v[f|0]=0}ib=g+32|0;return b|0}function b5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;c=ib+-64|0;ib=c;e=x[a>>2];a=x[e>>2];f=x[a+4>>2];x[c+40>>2]=x[a+20>>2];d=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=d;Qf(c+48|0,c+32|0,f);a=x[e+4>>2];e=x[a+8>>2];f=x[a+4>>2];d=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=d;d=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=d;x[c+8>>2]=x[a+8>>2];d=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=d;a:{b:{c:{d:{d=x[c+4>>2];if(f>>>0<=d>>>0){h=x[c+20>>2];if(f>>>0>h>>>0){break d}if(e>>>0>A[c+8>>2]){break c}i=x[c+28>>2];if(e>>>0>x[c+24>>2]-i>>>0){break b}j=b+12|0;k=x[c+16>>2];l=x[c>>2];b=0;e:while(1){if((b|0)==(e|0)){break a}m=D(b,d);n=D(b+i|0,h);a=0;while(1)if((a|0)==(f|0)){b=b+1|0;continue e}else{g=kd((x[(a+m<<2)+l>>2]+kd(Js(j),21)|0)+2048|0,12);g=(g|0)>=32767?32767:g;w[(a+n<<1)+k>>1]=(g|0)<=-32768?-32768:g;a=a+1|0;continue}}}aa(7192,8993,33,8706);p()}aa(7157,8993,34,8706);p()}aa(5900,8993,35,8706);p()}aa(5870,8993,36,8706);p()}ib=c- -64|0}function C2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=ib-32|0;ib=g;x[g+24>>2]=b;a:{b:{if(!(x[d+4>>2]&1)){x[g>>2]=-1;b=lb[x[x[a>>2]+16>>2]](a,b,c,d,e,g)|0;c:{switch(x[g>>2]){case 1:v[f|0]=1;break a;case 0:break b;default:break c}}v[f|0]=1;x[e>>2]=4;break a}ed(g,d);x[27524]=0;b=T(19,g|0)|0;a=x[27524];x[27524]=0;d:{e:{f:{g:{if((a|0)!=1){_b(g);ed(g,d);x[27524]=0;a=T(1147,g|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break g}_b(g);x[27524]=0;R(1148,g|0,a|0);d=x[27524];x[27524]=0;if((d|0)==1){b=P()|0;break d}x[27524]=0;R(1149,g|12,a|0);a=x[27524];x[27524]=0;if((a|0)==1){break f}x[27524]=0;d=g+24|0;a=va(1150,d|0,c|0,g|0,d|0,b|0,e|0,1)|0;b=x[27524];x[27524]=0;if((b|0)==1){break e}v[f|0]=(a|0)==(g|0);b=x[g+24>>2];while(1){d=wb(d-12|0);if((g|0)!=(d|0)){continue}break}break a}b=P()|0;_b(g);break d}b=P()|0;_b(g);break d}b=P()|0;wb(g);break d}b=P()|0;while(1){d=wb(d-12|0);if((g|0)!=(d|0)){continue}break}}S(b|0);p()}v[f|0]=0}ib=g+32|0;return b|0}function o4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=ib-32|0;ib=h;f=wf(h+16|0,1,0);a:{b:{while(1){j=h+8|0;d=vc(f);m=d;n=Eb(f)+d|0;i=z[b>>1];d=0;c:{if((c|0)==10){Yx(j,m,n,i);break c}e=i;k=D(c,c);l=D(k,c);o=D(k,k);d:{while(1){e=e&65535;g=d|1;if(e>>>0<c>>>0){break d}g=d|2;if(e>>>0<k>>>0){break d}g=d|3;if(e>>>0<l>>>0){break d}if(e>>>0<o>>>0){g=d+4|0}else{d=d+4|0;e=(e>>>0)/(o>>>0)|0;continue}break}}d=g;if((d|0)>(n-m|0)){x[j+4>>2]=61;x[j>>2]=n;break c}l=d+m|0;e=l;while(1){d=i&65535;i=(d|0)/(c|0)|0;e=e-1|0;v[e|0]=y[(d-D(c,i)|0)+4898|0];if(i&65535){continue}break}x[j+4>>2]=0;x[j>>2]=l}if(!x[h+12>>2]){break b}d=Og(Eb(f));x[27524]=0;R(59,f|0,d|0);d=x[27524];x[27524]=0;if((d|0)!=1){continue}break}break a}c=x[h+8>>2];b=vc(f);x[27524]=0;R(60,f|0,c-b|0);b=x[27524];x[27524]=0;e:{if((b|0)!=1){x[27524]=0;R(72,a|0,f|0);a=x[27524];x[27524]=0;if((a|0)!=1){break e}break a}break a}wb(f);ib=h+32|0;return}a=P()|0;wb(f);S(a|0);p()}function uG(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;a=ib-16|0;ib=a;x[a+12>>2]=c;x[a+8>>2]=f;x[a+12>>2]=c;x[a+8>>2]=f;b=x[a+12>>2];a:{while(1){if(b>>>0>=d>>>0){c=0;break a}c=2;b=x[b>>2];if(b>>>0>1114111|(b&-2048)==55296){break a}b:{c:{if(b>>>0<=127){c=1;f=x[a+8>>2];if((g-f|0)<=0){break a}x[a+8>>2]=f+1;v[f|0]=b;break c}if(b>>>0<=2047){c=x[a+8>>2];if((g-c|0)<2){break b}x[a+8>>2]=c+1;v[c|0]=b>>>6|192;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b&63|128;break c}c=x[a+8>>2];f=g-c|0;if(b>>>0<=65535){if((f|0)<3){break b}x[a+8>>2]=c+1;v[c|0]=b>>>12|224;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b>>>6&63|128;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b&63|128;break c}if((f|0)<4){break b}x[a+8>>2]=c+1;v[c|0]=b>>>18|240;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b>>>12&63|128;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b>>>6&63|128;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b&63|128}b=x[a+12>>2]+4|0;x[a+12>>2]=b;continue}break}c=1}x[e>>2]=x[a+12>>2];x[h>>2]=x[a+8>>2];ib=a+16|0;return c|0}function Gy(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=ib-16|0;ib=d;f=y[a+2|0];if(!(!f|(f|0)==255)){x[d+12>>2]=f+1;x[d+8>>2]=10;Zg(b,x[rd(d+12|0,d+8|0)>>2]);i=y[a+3|0];v[b+15|0]=i;v[b+16|0]=i;j=y[a+4|0];v[b+13|0]=j;l=y[a+5|0];v[b+14|0]=l;f=511;a:{b:{switch(c-1|0){case 1:e=4096;f=128;break a;case 0:break b;default:break a}}e=32768;f=1024}o=f>>>1|e;c=x[b>>2];k=$d(c,x[b+4>>2]);e=0;c:{while(1){if((e|0)==(k|0)){d:{c=y[b+12|0]&-2|v[a|0]&1;v[b+12|0]=c;if(y[a|0]&2){break d}c=c&251;break c}}else{m=Bb(c,e);h=(e<<2)+a|0;g=(y[h+6|0]|y[h+7|0]<<8)>>>4|0;w[m>>1]=g;e:{if(e){n=z[Bb(c,e-1|0)>>1];if(g>>>0>=n>>>0){break e}g=n+1|0}else{g=0}p=Bb(c,e),q=g,w[p>>1]=q}x[d+12>>2]=(((y[h+8|0]|y[h+9|0]<<8)<<16>>16)+o|0)/(f|0);x[d+8>>2]=0;x[d+4>>2]=64;p=m,q=x[Oj(d+12|0,d+8|0,d+4|0)>>2],v[p+2|0]=q;e=e+1|0;continue}break}c=c&-5|(k>>>0>=i>>>0)<<2}v[b+12|0]=c;if(j>>>0<=l>>>0?y[a|0]&4:0){a=c&-3|(k>>>0>=j>>>0)<<1}else{a=c&253}v[b+12|0]=a}ib=d+16|0}function Xf(a,b,c){v[a+5|0]=c;a:{b:{switch(b|0){case 0:if(!c){break a}v[a+3|0]=1;return;case 1:v[a+3|0]=2;return;case 2:v[a+3|0]=3;return;case 3:v[a+3|0]=4;return;case 4:v[a+3|0]=5;return;case 5:v[a+3|0]=6;return;case 6:v[a+3|0]=7;return;case 7:v[a+3|0]=8;return;case 8:v[a+3|0]=9;return;case 9:v[a+3|0]=10;return;case 10:v[a+3|0]=11;return;case 11:v[a+3|0]=12;return;case 12:v[a+3|0]=13;return;case 13:v[a+3|0]=14;v[a+5|0]=D(c>>>4|0,10)+(c&15);return;case 14:v[a+3|0]=19;return;case 15:if(c>>>0<=31){v[a+3|0]=16;return}v[a+3|0]=17;return;case 16:v[a+3|0]=23;return;case 17:v[a+3|0]=24;return;case 20:v[a+3|0]=25;return;case 21:v[a+3|0]=30;return;case 25:v[a+3|0]=29;return;case 27:v[a+3|0]=15;return;case 29:v[a+3|0]=18;return;case 32:v[a+3|0]=37;return;case 33:v[a+3|0]=28;return;case 34:v[a+3|0]=27;return;case 35:v[a+3|0]=31;return;case 36:v[a+3|0]=32;return;case 37:v[a+3|0]=32;return;case 38:v[a+3|0]=34;return;default:break b}}v[a+3|0]=0}}function qka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=ib-48|0;ib=f;w[a>>1]=0;w[a+2>>1]=0;w[a+4>>1]=0;c=f+44|0;so(b,c);a:{if(!bS(c)){break a}d=y[f+46|0];g=y[f+47|0];e=y[f+45|0];v[a+4|0]=1;h=e>>>3&3;c=(h|0)!=3;e=(e^-1)>>>1&3;g=g>>>0<192;w[a+2>>1]=z[(D(c,6)+(e<<1)|0)+27384>>1]<<g;i=D(D(y[(e+D(c,3)|0)+27160|0],z[((D(c,90)+D(e,30)|0)+(d>>>3&30)|0)+27168>>1]),1e3);d=d>>>1|0;d=D(((i>>>0)/z[(D(h,6)+(d&6)|0)+27360>>1]|0)+(d&1)|0,e?1:4);w[a>>1]=d;e=y[(g|c<<1)+27396|0];if(e+8>>>0>(d&65535)>>>0){break a}c=ib-32|0;ib=c;x[c+28>>2]=e+4;x[c+8>>2]=36;g=x[b>>2];h=x[b+8>>2];d=x[Hb(c+28|0,c+8|0)>>2];if(!Ob(g,h,d)){d=jf(b)}h=c+8|0;pr(h,f);g=dc(c+16|0,x[c+8>>2],d);kc(c,x[b>>2],x[b+8>>2],x[g>>2],x[g+4>>2]);pr(h,f);Rb(x[c+8>>2]+d|0,0,36-d|0);Yb(b,x[c+28>>2]);ib=c+32|0;b=2;c=e>>>0<=2?2:e;while(1){if((b|0)!=(c|0)){d=b+f|0;b=b+1|0;if(!y[d|0]){continue}break a}break}b=e+f|0;if(Qb(b,9514,4)){b=Qb(b,11036,4)}else{b=0}v[a+5|0]=!b}ib=f+48|0;return a|0}function YZ(a){a=a|0;var b=0,c=0,d=0,e=0;b=ib+-64|0;ib=b;e=Kb(a);x[27524]=0;a=ga(130)|0;c=x[27524];x[27524]=0;a:{b:{if((c|0)==1){break b}c:{d:{if(!a){break d}x[27524]=0;c=Q(1,b+32|0,8911)|0;a=x[27524];x[27524]=0;if((a|0)==1){break c}x[27524]=0;a=ga(130)|0;d=x[27524];x[27524]=0;e:{f:{g:{h:{if((d|0)==1){break h}x[27524]=0;x[b+12>>2]=a;R(136,b+16|0,b+12|0);a=x[27524];x[27524]=0;if((a|0)==1){break h}x[27524]=0;U(2,b+48|0,c|0,b+16|0);a=x[27524];x[27524]=0;if((a|0)==1){break g}d=b+48|0;a=Gb(e,d);xb(d);xb(b+16|0);xb(c);x[27524]=0;c=ga(132)|0;d=x[27524];x[27524]=0;if((d|0)==1){break b}if(!c){break e}x[27524]=0;Q(137,a|0,17476)|0;c=x[27524];x[27524]=0;if((c|0)!=1){break e}break b}a=P()|0;break f}a=P()|0;xb(b+16|0)}xb(c);break a}x[27524]=0;c=ga(131)|0;d=x[27524];x[27524]=0;if((d|0)==1){break b}if(!c){break d}x[27524]=0;Q(137,a|0,16778)|0;a=x[27524];x[27524]=0;if((a|0)==1){break b}}ib=b- -64|0;return}a=P()|0;break a}a=P()|0}xb(e);S(a|0);p()}function Nx(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=E(0);c=ib+-64|0;ib=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;Qf(c+48|0,c+32|0,d);a=x[b+4>>2];d=x[a+8>>2];e=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;a:{b:{c:{d:{f=x[c+4>>2];if(f>>>0>=e>>>0){if(A[c+20>>2]<e>>>0){break d}if(d>>>0>A[c+8>>2]){break c}g=x[c+28>>2];if(d>>>0>x[c+24>>2]-g>>>0){break b}h=x[c+16>>2];i=x[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}j=b+g|0;k=D(b,f);a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{l=Be(ug(C[(a+k<<3)+i>>3])*134217728);m=x[(a<<2)+h>>2]+(j<<2)|0,n=E(+(Mm(l)|0)*7.450580596923828e-9),B[m>>2]=n;a=a+1|0;continue}}}aa(7192,8993,77,8673);p()}aa(7157,8993,78,8673);p()}aa(5900,8993,79,8673);p()}aa(5870,8993,80,8673);p()}ib=c- -64|0}function Iq(a){var b=0,c=0,d=0,e=0,f=0;e=ib-16|0;ib=e;a:{b:{c:{d:{e:{f:{g:{h:{b=x[a+480180>>2];switch(b-1|0){case 7:break e;case 0:case 1:case 3:break f;case 2:case 4:case 5:case 6:break g;default:break h}}if((b|0)==16){break b}if((b|0)==32){break f}if((b|0)==64|(b|0)==256|((b|0)==512|(b|0)==2048)|(b|0)==8192){break b}if((b|0)==65536){break d}d=1;if((b|0)==2097152){break a}if((b|0)==4194304){break c}if((b|0)==536870912|(b|0)==67108864|(b|0)==134217728){break a}d=b;if((b|0)==16777216){break a}}d=32;break a}d=b;break a}d=4;if(z[a+480192>>1]){break a}c=Cb(x[a+484344>>2]);x[e+8>>2]=c;a=Cb(x[a+484348>>2]);while(1){if(!Mb(c,a)){d=1;break a}if(!(!Mb(x[c>>2],x[c+4>>2])|x[c+12>>2]==64)){break a}c=x[ou(e+8|0)>>2];continue}}d=16777216;break a}d=32;f=z[a+480188>>1];if(f>>>0>16){break a}while(1){if((c|0)==(f|0)){break b}b=(c<<5)+a|0;if(v[b+480281|0]&1){break a}c=c+1|0;if(z[b+480286>>1]==64){continue}break}break a}d=2}ib=e+16|0;return d}function Mx(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=E(0);c=ib+-64|0;ib=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;Qf(c+48|0,c+32|0,d);a=x[b+4>>2];d=x[a+8>>2];e=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;a:{b:{c:{d:{f=x[c+4>>2];if(f>>>0>=e>>>0){g=x[c+20>>2];if(g>>>0<e>>>0){break d}if(d>>>0>A[c+8>>2]){break c}h=x[c+28>>2];if(d>>>0>x[c+24>>2]-h>>>0){break b}i=x[c+16>>2];j=x[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}k=D(b,f);l=D(b+h|0,g);a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{m=(a+l<<2)+i|0,n=E(+(Mm(Be(ug(C[(a+k<<3)+j>>3])*134217728))|0)*7.450580596923828e-9),B[m>>2]=n;a=a+1|0;continue}}}aa(7192,8993,77,8673);p()}aa(7157,8993,78,8673);p()}aa(5900,8993,79,8673);p()}aa(5870,8993,80,8673);p()}ib=c- -64|0}function n5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=ib+-64|0;ib=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;Qf(c+48|0,c+32|0,d);a=x[b+4>>2];d=x[a+8>>2];e=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;a:{b:{c:{d:{g=x[c+4>>2];if(g>>>0>=e>>>0){if(A[c+20>>2]<e>>>0){break d}if(d>>>0>A[c+8>>2]){break c}h=x[c+28>>2];if(d>>>0>x[c+24>>2]-h>>>0){break b}i=x[c+16>>2];j=x[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}k=b+h|0;l=D(b,g);a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{m=x[(a<<2)+i>>2]+(k<<1)|0;f=kd(x[(a+l<<2)+j>>2]+2048|0,12);f=(f|0)>=32767?32767:f;w[m>>1]=(f|0)<=-32768?-32768:f;a=a+1|0;continue}}}aa(7192,8993,33,8706);p()}aa(7157,8993,34,8706);p()}aa(5900,8993,35,8706);p()}aa(5870,8993,36,8706);p()}ib=c- -64|0}function hZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;j=ib-32|0;ib=j;e=cn(j+8|0,a);c=ib-48|0;ib=c;k=-1;a:{if(!SD(e,c+8|0)){break a}k=0;if(!WD(c+8|0)){break a}l=xf(13061);if(l){o=x[e+12>>2];b:{if(!yl(e,y[c+24|0]|y[c+25|0]<<8|(y[c+26|0]<<16|y[c+27|0]<<24))){break b}while(1){c:{if((y[c+20|0]|y[c+21|0]<<8|(y[c+22|0]<<16|y[c+23|0]<<24))>>>0>n>>>0){if(kg(e,5)){break c}}f=m&1;break b}f=0;h=1;d:{if((y[c+12|0]|y[c+13|0]<<8)>>>0>=64){d=_q(e);a=d&63;g=d<<24>>24;e:{if(!(d&64)){break e}d=6;while(1){i=_q(e);a=(i&127)<<d|a;if(i<<24>>24>=0){break e}i=d>>>0<25;d=d+7|0;if(i){continue}break}}d=(g|0)<0;g=d?-2147483648:a;if(((d?(a|0)>=0?0-a|0:g:g)|0)<=0){break d}}while(1){d=_q(e);if(d){g=f>>>0>=l>>>0;a=g&h;if(!((h^1)&1|g)){a=(Xp(d<<24>>24)&255)==y[f+13061|0]}h=a;f=f+1|0;continue}break}gd(e,4);m=(f|0)==(l|0)?h&1?1:m:m}n=n+1|0;continue}}yl(e,o)}if(!f){break a}k=Ee(e,b,VD(c+8|0),0)}ib=c+48|0;ib=j+32|0;return k|0}function $ca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=x[a>>2];c=Wj(d,x[a+4>>2]);if(c>>>0<b>>>0){g=ib-32|0;ib=g;e=b-c|0;b=x[Db(a)>>2];c=x[a+4>>2];a:{if(e>>>0<=b-c>>11>>>0){b=ib-16|0;ib=b;x[b>>2]=a;a=x[a+4>>2];x[b+4>>2]=a;x[b+8>>2]=a+(e<<11);a=x[b+4>>2];c=x[b+8>>2];while(1){if((a|0)==(c|0)){ic(b);ib=b+16|0}else{it(a);a=a+2048|0;x[b+4>>2]=a;continue}break}break a}h=Db(a);i=g+8|0;b=a;f=Wj(x[a>>2],c)+e|0;c=ib-16|0;ib=c;x[c+12>>2]=f;d=ib-16|0;ib=d;x[d+12>>2]=2097151;x[d+8>>2]=2147483647;a=x[Hb(d+12|0,d+8|0)>>2];ib=d+16|0;b:{if(a>>>0>=f>>>0){d=vy(b);if(d>>>0<a>>>1>>>0){x[c+8>>2]=d<<1;a=x[Yc(c+8|0,c+12|0)>>2]}ib=c+16|0;break b}_c();p()}d=JN(i,a,Wj(x[b>>2],x[b+4>>2]),h);c=d;a=ib-16|0;ib=a;x[a>>2]=x[c+8>>2];f=x[c+8>>2];x[a+8>>2]=c+8;x[a+4>>2]=f+(e<<11);c=x[a>>2];while(1){if(x[a+4>>2]!=(c|0)){it(c);c=x[a>>2]+2048|0;x[a>>2]=c;continue}break}Vd(a);ib=a+16|0;Dd(b,d);IN(d)}ib=g+32|0;return}if(b>>>0<c>>>0){Od(a,d+(b<<11)|0)}}function aga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=ib-16|0;ib=e;n=x[a+16>>2];o=qg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);k=x[a+128>>2];a:{if(!k){i=x[a+8>>2];j=x[a+12>>2];g=x[a>>2];b=x[a+4>>2];h=0;break a}i=x[a+8>>2];j=x[a+12>>2];l=rg(i,j,k);m=kb;h=x[a+76>>2];g=x[a>>2];b=x[a+4>>2];Zf(g,b,rf(i,j,d),kb);h=h>>>0<kb>>>0?d:0}f=a+112|0;p=x[a+24>>2];q=x[a+20>>2];x[e>>2]=g;x[e+4>>2]=b;b:while(1){if(d){b=x[e+4>>2];x[e+8>>2]=x[e>>2];x[e+12>>2]=0;h=h-1|0;l=h?l:0;m=h?m:0;d=d-1|0;g=(b<<1)+n|0;b=k;while(1)if((b|0)<=0){Pb(f,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){Sd(f,w[(x[e+12>>2]<<1)+g>>1]/4<<16>>16);Rd(f,b);x[f>>2]=x[f>>2];x[f+4>>2]=0}g=x[c>>2];b=pg(f,o);x[c>>2]=g+D(b,q);x[c+4>>2]=x[c+4>>2]+D(b,p);Pb(e,i,j);c=c+8|0;continue b}else{Sd(f,w[(x[e+12>>2]<<1)+g>>1]/4<<16>>16);Rd(f,4);Pb(e+8|0,l,m);b=b-1|0;continue}}break}b=x[e+4>>2];x[a>>2]=x[e>>2];x[a+4>>2]=b;ib=e+16|0}function d5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=ib+-64|0;ib=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;Qf(c+48|0,c+32|0,d);a=x[b+4>>2];d=x[a+8>>2];e=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;a:{b:{c:{d:{g=x[c+4>>2];if(g>>>0>=e>>>0){h=x[c+20>>2];if(h>>>0<e>>>0){break d}if(d>>>0>A[c+8>>2]){break c}i=x[c+28>>2];if(d>>>0>x[c+24>>2]-i>>>0){break b}j=x[c+16>>2];k=x[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}l=D(b,g);m=D(b+i|0,h);a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{f=kd(x[(a+l<<2)+k>>2]+2048|0,12);f=(f|0)>=32767?32767:f;w[(a+m<<1)+j>>1]=(f|0)<=-32768?-32768:f;a=a+1|0;continue}}}aa(7192,8993,33,8706);p()}aa(7157,8993,34,8706);p()}aa(5900,8993,35,8706);p()}aa(5870,8993,36,8706);p()}ib=c- -64|0}function _r(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;a:{b:{d=$i(a)&2047;e=$i(5551115123125783e-32);c=d-e|0;if(c>>>0<$i(512)-e>>>0){e=d;break b}if((c|0)<0){return a+1}e=0;if($i(1024)>>>0>d>>>0){break b}o(+a);e=j(1)|0;b=0;if(!(j(0)|0)&(e|0)==-1048576){break a}if($i(O)>>>0<=d>>>0){return a+1}if((e|0)<0){return Yr(12882297539194267e-247)}return Yr(3105036184601418e216)}b=C[170];f=C[169]*a+b;b=f-b;a=b*C[172]+(b*C[171]+a);b=a*a;g=b*b*(a*C[176]+C[175]);b=b*(a*C[174]+C[173]);o(+f);j(1)|0;i=j(0)|0;c=i<<4&2032;a=g+(b+(C[c+1464>>3]+a));c=c+1472|0;h=x[c>>2];d=x[c+4>>2];c=h;h=0;c=c+h|0;d=(i<<13)+d|0;d=c>>>0<h>>>0?d+1|0:d;if(!e){c:{if(!(i&-2147483648)){l(0,c|0);l(1,d-1058013184|0);b=+n();a=(b*a+b)*5486124068793689e288;break c}l(0,c|0);l(1,d+1071644672|0);b=+n();f=b*a;a=f+b;if(a<1){$E(WF()*22250738585072014e-324);g=a+1;a=g+(f+(b-a)+(a+(1-g)))+-1;a=a==0?0:a}a=a*22250738585072014e-324}return a}l(0,c|0);l(1,d|0);b=+n();b=b*a+b}return b}function mia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=ib-16|0;ib=f;w[f+12>>1]=c;w[f+14>>1]=b;w[f+10>>1]=d;h=z[x[x[a+24>>2]+8>>2]+12>>1];a:{if(h>>>0<=b>>>0){break a}if(!c|xj(a)>>>0>=h>>>0){break a}Mf(f+12|0,h-b&65535);k=f,l=Gl(x[a>>2],x[a+4>>2]),w[k+8>>1]=l;d=z[f+12>>1];WU(a,d+z[pe(f+14|0,f+8|0)>>1]|0);c=x[a>>2];e=a;if(Oc(c,x[a+4>>2])>>>0<b>>>0){Dg(e,b);c=x[e>>2]}a=Cb(c);c=ib-16|0;ib=c;x[c+8>>2]=a;a=x[KR(c+8|0,b)>>2];ib=c+16|0;a=x[Wb(f,a)>>2];i=f+10|0;j=ib-32|0;ib=j;b=a;a=x[e>>2];g=(Do(b,Cb(a))<<1)+a|0;a=d;b:{if(!a){break b}b=x[Db(e)>>2];d=x[e+4>>2];if(a>>>0<=b-d>>1>>>0){b=a;c=d-g>>1;if(c>>>0<a>>>0){No(e,a-c|0,i);b=c;if((d|0)==(g|0)){break b}}HR(e,g,d,(a<<1)+g|0);tu(g,b,((g>>>0<=i>>>0?A[e+4>>2]>i>>>0?a:0:0)<<1)+i|0);break b}b=Db(e);b=Uj(j+8|0,Vj(e,Oc(x[e>>2],d)+a|0),g-x[e>>2]>>1,b);mD(b,a,i);g=GR(e,b,g);Ui(b)}Cb(g);ib=j+32|0;if(Oc(x[e>>2],x[e+4>>2])>>>0<=h>>>0){break a}Dg(e,h)}ib=f+16|0}function eha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0;g=ib-16|0;ib=g;f=x[a+48>>2];j=x[a+24>>2];k=x[a+20>>2];e=x[a+44>>2];l=x[a+16>>2];b=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=b;m=x[a+72>>2];b=x[a+68>>2];n=b;o=b>>31;b=x[a+64>>2];p=b;q=b>>31;b=x[a+60>>2];r=b;s=b>>31;t=x[a+8>>2];u=x[a+12>>2];while(1){b=e;if(d){e=Vb(b,-16777216,16776704);e=qoa(p,q,e,e>>31);i=kb;f=Vb(f,-16777216,16776704);h=qoa(n,o,f,f>>31);e=h+e|0;f=kb+i|0;f=e>>>0<h>>>0?f+1|0:f;i=e;h=x[g+12>>2]+l|0;e=v[h|0];w=i;i=((D(v[h+1|0]-e|0,x[g+8>>2]>>>10&4194048)|0)/16384|0)+(e<<8)<<8;e=i;h=qoa(e,e>>31,r,s);e=w+h|0;f=kb+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Vc(e,f,24);e=(f|0)/256|0;x[c>>2]=D(e,k)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(e,j);Pb(g+8|0,t,u);e=f-(i&m)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+48>>2]=f;x[a+44>>2]=b;ib=g+16|0}function nS(a,b,c,d){var e=0,f=0;e=ib-16|0;ib=e;v[e+15|0]=c;f=b&15;b=y[f+27088|0];a:{b:{switch(f|0){case 0:b=c?d>>>0>=51?b:0:0;break a;case 5:c:{d:{f=c&15;e:{if(!((f|0)!=2&(c&240)!=32)){c=159;v[e+15|0]=159;b=20;break e}if((f|0)==12){break d}}if(d>>>0<51){break a}if((c&240)==192){break c}break a}if(d>>>0<51){break a}}v[e+15|0]=0;b=25;break a;case 7:b=d>>>0>=52?b:0;break a;case 10:c=c&240;if(!c){break a}v[e+15|0]=c;break a;case 11:v[e+15|0]=D(c&15,17);break a;case 12:v[e+15|0]=c>>>2;break a;case 13:v[e+15|0]=D(c>>>4|0,10)+(c&15);break a;case 14:f:{switch((c>>>4|0)-1|0){case 0:v[e+15|0]=c|240;b=2;break a;case 1:v[e+15|0]=c|240;b=3;break a;case 7:if(d>>>0<52){break a}v[e+15|0]=c&15|96;case 11:case 12:b=20;break a;case 8:b=15;v[e+15|0]=c&15;break a;case 9:v[e+15|0]=c<<4|15;b=11;break a;case 10:break f;default:break a}}v[e+15|0]=c|240;b=11;break a;case 15:break b;default:break a}}b=c>>>0>47?17:b}fe(a,b,e+15|0);ib=e+16|0}function dha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=ib-16|0;ib=g;f=x[a+48>>2];j=x[a+24>>2];k=x[a+20>>2];e=x[a+44>>2];l=x[a+16>>2];b=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=b;m=x[a+72>>2];b=x[a+68>>2];n=b;o=b>>31;b=x[a+64>>2];p=b;q=b>>31;b=x[a+60>>2];r=b;s=b>>31;t=x[a+8>>2];u=x[a+12>>2];while(1){b=e;if(d){e=Vb(b,-16777216,16776704);e=qoa(p,q,e,e>>31);i=kb;f=Vb(f,-16777216,16776704);h=qoa(n,o,f,f>>31);e=h+e|0;f=kb+i|0;f=e>>>0<h>>>0?f+1|0:f;i=e;h=(x[g+12>>2]<<1)+l|0;e=w[h>>1];v=i;i=e+((D(w[h+2>>1]-e|0,x[g+8>>2]>>>18|0)|0)/16384|0)<<8;e=i;h=qoa(e,e>>31,r,s);e=v+h|0;f=kb+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Vc(e,f,24);e=(f|0)/256|0;x[c>>2]=D(e,k)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(e,j);Pb(g+8|0,t,u);e=f-(i&m)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+48>>2]=f;x[a+44>>2]=b;ib=g+16|0}function Gma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;md(b,32);xo(b);f=b,g=Fb(y[a+40|0]|y[a+41|0]<<8)>>>2|0,w[f+32>>1]=g;c=z[b+34>>1];if((se((y[a+38|0]|y[a+39|0]<<8)<<16>>16)|0)>0){c=c|32;w[b+34>>1]=c;d=se((y[a+38|0]|y[a+39|0]<<8)<<16>>16);e=(d<<8&-256)+2047|0;d=d>>>24|0;f=b,g=Ec(soa(e,e>>>0<2047?d+1|0:d,4095,0),kb),w[f+28>>1]=g}f=b,g=ac(y[a+58|0]|y[a+59|0]<<8|(y[a+60|0]<<16|y[a+61|0]<<24)),x[f>>2]=g;f=b,g=ac(y[a+62|0]|y[a+63|0]<<8|(y[a+64|0]<<16|y[a+65|0]<<24)),x[f+4>>2]=g;f=b,g=ac(y[a+62|0]|y[a+63|0]<<8|(y[a+64|0]<<16|y[a+65|0]<<24))+ac(y[a+66|0]|y[a+67|0]<<8|(y[a+68|0]<<16|y[a+69|0]<<24))|0,x[f+8>>2]=g;c=c&-3|((Fb(y[a+44|0]|y[a+45|0]<<8)|0)!=0)<<1;w[b+34>>1]=c;f=b,g=c&65531|Fb(y[a+44|0]|y[a+45|0]<<8)<<1&4,w[f+34>>1]=g;f=b,g=ac(y[a+54|0]|y[a+55|0]<<8|(y[a+56|0]<<16|y[a+57|0]<<24))<<1,x[f+24>>2]=g;c=se((y[a+42|0]|y[a+43|0]<<8)<<16>>16);if(c){Cl(b,+(c|0)/96);c=se((y[a+42|0]|y[a+43|0]<<8)<<16>>16)}v[b+37|0]=c<<4}function sba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=E(0),o=0,p=0,q=0,r=0,s=0,t=E(0),u=E(0),v=E(0),w=E(0),z=0,A=0,C=0,D=0,G=0,H=E(0);g=ib-16|0;ib=g;m=x[a+4240>>2];a:{if(!m){break a}if(!fi(a+44|0)){break a}n=B[a+4220>>2];e=x[a+44>>2];D=g,G=Hc(e,0),x[D+8>>2]=G;D=g,G=Hc(e,1),x[D+12>>2]=G;e=x[a+56>>2];o=Hc(e,0);x[g>>2]=o;p=Hc(e,1);x[g+4>>2]=p;w=E(E(1)-n);q=x[a+4208>>2];z=y[a+4264|0];e=d;b:while(1){if(e){k=x[a+4244>>2];A=k<<1;f=0;l=0;while(1)if((f|0)==2){f=k+1|0;x[a+4244>>2]=(f|0)!=(m|0)?f:0;e=e-1|0;continue b}else{h=(z?1-l|0:f)&255;j=x[((h<<2)+a|0)+4248>>2];C=x[a+4240>>2];r=f<<2;s=r+(g+8|0)|0;i=x[s>>2];x[s>>2]=i+4;j=k-j|0;t=B[Bb(q,h+((j>>31&C)+j<<1)|0)>>2];u=B[i>>2];v=E(E(t*B[a+4224>>2])+E(u*B[a+4260>>2]));D=Bb(q,f+A|0),H=E(F(v))<E(10000000195414814e-40)?E(0):v,B[D>>2]=H;h=g+r|0;i=x[h>>2];x[h>>2]=i+4;B[i>>2]=E(u*w)+E(n*t);l=l+1|0;f=f+1|0;continue}}break}zi(a,b,c,o,p,d)}ib=g+16|0}function JJ(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;x[a+4>>2]=b;x[a>>2]=110136;e=(b>>>0)/48|0;d=((0-b|0)!=(D(e,-48)|0))+e|0;x[a+12>>2]=d;e=(b>>>0)/(d>>>0)|0;x[a+8>>2]=e;f=e>>>0<64;c=e&31;if((e&63)>>>0>=32){g=-1<<c}else{g=(1<<c)-1&-1>>>32-c|-1<<c}c=0;x[a+24>>2]=c;f=f?g&65536:0;x[a+28>>2]=f;g=soa(c,f,d,0);h=kb;f=f^65536;if((h|0)==(f|0)&c>>>0>g>>>0|f>>>0>h>>>0){d=d+1|0;x[a+12>>2]=d;e=(b>>>0)/(d>>>0)|0;x[a+8>>2]=e;f=e>>>0<64;c=e&31;if((e&63)>>>0>=32){c=-1<<c}else{c=(1<<c)-1&-1>>>32-c|-1<<c}x[a+24>>2]=0;x[a+28>>2]=f?c&65536:0}x[a+16>>2]=d-((b>>>0)%(d>>>0)|0);b=e>>>0<63;c=63-e|0;d=c&31;if((c&63)>>>0>=32){c=0;d=-1>>>d|0}else{c=-1>>>d|0;d=c|(1<<d)-1<<32-d}x[a+48>>2]=b?d:-1;x[a+52>>2]=b?c:-1;c=64-e|0;d=c&31;if((c&63)>>>0>=32){c=0;d=-1>>>d|0}else{c=-1>>>d|0;d=c|(1<<d)-1<<32-d}x[a+40>>2]=e?d:0;x[a+44>>2]=e?c:0;d=e+1|0;e=d&31;if((d&63)>>>0>=32){c=-1<<e}else{c=(1<<e)-1&-1>>>32-e|-1<<e}x[a+32>>2]=0;x[a+36>>2]=b?c&65536:0;return a}function Uw(a,b,c,d,e,f,g,h,i,j,k,l){var m=0;m=ib-16|0;ib=m;v[m+15|0]=a;a:{b:{if((a|0)==(f|0)){if(!y[b|0]){break b}a=0;v[b|0]=0;b=x[e>>2];x[e>>2]=b+1;v[b|0]=46;if(!Eb(h)){break a}b=x[j>>2];if((b-i|0)>159){break a}c=x[k>>2];x[j>>2]=b+4;x[b>>2]=c;break a}c:{if((a|0)!=(g|0)){break c}if(!Eb(h)){break c}if(!y[b|0]){break b}a=0;b=x[j>>2];if((b-i|0)>159){break a}a=x[k>>2];x[j>>2]=b+4;x[b>>2]=a;a=0;x[k>>2]=0;break a}a=-1;f=Bi(l,l+32|0,m+15|0)-l|0;if((f|0)>31){break a}g=y[f+98224|0];d:{e:{switch((f&-2)-22|0){case 2:b=x[e>>2];if((b|0)!=(d|0)&(y[b-1|0]&95)!=(y[c|0]&127)){break a}x[e>>2]=b+1;v[b|0]=g;a=0;break a;case 0:v[c|0]=80;break d;default:break e}}a=g&95;if((a|0)!=y[c|0]){break d}v[c|0]=a|128;if(!y[b|0]){break d}v[b|0]=0;if(!Eb(h)){break d}a=x[j>>2];if((a-i|0)>159){break d}b=x[k>>2];x[j>>2]=a+4;x[a>>2]=b}a=x[e>>2];x[e>>2]=a+1;v[a|0]=g;a=0;if((f|0)>21){break a}x[k>>2]=x[k>>2]+1;break a}a=-1}ib=m+16|0;return a}function tha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0;g=ib-16|0;ib=g;m=x[a+16>>2];j=ag(1,2);b=kb;n=b;Pb(a,j,b);f=x[a+48>>2];o=x[a+24>>2];p=x[a+20>>2];e=x[a+44>>2];b=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=b;q=x[a+72>>2];b=x[a+68>>2];r=b;s=b>>31;b=x[a+64>>2];t=b;u=b>>31;b=x[a+60>>2];v=b;y=b>>31;z=x[a+8>>2];A=x[a+12>>2];while(1){b=e;if(d){k=w[(x[g+12>>2]<<1)+m>>1]<<8;e=k;e=qoa(e,e>>31,v,y);i=kb;h=e;e=Vb(b,-16777216,16776704);l=qoa(t,u,e,e>>31);h=h+l|0;e=kb+i|0;e=h>>>0<l>>>0?e+1|0:e;f=Vb(f,-16777216,16776704);i=qoa(r,s,f,f>>31);h=i+h|0;f=kb+e|0;f=h>>>0<i>>>0?f+1|0:f;e=h+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Vc(e,f,24);e=(f|0)/256|0;x[c>>2]=D(e,p)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(e,o);Pb(g+8|0,z,A);e=f-(q&k)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+48>>2]=f;x[a+44>>2]=b;sg(a,j,n);ib=g+16|0}function Qp(a){a=a|0;var b=0,c=0,d=E(0),e=E(0),f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=E(0),n=0,o=E(0);b=x[a+36>>2];if(!b){Ic(a+16|0);return}a:{b:{switch(z[a>>1]){case 3:c=a+16|0;if(b>>>0>=1001){Ic(c);return}kk(c,b);b=w[a+28>>1];d=E(vm(a,(b<<16)+65536>>16)/vm(a,b));c=x[a+36>>2]+1|0;d=ze(d,E(E(1)/E(c>>>0)));a=x[a+16>>2];b=1;while(1){if((b|0)==(c|0)){break a}e=ze(d,E(b>>>0));n=Bb(a,b-1|0),o=e,B[n>>2]=o;b=b+1|0;continue};case 1:c=a+16|0;f=z[a+30>>1];if(f>>>0>1e3/(b>>>0)>>>0){Ic(c);return}kk(c,D(b,f));h=z[a+30>>1];j=By(w[a+28>>1],h);i=x[a+36>>2];d=E(E(1)/E(i+1>>>0));c=0;c:while(1){if((c&65535)>>>0>=f>>>0){break a}b=By(c+j<<16>>16,h)<<16;e=vm(a,b+65536>>16);b=b>>16;e=ze(E(e/vm(a,b)),d);k=D(b,x[a+36>>2]);l=x[a+16>>2];b=1;while(1){g=b&65535;if(i>>>0<g>>>0){c=c+1|0;continue c}else{m=ze(e,E(g>>>0));n=Bb(l,(g+k|0)-1|0),o=m,B[n>>2]=o;b=b+1|0;continue}}};case 0:Ic(a+16|0);return;default:break b}}Ic(a+16|0);x[a+36>>2]=0}}function u9(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=ib-32|0;ib=d;x[27524]=0;g=Q(13,d+24|0,a|0)|0;c=x[27524];x[27524]=0;a:{b:{c:{if((c|0)!=1){d:{if(!y[g|0]){break d}c=d+16|0;ed(c,x[x[a>>2]-12>>2]+a|0);x[27524]=0;c=T(68,c|0)|0;e=x[27524];x[27524]=0;e:{f:{if((e|0)!=1){_b(d+16|0);e=Jo(d+8|0,a);f=x[x[a>>2]-12>>2];x[27524]=0;f=a+f|0;h=T(14,f|0)|0;i=x[27524];x[27524]=0;if((i|0)==1){break f}e=x[e>>2];x[27524]=0;c=Sa(69,c|0,e|0,f|0,h|0,+b)|0;e=x[27524];x[27524]=0;if((e|0)==1){break f}x[d+16>>2]=c;if(!sC(d+16|0)){break d}c=x[x[a>>2]-12>>2];x[27524]=0;R(16,a+c|0,5);c=x[27524];x[27524]=0;if((c|0)!=1){break d}c=V(0)|0;break e}c=V(0)|0;_b(d+16|0);break e}c=V(0)|0}Hl(g);break c}Hl(g);break b}c=V(0)|0}_(c|0)|0;c=x[x[a>>2]-12>>2];x[27524]=0;Y(17,a+c|0);c=x[27524];x[27524]=0;if((c|0)==1){break a}$()}ib=d+32|0;return a|0}a=P()|0;x[27524]=0;Z(18);d=x[27524];x[27524]=0;if((d|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function uha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0;g=ib-16|0;ib=g;m=x[a+16>>2];j=ag(1,2);b=kb;n=b;Pb(a,j,b);f=x[a+48>>2];o=x[a+24>>2];p=x[a+20>>2];e=x[a+44>>2];b=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=b;q=x[a+72>>2];b=x[a+68>>2];r=b;s=b>>31;b=x[a+64>>2];t=b;u=b>>31;b=x[a+60>>2];w=b;y=b>>31;z=x[a+8>>2];A=x[a+12>>2];while(1){b=e;if(d){k=v[x[g+12>>2]+m|0]<<16;e=k;e=qoa(e,e>>31,w,y);i=kb;h=e;e=Vb(b,-16777216,16776704);l=qoa(t,u,e,e>>31);h=h+l|0;e=kb+i|0;e=h>>>0<l>>>0?e+1|0:e;f=Vb(f,-16777216,16776704);i=qoa(r,s,f,f>>31);h=i+h|0;f=kb+e|0;f=h>>>0<i>>>0?f+1|0:f;e=h+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Vc(e,f,24);e=(f|0)/256|0;x[c>>2]=D(e,p)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(e,o);Pb(g+8|0,z,A);e=f-(q&k)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+48>>2]=f;x[a+44>>2]=b;sg(a,j,n);ib=g+16|0}function uka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=ib-16|0;ib=e;w[e+12>>1]=0;x[e+8>>2]=0;j=8;n=D(c,d)<<1;a:while(1){if((d|0)!=(l|0)){i=(l<<1)+b|0;o=n+i|0;while(1){b:{c:{if(i>>>0<o>>>0){w[e+6>>1]=0;HU(a,e+15|0,e+12|0,j,e+6|0);g=z[e+6>>1];f=z[e+12>>1];c=j;while(1){if(c&255){h=f<<1;f=h&254;d:{if(f){h=(h&65534)>>>0>255;break d}if(!vf(a,e+5|0)){break c}f=y[e+5|0];h=f>>>7|0;f=f<<1&254|1}c=c-1|0;g=g<<1|h;continue}break}w[e+12>>1]=f;break b}l=l+1|0;continue a}w[e+12>>1]=0}c=1;h=g&65535;e:{if(h>>>0<4){break e}f=15;while(1){c=f;m=f&255;if(h>>>m&1){break e}f=c-1|0;if(m>>>0>1){continue}break}}f=g&1;v[e+15|0]=f;g=f-1^(g&65534)>>>1;f=g+z[e+8>>1]|0;w[e+6>>1]=f;w[i>>1]=f;x[e+8>>2]=((g>>1)-(k<<16>>16)|0)+(f<<16>>16<<1);i=(d<<1)+i|0;j=(c+j&254)>>>1|0;c=-32768;k=x[e+8>>2];f:{if((k|0)>=-32768){c=32767;if((k|0)<32768){break f}}x[e+8>>2]=c}k=f;continue}}break}ib=e+16|0}function oaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=ib-80|0;ib=e;x[e+72>>2]=c;a=ge(a,e+72|0);c=sc(a+4|0);g=sc(a+24|0);h=sc(a+32|0);i=Nb(a+36|0);x[a+56>>2]=3;j=Nb(a+68|0);x[27524]=0;R(953,a|0,d|0);f=x[27524];x[27524]=0;a:{b:{c:{d:{if((f|0)!=1){f=x[b>>2];k=x[b+4>>2];l=x[b+12>>2];x[e+40>>2]=x[b+8>>2];x[e+44>>2]=l;x[e+32>>2]=f;x[e+36>>2]=k;b=Id(e+24|0);f=x[e+44>>2];x[e+16>>2]=x[e+40>>2];x[e+20>>2]=f;x[27524]=0;f=x[e+36>>2];x[e+8>>2]=x[e+32>>2];x[e+12>>2]=f;f=x[b+4>>2];x[e>>2]=x[b>>2];x[e+4>>2]=f;U(942,e+48|0,e+8|0,e|0);b=x[27524];x[27524]=0;if((b|0)==1){break d}x[27524]=0;U(954,a|0,e+48|0,d|0);b=x[27524];x[27524]=0;if((b|0)==1){break c}yb(e+48|0);x[27524]=0;Y(955,a|0);b=x[27524];x[27524]=0;if((b|0)==1){break b}Xc(e+72|0);ib=e+80|0;return a|0}d=P()|0;break a}d=P()|0;break a}d=P()|0;yb(e+48|0);break a}d=P()|0}ve(j);nf(i);hl(h);lh(g);kh(c);Xc(a);Xc(e+72|0);S(d|0);p()}function Vca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=E(0),j=0,k=0,l=0,m=0,n=E(0),o=E(0),p=E(0),q=E(0),r=0,s=0,t=0,u=E(0),v=E(0),w=E(0),y=E(0),z=0,A=0,C=0,D=E(0);r=x[a+4220>>2];if(r){f=x[a+44>>2];k=Hc(f,0);l=Hc(f,1);g=x[a+56>>2];s=Hc(g,0);j=x[a+4208>>2];z=x[a+4228>>2];f=d;t=Hc(g,1);m=t;g=s;while(1){if(f){h=x[a+4224>>2];e=h-z|0;e=(x[a+4220>>2]&e>>31)+e<<1;A=Bb(j,e);n=B[Bb(j,e|1)>>2];u=B[a+4244>>2];o=B[A>>2];v=B[a+4252>>2];p=B[l>>2];w=B[a+4248>>2];q=B[k>>2];y=B[a+4256>>2];i=E(E(n*u)+E(E(o*v)+E(E(p*w)+E(q*y))));e=h<<1;C=Bb(j,e),D=E(F(i))<E(10000000195414814e-40)?E(0):i,B[C>>2]=D;i=E(E(o*u)+E(E(n*v)+E(E(q*w)+E(p*y))));C=Bb(j,e|1),D=E(F(i))<E(10000000195414814e-40)?E(0):i,B[C>>2]=D;h=h+1|0;x[a+4224>>2]=(h|0)!=(r|0)?h:0;B[g>>2]=E(q*B[a+4240>>2])+E(o*B[a+4236>>2]);B[m>>2]=E(p*B[a+4240>>2])+E(n*B[a+4236>>2]);f=f-1|0;m=m+4|0;g=g+4|0;l=l+4|0;k=k+4|0;continue}else{zi(a,b,c,s,t,d)}break}}}function GH(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=ib-32|0;ib=c;a:{if(y[a+52|0]){d=x[a+48>>2];if(!b){break a}v[a+52|0]=0;x[a+48>>2]=-1;break a}x[c+24>>2]=1;e=x[Ve(c+24|0,a+44|0)>>2];h=(e|0)>0?e:0;while(1){if((f|0)!=(h|0)){d=-1;g=cu(x[a+32>>2]);if((g|0)==-1){break a}v[(c+24|0)+f|0]=g;f=f+1|0;continue}break}b:{c:{if(y[a+53|0]){v[c+23|0]=y[c+24|0];break c}h=c+24|0;while(1){d:{d=x[a+40>>2];g=x[d>>2];j=x[d+4>>2];i=c+24|0;f=i+e|0;e:{switch(TH(x[a+36>>2],d,i,f,c+16|0,c+23|0,h,c+12|0)-1|0){case 0:break e;case 1:break b;case 2:break d;default:break c}}d=x[a+40>>2];x[d>>2]=g;x[d+4>>2]=j;if((e|0)==8){break b}d=cu(x[a+32>>2]);if((d|0)==-1){break b}v[f|0]=d;e=e+1|0;continue}break}v[c+23|0]=y[c+24|0]}f:{if(!b){while(1){if((e|0)<=0){break f}d=-1;e=e-1|0;if((ns(Ke(v[e+(c+24|0)|0]),x[a+32>>2])|0)!=-1){continue}break a}}d=Ke(v[c+23|0]);x[a+48>>2]=d;break a}d=Ke(v[c+23|0]);break a}d=-1}ib=c+32|0;return d}function cga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=ib-16|0;ib=e;n=x[a+16>>2];o=qg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);k=x[a+128>>2];a:{if(!k){i=x[a+8>>2];j=x[a+12>>2];g=x[a>>2];b=x[a+4>>2];h=0;break a}i=x[a+8>>2];j=x[a+12>>2];l=rg(i,j,k);m=kb;h=x[a+76>>2];g=x[a>>2];b=x[a+4>>2];Zf(g,b,rf(i,j,d),kb);h=h>>>0<kb>>>0?d:0}f=a+112|0;p=x[a+24>>2];q=x[a+20>>2];x[e>>2]=g;x[e+4>>2]=b;b:while(1){if(d){b=x[e+4>>2];x[e+8>>2]=x[e>>2];x[e+12>>2]=0;h=h-1|0;l=h?l:0;m=h?m:0;d=d-1|0;g=b+n|0;b=k;while(1)if((b|0)<=0){Pb(f,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){Sd(f,v[x[e+12>>2]+g|0]<<6);Rd(f,b);x[f>>2]=x[f>>2];x[f+4>>2]=0}g=x[c>>2];b=pg(f,o);x[c>>2]=g+D(b,q);x[c+4>>2]=x[c+4>>2]+D(b,p);Pb(e,i,j);c=c+8|0;continue b}else{Sd(f,v[x[e+12>>2]+g|0]<<6);Rd(f,4);Pb(e+8|0,l,m);b=b-1|0;continue}}break}b=x[e+4>>2];x[a>>2]=x[e>>2];x[a+4>>2]=b;ib=e+16|0}function nv(a){var b=0,c=0,d=0,e=0;c=ib-16|0;ib=c;a:{if(y[a+3|0]!=19){break a}v[a+3|0]=20;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{b=y[a+5|0];switch(b>>>4|0){case 4:break j;case 3:break k;case 2:break l;case 1:break m;case 0:break n;case 13:break b;case 12:break c;case 11:break d;case 10:break e;case 9:break f;case 7:break g;case 6:break h;case 5:break i;default:break a}}v[a+3|0]=0;break a}v[a+3|0]=2;v[a+5|0]=b|240;break a}v[a+3|0]=3;v[a+5|0]=b|240;break a}v[a+5|0]=b&15|16;break a}v[a+5|0]=b&3|48;break a}v[a+5|0]=b&15|32;break a}v[a+5|0]=b&15|176;break a}v[a+5|0]=b&3|64;break a}v[a+3|0]=15;v[a+5|0]=b&15;break a}if(b&15){v[a+3|0]=11;v[a+5|0]=b<<4|15;break a}v[a+3|0]=0;break a}b=b&15;if(b){v[a+3|0]=11;x[c+12>>2]=b;x[c+8>>2]=14;d=a,e=y[rd(c+12|0,c+8|0)|0]|240,v[d+5|0]=e;break a}v[a+3|0]=0;break a}if((b|0)!=192){break a}v[a|0]=254;v[a+3|0]=0;break a}if((b|0)!=208){break a}v[a+3|0]=0}ib=c+16|0}function pG(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;b=0;a=c;while(1){a:{if(a>>>0>=d>>>0|b>>>0>=e>>>0){break a}g=1;f=v[a|0];b:{if((f|0)>=0){break b}if(f>>>0<4294967234){break a}if(f>>>0<=4294967263){if((d-a|0)<2){break a}g=2;if((y[a+1|0]&192)==128){break b}break a}g=f&255;c:{d:{if(f>>>0<=4294967279){if((d-a|0)<3){break a}h=y[a+2|0];f=y[a+1|0];if((g|0)==237){break d}if((g|0)==224){if((f&224)==160){break c}break a}if((f&192)!=128){break a}break c}if((d-a|0)<4|f>>>0>4294967284|e-b>>>0<2){break a}h=y[a+3|0];i=y[a+2|0];f=y[a+1|0];e:{f:{switch(g-240|0){case 0:if((f+112&255)>>>0<48){break e}break a;case 4:if((f&240)==128){break e}break a;default:break f}}if((f&192)!=128){break a}}if((i&192)!=128|(h&192)!=128|(g<<18&1835008|(f&48)<<12)>>>0>1114111){break a}b=b+1|0;g=4;break b}if((f&224)!=128){break a}}g=3;if((h&192)!=128){break a}}b=b+1|0;a=a+g|0;continue}break}return a-c|0}function Hga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=ib-16|0;ib=f;a:{b:{c:{g=x[a+12>>2];i=x[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|(g|0)==-1){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}j=x[a+16>>2];k=x[a+24>>2];l=x[a+20>>2];e=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=e;while(1){if(d){e=(x[f+12>>2]<<1)+j|0;h=(x[f+8>>2]>>>16&65520)+b|0;e=(((((((D(w[e-4>>1],w[h+2>>1])+D(w[e-6>>1],w[h>>1])|0)+D(w[e-2>>1],w[h+4>>1])|0)+D(w[e>>1],w[h+6>>1])|0)+D(w[e+2>>1],w[h+8>>1])|0)+D(w[e+4>>1],w[h+10>>1])|0)+D(w[e+6>>1],w[h+12>>1])|0)+D(w[e+8>>1],w[h+14>>1])|0)/32768|0;x[c>>2]=x[c>>2]+D(e,l);x[c+4>>2]=x[c+4>>2]+D(e,k);Pb(f+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;ib=f+16|0}function HH(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=ib-32|0;ib=c;a:{if(y[a+52|0]){d=x[a+48>>2];if(!b){break a}v[a+52|0]=0;x[a+48>>2]=-1;break a}x[c+24>>2]=1;e=x[Ve(c+24|0,a+44|0)>>2];h=(e|0)>0?e:0;while(1){if((f|0)!=(h|0)){d=-1;g=cu(x[a+32>>2]);if((g|0)==-1){break a}v[(c+24|0)+f|0]=g;f=f+1|0;continue}break}b:{c:{if(y[a+53|0]){x[c+20>>2]=v[c+24|0];break c}h=c+24|0;while(1){d:{d=x[a+40>>2];g=x[d>>2];j=x[d+4>>2];i=c+24|0;f=i+e|0;e:{switch(TH(x[a+36>>2],d,i,f,c+16|0,c+20|0,h,c+12|0)-1|0){case 0:break e;case 1:break b;case 2:break d;default:break c}}d=x[a+40>>2];x[d>>2]=g;x[d+4>>2]=j;if((e|0)==8){break b}d=cu(x[a+32>>2]);if((d|0)==-1){break b}v[f|0]=d;e=e+1|0;continue}break}x[c+20>>2]=v[c+24|0]}f:{if(!b){while(1){if((e|0)<=0){break f}d=-1;e=e-1|0;if((ns(v[e+(c+24|0)|0],x[a+32>>2])|0)!=-1){continue}break a}}d=x[c+20>>2];x[a+48>>2]=d;break a}d=x[c+20>>2];break a}d=-1}ib=c+32|0;return d}function Hs(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=ib+-64|0;ib=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;Qf(c+48|0,c+32|0,d);a=x[b+4>>2];d=x[a+8>>2];e=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;a:{b:{c:{d:{f=x[c+4>>2];if(f>>>0>=e>>>0){g=x[c+20>>2];if(g>>>0<e>>>0){break d}if(d>>>0>A[c+8>>2]){break c}h=x[c+28>>2];if(d>>>0>x[c+24>>2]-h>>>0){break b}i=x[c+16>>2];j=x[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}k=D(b,f);l=D(b+h|0,g);a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{B[(a+l<<2)+i>>2]=E(x[(a+k<<2)+j>>2])*E(7.450580596923828e-9);a=a+1|0;continue}}}aa(7192,8993,33,8706);p()}aa(7157,8993,34,8706);p()}aa(5900,8993,35,8706);p()}aa(5870,8993,36,8706);p()}ib=c- -64|0}function Pia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;g=ib-144|0;ib=g;Tq(a);a:{b:{if(!kg(a,64)){break b}c:{d:{if(!yl(a,60)){break d}if(!qT(a,14138)){break d}c=15;d=450;break c}Tq(a);if(!kg(a,128)){break b}b=0;if(!yl(a,124)){break a}if(!qT(a,15376)){break a}c=31;d=930}Tq(a);b=0;e:{while(1){if((b&65535)>>>0>=c>>>0){break e}b=b+1|0;if(oT(a)>>>0<=131072){continue}break}b=0;break a}gd(a,4);if(!kg(a,2)){break b}b=0;e=ib-16|0;ib=e;c=ib-16|0;ib=c;Zm(c+8|0,e+8|0);f=x[c+12>>2];ld(c,a,x[c+8>>2],x[c+12>>2]);h=x[c+4>>2];if((f|0)==(h|0)){gd(a,x[c+12>>2])}ib=c+16|0;if((f|0)==(h|0)){i=Fb(z[e+8>>1])}ib=e+16|0;if(i>>>0<178){break a}b=-1;if(!kg(a,d)){break a}gd(a,d);d=ib-16|0;ib=d;e=g+8|0;qU(d+8|0,e);c=x[d+12>>2];ld(d,a,x[d+8>>2],x[d+12>>2]);f=x[d+4>>2];if((f|0)==(c|0)){gd(a,x[d+12>>2])}ib=d+16|0;a=(c|0)==(f|0);if(!a){PA(e)}if(!a){break a}b=pT(y[g+8|0]);break a}b=-1}ib=g+144|0;return b|0}function ula(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;e=ib-32|0;ib=e;b=ib-32|0;ib=b;x[b+16>>2]=1073741824;w[b+22>>1]=12;c=mc(64);x[27524]=0;d=T(841,c|0)|0;f=x[27524];x[27524]=0;a:{b:{c:{if((f|0)!=1){c=uf(b+8|0,d);d=x[c>>2];x[27524]=0;R(842,d|0,a|0);a=x[27524];x[27524]=0;if((a|0)==1){break c}a=x[c>>2];x[27524]=0;a=W(843,a|0,b+22|0,b+16|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break c}d:{if(!a){sc(b+24|0);break d}a=x[c>>2];x[27524]=0;R(844,a|0,15);a=x[27524];x[27524]=0;if((a|0)==1){break c}ge(b+24|0,c)}yg(c);ib=b+32|0;b=x[b+24>>2];break a}a=P()|0;Ib(c);break b}a=P()|0;yg(c)}S(a|0);p()}x[e+24>>2]=b;a=0;e:{f:{g:{while(1){if((a|0)==12){break e}x[27524]=0;c=Q(1,e+8|0,(a<<2)+32192|0)|0;d=x[27524];x[27524]=0;if((d|0)!=1){x[27524]=0;U(490,b|0,a|0,c|0);d=x[27524];x[27524]=0;if((d|0)==1){break g}xb(c);a=a+1|0;continue}break}a=P()|0;break f}a=P()|0;xb(c)}yg(e+24|0);S(a|0);p()}ib=e+32|0;return b|0}function sG(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=c;while(1){a:{if(e>>>0<=i>>>0|a>>>0>=d>>>0){break a}f=1;b=v[a|0];b:{if((b|0)>=0){break b}if(b>>>0<4294967234){break a}if(b>>>0<=4294967263){if((d-a|0)<2){break a}f=2;if((y[a+1|0]&192)==128){break b}break a}g=b&255;c:{d:{if(b>>>0<=4294967279){if((d-a|0)<3){break a}h=y[a+2|0];b=y[a+1|0];if((g|0)==237){break d}if((g|0)==224){if((b&224)==160){break c}break a}if((b&192)!=128){break a}break c}if((d-a|0)<4|b>>>0>4294967284){break a}f=y[a+3|0];h=y[a+2|0];b=y[a+1|0];e:{f:{switch(g-240|0){case 0:if((b+112&255)>>>0<48){break e}break a;case 4:if((b&240)==128){break e}break a;default:break f}}if((b&192)!=128){break a}}if((h&192)!=128|(f&192)!=128){break a}f=4;if((g<<18&1835008|(b&48)<<12)>>>0>1114111){break a}break b}if((b&224)!=128){break a}}f=3;if((h&192)!=128){break a}}i=i+1|0;a=a+f|0;continue}break}return a-c|0}function hv(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=ib-560|0;ib=f;w[f+558>>1]=b;a:{if((b-256&65535)>>>0<65281){break a}e=((b<<2)+a|0)+900380|0;b=x[e>>2];b:{if(b){c=TR(f,c);d=x[c+4>>2];x[b>>2]=x[c>>2];x[b+4>>2]=d;d=y[c+11|0]|y[c+12|0]<<8|(y[c+13|0]<<16|y[c+14|0]<<24);e=y[c+7|0]|y[c+8|0]<<8|(y[c+9|0]<<16|y[c+10|0]<<24);v[b+7|0]=e;v[b+8|0]=e>>>8;v[b+9|0]=e>>>16;v[b+10|0]=e>>>24;v[b+11|0]=d;v[b+12|0]=d>>>8;v[b+13|0]=d>>>16;v[b+14|0]=d>>>24;v[b+15|0]=y[c+15|0];d=x[c+44>>2];x[b+40>>2]=x[c+40>>2];x[b+44>>2]=d;d=x[c+36>>2];x[b+32>>2]=x[c+32>>2];x[b+36>>2]=d;d=x[c+28>>2];x[b+24>>2]=x[c+24>>2];x[b+28>>2]=d;d=x[c+20>>2];x[b+16>>2]=x[c+16>>2];x[b+20>>2]=d;Yy(b+48|0,c+48|0);Yy(b+68|0,c+68|0);Yy(b+88|0,c+88|0);rc(b+108|0,c+108|0,448);d=b;wu(c);break b}b=ot(556);if(!b){x[e>>2]=0;break a}d=TR(b,c);x[e>>2]=d}g=a,h=z[pe(a+480192|0,f+558|0)>>1],w[g+480192>>1]=h}ib=f+560|0;return d|0}function Iga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=ib-16|0;ib=f;a:{b:{c:{g=x[a+12>>2];i=x[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|(g|0)==-1){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}j=x[a+16>>2];k=x[a+24>>2];l=x[a+20>>2];e=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=e;while(1){if(d){e=x[f+12>>2]+j|0;h=(x[f+8>>2]>>>16&65520)+b|0;e=(((((((D(v[e-2|0],w[h+2>>1])+D(v[e-3|0],w[h>>1])|0)+D(v[e-1|0],w[h+4>>1])|0)+D(v[e|0],w[h+6>>1])|0)+D(v[e+1|0],w[h+8>>1])|0)+D(v[e+2|0],w[h+10>>1])|0)+D(v[e+3|0],w[h+12>>1])|0)+D(v[e+4|0],w[h+14>>1])<<8)/32768|0;x[c>>2]=x[c>>2]+D(e,l);x[c+4>>2]=x[c+4>>2]+D(e,k);Pb(f+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;ib=f+16|0}function Is(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=ib+-64|0;ib=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;Qf(c+48|0,c+32|0,d);a=x[b+4>>2];d=x[a+8>>2];e=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;a:{b:{c:{d:{f=x[c+4>>2];if(f>>>0>=e>>>0){if(A[c+20>>2]<e>>>0){break d}if(d>>>0>A[c+8>>2]){break c}g=x[c+28>>2];if(d>>>0>x[c+24>>2]-g>>>0){break b}h=x[c+16>>2];i=x[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}j=b+g|0;k=D(b,f);a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{B[x[(a<<2)+h>>2]+(j<<2)>>2]=E(x[(a+k<<2)+i>>2])*E(7.450580596923828e-9);a=a+1|0;continue}}}aa(7192,8993,33,8706);p()}aa(7157,8993,34,8706);p()}aa(5900,8993,35,8706);p()}aa(5870,8993,36,8706);p()}ib=c- -64|0}function fia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;g=ib-16|0;ib=g;d=x[b>>2];e=tk(d,x[b+4>>2]);a:{if(e>>>0<c>>>0){i=ib-32|0;ib=i;f=c-e|0;e=x[Db(b)>>2];d=x[b+4>>2];b:{if(f>>>0<=e-d>>4>>>0){h=ib-16|0;ib=h;d=Wt(h,b,f);e=x[d+4>>2];f=x[d+8>>2];while(1){if((e|0)==(f|0)){ic(d);ib=h+16|0}else{Xu(e);e=e+16|0;x[d+4>>2]=e;continue}break}break b}e=Db(b);e=wS(i+8|0,xS(b,tk(x[b>>2],d)+f|0),tk(x[b>>2],x[b+4>>2]),e);d=ib-16|0;ib=d;x[d>>2]=x[e+8>>2];h=x[e+8>>2];x[d+8>>2]=e+8;x[d+4>>2]=h+(f<<4);f=x[d>>2];while(1){if(x[d+4>>2]!=(f|0)){Xu(f);f=x[d>>2]+16|0;x[d>>2]=f;continue}break}Vd(d);ib=d+16|0;Dd(b,e);d=x[e+4>>2];f=x[e+8>>2];while(1){if((d|0)!=(f|0)){f=f-16|0;x[e+8>>2]=f;continue}break}d=x[e>>2];if(d){ep(e);Ib(d)}}ib=i+32|0;break a}if(c>>>0<e>>>0){Od(b,d+(c<<4)|0)}}if(Ob(x[a>>2],x[a+8>>2],c<<4)){c=x[b>>2];cc(g+8|0,c,tk(c,x[b+4>>2])<<4);sd(g,a,x[g+8>>2],x[g+12>>2])}ib=g+16|0}function ica(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{g=b;c=ib-16|0;ib=c;d=Kb(a);while(1){b:{c:{d:{if(Eb(g)>>>0>f>>>0){b=x[Hi(g,f)>>2];if(b>>>0>=2097152){x[27524]=0;R(925,d|0,63);a=x[27524];x[27524]=0;if((a|0)!=1){break c}break b}a=0;while(1){if((a|0)==6){b=7;a=6;break d}e=b&63;v[(c+10|0)+a|0]=e;if(b>>>0>=64){a=a+1|0;b=b>>>6|0;continue}break}if(a){b=a+1|0;if((b|0)!=2){break d}a=1;b=2;if((e|0)!=1){break d}a=y[c+10|0]|64}else{a=y[c+10|0]}x[27524]=0;R(925,d|0,a<<24>>24);a=x[27524];x[27524]=0;if((a|0)!=1){break c}break b}ib=c+16|0;break a}i=(-1<<b^-1)<<7-a;e=b-1|0;j=e+(c+10|0)|0;a=b;while(1){if(!a){break c}e:{if((a|0)==(b|0)){a=y[j|0];x[27524]=0;R(925,d|0,(a|i)<<24>>24);h=x[27524];x[27524]=0;a=e;break e}x[27524]=0;a=a-1|0;R(925,d|0,v[a+(c+10|0)|0]|-128);h=x[27524];x[27524]=0}if((h|0)!=1){continue}break}break b}f=f+1|0;continue}break}a=P()|0;xb(d);S(a|0);p()}}function bZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=ib-96|0;ib=d;yc(b);ap(a);a:{if(!Rv(b,d+56|0)){break a}if(!RD(d+56|0)){break a}b:{if(!c){break b}if(!Ob(x[b>>2],x[b+8>>2],ac(x[d+60>>2])-28|0)){break a}ew(a);g=d,h=dw(),x[g+32>>2]=h;e=d+32|0;cw(_j(x[a+4>>2])+32|0,e);Ar(e);c=x[_j(x[a+4>>2])+32>>2];x[27524]=0;R(195,e|0,b|0);b=x[27524];x[27524]=0;c:{if((b|0)==1){break c}b=x[d+32>>2];e=x[d+60>>2];f=x[d+68>>2];x[27524]=0;b=fa(196,b|0,ac(e)-28|0,c|0,ac(f)|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break c}e=0;if(!b){break a}he(d+16|0,x[c>>2],x[c+4>>2]);lg(d+24|0,x[d+16>>2],x[d+20>>2]);b=Id(d+8|0);c=x[b+4>>2];x[d>>2]=x[b>>2];x[d+4>>2]=c;b=yr(d+32|0,x[d+24>>2],x[d+28>>2],d);fd(_j(x[a+4>>2])+12|0,b);yb(b);break b}a=Ba(108196,26072)|0;b=jb;d:{if((da(108196)|0)==(b|0)){break d}if((da(26072)|0)==(b|0)){break d}S(a|0);p()}_(a|0)|0;$();e=0;break a}e=1}ib=d+96|0;return e|0}function Kfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=ib-16|0;ib=e;x[e+12>>2]=1;a:{if(oo(a)){c=x[a>>2];j=xg(c,x[a+4>>2]);x[e+8>>2]=j;k=x[Hb(e+12|0,e+8|0)>>2];while(1){if(k){k=k-1|0;if((b|0)!=(c|0)){f=Cb(x[b>>2]);g=Cb(x[b+4>>2]);d=ib-16|0;ib=d;h=nC(f,g);b:{if(h>>>0<=_m(c)>>>0){x[d+8>>2]=g;l=x[c>>2];i=Oc(l,x[c+4>>2]);m=i>>>0>=h>>>0;if(m){i=g}else{x[d+8>>2]=f;KR(d+8|0,i);i=x[d+8>>2]}f=ji(f,i,l);if(!m){MR(c,x[d+8>>2],g,h-Oc(x[c>>2],x[c+4>>2])|0);break b}Od(c,f);break b}LR(c);sq(c,Vj(c,h));MR(c,f,g,h)}ib=d+16|0;cp(c+12|0,b+12|0);w[c+28>>1]=z[b+28>>1]}c=c+32|0;continue}break}if(!j){eA(a,1-j|0,b);break a}BR(a,x[a>>2]+32|0);break a}if(x[a>>2]){ER(a);c=x[a>>2];oo(a);Ib(c);n=Db(a),o=0,x[n>>2]=o;x[a>>2]=0;x[a+4>>2]=0}c=oq(a,1);if(zh(134217727)>>>0<c>>>0){_c();p()}d=rS(c);x[a>>2]=d;x[a+4>>2]=d;n=Db(a),o=d+(c<<5)|0,x[n>>2]=o;eA(a,1,b)}ib=e+16|0}function GE(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;g=ib-32|0;ib=g;f=d&2147483647;e=f-1065418752|0;h=f-1082064896|0;a:{if((e|0)==(h|0)&0|e>>>0<h>>>0){f=(d&33554431)<<7|c>>>25;e=0;i=e;h=c&33554431;if(!(!e&(h|0)==16777216?!(a|b):!e&h>>>0<16777216)){e=f+1073741825|0;break a}e=f+1073741824|0;if(h^16777216|a|(b|i)){break a}e=(f&1)+e|0;break a}if(!(!c&(f|0)==2147418112?!(a|b):f>>>0<2147418112)){e=((d&33554431)<<7|c>>>25)&4194303|2143289344;break a}e=2139095040;if(f>>>0>1082064895){break a}e=0;f=f>>>16|0;if(f>>>0<16145){break a}e=d&65535|65536;Sf(g+16|0,a,b,c,e,f-16129|0);xm(g,a,b,c,e,16257-f|0);b=x[g+8>>2];e=(x[g+12>>2]&33554431)<<7|b>>>25;h=x[g>>2]|(x[g+16>>2]|x[g+24>>2]|(x[g+20>>2]|x[g+28>>2]))!=0;f=x[g+4>>2];a=0;b=b&33554431;if(!(!a&(b|0)==16777216?!(h|f):!a&b>>>0<16777216)){e=e+1|0;break a}if(b^16777216|h|(a|f)){break a}e=(e&1)+e|0}ib=g+32|0;return l(2,d&-2147483648|e),r()}function rka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=ib-16|0;ib=e;w[e+12>>1]=0;x[e+8>>2]=0;n=D(c,d);k=4;a:while(1){if((d|0)!=(l|0)){i=b+l|0;o=n+i|0;while(1){b:{c:{if(i>>>0<o>>>0){v[e+7|0]=0;GU(a,e+15|0,e+12|0,e+7|0);g=y[e+7|0];f=z[e+12>>1];c=k;while(1){if(c&255){h=f<<1;f=h&254;d:{if(f){h=(h&65534)>>>0>255;break d}if(!vf(a,e+6|0)){break c}f=y[e+6|0];h=f>>>7|0;f=f<<1&254|1}c=c-1|0;g=g<<1|h;continue}break}w[e+12>>1]=f;break b}l=l+1|0;continue a}w[e+12>>1]=0}c=1;h=g&255;e:{if(h>>>0<4){break e}f=7;while(1){c=f;m=f&255;if(h>>>m&1){break e}f=c-1|0;if(m>>>0>1){continue}break}}f=g&1;v[e+15|0]=f;g=f-1^(g&254)>>>1;f=g+y[e+8|0]|0;v[e+7|0]=f;v[i|0]=f;x[e+8>>2]=((g>>1)-(j<<24>>24)|0)+(f<<24>>24<<1);i=d+i|0;k=(c+k&254)>>>1|0;c=-128;j=x[e+8>>2];f:{if((j|0)>=-128){c=127;if((j|0)<128){break f}}x[e+8>>2]=c}j=f;continue}}break}ib=e+16|0}function pga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=ib-16|0;ib=e;g=x[a+24>>2];h=x[a+20>>2];i=x[a+16>>2];f=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=f;j=b+24|0;k=x[a+8>>2];l=x[a+12>>2];while(1){if(d){f=x[e+8>>2];m=((((x[e+12>>2]&2147483647)<<1|f>>>31)&2147483646)<<1)+i|0;b=(((f>>>16|0)+4&131064)<<1)+j|0;n=w[b+14>>1];o=w[b+12>>1];p=w[b+10>>1];q=w[b+8>>1];r=w[b+6>>1];s=w[b+4>>1];t=w[b+2>>1];u=w[b>>1];f=0;while(1){if((f|0)!=2){b=(f<<1)+m|0;x[(f<<2)+e>>2]=(((((D(w[b+8>>1],p)+D(w[b+4>>1],q)|0)+D(w[b+12>>1],o)|0)+D(w[b+16>>1],n)|0)/2|0)+((((D(w[b-8>>1],t)+D(w[b-12>>1],u)|0)+D(w[b-4>>1],s)|0)+D(w[b>>1],r)|0)/2|0)|0)/16384;f=f+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[e>>2],h);x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],g);Pb(e+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;ib=e+16|0}function Maa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=E(0),m=0,n=0,o=E(0),p=E(0),q=E(0),r=E(0),s=E(0),t=E(0),u=E(0),v=E(0),w=E(0);h=ib-16|0;ib=h;if(fi(a+44|0)){f=x[a+44>>2];g=Hc(f,0);x[h+8>>2]=g;f=Hc(f,1);x[h+12>>2]=f;j=x[a+56>>2];m=Hc(j,0);x[h>>2]=m;j=Hc(j,1);x[h+4>>2]=j;a:{if(B[Bb(a+4208|0,2)>>2]!=E(.5)){f=d;b:while(1){g=0;if(!f){break a}while(1)if((g|0)==2){f=f-1|0;continue b}else{k=g<<2;e=k+(h+8|0)|0;i=x[e>>2];x[e>>2]=i+4;e=a+k|0;n=e+4248|0;q=B[n>>2];l=B[i>>2];r=B[a+4236>>2];s=B[a+4232>>2];t=B[a+4228>>2];u=B[a+4220>>2];v=B[a+4224>>2];i=e+4240|0;o=B[i>>2];B[n>>2]=o;B[i>>2]=l;i=e+4264|0;w=B[i>>2];e=e+4256|0;p=B[e>>2];B[i>>2]=p;l=E(E(E(E(t*q)+E(E(u*l)+E(v*o)))-E(s*p))-E(r*w));B[e>>2]=l;k=h+k|0;e=x[k>>2];x[k>>2]=e+4;B[e>>2]=l;g=g+1|0;continue}}}e=g;g=d<<2;rc(m,e,g);rc(j,f,g);f=x[a+56>>2];m=Hc(f,0);j=Hc(f,1)}zi(a,b,c,m,j,d)}ib=h+16|0}function Fia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=x[a>>2];c=wd(d,x[a+4>>2]);if(c>>>0<b>>>0){f=ib-32|0;ib=f;c=b-c|0;b=x[Db(a)>>2];d=x[a+4>>2];a:{if(c>>>0<=(b-d|0)/12>>>0){d=ib-16|0;ib=d;b=hu(d,a,c);a=x[b+4>>2];c=x[b+8>>2];while(1){if((a|0)==(c|0)){ic(b);ib=d+16|0}else{US(a);a=a+12|0;x[b+4>>2]=a;continue}break}break a}b=Db(a);b=Pk(f+8|0,on(a,wd(x[a>>2],d)+c|0),wd(x[a>>2],x[a+4>>2]),b);e=ib-16|0;ib=e;d=TS(e,b+8|0,c);c=x[d>>2];while(1){if(x[d+4>>2]!=(c|0)){US(c);c=x[d>>2]+12|0;x[d>>2]=c;continue}break}Vd(d);ib=e+16|0;e=x[a>>2];c=x[a+4>>2];d=b+4|0;while(1){if((c|0)!=(e|0)){c=c-12|0;SS(x[d>>2]-12|0,c);x[d>>2]=x[d>>2]-12;continue}break}oc(a,d);oc(a+4|0,b+8|0);oc(Db(a),zc(b));x[b>>2]=x[b+4>>2];a=x[b+4>>2];while(1){c=x[b+8>>2];if((c|0)!=(a|0)){c=c-12|0;x[b+8>>2]=c;VS(c);continue}break}a=x[b>>2];if(a){ep(b);Ib(a)}}ib=f+32|0;return}if(b>>>0<c>>>0){WS(a,d+D(b,12)|0)}}function Rea(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=ib-16|0;ib=f;b=x[a+4>>2];if(Qd(y[b+223884|0])){sQ(b+223860|0);b=x[a+4>>2]}x[a+24>>2]=0;x[a+28>>2]=0;x[b>>2]=0;c=x[a>>2];x[b+40>>2]=x[c+480196>>2];x[b+44>>2]=x[c+480204>>2];x[b+80>>2]=x[c+480200>>2];c=z[c+480188>>1];x[f+8>>2]=0;x[f+12>>2]=0;d=f+8|0;w[d+4>>1]=65280;x[d>>2]=0;e=ib-16|0;ib=e;x[e+12>>2]=c;b=a+8|0;a:{if(mn(b)>>>0>=c>>>0){g=x[b>>2];h=ah(g,x[b+4>>2]);x[e+8>>2]=h;i=x[Hb(e+12|0,e+8|0)>>2];while(1){if(i){x[g>>2]=x[d>>2];w[g+4>>1]=z[d+4>>1];i=i-1|0;g=g+8|0;continue}break}if(c>>>0>h>>>0){FP(b,c-h|0,d);break a}Od(b,x[b>>2]+(c<<3)|0);break a}OQ(b);Vz(b,xr(b,c));FP(b,c,d)}ib=e+16|0;b=0;while(1){c=x[a>>2];if(z[c+480188>>1]<=b>>>0){ib=f+16|0}else{d=D(b,872);io((d+x[a+4>>2]|0)+616|0,c,b&65535,134217728);c=d+x[a+4>>2]|0;w[c+1432>>1]=0;v[c+1418|0]=0;v[c+1415|0]=0;v[c+1413|0]=0;b=b+1|0;continue}break}}function Ada(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=x[a>>2];d=Fk(e,x[a+4>>2]);if(d>>>0<b>>>0){h=ib-32|0;ib=h;a:{b:{e=b-d|0;b=x[Db(a)>>2];f=x[a+4>>2];c:{if(e>>>0<=(b-f|0)/52>>>0){Dy(a,e,c);break c}d=Db(a);f=$N(a,Fk(x[a>>2],f)+e|0);g=Fk(x[a>>2],x[a+4>>2]);b=h+8|0;tg(b+12|0,d);if(f){d=_N(f)}else{d=0}x[b>>2]=d;g=d+D(g,52)|0;x[b+8>>2]=g;x[b+4>>2]=g;i=zc(b),j=d+D(f,52)|0,x[i>>2]=j;x[27524]=0;U(885,b|0,e|0,c|0);c=x[27524];x[27524]=0;if((c|0)==1){break b}f=x[a>>2];c=x[a+4>>2];e=b+4|0;while(1){if((c|0)!=(f|0)){c=c-52|0;d=xl(x[e>>2]-52|0,c);x[d+20>>2]=x[c+20>>2];g=x[c+16>>2];x[d+12>>2]=x[c+12>>2];x[d+16>>2]=g;SS(d+24|0,c+24|0);$c(d+36|0,c+36|0);x[d+48>>2]=x[c+48>>2];x[e>>2]=x[e>>2]-52;continue}break}oc(a,e);oc(a+4|0,b+8|0);oc(Db(a),zc(b));x[b>>2]=x[b+4>>2];ZN(b)}ib=h+32|0;break a}a=P()|0;ZN(b);S(a|0);p()}return}if(b>>>0<d>>>0){aO(a,e+D(b,52)|0)}}function lP(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{g=b;c=ib-16|0;ib=c;d=Kb(a);while(1){b:{c:{d:{if(Eb(g)>>>0>f>>>0){b=x[Hi(g,f)>>2];if(b>>>0>=2097152){x[27524]=0;R(51,d|0,63);a=x[27524];x[27524]=0;if((a|0)!=1){break c}break b}a=0;while(1){if((a|0)==6){b=7;a=6;break d}e=b&63;v[(c+10|0)+a|0]=e;if(b>>>0>=64){a=a+1|0;b=b>>>6|0;continue}break}if(a){b=a+1|0;if((b|0)!=2){break d}a=1;b=2;if((e|0)!=1){break d}a=y[c+10|0]|64}else{a=y[c+10|0]}x[27524]=0;R(51,d|0,a&255);a=x[27524];x[27524]=0;if((a|0)!=1){break c}break b}ib=c+16|0;break a}i=(-1<<b^-1)<<7-a;e=b-1|0;j=e+(c+10|0)|0;a=b;while(1){if(!a){break c}e:{if((a|0)==(b|0)){a=y[j|0];x[27524]=0;R(51,d|0,a|i&255);h=x[27524];x[27524]=0;a=e;break e}x[27524]=0;a=a-1|0;R(51,d|0,y[a+(c+10|0)|0]|128);h=x[27524];x[27524]=0}if((h|0)!=1){continue}break}break b}f=f+1|0;continue}break}a=P()|0;xb(d);S(a|0);p()}}function Qw(a,b,c,d,e,f,g,h,i,j,k,l){a:{b:{if((a|0)==(f|0)){if(!y[b|0]){break a}f=0;v[b|0]=0;a=x[e>>2];x[e>>2]=a+1;v[a|0]=46;if(!Eb(h)){break b}a=x[j>>2];if((a-i|0)>159){break b}b=x[k>>2];x[j>>2]=a+4;x[a>>2]=b;return 0}c:{if((a|0)!=(g|0)){break c}if(!Eb(h)){break c}if(!y[b|0]){break a}f=0;a=x[j>>2];if((a-i|0)>159){break b}b=x[k>>2];x[j>>2]=a+4;x[a>>2]=b;x[k>>2]=0;return 0}f=-1;a=Sw(l,l+128|0,a)-l|0;if((a|0)>124){break b}g=y[(a>>2)+98224|0];d:{e:{f=a&-5;if((f|0)!=88){if((f|0)!=96){break e}a=x[e>>2];if((a|0)!=(d|0)){f=-1;if((y[a-1|0]&95)!=(y[c|0]&127)){break b}}x[e>>2]=a+1;v[a|0]=g;return 0}v[c|0]=80;break d}d=g&95;if((d|0)!=y[c|0]){break d}v[c|0]=d|128;if(!y[b|0]){break d}v[b|0]=0;if(!Eb(h)){break d}b=x[j>>2];if((b-i|0)>159){break d}c=x[k>>2];x[j>>2]=b+4;x[b>>2]=c}b=x[e>>2];x[e>>2]=b+1;v[b|0]=g;f=0;if((a|0)>84){break b}x[k>>2]=x[k>>2]+1}return f}return-1}function _4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=ib+-64|0;ib=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;Qf(c+48|0,c+32|0,d);a=x[b+4>>2];d=x[a+8>>2];e=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;a:{b:{c:{d:{f=x[c+4>>2];if(f>>>0>=e>>>0){g=x[c+20>>2];if(g>>>0<e>>>0){break d}if(d>>>0>A[c+8>>2]){break c}h=x[c+28>>2];if(d>>>0>x[c+24>>2]-h>>>0){break b}i=x[c+16>>2];j=x[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}k=D(b,f);l=D(b+h|0,g);a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{B[(a+l<<2)+i>>2]=C[(a+k<<3)+j>>3];a=a+1|0;continue}}}aa(7192,8993,77,8673);p()}aa(7157,8993,78,8673);p()}aa(5900,8993,79,8673);p()}aa(5870,8993,80,8673);p()}ib=c- -64|0}function UA(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;i=ib-32|0;ib=i;sU(a,b);h=ib-16|0;ib=h;md(c,1);g=Fb(y[b+22|0]|y[b+23|0]<<8)<<1;x[c>>2]=g;v[c+37|0]=y[b+24|0]<<4;v[h+15|0]=y[b+25|0];v[h+14|0]=64;l=c,m=y[Ub(h+15|0,h+14|0)|0]<<2,w[l+30>>1]=m;f=Fb(y[b+26|0]|y[b+27|0]<<8);a=f<<1;k=Fb(y[b+28|0]|y[b+29|0]<<8);j=k<<1;a=k>>>0>=2?a+j>>>0<=g>>>0?a:f+j>>>0>g>>>0?a:f:a;a:{b:{switch(g|0){case 2:x[c>>2]=0;break a;case 0:break a;default:break b}}x[c+4>>2]=a;f=a+j|0;x[c+8>>2]=f;if(a>>>0>=g>>>0){a=g-1|0;x[c+4>>2]=a}if(!(!(f>>>0<4|a>>>0>f>>>0)&f-a>>>0>3)){x[c+4>>2]=0;x[c+8>>2]=0;f=0;a=0}if(!(f>>>0>8|a|(!e|f>>>0>=g>>>0))){x[c+8>>2]=0;break a}if(a>>>0>=f>>>0){break a}w[c+34>>1]=z[c+34>>1]|2}ib=h+16|0;Ll(i,3,b);a=i+16|0;Fc(a,i);c=Cc(d,a);wb(a);a=0;while(1){if((a|0)!=32){d=a+c|0;if((y[d|0]-1&255)>>>0<=30){v[d|0]=32}a=a+1|0;continue}break}a=XA(b);ib=i+32|0;return a}function CF(a,b,c,d,e,f,g,h){var i=0,j=0,k=E(0);i=ib-96|0;ib=i;Wy(x[a+24>>2]);v[x[a+24>>2]+1298424|0]=x[a+52>>2]!=0;x[i+92>>2]=f;x[i+88>>2]=e;x[i+84>>2]=d;x[i+80>>2]=c;a:{d=i+80|0;c=0;while(1){b:{if((c|0)!=4){if(x[(c<<2)+d>>2]){break b}}else{c=4}break a}c=c+1|0;continue}}x[i+40>>2]=b;x[i+36>>2]=c;x[i+32>>2]=d;e=x[a+32>>2];k=B[a+48>>2];x[i+8>>2]=b;c=x[i+36>>2];x[i>>2]=x[i+32>>2];x[i+4>>2]=c;d=ib-16|0;ib=d;x[d+8>>2]=x[i+8>>2];c=x[i+4>>2];x[d>>2]=x[i>>2];x[d+4>>2]=c;c=FJ(i+48|0);x[c+8>>2]=e;x[c+4>>2]=0;x[c>>2]=h;e=x[d+4>>2];x[c+12>>2]=x[d>>2];x[c+16>>2]=e;x[c+20>>2]=x[d+8>>2];B[c+24>>2]=k;x[c>>2]=g;ib=d+16|0;while(1){if(b){d=x[a+24>>2];x[i+24>>2]=b;x[i+28>>2]=0;x[i+16>>2]=134217727;x[i+20>>2]=0;d=HJ(d,x[hr(i+24|0,i+16|0)>>2],c);j=d+j|0;b=b-d|0;if(d){continue}}break}if(!(x[a+52>>2]!=1|j)){a=x[a+24>>2];x[a+480208>>2]=x[a+480208>>2]&-513}ib=i+96|0;return j}function WX(a,b,c){var d=0,e=0;e=ib-16|0;ib=e;v[e+15|0]=c;a:{if(b>>>0>35){break a}b:{c:{d:{e:{f:{g:{h:{d=y[b+26304|0];switch(d-6|0){case 2:case 3:case 4:case 6:case 7:case 9:case 10:case 12:break a;case 11:break c;case 13:break d;case 0:case 1:case 5:break f;case 8:break g;default:break h}}if((d|0)==31){break b}if((d|0)==23){break e}if((d|0)!=1){break a}d=(c|0)!=0;break a}v[e+15|0]=D(c>>>4|0,10)+(c&15);d=14;break a}b=c&240;if(!b|(b|0)==240|(c&15)==15){break a}v[e+15|0]=b;break a}if(c>>>0<=64){v[e+15|0]=c<<1;d=23;break a}v[e+15|0]=128;d=23;break a}d=19;i:{switch((c&240)-48>>>4|0){case 0:v[e+15|0]=159;d=20;break a;case 1:v[e+15|0]=192;d=20;break a;case 2:if(c&14){break a}v[e+15|0]=((c|0)!=80)<<6;d=21;break a;case 4:break i;default:break a}}v[e+15|0]=c&15|160;d=20;break a}d=c>>>0<32?16:17;break a}v[e+15|0]=(b<<5|c>>>3)^128;d=31}fe(a,d,e+15|0);ib=e+16|0}function lm(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;dl(a);a:{b:{c:{f=x[b+32>>2];d:{if(!f){e=x[b+2084>>2];if(e){break d}break b}c=x[b+4>>2];if((c|0)<9){break c}e=x[b+2084>>2];if(!e){break c}}h=x[a+1392>>2];j=km(h);d=x[b+2092>>2];c=0;while(1){if((d|0)>=2){f=d>>>1|0;i=f+c|0;g=A[(i<<2)+e>>2]>j>>>0;d=g?f:d-f|0;c=g?c:i;continue}break}d=x[a+1396>>2];c=y[b+23|0]?c:x[x[b+2088>>2]+(c<<2)>>2];b=y[c+x[b+8>>2]|0];e:{if((d|0)<(b|0)){c=-1;b=0;break e}x[a+1392>>2]=h>>>b;b=d-b|0}x[a+1396>>2]=b;return c}if(y[b+23|0]){break a}e=(c|0)>0?c:0;while(1){if((d|0)!=(e|0)){f:{c=y[x[b+8>>2]+d|0];if((c|0)==255){break f}g=x[a+1392>>2];if(x[f+(d<<2)>>2]!=(g&(-1<<c^-1))){break f}e=x[a+1396>>2];if((e|0)>=(c|0)){x[a+1392>>2]=g>>>c;x[a+1396>>2]=e-y[x[b+8>>2]+d|0];return d}x[a+1396>>2]=0;break b}d=d+1|0;continue}break}fc(a,21);x[a+1396>>2]=0}return-1}aa(11274,13154,1705,5448);p()}function j5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=ib+-64|0;ib=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;Qf(c+48|0,c+32|0,d);a=x[b+4>>2];d=x[a+8>>2];e=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;a:{b:{c:{d:{f=x[c+4>>2];if(f>>>0>=e>>>0){if(A[c+20>>2]<e>>>0){break d}if(d>>>0>A[c+8>>2]){break c}g=x[c+28>>2];if(d>>>0>x[c+24>>2]-g>>>0){break b}h=x[c+16>>2];i=x[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}j=b+g|0;k=D(b,f);a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{B[x[(a<<2)+h>>2]+(j<<2)>>2]=C[(a+k<<3)+i>>3];a=a+1|0;continue}}}aa(7192,8993,77,8673);p()}aa(7157,8993,78,8673);p()}aa(5900,8993,79,8673);p()}aa(5870,8993,80,8673);p()}ib=c- -64|0}function cY(a){var b=0,c=0,d=0,e=0,f=0,g=0;if((y[a|0]-16&255)>>>0>=241){e=a+1954|0;c=a+1698|0;a:{b:{while(1){if((c|0)==(e|0)){c=0;e=0;while(1){b=32;if((c|0)==32){break a}d=D(c,13)+a|0;if(y[d+14|0]){break b}b=(c<<4)+a|0;if(y[b+418|0]|y[b+419|0]<<8|(y[b+420|0]<<16|y[b+421|0]<<24)){break b}f=y[b+422|0]|y[b+423|0]<<8|(y[b+424|0]<<16|y[b+425|0]<<24);if(y[d+942|0]|f>>>0>1048575){break b}d=D(c,11)+a|0;g=d+1346|0;if(y[g|0]>15|y[d+1351|0]>3|y[d+1356|0]>3){break b}c:{d:{e:{if(f){d=y[b+430|0]|y[b+431|0]<<8|(y[b+432|0]<<16|y[b+433|0]<<24);if(d>>>0<=1048574&(d>>>0<(y[b+426|0]|y[b+427|0]<<8|(y[b+428|0]<<16|y[b+429|0]<<24))>>>0|d>>>0>f>>>0)){break b}b=1;if(e){break c}if(f){break d}break e}b=1;if(e){break c}}if(Qb(g,26269,11)){break d}b=0;break c}b=1}e=b;c=c+1|0;continue}}b=v[c|0];c=c+1|0;if((b|0)>=-1){continue}break}return 0}b=c}a=b>>>0>31&e}else{a=0}return a}function f_(){var a=0,b=0,c=0,d=0;c=ib-32|0;ib=c;a:{a=Kc(c+16|0,15021);if(!Eb(a)){break a}b:{if((Lg(a,14644)|0)!=-1){b=Lg(a,14644);x[27524]=0;X(134,c|0,a|0,b+1|0,-1);b=x[27524];x[27524]=0;if((b|0)==1){break b}Ac(a,c);wb(c)}if((Lg(a,16776)|0)!=-1){b=Lg(a,16776);x[27524]=0;X(134,c|0,a|0,b+1|0,-1);b=x[27524];x[27524]=0;if((b|0)==1){break b}Ac(a,c);wb(c)}if((Lg(a,13857)|0)!=-1){b=Lg(a,13857);x[27524]=0;X(134,c|0,a|0,0,b|0);b=x[27524];x[27524]=0;if((b|0)==1){break b}Ac(a,c);wb(c)}if((Lg(a,13706)|0)!=-1){b=Lg(a,13706);x[27524]=0;X(134,c|0,a|0,0,b|0);b=x[27524];x[27524]=0;if((b|0)==1){break b}Ac(a,c);wb(c)}if((Lg(a,13749)|0)!=-1){b=Lg(a,13749);x[27524]=0;X(134,c|0,a|0,0,b|0);b=x[27524];x[27524]=0;if((b|0)==1){break b}Ac(a,c);wb(c)}x[27524]=0;b=T(135,a|0)|0;d=x[27524];x[27524]=0;if((d|0)!=1){break a}}c=P()|0;wb(a);S(c|0);p()}wb(a);ib=c+32|0;return b|0}function $w(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=a;a:{if(b&3){while(1){c=y[b|0];if(!c|(c|0)==61){break a}b=b+1|0;if(b&3){continue}break}}c=x[b>>2];b:{if((c^-1)&c-16843009&-2139062144){break b}while(1){if((c^1027423549)-16843009&(c^-1)&-2139062144){break b}c=x[b+4>>2];b=b+4|0;if(!(c-16843009&(c^-1)&-2139062144)){continue}break}}while(1){c=b;e=y[b|0];if((e|0)!=61){b=c+1|0;if(e){continue}}break}b=c}if((a|0)==(b|0)){return 0}g=b-a|0;c:{if(y[g+a|0]){break c}f=x[120814];if(!f){break c}b=x[f>>2];if(!b){break c}while(1){d:{c=a;e=b;i=0;h=g;d=0;e:{if(!g){break e}d=y[c|0];f:{if(!d){break f}while(1){g:{j=y[e|0];if(!j){break g}h=h-1|0;if(!h|(d|0)!=(j|0)){break g}e=e+1|0;d=y[c+1|0];c=c+1|0;if(d){continue}break f}break}i=d}d=(i&255)-y[e|0]|0}if(!d){b=b+g|0;if(y[b|0]==61){break d}}b=x[f+4>>2];f=f+4|0;if(b){continue}break c}break}k=b+1|0}return k}function yR(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;g=ib-16|0;ib=g;b=x[a>>2];Wb(g+8|0,b);a:{b:{c:{d:{e:{if(Ed(x[b+16>>2])){while(1){if(c>>>0>31){break e}x[27524]=0;d=ga(43)|0;e=x[27524];x[27524]=0;if((e|0)!=1){f=d|f;c=c+32|0;continue}break}c=V(108780)|0;if((jb|0)!=(da(108780)|0)){break c}_(c|0)|0;v[b+20|0]=0;x[27524]=0;Y(31,b|0);c=x[27524];x[27524]=0;if((c|0)==1){break d}$();break e}v[b+20|0]=0}if(!y[b+20|0]){d=x[b+24>>2];b=0;c=1;while(1){if(c){c=0;b=x[d+2496>>2];e=d+(b<<2)|0;i=x[d+((b+397>>>0)%624<<2)>>2];h=(b+1>>>0)%624|0;b=x[d+(h<<2)>>2];b=i^(b&2147483647|x[e>>2]&-2147483648)>>>1^0-(b&1)&-1727483681;x[e>>2]=b;x[d+2496>>2]=h;b=b^b>>>11;b=b<<7&-1658038656^b;b=b<<15&-272236544^b;b=b>>>18^b;continue}break}f=b^f}ib=g+16|0;break a}c=P()|0;x[27524]=0;Z(18);a=x[27524];x[27524]=0;if((a|0)==1){break b}}S(c|0);p()}V(0)|0;Sb();p()}return x[a+28>>2]&f}function em(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=ib-16|0;ib=d;x[a+4>>2]=0;if(Qd(y[jm(d+8|0,a,1)|0])){a:{b:{c:{if((b|0)==2147483647){while(1){b=x[(x[x[a>>2]-12>>2]+a|0)+24>>2];x[27524]=0;b=T(108,b|0)|0;c=x[27524];x[27524]=0;d:{if((c|0)!=1){if(!pc(b,-1)){break d}break b}break c}x[a+4>>2]=x[a+4>>2]+1;continue}}if(x[a+4>>2]>=(b|0)){break a}e:{while(1){c=x[(x[x[a>>2]-12>>2]+a|0)+24>>2];x[27524]=0;c=T(108,c|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break e}if(pc(c,-1)){break b}c=x[a+4>>2]+1|0;x[a+4>>2]=c;if((b|0)>(c|0)){continue}break}c=0;break a}}_(V(0)|0)|0;c=1;hm(x[x[a>>2]-12>>2]+a|0,1);f:{g:{if(x[(x[x[a>>2]-12>>2]+a|0)+20>>2]&1){x[27524]=0;Z(109);a=x[27524];x[27524]=0;if((a|0)!=1){break f}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)==1){break g}S(a|0);p()}$();break a}V(0)|0;Sb()}p()}c=2}Kj(x[x[a>>2]-12>>2]+a|0,c)}ib=d+16|0;return a|0}function qga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=ib-16|0;ib=e;g=x[a+24>>2];h=x[a+20>>2];i=x[a+16>>2];f=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=f;j=b+24|0;k=x[a+8>>2];l=x[a+12>>2];while(1){if(d){f=x[e+8>>2];m=(((x[e+12>>2]&2147483647)<<1|f>>>31)&-2)+i|0;b=(((f>>>16|0)+4&131064)<<1)+j|0;n=w[b+14>>1];o=w[b+12>>1];p=w[b+10>>1];q=w[b+8>>1];r=w[b+6>>1];s=w[b+4>>1];t=w[b+2>>1];u=w[b>>1];f=0;while(1){if((f|0)!=2){b=f+m|0;x[(f<<2)+e>>2]=(((((D(v[b+4|0],p)+D(v[b+2|0],q)|0)+D(v[b+6|0],o)|0)+D(v[b+8|0],n)<<8)/2|0)+((((D(v[b-4|0],t)+D(v[b-6|0],u)|0)+D(v[b-2|0],s)|0)+D(v[b|0],r)<<8)/2|0)|0)/16384;f=f+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[e>>2],h);x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],g);Pb(e+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;ib=e+16|0}function Qha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=ib-32|0;ib=g;d=ib-16|0;ib=d;c=a+33|0;x[b>>2]=y[c+206|0]|y[c+207|0]<<8;nO(c,b+48|0,y[c+192|0],y[c+200|0],y[c+194|0],y[c+195|0],y[c+196|0],0);nO(c,b+68|0,y[c+193|0],y[c+201|0],y[c+197|0],y[c+198|0],y[c+199|0],1);f=b+236|0;while(1){if((e|0)==96){if(y[c+208|0]){v[b+31|0]=y[c+209|0]+1;f=y[b+31|0];a:{b:{if(!f){e=1;break b}e=16;if(f>>>0<17){break a}}v[b+31|0]=e}w[d+14>>1]=y[c+210|0]|y[c+211|0]<<8;w[d+12>>1]=127;i=b,j=y[Tc(d+14|0,d+12|0)|0]+1|0,v[i+30|0]=j}v[b+33|0]=y[c+212|0];ib=d+16|0}else{i=bc(f,e+12|0),j=y[c+e|0],w[i>>1]=j;e=e+1|0;continue}break}e=b+236|0;while(1){if((h|0)!=96){f=bc(e,h+12|0);d=y[c+h|0];w[f>>1]=d>>>0<(y[a+27|0]|y[a+28|0]<<8)>>>0?d:0;h=h+1|0;continue}break}Ll(g,3,a+4|0);c=g+16|0;Fc(c,g);Cc(b+492|0,c);wb(c);if(!y[a+241|0]){v[b+30|0]=y[a+26|0]}ib=g+32|0}function GS(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=ib-16|0;ib=f;n=x[a+20>>2];g=z[a+34>>1]&65;x[f+8>>2]=g;x[f>>2]=g^65;g=b;i=a+24|0;o=d+1298224|0;e=d+1074992|0;j=sj(d);p=a+4|0;q=a+12|0;r=a+8|0;s=a+16|0;t=d+480180|0;while(1){if((e|0)!=(o|0)){if(x[e+104>>2]==(a|0)){if(x[e+16>>2]){x[e+16>>2]=g}if(A[e+4>>2]>c>>>0){x[e>>2]=0;x[e+4>>2]=0}b=a;if(x[e+76>>2]){wc(e+76|0,c);b=x[e+104>>2]}d=x[e+88>>2];b=LD(d,b);h=x[(b?q:p)>>2];x[e+84>>2]=x[(b?s:r)>>2];x[e+80>>2]=h;b=d|x[f+8>>2];x[e+88>>2]=b;x[e+88>>2]=b&(x[f>>2]^-1);b=e+704|0;h=x[a+24>>2];a:{if(!x[e+704>>2]|!h){break a}if(Nm(x[t>>2])){break a}d=x[(j?b:i)>>2];k=qoa(x[(j?i:b)>>2],0,x[e+700>>2],0);l=k+(d>>>1|0)|0;m=kb;u=e,v=Ec(soa(l,k>>>0>l>>>0?m+1|0:m,d,0),kb),x[u+700>>2]=v}x[b>>2]=h}e=e+872|0;continue}break}x[a>>2]=c;x[a+20>>2]=g;iA(n);ib=f+16|0}function Yp(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;c=ib-16|0;ib=c;a:{b:{switch(y[a+480224|0]-1|0){default:b=x[a+24620>>2];d=b>>31;x[c+8>>2]=1;x[c>>2]=x[a+1074420>>2]<<1;f=qoa(b,d,5e4,0);e=kb;b=x[Yc(c+8|0,c)>>2];b=Dc(roa(f,e,b,b>>31),kb);x[a+1074404>>2]=b;break a;case 1:b=x[a+24620>>2];x[c+8>>2]=1;x[c+12>>2]=0;g=c,h=qoa(x[a+1074420>>2],0,qoa(x[a+1074408>>2],0,x[a+1074416>>2],0),kb),x[g>>2]=h;x[c+4>>2]=kb;b=qoa(b,0,6e5,0);d=c+8|0;e=b;f=kb;b=Gv(x[d>>2],x[d+4>>2],x[c>>2],x[c+4>>2])?c:d;b=soa(e,f,x[b>>2],x[b+4>>2]);x[a+1074404>>2]=b;break a;case 0:break b}}b=x[a+24620>>2];d=b>>31;x[c+8>>2]=1;x[c>>2]=x[a+1074420>>2];f=qoa(b,d,1e4,0);e=kb;b=x[Yc(c+8|0,c)>>2];b=Dc(roa(f,e,b,b>>31),kb);x[a+1074404>>2]=b}e=a+1074404|0;a=x[a+480244>>2];b=qoa(a,a>>31,b,b>>31)+32768|0;a=kb;a=Dc(roa(b,b>>>0<32768?a+1|0:a,65536,0),kb);x[e>>2]=a?a:1;ib=c+16|0}function YG(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0,q=0;o(+a);b=j(1)|0;c=j(0)|0;a:{b:{c:{d:{if((b|0)>0|(b|0)>=0){e=b;if(b>>>0>1048575){break d}}if(!(b&2147483647|c)){return-1/(a*a)}if((b|0)>0|(b|0)>=0){break c}return(a-a)/0}if(e>>>0>2146435071){break a}b=1072693248;k=-1023;if((e|0)!=1072693248){b=e;break b}if(c){break b}return 0}o(+(a*0x40000000000000));b=j(1)|0;c=j(0)|0;k=-1077}l(0,c|0);c=b+614242|0;l(1,(c&1048575)+1072079006|0);d=+n()+-1;f=d*(d*.5);g=d/(d+2);h=g*g;a=h*h;o(+(d-f));b=j(1)|0;j(0)|0;l(0,0);l(1,b|0);i=+n();m=i*1.4426950407214463;p=+((c>>>20|0)+k|0);q=m+p;a=g*(f+(a*(a*(a*.15313837699209373+.22222198432149784)+.3999999999940942)+h*(a*(a*(a*.14798198605116586+.1818357216161805)+.2857142874366239)+.6666666666666735)))+(d-i-f);a=q+(m+(p-q)+((a+i)*1.6751713164886512e-10+a*1.4426950407214463))}return a}function jea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=ib-32|0;ib=d;e=Kb(d+16|0);a:{b:{c:{if(c>>>0<64){break c}x[27524]=0;c=T(193,b|0)|0;f=x[27524];x[27524]=0;d:{if((f|0)!=1){x[d+12>>2]=c;if((c|0)>0){break d}x[27524]=0;Q(55,a|0,21631)|0;a=x[27524];x[27524]=0;if((a|0)!=1){break b}}break a}x[27524]=0;c=T(206,b|0)|0;f=x[27524];x[27524]=0;if((f|0)!=1){g=d,h=Mi(c),x[g+8>>2]=h;c=x[rd(d+12|0,d+8|0)>>2];x[27524]=0;R(46,e|0,c|0);c=x[27524];x[27524]=0;if((c|0)!=1){break c}}break a}e:{while(1){f:{x[27524]=0;c=T(210,b|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break f}if(!c){break e}x[27524]=0;W(853,e|0,1,((c-65&255)>>>0<26?c+32|0:c)<<24>>24)|0;c=x[27524];x[27524]=0;if((c|0)!=1){continue}}break}break a}x[27524]=0;Q(192,b|0,4)|0;b=x[27524];x[27524]=0;if((b|0)==1){break a}$c(a,e)}wb(e);ib=d+32|0;return}a=P()|0;wb(e);S(a|0);p()}function LM(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=E(0),k=0,l=E(0),m=0,n=0,o=0,p=E(0);d=a+4208|0;j=E(E(B[Bb(d,2)>>2]*E(2999.9990234375))+E(.0010000000474974513));l=E(B[Bb(d,3)>>2]*E(.9980000257492065));f=-3e3/+E(j*E(A[x[a+16>>2]+24620>>2]));h=a+4272|0;c=ck(10,f*+A[Bb(h,4)>>2]);d=a+4232|0;o=Bb(d,0),p=E(c),B[o>>2]=p;c=ck(10,f*+A[Bb(h,5)>>2]);o=Bb(d,1),p=E(c),B[o>>2]=p;m=f*(1/+E(l+E(.0010000000474974513))+-1);c=0;while(1){if((e|0)==4){e=a+4208|0;f=ck(10,+JM(B[Bb(e,0)>>2])*.05);b=4/M(c)*f;c=ck(10,+JM(B[Bb(e,1)>>2])*.1);B[a+4228>>2]=b*M(c);B[a+4224>>2]=f*M(1-c)}else{g=Bb(h,e);k=e>>>1|0;n=x[Bb(h,k+4|0)>>2];g=x[g>>2];i=ck(10,m*+(n+g>>>0));b=ck(10,f*+(g>>>0));j=B[Bb(d,k)>>2];g=e<<1;i=(1-i)*.5;o=Bb(d,g+2|0),p=E(b*(1-i)),B[o>>2]=p;o=Bb(d,g+3|0),p=E(b*i),B[o>>2]=p;b=b*+j;b=b*(b*(b*(b+1)+1)+1)+1;c=b*b+c;e=e+1|0;continue}break}}function vW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;while(1){a:{g=c;if(!c){g=0;break a}c=g-1|0;if(!y[c+b|0]){continue}}break}b:{if((d|0)!=4){break b}c=0;while(1){if((c|0)==(g|0)){if((e|0)==(f|0)){d=2;if((e|0)==(h|0)){break b}}if(e){d=0;if(!f){break b}}d=e?3:f?1:3}else{c:{d:{e:{d=b+c|0;i=y[d|0];switch(i-10|0){case 0:break d;case 3:break e;default:break c}}e=e+1|0;break c}f=f+1|0}h=c?(y[d-1|0]==13&(i|0)==10)+h|0:h;c=c+1|0;continue}break}}e=0;f=(d|0)==2;c=0;while(1){if(c>>>0<g>>>0){c=((f&y[b+c|0]==13)+c|0)+1|0;e=e+1|0;continue}break}Vf(a);It(a,e);f=(d|0)==1?32:13;h=d&-3?13:32;d=(d|0)==2;c=0;while(1){if(c>>>0<g>>>0){f:{g:{h:{i:{e=v[b+c|0];switch(e-10|0){case 1:case 2:break f;case 0:break g;case 3:break h;default:break i}}if(e){break f}e=32;break f}c=c+d|0;e=f;break f}e=h}dq(a,e);c=c+1|0;continue}break}}function XI(a,b,c,d){var e=0,f=E(0),g=0,h=E(0),i=0,j=0,k=0,l=E(0),m=E(0),n=E(0),o=0;e=ib-96|0;ib=e;o=(d|0)>0?d:0;while(1){if((j|0)!=(o|0)){B[e+48>>2]=-B[a>>2];B[e>>2]=B[a+68>>2];d=0;while(1){if((d|0)!=4){i=(e+48|0)+(d<<3)|0;g=(d<<4)+a|0;h=B[g+4>>2];f=B[g+8>>2];B[i+4>>2]=h+f;k=d<<1;B[(8-k<<2)+e>>2]=h-f;h=B[g+16>>2];f=B[g+12>>2];B[(7-k<<2)+e>>2]=h-f;B[i+8>>2]=-E(h+f);d=d+1|0;continue}break}WI(e+48|0);WI(e);B[e+4>>2]=-B[e+4>>2];B[e+12>>2]=-B[e+12>>2];B[e+20>>2]=-B[e+20>>2];B[e+28>>2]=-B[e+28>>2];g=0;while(1){if((g|0)!=9){d=g<<2;i=d+b|0;h=B[i>>2];f=B[d+(e+48|0)>>2];l=B[d+86416>>2];m=B[d+86452>>2];n=B[d+e>>2];B[i>>2]=E(f*l)-E(m*n);i=a+d|0;d=c+d|0;f=E(E(f*m)+E(n*l));B[i>>2]=E(h*B[d>>2])-E(B[d+36>>2]*f);B[(17-g<<2)+a>>2]=E(h*B[d+36>>2])+E(f*B[d>>2]);g=g+1|0;continue}break}b=b+36|0;a=a+72|0;j=j+1|0;continue}break}ib=e+96|0}function iY(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=ib-16|0;ib=e;md(b,0);x[b>>2]=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);c=cr(a+4|0,a);d=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[b+4>>2]=d;c=cr(a+8|0,a);f=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[b+8>>2]=f;c=(y[a+15|0]|y[a+16|0]<<8)<<1;x[b+24>>2]=c;c=y[a+15|0]|y[a+16|0]<<8?c:16726;x[b+24>>2]=c;g=b,h=(D(pv(v[a+17|0],y[a+14|0]<<28>>24),c)>>>0)/8363|0,x[g+24>>2]=h;v[e+15|0]=y[a+18|0];v[e+14|0]=127;g=b,h=(((y[Ub(e+15|0,e+14|0)|0]<<8|64)&65344)>>>0)/127|0,w[g+30>>1]=h;c=y[a+14|0];if(c>>>0>=16){w[b+34>>1]=32;w[b+28>>1]=c&240}c=y[a+19|0];if(c&4){w[b+34>>1]=z[b+34>>1]|1;c=y[a+19|0]}a:{if(!(c&8)|d>>>0>=f>>>0){break a}f=z[b+34>>1];d=f|2;w[b+34>>1]=d;c=y[a+19|0];if(c&16){d=f|6;w[b+34>>1]=d;c=y[a+19|0]}if(!(c&64)){break a}w[b+34>>1]=d|128}ib=e+16|0}function sL(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=ib+-64|0;ib=e;a:{b:{if((b|0)>=0){d=x[a+24>>2];if(xj(Tb(x[d+484360>>2],y[d+484376|0]))>>>0>b>>>0){break b}}a=a+16|0;break a}d=0;c:{f=x[a+24>>2];g=x[f+484344>>2];i=x[f+484348>>2];h=z[bc(x[Tb(x[f+484360>>2],y[f+484376|0])>>2],b)>>1];if(!Sm(g,i,h)){break c}if((c|0)>=0){d=c;if((d|0)<x[Xb(g,h)+12>>2]){break c}}a=a+16|0;break a}w[f+1074448>>1]=b;c=f;f=b&65535;NO(c,f);c=x[a+24>>2];x[c+1074392>>2]=-2;x[c+1074428>>2]=d;g=y[a+64|0];b=e+24|0;w[b+4>>1]=0;v[b+6|0]=255;x[b+16>>2]=2;x[b>>2]=0;w[b+12>>1]=f;x[b+8>>2]=d;d=x[b+20>>2];x[e+16>>2]=x[b+16>>2];x[e+20>>2]=d;d=x[b+12>>2];x[e+8>>2]=x[b+8>>2];x[e+12>>2]=d;d=x[b+4>>2];x[e>>2]=x[b>>2];x[e+4>>2]=d;b=e+48|0;ru(b,c,g?7:1,e);j=a,k=C[GO(x[e+52>>2])>>3],C[j+16>>3]=k;Li(b);a=a+16|0}ib=e- -64|0;return+C[a>>3]}function nO(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;k=ib-16|0;ib=k;v[k+15|0]=c;v[k+14|0]=12;Zg(b,y[Ub(k+15|0,k+14|0)|0]);c=0;l=x[b>>2];m=x[b+4>>2];p=$d(l,m);while(1){if((c|0)==(p|0)){c=0;v[b+12|0]=0;a:{if(!(d&1)){break a}if(pc(l,m)){break a}c=1;v[b+12|0]=1}if(e>>>0<=11){if(d&2){c=c|4;v[b+12|0]=c}v[b+15|0]=e;v[b+16|0]=e}if(!(g>>>0>11|f>>>0>g>>>0)){if(d&4){v[b+12|0]=c|2}v[b+14|0]=g;v[b+13|0]=f}ib=k+16|0}else{b:{c:{d:{switch(h|0){case 0:j=Bb(l,c);i=(c<<2)+a|0;w[j>>1]=y[i+96|0]|y[i+97|0]<<8;i=i+98|0;break c;case 1:break d;default:break b}}j=Bb(l,c);i=(c<<2)+a|0;w[j>>1]=y[i+144|0]|y[i+145|0]<<8;i=i+146|0}v[j+2|0]=y[i|0]}e:{if(!c){break e}i=Bb(l,c);j=z[i>>1];n=Bb(l,c-1|0);o=z[n>>1];if(j>>>0>255|j>>>0>=o>>>0){break e}j=j|o&65280;w[i>>1]=j;if(j>>>0>=z[n>>1]){break e}w[i>>1]=j+256}c=c+1|0;continue}break}}function UP(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=ib-16|0;ib=e;h=-1;a:{if(!Sy(a,b,2)){break a}f=x[b+656>>2];g=a+1074312|0;Ab(e+8|0,g,31);b:{if(zb(x[x[e+8>>2]>>2],x[e+12>>2])){d=x[b+740>>2];if(d){break b}break a}d=x[b+740>>2]}Ab(e+8|0,g,31);g=d-zb(x[x[e+8>>2]>>2],x[e+12>>2])|0;i=x[a+480180>>2];d=(i|0)==4096;j=f+88|0;f=d?64:(i|0)==16384?192:512;d=kq(j,g,f,d?255:64)-(f>>>1|0)|0;if(y[b+746|0]&16){h=fq(a,b,!(x[b+88>>2]&32768),d);break a}if(Aj(x[b+656>>2])){if((d|0)==w[b+772>>1]){break a}k=b,l=dd(d),w[k+772>>1]=l;v[b+851|0]=y[b+851|0]|64;break a}a=sj(a);x[e+8>>2]=d;c:{if((d|0)<0){x[e+8>>2]=0-d;gi(e+8|0,255);a=(x[e+8>>2]<<2)+(a?38176:37152)|0;break c}gi(e+8|0,255);a=(x[e+8>>2]<<2)+(a?37152:38176)|0}a=x[a>>2];b=a;d=a>>31;a=x[c>>2];k=c,l=Dc(roa(qoa(b,d,a,a>>31),kb,65536,0),kb),x[k>>2]=l}ib=e+16|0;return h}function Tda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;md(c,0);w[c+28>>1]=y[a+36|0]<<2;d=y[a+37|0];w[c+32>>1]=64;w[c+30>>1]=d<<2;x[c>>2]=y[a+40|0]|y[a+41|0]<<8|(y[a+42|0]<<16|y[a+43|0]<<24);x[c+4>>2]=y[a+44|0]|y[a+45|0]<<8|(y[a+46|0]<<16|y[a+47|0]<<24);x[c+8>>2]=y[a+48|0]|y[a+49|0]<<8|(y[a+50|0]<<16|y[a+51|0]<<24);x[c+24>>2]=y[a+52|0]|y[a+53|0]<<8|(y[a+54|0]<<16|y[a+55|0]<<24);d=y[b+151|0];if(d>>>0<=4){v[c+38|0]=y[d+42746|0]}d=y[b+152|0]|y[b+153|0]<<8;v[c+39|0]=d;e=(y[b+156|0]|y[b+157|0]<<8)>>>4|0;v[c+41|0]=e;b=(y[b+154|0]|y[b+155|0]<<8)>>>2|0;v[c+40|0]=b;if((b|e)&255){v[c+39|0]=d^-1}b=y[a+38|0]|y[a+39|0]<<8;if(b&4){w[c+34>>1]=z[c+34>>1]|1;b=y[a+38|0]|y[a+39|0]<<8}if(b&8){w[c+34>>1]=z[c+34>>1]|2;b=y[a+38|0]|y[a+39|0]<<8}if(b&16){w[c+34>>1]=z[c+34>>1]|4;b=y[a+38|0]|y[a+39|0]<<8}if(b&32){w[c+34>>1]=z[c+34>>1]|32}}function Rga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=ib-16|0;ib=b;g=x[a+40>>2];h=x[a+36>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+32>>2];k=x[a+28>>2];l=x[a+8>>2];m=x[a+12>>2];while(1){if(d){f=x[b+8>>2];n=((((x[b+12>>2]&2147483647)<<1|f>>>31)&2147483646)<<1)+i|0;e=f>>>21&2040;o=w[e+39734>>1];p=w[e+39732>>1];q=w[e+39730>>1];r=w[e+39728>>1];e=0;while(1){if((e|0)!=2){f=(e<<1)+n|0;x[(e<<2)+b>>2]=(((D(w[f>>1],q)+D(w[f-4>>1],r)|0)+D(w[f+4>>1],p)|0)+D(w[f+8>>1],o)|0)/16384;e=e+1|0;continue}break}h=h+k|0;x[c>>2]=x[c>>2]+D(x[b>>2],h>>12);g=g+j|0;x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],g>>12);Pb(b+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=g;x[a+20>>2]=h>>12;x[a+36>>2]=h;x[a+24>>2]=g>>12;ib=b+16|0}function rfa(a,b,c){a=a|0;b=b|0;c=c|0;a:{switch(b|0){case 0:le(a,0,c);return;case 1:le(a,1,c);return;case 2:le(a,2,c);return;case 3:le(a,3,c);return;case 4:le(a,4,c);return;case 5:le(a,5,c);return;case 6:le(a,6,c);return;case 7:le(a,7,c);return;case 8:le(a,8,c);return;case 9:le(a,9,c);return;case 10:le(a,10,c);return;case 11:le(a,11,c);return;case 12:le(a,12,c);return;case 13:le(a,13,c);return;case 14:le(a,14,c);return;case 15:le(a,15,c);return;case 16:le(a,16,c);return;case 17:le(a,17,c);return;case 18:le(a,18,c);return;case 19:le(a,19,c);return;case 20:FQ(a,23712,c);return;case 21:FQ(a,24736,c);return;case 22:le(a,20,c);return;case 23:le(a,21,c);return;case 24:le(a,22,c);return;case 25:le(a,23,c);return;case 26:le(a,24,c);return;case 27:le(a,25,c);return;case 28:le(a,26,c);return;default:break a}}Kb(a)}function oz(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=z[a+480188>>1];h=d>>>0<=256?256:d;f=x[a+1298300>>2];c=d;a:{while(1){if((c|0)!=(h|0)){e=D(c,872)+a|0;if(!x[e+1075068>>2]){if(!uj(x[e+1075648>>2])|y[e+1075081|0]&24){break a}}if(y[e+1075081|0]&2){if(!Ed(f)){break a}if(!CP(f,c&65535)){break a}}c=c+1|0;continue}break}e=0;f=65535;g=8388608;if(b>>>0<=255){b=D(b,872)+a|0;if(!x[b+1075688>>2]){c=65535;if(x[b+1075068>>2]){break a}}g=x[b+1075680>>2]|x[b+1075672>>2]<<9}while(1){if((d|0)==(h|0)){c=f;break a}b=D(d,872)+a|0;if(!(x[b+1075688>>2]?0:x[b+1075068>>2])){c=(x[b+1075680>>2]|x[b+1075672>>2]<<9)>>>(x[b+1075080>>2]>>>1&1)|0;b:{c:{if(c>>>0<g>>>0){b=x[(D(d,872)+a|0)+1075716>>2];break c}if((c|0)!=(g|0)){break b}b=x[(D(d,872)+a|0)+1075716>>2];if(e>>>0>=b>>>0){break b}}g=c;f=d;e=b}d=d+1|0;continue}break}c=d}return c&65535}function Fea(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=ib-880|0;ib=b;c=Rb(a,0,76);x[c+84>>2]=0;x[c+88>>2]=0;x[c+80>>2]=256;w[c+76>>1]=65535;x[c+92>>2]=0;x[c+96>>2]=0;v[c+100|0]=1;d=c+223848|0;e=c+616|0;a=e;while(1){a=zS(a)+872|0;if((d|0)!=(a|0)){continue}break}d=Nb(d);g=sz(c+223860|0);f=b+8|0;Rb(f,0,108);tA(b+120|0,48e3);Rb(b+664|0,0,72);v[b+754|0]=0;w[b+752>>1]=65535;v[b+746|0]=0;w[b+744>>1]=65535;v[b+738|0]=0;w[b+736>>1]=65535;x[b+748>>2]=0;x[b+740>>2]=0;Rb(b+756|0,0,103);x[b+868>>2]=0;x[b+872>>2]=0;v[b+875|0]=0;v[b+876|0]=0;v[b+877|0]=0;v[b+878|0]=0;x[b+860>>2]=0;x[b+864>>2]=0;v[b+859|0]=y[b+859|0]&128;a=((e+223232|0)-e|0)/872|0;while(1){if((a|0)>0){a=a-1|0;e=aq(e,f)+872|0;continue}break}x[27524]=0;R(542,d|0,32);a=x[27524];x[27524]=0;if((a|0)!=1){ib=b+880|0;return c|0}a=P()|0;bq(g);ec(d);S(a|0);p()}function TI(a){var b=0,c=0,d=0,e=0,f=0,g=0;c=x[a+32>>2];a:{b:{b=x[a+1380>>2];if((b|0)==-1){d=1;b=-1;break b}e=x[a+1116>>2];d=(b|0)>(e|0)?b:e;while(1){c:{if((b|0)!=(d|0)){f=y[(a+b|0)+1120|0];c=f+c|0;if((f|0)==255){break c}d=b}if(A[a+40>>2]<c>>>0){fc(a,1);break a}b=(d|0)==(e|0)?-1:d;d=0;break b}b=b+1|0;continue}}while(1){if((b|0)!=-1){return 1}e=x[a+40>>2];if(e>>>0<=c+26>>>0){fc(a,1);break a}if(Qb(c,109124,4)){fc(a,21);break a}if(y[c+4|0]){fc(a,21);break a}d:{if(d){if(!x[a+992>>2]|!(v[c+5|0]&1)){break d}fc(a,21);break a}if(v[c+5|0]&1){break d}fc(a,21);break a}b=0;f=c+27|0;d=y[c+26|0];c=f+d|0;if(e>>>0<c>>>0){fc(a,1);break a}while(1){e:{if((b|0)==(d|0)){b=d;break e}g=y[b+f|0];c=g+c|0;if((g|0)!=255){break e}b=b+1|0;continue}break}b=(b|0)==(d|0)?-1:b;d=0;if(c>>>0<=e>>>0){continue}break}fc(a,1)}return 0}function sna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=ib-32|0;ib=g;e=b;b=x[a>>2];b=to(e,Cb(b))+b|0;e=XW(c,d);a:{if((e|0)<=0){break a}f=x[Db(a)>>2];h=x[a+4>>2];if((f-h|0)>=(e|0)){x[g+8>>2]=d;i=h-b|0;if((i|0)<(e|0)){x[g+8>>2]=c;DB(g+8|0,i);f=x[g+8>>2];l=ib-16|0;ib=l;j=_l(l,a,e-i|0);k=ib-16|0;ib=k;x[k+8>>2]=f;while(1){if(Mb(f,d)){Uk(x[j+4>>2],y[f|0]);f=Ie(k+8|0);x[j+4>>2]=x[j+4>>2]+1;f=x[f>>2];continue}break}ib=k+16|0;ic(j);ib=l+16|0;if((i|0)<=0){break a}}WW(a,b,h,b+e|0);wh(c,x[g+8>>2],b);break a}f=Db(a);f=am(g+8|0,Zl(a,cd(x[a>>2],h)+e|0),b-x[a>>2]|0,f);e=ib-32|0;ib=e;x[e+24>>2]=c;c=qw(e+8|0,f+8|0,XW(c,d));d=x[c>>2];while(1){if(x[c+4>>2]!=(d|0)){Uk(d,y[x[e+24>>2]]);d=x[c>>2]+1|0;x[c>>2]=d;Ie(e+24|0);continue}break}Vd(c);ib=e+32|0;b=VW(a,f,b);$l(f)}Cb(b);ib=g+32|0}function V4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=ib-96|0;ib=d;x[27524]=0;e=x[b+12>>2];x[d+40>>2]=x[b+8>>2];x[d+44>>2]=e;e=x[b+4>>2];x[d+32>>2]=x[b>>2];x[d+36>>2]=e;e=T(1103,d+32|0)|0;f=x[27524];x[27524]=0;if((f|0)!=1){a:{b:{if(e){x[27524]=0;R(1104,d+72|0,b|0);b=x[27524];x[27524]=0;if((b|0)!=1){b=d+80|0;_o(b,x[d+72>>2],x[d+76>>2]);e=zf(d+88|0,b);f=zf(d- -64|0,c);g=x[e+4>>2];x[d+8>>2]=x[e>>2];x[d+12>>2]=g;e=x[f+4>>2];x[d>>2]=x[f>>2];x[d+4>>2]=e;$o(a,d+8|0,d);break b}break a}x[27524]=0;R(1105,d+72|0,b|0);b=x[27524];x[27524]=0;if((b|0)==1){break a}b=d+80|0;_o(b,x[d+72>>2],x[d+76>>2]);e=zf(d+56|0,b);f=zf(d+48|0,c);g=x[e+4>>2];x[d+24>>2]=x[e>>2];x[d+28>>2]=g;e=x[f+4>>2];x[d+16>>2]=x[f>>2];x[d+20>>2]=e;$o(a,d+24|0,d+16|0)}Ud(b);Ud(d+72|0);Ud(c);ib=d+96|0;return}}a=P()|0;Ud(c);S(a|0);p()}function _aa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;b=Ai(a,b,c,d);x[b+4260>>2]=0;x[b>>2]=46780;c=b+4960|0;e=b+4504|0;d=e;while(1){d=Nb(d)+24|0;if((d|0)!=(c|0)){continue}break}v[b+5046|0]=1;w[b+5044>>1]=0;a=b+4208|0;f=Bb(a,0),g=1063675494,x[f>>2]=g;f=Bb(a,1),g=1065185444,x[f>>2]=g;f=Bb(a,2),g=0,x[f>>2]=g;f=Bb(a,3),g=1032805417,x[f>>2]=g;f=Bb(a,4),g=1053079357,x[f>>2]=g;f=Bb(a,5),g=1059859440,x[f>>2]=g;f=Bb(a,6),g=1047457519,x[f>>2]=g;f=Bb(a,7),g=1062836634,x[f>>2]=g;f=Bb(a,8),g=1038174126,x[f>>2]=g;f=Bb(a,9),g=1065353216,x[f>>2]=g;f=Bb(a,10),g=1065353216,x[f>>2]=g;f=Bb(a,11),g=1048525618,x[f>>2]=g;f=Bb(a,12),g=1059760811,x[f>>2]=g;x[27524]=0;R(903,b+44|0,2);a=x[27524];x[27524]=0;if((a|0)==1){a=P()|0;while(1){c=uc(c-24|0);if((e|0)!=(c|0)){continue}break}Rf(b);S(a|0);p()}return b|0}function haa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=ib-32|0;ib=e;x[27524]=0;Y(958,a|0);d=x[27524];x[27524]=0;a:{b:{c:{d:{e:{f:{g:{if((d|0)==1){break g}x[27524]=0;Y(959,b|0);d=x[27524];x[27524]=0;if((d|0)==1){break g}x[27524]=0;Y(959,c|0);d=x[27524];x[27524]=0;if((d|0)==1){break g}f=x[a+24>>2];x[27524]=0;d=Q(55,e+16|0,b|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break g}x[27524]=0;c=Q(55,e|0,c|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break f}x[27524]=0;X(974,f|0,d|0,c|0,1);b=x[27524];x[27524]=0;if((b|0)==1){break e}wb(c);wb(d);b=1;break b}b=V(0)|0;break c}b=V(0)|0;break d}b=V(0)|0;wb(c)}wb(d)}_(b|0)|0;b=0;x[27524]=0;X(945,6412,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)==1){break a}$()}ib=e+32|0;return b|0}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function jR(a,b,c){a:{switch(b|0){case 0:me(a,0,c);return;case 1:me(a,1,c);return;case 2:me(a,2,c);return;case 3:me(a,3,c);return;case 4:me(a,4,c);return;case 5:me(a,5,c);return;case 6:me(a,6,c);return;case 7:me(a,7,c);return;case 8:me(a,8,c);return;case 9:me(a,9,c);return;case 10:me(a,10,c);return;case 11:me(a,11,c);return;case 12:me(a,12,c);return;case 13:me(a,13,c);return;case 14:me(a,14,c);return;case 15:me(a,15,c);return;case 16:me(a,16,c);return;case 17:me(a,17,c);return;case 18:me(a,18,c);return;case 19:me(a,19,c);return;case 20:SQ(a,23712,c);return;case 21:SQ(a,24736,c);return;case 22:me(a,20,c);return;case 23:me(a,21,c);return;case 24:me(a,22,c);return;case 25:me(a,23,c);return;case 26:me(a,24,c);return;case 27:me(a,25,c);return;case 28:me(a,26,c);return;default:break a}}Kb(a)}function Sga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=ib-16|0;ib=b;g=x[a+40>>2];h=x[a+36>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+32>>2];k=x[a+28>>2];l=x[a+8>>2];m=x[a+12>>2];while(1){if(d){f=x[b+8>>2];n=(((x[b+12>>2]&2147483647)<<1|f>>>31)&-2)+i|0;e=f>>>21&2040;o=w[e+39734>>1];p=w[e+39732>>1];q=w[e+39730>>1];r=w[e+39728>>1];e=0;while(1){if((e|0)!=2){f=e+n|0;x[(e<<2)+b>>2]=(((D(v[f|0],q)+D(v[f-2|0],r)|0)+D(v[f+2|0],p)|0)+D(v[f+4|0],o)<<8)/16384;e=e+1|0;continue}break}h=h+k|0;x[c>>2]=x[c>>2]+D(x[b>>2],h>>12);g=g+j|0;x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],g>>12);Pb(b+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=g;x[a+20>>2]=h>>12;x[a+36>>2]=h;x[a+24>>2]=g>>12;ib=b+16|0}function aH(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=ib-32|0;ib=h;a:{b:{c:{if((b|0)!=(c|0)){j=x[12e4];x[12e4]=0;g=ib-16|0;ib=g;Fd();e=ib-16|0;ib=e;f=ib-16|0;ib=f;_w(f,b,h+28|0,2);k=x[f>>2];i=x[f+4>>2];b=x[f+12>>2];x[e+8>>2]=x[f+8>>2];x[e+12>>2]=b;x[e>>2]=k;x[e+4>>2]=i;ib=f+16|0;i=x[e>>2];f=x[e+4>>2];b=x[e+12>>2];x[g+8>>2]=x[e+8>>2];x[g+12>>2]=b;x[g>>2]=i;x[g+4>>2]=f;ib=e+16|0;f=x[g>>2];e=x[g+4>>2];b=x[g+12>>2];x[h+16>>2]=x[g+8>>2];x[h+20>>2]=b;x[h+8>>2]=f;x[h+12>>2]=e;ib=g+16|0;i=x[h+16>>2];f=x[h+20>>2];g=x[h+8>>2];e=x[h+12>>2];b=x[12e4];if(!b){break c}if(x[h+28>>2]!=(c|0)){break b}l=g;m=e;n=i;o=f;if((b|0)!=68){break a}break b}x[d>>2]=4;break a}x[12e4]=j;if(x[h+28>>2]==(c|0)){break a}}x[d>>2]=4;g=l;e=m;i=n;f=o}x[a>>2]=g;x[a+4>>2]=e;x[a+8>>2]=i;x[a+12>>2]=f;ib=h+32|0}function Fd(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0;if(y[483540]){return x[120884]}c=ib-32|0;ib=c;a:{b:{while(1){e=(c+8|0)+(a<<2)|0;d=1<<a&2147483647;if(d|1){d=xH(a,d?14293:21631)}else{d=x[a<<2>>2]}x[e>>2]=d;if((d|0)==-1){break b}a=a+1|0;if((a|0)!=6){continue}break}if(!wH(0)){b=105216;if(!Qb(c+8|0,105216,24)){break a}b=105240;if(!Qb(c+8|0,105240,24)){break a}a=0;if(!y[483312]){while(1){f=(a<<2)+483264|0,g=xH(a,21631),x[f>>2]=g;a=a+1|0;if((a|0)!=6){continue}break}v[483312]=1;x[120822]=x[120816]}b=483264;if(!Qb(c+8|0,483264,24)){break a}b=483288;if(!Qb(c+8|0,483288,24)){break a}b=Gd(24);if(!b){break b}}a=x[c+12>>2];x[b>>2]=x[c+8>>2];x[b+4>>2]=a;a=x[c+28>>2];x[b+16>>2]=x[c+24>>2];x[b+20>>2]=a;a=x[c+20>>2];x[b+8>>2]=x[c+16>>2];x[b+12>>2]=a;break a}b=0}ib=c+32|0;v[483540]=1;x[120884]=b;return b}function Jv(a,b,c,d){var e=0,f=0,g=0,h=0;g=ib-16|0;ib=g;a:{if(!c){break a}if(d){b=dc(g+8|0,a,b);a=ib-16|0;ib=a;x[a+12>>2]=c;d=x[b+4>>2];b:{if(!d){d=x[b>>2];break b}e=32-d|0;x[a+8>>2]=e;c=x[b>>2];h=e;e=x[Hb(a+8|0,a+12|0)>>2];x[c>>2]=-1<<d&-1>>>h-e|x[c>>2];f=x[a+12>>2];d=c+4|0;x[b>>2]=d;c=f-e|0}e=d;d=c>>>5<<2;Rb(e,255,d);e=c&31;x[a+12>>2]=e;if((c&-32)!=(c|0)){c=b;b=d+x[b>>2]|0;x[c>>2]=b;x[b>>2]=x[b>>2]|-1>>>32-e}ib=a+16|0;break a}b=dc(g,a,b);a=ib-16|0;ib=a;x[a+12>>2]=c;d=x[b+4>>2];c:{if(!d){d=x[b>>2];break c}e=32-d|0;x[a+8>>2]=e;c=x[b>>2];f=x[c>>2];h=e;e=x[Hb(a+8|0,a+12|0)>>2];x[c>>2]=(-1<<d&-1>>>h-e^-1)&f;f=x[a+12>>2];d=c+4|0;x[b>>2]=d;c=f-e|0}e=d;d=c>>>5<<2;Rb(e,0,d);e=c&31;x[a+12>>2]=e;if((c&-32)!=(c|0)){c=b;b=d+x[b>>2]|0;x[c>>2]=b;x[b>>2]=x[b>>2]&(-1>>>32-e^-1)}ib=a+16|0}ib=g+16|0}function sn(a,b,c,d){var e=0,f=0;f=ib-16|0;ib=f;x[27524]=0;Y(958,a|0);e=x[27524];x[27524]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((e|0)!=1){e=x[a+24>>2];x[27524]=0;R(d|0,f|0,e|0);d=x[27524];x[27524]=0;if((d|0)==1){break i}d=x[f>>2];e=wd(d,x[f+4>>2]);if(e>>>0<2147483647){break h}d=ba(8)|0;x[27524]=0;b=Q(1013,d|0,7377)|0;e=x[27524];x[27524]=0;if((e|0)==1){break g}x[27524]=0;U(123,b|0,108556,172);b=x[27524];x[27524]=0;if((b|0)!=1){break b}b=V(0)|0;break f}b=V(0)|0;break e}b=V(0)|0;break e}j:{if(!((b|0)<(e|0)&(b|0)>=0)){b=mg(21631);break j}b=mg(Jc(Cd(d,b)))}ve(f);break d}b=V(0)|0;ca(d|0)}ve(f)}_(b|0)|0;b=0;x[27524]=0;X(945,c|0,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)==1){break c}$()}ib=f+16|0;return b}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){break a}V(0)|0;Sb()}p()}S(a|0);p()}function Vna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=ib-48|0;ib=g;h=a+8|0;c=x[a+8>>2];j=zc(a);a:{if((c|0)!=x[j>>2]){break a}i=a+4|0;e=x[a+4>>2];d=x[a>>2];if(e>>>0>d>>>0){a=e;d=((a-d>>1)+1|0)/-2<<1;e=a+d|0;while(1){if((a|0)!=(c|0)){e=LX(e,a)+2|0;a=a+2|0;continue}break}c=e;x[h>>2]=c;x[i>>2]=d+x[i>>2];break a}x[g+24>>2]=c-d;x[g+44>>2]=1;e=g+24|0;c=x[Yc(e,g+44|0)>>2];c=Uj(e,c,c>>>2|0,x[a+16>>2]);d=Wb(g+16|0,x[a+4>>2]);f=x[Wb(g+8|0,x[a+8>>2])>>2];e=ib-32|0;ib=e;d=x[d>>2];x[e+24>>2]=d;d=Uo(e+8|0,c+8|0,nC(d,f));f=x[d>>2];while(1){if(x[d+4>>2]!=(f|0)){k=f;f=x[e+24>>2];Rj(k,y[f|0]|y[f+1|0]<<8);f=x[d>>2]+2|0;x[d>>2]=f;Ye(e+24|0);continue}break}Vd(d);ib=e+32|0;oc(a,c);oc(i,c+4|0);oc(h,c+8|0);oc(j,zc(c));Ui(c);c=x[a+8>>2]}Rj(c,y[b|0]|y[b+1|0]<<8);x[h>>2]=x[h>>2]+2;ib=g+48|0}function Cla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=ib-16|0;ib=e;c=Af(a,c);Pd(e,x[a+36>>2]);h=a;a:{if(!c){Pc(e,a+32|0,5);d=0;if(zb(x[x[e>>2]>>2],x[e+4>>2])){break a}}d=ib-32|0;ib=d;f=x[a+36>>2];dg(f,d+30|0);b:{c:{d:{e:{a=z[d+30>>1];if(a>>>0>=4001){i=x[b+12>>2];a=ib-16|0;ib=a;g=xc(a,15908);$c(d,g);xb(g);ib=a+16|0;x[27524]=0;U(482,d+16|0,d|0,d+30|0);a=x[27524];x[27524]=0;if((a|0)==1){break e}a=x[i+1298472>>2];x[27524]=0;U(380,a|0,2,d+16|0);a=x[27524];x[27524]=0;if((a|0)==1){break d}xb(d+16|0);$b(d);a=4e3}Dg(Dj(x[b>>2],0),a);b=Dj(x[b>>2],0);j=d,k=Cb(x[b>>2]),x[j+16>>2]=k;b=Cb(x[b+4>>2]);break b}b=P()|0;break c}b=P()|0;xb(d+16|0)}$b(d);S(b|0);p()}while(1){a=x[d+16>>2];if(Mb(a,b)){dg(f,d);w[a>>1]=z[d>>1];Ye(d+16|0);continue}break}ib=d+32|0;d=c}af(h,d);ib=e+16|0}function oD(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=ib-32|0;ib=d;x[27524]=0;f=Q(13,d+24|0,a|0)|0;e=x[27524];x[27524]=0;a:{b:{c:{if((e|0)!=1){d:{e:{if(!y[f|0]){break e}g=Jo(d+8|0,a);e=x[x[a>>2]-12>>2]+a|0;h=x[e+4>>2];x[27524]=0;i=T(14,e|0)|0;j=x[27524];x[27524]=0;if((j|0)==1){break d}g=x[g>>2];x[27524]=0;c=b+c|0;b=ka(15,g|0,b|0,((h&176)==32?c:b)|0,c|0,e|0,i|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break d}x[d+16>>2]=b;if(!sC(d+16|0)){break e}b=x[x[a>>2]-12>>2];x[27524]=0;R(16,a+b|0,5);b=x[27524];x[27524]=0;if((b|0)!=1){break e}break d}Hl(f);break b}b=V(0)|0;Hl(f);break c}b=V(0)|0}_(b|0)|0;b=x[x[a>>2]-12>>2];x[27524]=0;Y(17,a+b|0);b=x[27524];x[27524]=0;if((b|0)==1){break a}$()}ib=d+32|0;return a}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)==1){V(0)|0;Sb();p()}S(a|0);p()}function nga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=ib-16|0;ib=f;g=x[a+40>>2];h=x[a+36>>2];i=x[a+16>>2];e=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=e;j=b+24|0;k=x[a+32>>2];l=x[a+28>>2];m=x[a+8>>2];n=x[a+12>>2];while(1){if(d){b=(x[f+12>>2]<<1)+i|0;e=(((x[f+8>>2]>>>16|0)+4&131064)<<1)+j|0;b=(((((D(w[b+4>>1],w[e+10>>1])+D(w[b+2>>1],w[e+8>>1])|0)+D(w[b+6>>1],w[e+12>>1])|0)+D(w[b+8>>1],w[e+14>>1])|0)/2|0)+((((D(w[b-4>>1],w[e+2>>1])+D(w[b-6>>1],w[e>>1])|0)+D(w[b-2>>1],w[e+4>>1])|0)+D(w[b>>1],w[e+6>>1])|0)/2|0)|0)/16384|0;h=h+l|0;x[c>>2]=x[c>>2]+D(b,h>>12);g=g+k|0;x[c+4>>2]=x[c+4>>2]+D(b,g>>12);Pb(f+8|0,m,n);c=c+8|0;d=d-1|0;continue}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;x[a+40>>2]=g;x[a+20>>2]=h>>12;x[a+36>>2]=h;x[a+24>>2]=g>>12;ib=f+16|0}function Hq(a,b){var c=0;c=ib-16|0;ib=c;a=rr(a);a:{b:{c:{switch(b-1|0){default:if((b|0)!=16777216){break b}Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(a,7,1),9,1),10,1),13,1),15,1),16,1),17,1),18,1),20,1),21,1),24,1),25,1),26,1),28,1),30,1),31,1),33,1),34,1),39,1),41,1),44,1),46,1),45,1),47,1),48,1),50,1),99,1),102,1),104,1),105,1),115,1);break a;case 1:az(c,2);b=x[c+12>>2];x[a+8>>2]=x[c+8>>2];x[a+12>>2]=b;b=x[c+4>>2];x[a>>2]=x[c>>2];x[a+4>>2]=b;fg(a,107);break a;case 3:az(c,4);b=x[c+12>>2];x[a+8>>2]=x[c+8>>2];x[a+12>>2]=b;b=x[c+4>>2];x[a>>2]=x[c>>2];x[a+4>>2]=b;fg(a,4);break a;case 2:break b;case 0:break c}}Lb(a,88,1);break a}az(c,b);b=x[c+12>>2];x[a+8>>2]=x[c+8>>2];x[a+12>>2]=b;b=x[c+4>>2];x[a>>2]=x[c>>2];x[a+4>>2]=b}ib=c+16|0}function ada(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;a:{b:{if((Wj(x[a>>2],x[a+4>>2])|0)==2){if((Wj(x[a+12>>2],x[a+16>>2])|0)==(b|0)){break b}}x[27524]=0;R(905,a|0,2);c=x[27524];x[27524]=0;c:{if((c|0)==1){break c}x[27524]=0;R(905,a+12|0,b|0);c=x[27524];x[27524]=0;if((c|0)==1){break c}x[27524]=0;R(906,a+24|0,2);c=x[27524];x[27524]=0;if((c|0)==1){break c}x[27524]=0;R(906,a+36|0,b|0);c=x[27524];x[27524]=0;if((c|0)==1){break c}c=a;while(1)if((d|0)==2){a=0;while(1){if((a|0)==(b|0)){break b}d=nr(x[c+12>>2],a);f=Bb(x[c+36>>2],a),g=d,x[f>>2]=g;a=a+1|0;continue}}else{e=nr(x[a>>2],d);f=Bb(x[a+24>>2],d),g=e,x[f>>2]=g;d=d+1|0;continue}}b=V(108196)|0;if((jb|0)!=(da(108196)|0)){break a}_(b|0)|0;Ic(a);LN(a);b=a+12|0;Ic(b);LN(b);b=a+24|0;Ic(b);KN(b);a=a+36|0;Ic(a);KN(a);$()}return}S(b|0);p()}function mca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;a:{c=ib-16|0;ib=c;e=Kb(a);g=c,h=Ti(b),x[g+8>>2]=h;g=c,h=ir(b),x[g>>2]=h;a=0;b:{while(1){c:{if(!Fi(c+8|0,c)){if(!a){break c}x[27524]=0;R(49,e|0,65533);a=x[27524];x[27524]=0;if((a|0)!=1){break c}break b}b=y[x[c+8>>2]];d:{e:{if(!a){if(b<<24>>24>=0){a=0;x[27524]=0;R(49,e|0,b|0);b=x[27524];x[27524]=0;if((b|0)!=1){break d}break b}if((b&224)==192){d=b&31;a=1;break d}if((b&240)==224){d=b&15;a=2;break d}d=65533;if((b&248)!=240){break e}d=b&7;a=3;break d}if((b&192)!=128){d=0;x[27524]=0;R(49,e|0,65533);f=x[27524];x[27524]=0;a=0;if((f|0)==1){break b}}d=b&63|d<<6;a=a-1|0;if(a){break d}}a=0;x[27524]=0;R(49,e|0,d|0);b=x[27524];x[27524]=0;d=0;if((b|0)==1){break b}}Ie(c+8|0);continue}break}ib=c+16|0;break a}a=P()|0;Gc(e);S(a|0);p()}}function rca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=E(0);c=ib-4112|0;ib=c;h=lb[x[x[a>>2]+120>>2]](a)|0;if(!h){lb[x[x[a>>2]+124>>2]](a)}x[c+12>>2]=0;f=ib-16|0;ib=f;while(1){d=x[a+44>>2];if(Wj(d,x[a+48>>2])>>>0<=e>>>0){ib=f+16|0}else{x[f+12>>2]=0;d=nr(d,e);g=(d+2048|0)-d>>2;while(1){if((g|0)>0){B[d>>2]=B[f+12>>2];g=g-1|0;d=d+4|0;continue}break}e=e+1|0;continue}break}f=c+2064|0;a:while(1){if(b){x[c+8>>2]=b;wc(c+8|0,512);e=c+16|0;fz(e);d=x[c+8>>2];lb[x[x[a>>2]+60>>2]](a,e,f,d);e=0;while(1)if((e|0)==(d|0)){b=b-d|0;continue a}else{g=(c+16|0)+(e<<2)|0;B[c+4>>2]=F(B[g>>2]);i=c,j=B[oy(c+12|0,c+4|0)>>2],B[i+12>>2]=j;B[c+4>>2]=F(B[g+2048>>2]);i=c,j=B[oy(c+12|0,c+4|0)>>2],B[i+12>>2]=j;e=e+1|0;continue}}break}if(!h){lb[x[x[a>>2]+128>>2]](a)}ib=c+4112|0;return E(B[c+12>>2])}function qda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=ib-16|0;ib=f;j=Af(a,c);Pd(f,x[a+36>>2]);k=a;a:{if(!j){Pc(f,a+32|0,5);c=0;if(zb(x[x[f>>2]>>2],x[f+4>>2])){break a}}e=ib-48|0;ib=e;h=x[a+36>>2];Qk(h,e+40|0);c=x[e+44>>2];if(!c&A[e+40>>2]>=257|c){x[e+40>>2]=256;x[e+44>>2]=0}l=x[e+40>>2];m=x[e+44>>2];c=0;b:{c:{d:{e:{while(1){if(!m&c>>>0>=l>>>0){break b}dg(h,e+38|0);g=Kb(e+24|0);x[27524]=0;Q(489,h|0,g|0)|0;a=x[27524];x[27524]=0;if((a|0)!=1){x[27524]=0;U(11,e+8|0,d|0,g|0);a=x[27524];x[27524]=0;if((a|0)==1){break e}x[27524]=0;a=Q(894,b|0,e+38|0)|0;i=x[27524];x[27524]=0;if((i|0)==1){break d}i=a;a=e+8|0;Gb(i,a);xb(a);wb(g);c=c+1|0;continue}break}c=P()|0;break c}c=P()|0;break c}c=P()|0;xb(e+8|0)}wb(g);S(c|0);p()}ib=e+48|0;c=j}af(k,c);ib=f+16|0}function qd(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=x[a+112>>2];d=x[a+116>>2];e=!!(b|d);c=b;a:{i=e;f=x[a+4>>2];e=x[a+44>>2];b=f-e|0;h=b;g=b+x[a+120>>2]|0;b=x[a+124>>2]+(b>>31)|0;b=g>>>0<h>>>0?b+1|0:b;if(!(i&(c>>>0<=g>>>0&(b|0)>=(d|0)|(b|0)>(d|0)))){h=ex(a);if((h|0)>=0){break a}f=x[a+4>>2];e=x[a+44>>2]}x[a+112>>2]=-1;x[a+116>>2]=-1;x[a+104>>2]=f;c=e-f|0;d=c+g|0;b=(c>>31)+b|0;x[a+120>>2]=d;x[a+124>>2]=d>>>0<c>>>0?b+1|0:b;return-1}d=g+1|0;b=d?b:b+1|0;f=x[a+4>>2];e=x[a+8>>2];c=x[a+112>>2];g=x[a+116>>2];b:{if(!(c|g)){break b}i=c-d|0;c=g-(b+(d>>>0>c>>>0)|0)|0;j=e-f|0;g=j>>31;if((c|0)>=(g|0)&i>>>0>=j>>>0|(c|0)>(g|0)){break b}e=f+i|0}x[a+104>>2]=e;c=x[a+44>>2];e=c-f|0;d=e+d|0;b=(e>>31)+b|0;x[a+120>>2]=d;x[a+124>>2]=d>>>0<e>>>0?b+1|0:b;if(c>>>0>=f>>>0){v[f-1|0]=h}return h}function oga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=ib-16|0;ib=f;g=x[a+40>>2];h=x[a+36>>2];i=x[a+16>>2];e=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=e;j=b+24|0;k=x[a+32>>2];l=x[a+28>>2];m=x[a+8>>2];n=x[a+12>>2];while(1){if(d){b=x[f+12>>2]+i|0;e=(((x[f+8>>2]>>>16|0)+4&131064)<<1)+j|0;b=(((((D(v[b+2|0],w[e+10>>1])+D(v[b+1|0],w[e+8>>1])|0)+D(v[b+3|0],w[e+12>>1])|0)+D(v[b+4|0],w[e+14>>1])<<8)/2|0)+((((D(v[b-2|0],w[e+2>>1])+D(v[b-3|0],w[e>>1])|0)+D(v[b-1|0],w[e+4>>1])|0)+D(v[b|0],w[e+6>>1])<<8)/2|0)|0)/16384|0;h=h+l|0;x[c>>2]=x[c>>2]+D(b,h>>12);g=g+k|0;x[c+4>>2]=x[c+4>>2]+D(b,g>>12);Pb(f+8|0,m,n);c=c+8|0;d=d-1|0;continue}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;x[a+40>>2]=g;x[a+20>>2]=h>>12;x[a+36>>2]=h;x[a+24>>2]=g>>12;ib=f+16|0}function Uka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=ib-432|0;ib=d;yc(b);fB(b,d+376|0,d+296|0,d+8|0);k=d,l=Ag((m=y[d+427|0]+1|0,n=1,o=ac(x[d+408>>2]),o?m:n)),v[k+4|0]=l;i=y[Ub(26816,d+4|0)|0];v[d+7|0]=i;w[d+4>>1]=4;a:{b:{while(1){if((h&255)>>>0>=i>>>0){break b}e=Fb(z[d+8>>1])<<16>>16;if(!((e|0)<0|y[d+291|0]>63)){e=e&65535;f=0;while(1){if((f|0)==(e|0)){c:{e=g;g=ac(x[d+296>>2]);if(e>>>0<g>>>0){if(bd(b,g)){break c}}v[d+7|0]=h+1;break b}}else{d:{if(!bd(b,ac(x[d+392>>2])+(f<<2)|0)){break d}if(!bd(b,Go(b))){break d}e:{if(!c){j=Re(b);break e}j=Mj(b)}w[d+2>>1]=j;k=d,l=z[pe(d+4|0,d+2|0)>>1],w[k+4>>1]=l}f=f+1|0;continue}break}g=ac(x[d+296>>2]);fB(b,d+376|0,d+296|0,d+8|0);h=h+1|0;continue}break}Kv(a);break a}TU(a,z[d+4>>1],d+7|0)}ib=d+432|0}function zba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=E(0),g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=E(0),o=E(0),p=0,q=0,r=0,s=0;h=ib-16|0;ib=h;if(fi(a+44|0)){g=x[a+44>>2];r=h,s=Hc(g,0),x[r+8>>2]=s;r=h,s=Hc(g,1),x[r+12>>2]=s;g=x[a+56>>2];l=Hc(g,0);x[h>>2]=l;m=Hc(g,1);x[h+4>>2]=m;p=y[a+4273|0];q=y[a+4272|0];g=d;while(1){k=0;if(g){while(1){if((k|0)!=2){j=k<<2;i=j+(h+8|0)|0;e=x[i>>2];x[i>>2]=e+4;f=E(B[e>>2]*B[a+4240>>2]);e=a+j|0;i=e+4228|0;f=E(f+E(B[i>>2]*B[a+4236>>2]));B[i>>2]=f;f=bN(E(f*E(1073741824)),q,p);i=e+4244|0;e=e+4252|0;n=B[e>>2];o=B[a+4264>>2];f=E(E(E(f*B[a+4260>>2])-E(B[a+4268>>2]*B[i>>2]))-E(n*o));B[e>>2]=f;B[i>>2]=n+E(f*o);e=h+j|0;j=x[e>>2];x[e>>2]=j+4;B[j>>2]=f*E(9.313225746154785e-10);k=k+1|0;continue}break}g=g-1|0;continue}else{zi(a,b,c,l,m,d)}break}}ib=h+16|0}function NF(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=ib-48|0;ib=d;x[27524]=0;Y(958,a|0);e=x[27524];x[27524]=0;a:{b:{c:{if((e|0)!=1){e=Kb(d+32|0);x[27524]=0;Y(c|0,d+16|0);c=x[27524];x[27524]=0;d:{e:{if((c|0)!=1){h=d,i=Cb(x[d+16>>2]),x[h+8>>2]=i;f=1;while(1){g=Cb(x[d+20>>2]);c=x[d+8>>2];if(!Mb(c,g)){c=mg(Jc(e));ve(d+16|0);wb(e);break b}if(!f){x[27524]=0;Q(947,e|0,14619)|0;c=x[27524];x[27524]=0;if((c|0)==1){break e}c=x[d+8>>2]}x[27524]=0;Q(806,e|0,c|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break e}yq(d+8|0);f=0;continue}}c=V(0)|0;break d}c=V(0)|0;ve(d+16|0)}wb(e);break c}c=V(0)|0}_(c|0)|0;c=0;x[27524]=0;X(945,b|0,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)==1){break a}$()}ib=d+48|0;return c}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)==1){V(0)|0;Sb();p()}S(a|0);p()}function Yn(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=x[b+88>>2];d=c|2048;x[b+88>>2]=d;f=x[b+656>>2];if(!(!f|v[b+730|0]&1)){d=c|6144;x[b+88>>2]=d}a:{if(!x[b+76>>2]){break a}b:{if(!(d&8)|c&2048){break b}c=x[b+104>>2];if(!c){break b}e=z[c+34>>1];if(e&2){d=(e&4?d|4:d&-135)|2;x[b+88>>2]=d;e=x[c>>2];x[b+76>>2]=e;g=x[c+4>>2];x[b+80>>2]=g;c=x[c+8>>2];x[b+84>>2]=c;if(c>>>0<e>>>0){x[b+76>>2]=c;h=c}else{h=e}e=x[b+4>>2];if(h>>>0>=e>>>0){break b}x[b>>2]=0;x[b+4>>2]=((e-g>>>0)%(c-g>>>0)|0)+g;break b}d=d&-135;x[b+88>>2]=d;x[b+76>>2]=x[c>>2]}if(!f){break a}if(!(!(y[f+60|0]&2|x[a+480180>>2]&1064964)|!x[f>>2])){x[b+88>>2]=d|4096}if(y[f+65|0]==255|z[b+728>>1]!=65535){break a}i=b,j=dd(kq(f+48|0,x[b+724>>2],256,64)),w[i+728>>1]=j;i=b,j=z[Bb(x[f+48>>2],y[f+65|0])>>1],x[i+724>>2]=j}}function Mp(a){var b=E(0),c=0,d=0,e=0,f=0;c=ib-16|0;ib=c;e=(q(a),j(2));d=e&2147483647;a:{if(d>>>0<=1061752794){b=E(1);if(d>>>0<964689920){break a}b=ni(+a);break a}if(d>>>0<=1081824209){if(d>>>0>=1075235812){b=E(-ni(((e|0)<0?3.141592653589793:-3.141592653589793)+ +a));break a}f=+a;if((e|0)<0){b=oi(f+1.5707963267948966);break a}b=oi(1.5707963267948966-f);break a}if(d>>>0<=1088565717){if(d>>>0>=1085271520){b=ni(((e|0)<0?6.283185307179586:-6.283185307179586)+ +a);break a}if((e|0)<0){b=oi(-4.71238898038469-+a);break a}b=oi(+a+-4.71238898038469);break a}b=E(a-a);if(d>>>0>=2139095040){break a}b:{switch(ux(a,c+8|0)&3){case 0:b=ni(C[c+8>>3]);break a;case 1:b=oi(-C[c+8>>3]);break a;case 2:b=E(-ni(C[c+8>>3]));break a;default:break b}}b=oi(C[c+8>>3])}a=b;ib=c+16|0;return a}function u7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=ib+-64|0;ib=e;x[e+56>>2]=c;a=ge(a,e+56|0);c=sc(a+4|0);g=sc(a+24|0);h=sc(a+32|0);i=Nb(a+36|0);x[a+56>>2]=3;j=Nb(a+68|0);x[27524]=0;R(953,a|0,d|0);f=x[27524];x[27524]=0;a:{b:{c:{d:{if((f|0)!=1){he(e+16|0,x[b>>2],x[b+4>>2]);lg(e+24|0,x[e+16>>2],x[e+20>>2]);b=Id(e+8|0);x[27524]=0;f=x[b+4>>2];x[e>>2]=x[b>>2];x[e+4>>2]=f;Vr(957,e+32|0,x[e+24>>2],x[e+28>>2],e);b=x[27524];x[27524]=0;if((b|0)==1){break d}x[27524]=0;U(954,a|0,e+32|0,d|0);b=x[27524];x[27524]=0;if((b|0)==1){break c}yb(e+32|0);x[27524]=0;Y(955,a|0);b=x[27524];x[27524]=0;if((b|0)!=1){break a}}d=P()|0;break b}d=P()|0;break b}d=P()|0;yb(e+32|0)}ve(j);nf(i);hl(h);lh(g);kh(c);Xc(a);Xc(e+56|0);S(d|0);p()}Xc(e+56|0);ib=e- -64|0;return a|0}function G5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=ib-32|0;ib=d;j=d,k=aK(),x[j+24>>2]=k;g=a+24|0;c=d+24|0;ZJ(g,ce(c));lh(c);w[a+28>>1]=0;_R();f=ib-16|0;ib=f;e=mc(144);x[27524]=0;h=Q(1087,e|0,4)|0;i=x[27524];x[27524]=0;a:{if((i|0)!=1){e=x[uf(f+8|0,h)>>2];ib=f+16|0;break a}a=P()|0;Ib(e);S(a|0);p()}x[d+24>>2]=e;YJ(a+32|0,ce(c));hl(c);j=d,k=$J(x[a>>2]),x[j+24>>2]=k;XJ(a+4|0,ce(c));kh(c);Mn(x[g>>2],x[a+4>>2]);v[a+64|0]=1;x[a+60>>2]=0;x[a+48>>2]=1065353216;x[a+52>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;j=d,k=Ni(x[b>>2]),x[j+24>>2]=k;e=Gf(b);b:{while(1){b=x[d+24>>2];if(!Rg(b,e)){break b}c=ud(b);b=Pg(d+8|0,c);x[27524]=0;X(974,a|0,b|0,c+12|0,0);c=x[27524];x[27524]=0;if((c|0)!=1){wb(b);Ug(d+24|0);continue}break}a=P()|0;wb(b);S(a|0);p()}ib=d+32|0}function fZ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;g=ib-16|0;ib=g;bd(b,y[c+32|0]|y[c+33|0]<<8|(y[c+34|0]<<16|y[c+35|0]<<24));h=Nb(a);a=y[c+28|0]|y[c+29|0]<<8|(y[c+30|0]<<16|y[c+31|0]<<24);x[27524]=0;R(188,h|0,a|0);a=x[27524];x[27524]=0;if((a|0)!=1){a:{a=0;while(1){b:{if((y[c+28|0]|y[c+29|0]<<8|(y[c+30|0]<<16|y[c+31|0]<<24))>>>0<=a>>>0){break b}e=x[b+8>>2];f=x[b>>2];x[27524]=0;e=W(160,f|0,e|0,4)|0;f=x[27524];x[27524]=0;if((f|0)==1){break a}if(!e){break b}e=y[c+4|0]|y[c+5|0]<<8;x[27524]=0;e=Q(189,b|0,e|0)|0;f=x[27524];x[27524]=0;c:{if((f|0)!=1){x[g+12>>2]=e;if(wd(x[d>>2],x[d+4>>2])>>>0<=e>>>0){break c}x[27524]=0;R(190,h|0,g+12|0);e=x[27524];x[27524]=0;if((e|0)!=1){break c}}break a}a=a+1|0;continue}break}ib=g+16|0;return}}a=P()|0;uc(h);S(a|0);p()}function zN(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=ib-16|0;ib=c;e=x[b+4220>>2];f=x[b+4224>>2];g=x[b+4228>>2];h=x[b+4232>>2];i=x[b+4240>>2];j=x[b+4236>>2];l=y[b+4244|0];k=b+4208|0;Yi(k,33);d=x[k>>2];v[d+32|0]=l;v[d+24|0]=j;v[d+25|0]=j>>>8;v[d+26|0]=j>>>16;v[d+27|0]=j>>>24;v[d+28|0]=i;v[d+29|0]=i>>>8;v[d+30|0]=i>>>16;v[d+31|0]=i>>>24;v[d+16|0]=g;v[d+17|0]=g>>>8;v[d+18|0]=g>>>16;v[d+19|0]=g>>>24;v[d+20|0]=h;v[d+21|0]=h>>>8;v[d+22|0]=h>>>16;v[d+23|0]=h>>>24;v[d+8|0]=e;v[d+9|0]=e>>>8;v[d+10|0]=e>>>16;v[d+11|0]=e>>>24;v[d+12|0]=f;v[d+13|0]=f>>>8;v[d+14|0]=f>>>16;v[d+15|0]=f>>>24;v[d|0]=76;v[d+1|0]=70;v[d+2|0]=79;v[d+3|0]=32;v[d+4|0]=0;v[d+5|0]=0;v[d+6|0]=0;v[d+7|0]=0;he(c+8|0,x[k>>2],x[b+4212>>2]);dc(a,x[c+8>>2],x[c+12>>2]);ib=c+16|0}function x7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=ib+-64|0;ib=f;x[f+56>>2]=d;a=ge(a,f+56|0);d=sc(a+4|0);g=sc(a+24|0);h=sc(a+32|0);i=Nb(a+36|0);x[a+56>>2]=3;j=Nb(a+68|0);x[27524]=0;R(953,a|0,e|0);k=x[27524];x[27524]=0;a:{b:{c:{d:{if((k|0)!=1){cc(f+16|0,b,c);lg(f+24|0,x[f+16>>2],x[f+20>>2]);b=Id(f+8|0);x[27524]=0;c=x[b+4>>2];x[f>>2]=x[b>>2];x[f+4>>2]=c;Vr(957,f+32|0,x[f+24>>2],x[f+28>>2],f);b=x[27524];x[27524]=0;if((b|0)==1){break d}x[27524]=0;U(954,a|0,f+32|0,e|0);b=x[27524];x[27524]=0;if((b|0)==1){break c}yb(f+32|0);x[27524]=0;Y(955,a|0);b=x[27524];x[27524]=0;if((b|0)!=1){break a}}e=P()|0;break b}e=P()|0;break b}e=P()|0;yb(f+32|0)}ve(j);nf(i);hl(h);lh(g);kh(d);Xc(a);Xc(f+56|0);S(e|0);p()}Xc(f+56|0);ib=f- -64|0;return a|0}function MN(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;e=ib-16|0;ib=e;a:{if(tc(x[a>>2],x[a+4>>2])>>>0>511){break a}if(!fh(x[x[b>>2]-12>>2]+b|0)){break a}d=ib-16|0;ib=d;f=mc(64);x[27524]=0;g=T(841,f|0)|0;h=x[27524];x[27524]=0;b:{c:{if((h|0)!=1){f=uf(d,g);g=x[f>>2];x[27524]=0;g=W(900,g|0,b|0,c|0)|0;h=x[27524];x[27524]=0;d:{e:{if((h|0)!=1){if((g|0)==1){break e}sc(d+8|0);break d}a=P()|0;yg(f);break c}ge(d+8|0,f)}yg(f);ib=d+16|0;d=x[d+8>>2];break b}a=P()|0;Ib(f)}S(a|0);p()}x[e+8>>2]=d;f:{g:{if(!Ed(d)){x[27524]=0;b=Q(899,b|0,c|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break g}x[e>>2]=b;JV(e+8|0,ce(e));yg(e);d=x[e+8>>2]}if(!Ed(d)){break f}x[27524]=0;R(491,a|0,e+8|0);a=x[27524];x[27524]=0;i=d;if((a|0)!=1){break f}}a=P()|0;yg(e+8|0);S(a|0);p()}yg(e+8|0)}ib=e+16|0;return i}function eN(a){var b=0,c=0,d=0,e=0;b=ib-16|0;ib=b;e=(q(a),j(2));c=e&2147483647;a:{if(c>>>0<=1061752794){if(c>>>0<964689920){break a}a=oi(+a);break a}if(c>>>0<=1081824209){d=+a;if(c>>>0<=1075235811){if((e|0)<0){a=E(-ni(d+1.5707963267948966));break a}a=ni(d+-1.5707963267948966);break a}a=oi(-(((e|0)>=0?-3.141592653589793:3.141592653589793)+d));break a}if(c>>>0<=1088565717){if(c>>>0<=1085271519){d=+a;if((e|0)<0){a=ni(d+4.71238898038469);break a}a=E(-ni(d+-4.71238898038469));break a}a=oi(((e|0)<0?6.283185307179586:-6.283185307179586)+ +a);break a}if(c>>>0>=2139095040){a=E(a-a);break a}b:{switch(ux(a,b+8|0)&3){case 0:a=oi(C[b+8>>3]);break a;case 1:a=ni(C[b+8>>3]);break a;case 2:a=oi(-C[b+8>>3]);break a;default:break b}}a=E(-ni(C[b+8>>3]))}ib=b+16|0;return a}function CM(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=+c;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;j=ib-48|0;ib=j;k=x[a+4>>2];l=x[a>>2];a=x[a+8>>2];x[j+32>>2]=b;x[j+44>>2]=a;x[j+36>>2]=l;x[j+40>>2]=k;x[27524]=0;a=Q(938,(d?d:939)|0,e|0)|0;b=x[27524];x[27524]=0;a:{b:{c:{d:{if((b|0)!=1){x[j+16>>2]=a;a=x[ge(j+24|0,j+16|0)>>2];b=x[j+44>>2];x[j+8>>2]=x[j+40>>2];x[j+12>>2]=b;x[27524]=0;b=x[j+36>>2];x[j>>2]=x[j+32>>2];x[j+4>>2]=b;c=+sa(940,j|0,+c,a|0);a=x[27524];x[27524]=0;if((a|0)==1){break d}Xc(j+16|0);break b}a=V(0)|0;break c}a=V(0)|0;Xc(j+16|0)}_(a|0)|0;x[27524]=0;ia(941,15048,d|0,e|0,f|0,g|0,h|0,i|0);a=x[27524];x[27524]=0;if((a|0)==1){break a}$();c=0}ib=j+48|0;return+c}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function kq(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;h=ib-16|0;ib=h;f=x[a>>2];e=x[a+4>>2];i=$d(f,e)-1|0;while(1){a:{b:{if($d(f,e)-1>>>0<=g>>>0){g=i;break b}if(z[Mc(f,e,g)>>1]<(b|0)){break a}e=x[a+4>>2];f=x[a>>2]}i=z[Mc(f,e,g)>>1];f=0;x[h+12>>2]=0;c:{if((b|0)>=(i|0)){j=h,k=(y[Mc(x[a>>2],x[a+4>>2],g)+2|0]<<16>>>0)/(d>>>0)|0,x[j+12>>2]=k;break c}e=0;if(g){e=g-1|0;f=(y[Mc(x[a>>2],x[a+4>>2],e)+2|0]<<16>>>0)/(d>>>0)|0;x[h+12>>2]=f;e=z[Mc(x[a>>2],x[a+4>>2],e)>>1]}if((b|0)<=(e|0)|e>>>0>=i>>>0){break c}a=((y[Mc(x[a>>2],x[a+4>>2],g)+2|0]<<16>>>0)/(d>>>0)|0)-f|0;d=a;g=a>>31;a=b-e|0;b=qoa(d,g,a,a>>31);a=i-e|0;j=h,k=Dc(roa(b,kb,a,a>>31),kb)+f|0,x[j+12>>2]=k}re(h+12|0,0,65536);ib=h+16|0;return(D(x[h+12>>2],c)+32768|0)/65536|0}g=g+1|0;e=x[a+4>>2];f=x[a>>2];continue}}function WI(a){var b=E(0),c=E(0),d=E(0),e=E(0),f=E(0),g=E(0),h=E(0),i=E(0),j=E(0),k=E(0),l=E(0),m=E(0),n=E(0),o=E(0);f=B[a>>2];i=B[a+24>>2];c=E(f-i);d=B[a+16>>2];b=B[a+32>>2];g=B[a+8>>2];e=E(d+E(b-g));B[a+16>>2]=c+e;j=E(c-E(e*E(.5)));c=B[a+4>>2];e=B[a+20>>2];h=B[a+28>>2];k=E(E(E(c-e)-h)*E(.8660253882408142));B[a+4>>2]=j+k;l=E(E(d-b)*E(.1736481785774231));f=E(f+E(i*E(.5)));i=E(E(g+b)*E(.7660444378852844));m=E(l+E(f-i));n=E(E(c+e)*E(.9848077297210693));b=E(B[a+12>>2]*E(.8660253882408142));c=E(E(c+h)*E(.6427876353263855));o=E(E(n-b)-c);B[a+12>>2]=m+o;B[a+20>>2]=m-o;B[a+28>>2]=j-k;d=E(E(g+d)*E(.9396926164627075));g=E(E(f+d)-l);e=E(E(e-h)*E(.3420201539993286));h=E(E(e-b)-n);B[a+32>>2]=g+h;d=E(E(f-d)+i);b=E(E(b+e)-c);B[a+24>>2]=d+b;B[a+8>>2]=d-b;B[a>>2]=g-h}function tka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=ib-16|0;ib=e;v[e+15|0]=0;w[e+12>>1]=0;j=8;n=D(c,d)<<1;a:while(1){if((d|0)!=(k|0)){h=(k<<1)+b|0;o=n+h|0;while(1){b:{c:{if(h>>>0<o>>>0){w[e+10>>1]=0;HU(a,e+15|0,e+12|0,j,e+10|0);i=z[e+10>>1];f=z[e+12>>1];c=j;while(1){if(c&255){g=f<<1;f=g&254;d:{if(f){g=(g&65534)>>>0>255;break d}if(!vf(a,e+9|0)){break c}f=y[e+9|0];g=f>>>7|0;f=f<<1&254|1}c=c-1|0;i=i<<1|g;continue}break}w[e+12>>1]=f;break b}k=k+1|0;continue a}w[e+12>>1]=0}c=1;g=i&65535;e:{if(g>>>0<4){break e}f=15;while(1){c=f;m=f&255;if(g>>>m&1){break e}f=c-1|0;if(m>>>0>1){continue}break}}f=i&1;v[e+15|0]=f;l=(f-1^(i&65534)>>>1)+l|0;w[e+10>>1]=l;w[h>>1]=l;h=(d<<1)+h|0;j=(c+j&254)>>>1|0;continue}}break}ib=e+16|0}function Zha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=ib-80|0;ib=c;a:{d=x[a+4>>2];b:{if(d>>>0<b>>>0){f=Id(c+72|0);e=b-d|0;g=Ut(a);c:{if(!(e>>>0>g>>>0|d>>>0>g-e>>>0)){Im(c+56|0,x[a>>2],d);dc(f,x[c+56>>2],x[c+60>>2]);x[a+4>>2]=x[a+4>>2]+e;break c}d=ko(c+56|0);x[27524]=0;b=Q(734,a|0,b|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break a}x[27524]=0;R(735,d|0,b|0);b=x[27524];x[27524]=0;if((b|0)==1){break a}x[d+4>>2]=x[a+4>>2]+e;wl(c+40|0,x[a>>2]);Im(c+32|0,x[a>>2],x[a+4>>2]);wl(c+24|0,x[d>>2]);b=x[c+44>>2];x[c+8>>2]=x[c+40>>2];x[c+12>>2]=b;GT(c+48|0,c+8|0,x[c+32>>2],x[c+36>>2],x[c+24>>2],x[c+28>>2]);dc(f,x[c+48>>2],x[c+52>>2]);bu(a,d);$e(d)}a=dc(c+16|0,x[f>>2],x[f+4>>2]);Jv(x[a>>2],x[a+4>>2],e,0);break b}x[a+4>>2]=b}ib=c+80|0;return}a=P()|0;$e(d);S(a|0);p()}function j1(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=ib-16|0;ib=k;a:{if(a){a=IG(c);b:{if(b){Xk(k,a);b=x[k>>2];v[d|0]=b;v[d+1|0]=b>>>8;v[d+2|0]=b>>>16;v[d+3|0]=b>>>24;Wk(k,a);break b}$r(k,a);b=x[k>>2];v[d|0]=b;v[d+1|0]=b>>>8;v[d+2|0]=b>>>16;v[d+3|0]=b>>>24;Th(k,a)}aj(i,k);Gc(k);l=e,m=gj(a),x[l>>2]=m;l=f,m=hj(a),x[l>>2]=m;ih(k,a);Ac(g,k);wb(k);Uh(k,a);aj(h,k);Gc(k);a=Vk(a);break a}a=HG(c);c:{if(b){Xk(k,a);b=x[k>>2];v[d|0]=b;v[d+1|0]=b>>>8;v[d+2|0]=b>>>16;v[d+3|0]=b>>>24;Wk(k,a);break c}$r(k,a);b=x[k>>2];v[d|0]=b;v[d+1|0]=b>>>8;v[d+2|0]=b>>>16;v[d+3|0]=b>>>24;Th(k,a)}aj(i,k);Gc(k);l=e,m=gj(a),x[l>>2]=m;l=f,m=hj(a),x[l>>2]=m;ih(k,a);Ac(g,k);wb(k);Uh(k,a);aj(h,k);Gc(k);a=Vk(a)}x[j>>2]=a;ib=k+16|0}function TO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;a:{f=ib-16|0;ib=f;e=Kb(a);d=Ti(b);x[f+8>>2]=d;g=ir(b);a=0;b:{while(1){c:{if(!Mb(d,g)){if(!a){break c}x[27524]=0;R(49,e|0,65533);a=x[27524];x[27524]=0;if((a|0)!=1){break c}break b}b=y[d|0];d:{e:{if(!a){if(b<<24>>24>=0){a=0;x[27524]=0;R(49,e|0,b|0);b=x[27524];x[27524]=0;if((b|0)!=1){break d}break b}if((b&224)==192){c=b&31;a=1;break d}if((b&240)==224){c=b&15;a=2;break d}c=65533;if((b&248)!=240){break e}c=b&7;a=3;break d}if((b&192)!=128){c=0;x[27524]=0;R(49,e|0,65533);d=x[27524];x[27524]=0;a=0;if((d|0)==1){break b}}c=b&63|c<<6;a=a-1|0;if(a){break d}}a=0;x[27524]=0;R(49,e|0,c|0);b=x[27524];x[27524]=0;c=0;if((b|0)==1){break b}}d=x[Ie(f+8|0)>>2];continue}break}ib=f+16|0;break a}a=P()|0;Gc(e);S(a|0);p()}}function n1(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=ib-16|0;ib=k;a:{if(a){a=LG(c);b:{if(b){Xk(k,a);b=x[k>>2];v[d|0]=b;v[d+1|0]=b>>>8;v[d+2|0]=b>>>16;v[d+3|0]=b>>>24;Wk(k,a);break b}$r(k,a);b=x[k>>2];v[d|0]=b;v[d+1|0]=b>>>8;v[d+2|0]=b>>>16;v[d+3|0]=b>>>24;Th(k,a)}Ac(i,k);wb(k);l=e,m=gj(a),v[l|0]=m;l=f,m=hj(a),v[l|0]=m;ih(k,a);Ac(g,k);wb(k);Uh(k,a);Ac(h,k);wb(k);a=Vk(a);break a}a=KG(c);c:{if(b){Xk(k,a);b=x[k>>2];v[d|0]=b;v[d+1|0]=b>>>8;v[d+2|0]=b>>>16;v[d+3|0]=b>>>24;Wk(k,a);break c}$r(k,a);b=x[k>>2];v[d|0]=b;v[d+1|0]=b>>>8;v[d+2|0]=b>>>16;v[d+3|0]=b>>>24;Th(k,a)}Ac(i,k);wb(k);l=e,m=gj(a),v[l|0]=m;l=f,m=hj(a),v[l|0]=m;ih(k,a);Ac(g,k);wb(k);Uh(k,a);Ac(h,k);wb(k);a=Vk(a)}x[j>>2]=a;ib=k+16|0}function pU(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;while(1){if((c|0)!=20){g=b;b=v[a+c|0];b=g+((b&255)!=0&(b|0)<32)|0;c=c+1|0;continue}break}d=b;a:{if(b>>>0>5){break a}while(1){if((h|0)!=15){e=D(h,30)+a|0;f=e+20|0;c=0;b=0;while(1){if((c|0)!=22){g=b;b=v[c+f|0];b=g+((b&255)!=0&(b|0)<32)|0;c=c+1|0;continue}break}d=b+d|0;if(d>>>0>48){break a}c=y[e+45|0];if(y[e+44|0]|c>>>0>64){break a}b=Fb(y[e+42|0]|y[e+43|0]<<8);if(b>>>0>32768){break a}h=h+1|0;i=c|i;j=b+j|0;continue}break}if(!j|!(i&255)){break a}d=y[a+470|0];if(d>>>0>128){break a}b=y[a+471|0];if(b>>>0>220){break a}a=a+472|0;f=OA(a);b:{if((a|0)==(f|0)){break b}c=a;while(1){c=c+1|0;if((f|0)==(c|0)){break b}a=as(y[a|0],y[c|0])?c:a;continue}}a=y[a|0];if(a>>>0>63){break a}k=(b|(a|d))!=0}return k}function Q3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=ib-32|0;ib=c;x[c+28>>2]=0;if(Qd(y[jm(c+24|0,a,0)|0])){d=c+16|0;ed(d,x[x[a>>2]-12>>2]+a|0);x[27524]=0;d=T(1125,d|0)|0;e=x[27524];x[27524]=0;a:{b:{if((e|0)!=1){e=Jo(c+8|0,a);f=sc(c);g=x[x[a>>2]-12>>2];f=x[f>>2];e=x[e>>2];x[27524]=0;ma(1128,d|0,e|0,f|0,a+g|0,c+28|0,c+20|0);d=x[27524];x[27524]=0;if((d|0)!=1){break b}}b=V(0)|0;_b(c+16|0);_(b|0)|0;b=x[c+28>>2]|1;x[c+28>>2]=b;hm(x[x[a>>2]-12>>2]+a|0,b);c:{d:{if(x[(x[x[a>>2]-12>>2]+a|0)+20>>2]&1){x[27524]=0;Z(109);a=x[27524];x[27524]=0;if((a|0)!=1){break c}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)==1){break d}S(a|0);p()}$();break a}V(0)|0;Sb()}p()}_b(c+16|0);x[b>>2]=x[c+20>>2]}Kj(x[x[a>>2]-12>>2]+a|0,x[c+28>>2])}ib=c+32|0;return a|0}function yN(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=E(0);c=ib-80|0;ib=c;d=x[b>>2];b=x[b+4>>2];e=Id(c+48|0);f=x[e+4>>2];x[c>>2]=x[e>>2];x[c+4>>2]=f;b=yr(c+56|0,d,b,c);x[27524]=0;d=T(206,b|0)|0;e=x[27524];x[27524]=0;a:{if((e|0)==1){break a}x[27524]=0;d=W(911,b|0,c+8|0,d|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break a}b:{if(!d){break b}if(Qb(c+8|0,17600,4)|x[c+12>>2]){break b}g=a,h=Ld(B[c+16>>2],E(0)),B[g+4220>>2]=h;g=a,h=Ld(B[c+20>>2],E(0)),B[g+4224>>2]=h;g=a,h=Ld(B[c+24>>2],E(0)),B[g+4228>>2]=h;d=x[c+28>>2];if(d>>>0<=5){x[a+4232>>2]=d}x[a+4236>>2]=x[c+32>>2];v[a+4240|0]=y[c+36|0]!=0;v[a+4241|0]=y[c+37|0]!=0;v[a+4242|0]=y[c+38|0]!=0;v[a+4243|0]=y[c+39|0]!=0;v[a+4244|0]=y[c+40|0]!=0;et(a)}yb(b);ib=c+80|0;return}a=P()|0;yb(b);S(a|0);p()}function lz(a,b,c,d){var e=0,f=0,g=0,h=0;e=ib-16|0;ib=e;a:{if(!d){break a}if(c){v[b+815|0]=c;break a}c=y[b+815|0]}f=x[a+480180>>2];d=f&1048580;c=d?(c&240?-16:15)&c:c;b:{c:{d:{if(!d){d=c&240;e:{f:{g:{h:{c=c&15;if((c|0)==15){a=x[a+480208>>2]&4096;if(!d){break h}if(!a){break b}a=0-(d>>>2|0)|0;break d}a=x[a+480208>>2]&4096;if(!c|(d|0)!=240){break g}if(!a){break b}c=c<<2;break c}d=0;if(!a){break f}break b}if(a){break b}if(!c){break e}}c=c<<2;if(!(f&16777248)|!d){break c}break b}a=0-(d>>>2|0)|0;break d}if(y[a+480209|0]&16){break b}Ab(e+8|0,a+1074312|0,56);a=c&240;a=a?a>>>2|0:0-(c<<2&60)|0;if(!zb(x[x[e+8>>2]>>2],x[e+12>>2])){break d}a=(a|0)/4<<24>>24}c=a;if(!c){break b}}a=x[b+692>>2];w[b+784>>1]=0;g=b,h=Vb(a+c|0,0,256),x[g+692>>2]=h}ib=e+16|0}function uda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=ib-48|0;ib=e;g=Jc(b);d=Eb(b);i=Jc(c);h=Eb(c);d=d+g|0;f=-1;a:{while(1){if((d|0)==(g|0)){break a}d=d-1|0;if(Np(i,h,y[d|0])){continue}break}f=d-g|0}b:{c:{if((f|0)!=-1){k=e,l=ke(b),x[k+16>>2]=l;k=e,l=Op(e+16|0,f),x[k+24>>2]=l;k=e,l=Op(e+24|0,1),x[k+32>>2]=l;c=pj(e+40|0,e+32|0);k=e,l=Eh(b),x[k>>2]=l;d=pj(e+8|0,e);AN(b,x[c>>2],x[d>>2]);break c}if(!Eb(b)){break c}g=Jc(b);d=Eb(b);i=Jc(c);h=Eb(c);if(!d|!h){c=-1}else{c=g;f=d+c|0;h=h+i|0;while(1){d:{d=i;e:{if((c|0)!=(f|0)){while(1){if((d|0)==(h|0)){break e}j=v[d|0];d=d+1|0;if(!pc(v[c|0],j)){continue}break}}else{c=f}break d}c=c+1|0;continue}break}c=(c|0)==(f|0)?-1:c-g|0}if(c){break c}Kb(a);break b}$c(a,b)}ib=e+48|0}function xp(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0;o(+a);b=j(1)|0;d=j(0)|0;a:{b:{c:{d:{if((b|0)>0|(b|0)>=0){f=b;if(b>>>0>1048575){break d}}if(!(b&2147483647|d)){return-1/(a*a)}if((b|0)>0|(b|0)>=0){break c}return(a-a)/0}if(f>>>0>2146435071){break a}b=1072693248;g=-1023;if((f|0)!=1072693248){b=f;break b}if(d){break b}return 0}o(+(a*0x40000000000000));b=j(1)|0;d=j(0)|0;g=-1077}b=b+614242|0;h=+((b>>>20|0)+g|0);e=h*.6931471803691238;l(0,d|0);l(1,(b&1048575)+1072079006|0);a=+n()+-1;c=a/(a+2);i=e;k=a;m=c;e=a*(a*.5);c=c*c;a=c*c;a=i+(k+(m*(e+(a*(a*(a*.15313837699209373+.22222198432149784)+.3999999999940942)+c*(a*(a*(a*.14798198605116586+.1818357216161805)+.2857142874366239)+.6666666666666735)))+h*1.9082149292705877e-10-e))}return a}function il(a,b,c){var d=0,e=0,f=0,g=0;e=ib-48|0;ib=e;d=x[a+24>>2];g=x[d+24620>>2];a:{if(!((g|0)!=(b|0)|x[d+24624>>2]!=(c|0))){if(y[a+29|0]){break a}EO(d,1);break a}f=e+8|0;rc(f,d+24604|0,40);x[e+28>>2]=c;x[e+24>>2]=b;c=x[e+44>>2];Os(f,x[e+40>>2]);go(f,c);Xy(d,f);if((b|0)==(g|0)){break a}c=x[a+24>>2]+906300|0;d=rj(c);while(1){if((c|0)!=(d|0)){b=x[c>>2];b:{if(!b){break b}if(!(lb[x[x[b>>2]+120>>2]](b)|0)){break b}lb[x[x[b>>2]+112>>2]](b,0);lb[x[x[b>>2]+100>>2]](b);lb[x[x[b>>2]+128>>2]](b)}c=c+160|0;continue}break}c=x[a+24>>2]+906300|0;d=rj(c);while(1){if((c|0)!=(d|0)){b=x[c>>2];c:{if(!b){break c}if(lb[x[x[b>>2]+120>>2]](b)|0){break c}lb[x[x[b>>2]+112>>2]](b,1);lb[x[x[b>>2]+124>>2]](b)}c=c+160|0;continue}break}}v[a+29|0]=1;ib=e+48|0}function g_(a){a=a|0;var b=0,c=0,d=0,e=0;c=ib-192|0;ib=c;b=c+16|0;wi(b,a);x[27524]=0;R(89,c+32|0,b|0);a=x[27524];x[27524]=0;a:{b:{c:{d:{e:{if((a|0)!=1){x[27524]=0;a=Q(90,c+48|0,c+32|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break e}wb(c+32|0);wb(c+16|0);b=x[x[a>>2]-12>>2];x[27524]=0;d=ga(62)|0;e=x[27524];x[27524]=0;if((e|0)==1){break c}x[27524]=0;U(63,c+8|0,a+b|0,d|0);b=x[27524];x[27524]=0;if((b|0)==1){break c}_b(c+8|0);b=a+x[x[a>>2]-12>>2]|0;x[b+4>>2]=x[b+4>>2]&-75;x[b+4>>2]=x[b+4>>2]|8;x[27524]=0;b=Q(96,a|0,c+32|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break c}a=jh(x[(b+x[x[b>>2]-12>>2]|0)+16>>2]);d=x[c+32>>2];Cf(b);ib=c+192|0;a=a?0:d;break a}b=P()|0;break d}b=P()|0;wb(c+32|0)}wb(c+16|0);break b}b=P()|0;Cf(a)}S(b|0);p()}return a|0}function $C(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;g=ib-16|0;ib=g;e=x[b>>2];d=Oc(e,x[b+4>>2]);a:{if(d>>>0<c>>>0){i=ib-32|0;ib=i;d=c-d|0;f=x[Db(b)>>2];e=x[b+4>>2];b:{if(d>>>0<=f-e>>1>>>0){f=ib-16|0;ib=f;e=ei(f,b,d);d=x[e+4>>2];h=x[e+8>>2];while(1){if((d|0)==(h|0)){ic(e);ib=f+16|0}else{Mo(d);d=d+2|0;x[e+4>>2]=d;continue}break}break b}f=Db(b);e=Uj(i+8|0,Vj(b,Oc(x[b>>2],e)+d|0),Oc(x[b>>2],x[b+4>>2]),f);h=ib-16|0;ib=h;d=Uo(h,e+8|0,d);f=x[d>>2];while(1){if(x[d+4>>2]!=(f|0)){Mo(f);f=x[d>>2]+2|0;x[d>>2]=f;continue}break}Vd(d);ib=h+16|0;Dd(b,e);Ui(e)}ib=i+32|0;break a}if(c>>>0<d>>>0){Od(b,e+(c<<1)|0)}}c=Ob(x[a>>2],x[a+8>>2],c<<1);if(c){d=x[b>>2];cc(g+8|0,d,Oc(d,x[b+4>>2])<<1);sd(g,a,x[g+8>>2],x[g+12>>2])}ib=g+16|0;return c|0}function ska(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=ib-16|0;ib=e;v[e+15|0]=0;w[e+12>>1]=0;n=D(c,d);j=4;a:while(1){if((d|0)!=(k|0)){h=b+k|0;o=n+h|0;while(1){b:{c:{if(h>>>0<o>>>0){v[e+11|0]=0;GU(a,e+15|0,e+12|0,e+11|0);i=y[e+11|0];f=z[e+12>>1];c=j;while(1){if(c&255){g=f<<1;f=g&254;d:{if(f){g=(g&65534)>>>0>255;break d}if(!vf(a,e+10|0)){break c}f=y[e+10|0];g=f>>>7|0;f=f<<1&254|1}c=c-1|0;i=i<<1|g;continue}break}w[e+12>>1]=f;break b}k=k+1|0;continue a}w[e+12>>1]=0}c=1;g=i&255;e:{if(g>>>0<4){break e}f=7;while(1){c=f;m=f&255;if(g>>>m&1){break e}f=c-1|0;if(m>>>0>1){continue}break}}f=i&1;v[e+15|0]=f;l=(f-1^(i&254)>>>1)+l|0;v[e+11|0]=l;v[h|0]=l;h=d+h|0;j=(c+j&254)>>>1|0;continue}}break}ib=e+16|0}function Nfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=ib-48|0;ib=g;h=a+8|0;c=x[a+8>>2];j=zc(a);a:{if((c|0)!=x[j>>2]){break a}i=a+4|0;d=x[a+4>>2];e=x[a>>2];if(d>>>0>e>>>0){a=((d-e>>2)+1|0)/-2<<2;c=ji(d,c,a+d|0);x[h>>2]=c;x[i>>2]=a+x[i>>2];break a}x[g+24>>2]=c-e>>1;x[g+44>>2]=1;d=g+24|0;c=x[Yc(d,g+44|0)>>2];c=cg(d,c,c>>>2|0,x[a+16>>2]);e=Wb(g+16|0,x[a+4>>2]);f=x[Wb(g+8|0,x[a+8>>2])>>2];d=ib-32|0;ib=d;e=x[e>>2];x[d+24>>2]=e;e=Ym(d+8|0,c+8|0,vu(f,e));f=x[e>>2];while(1){if(x[e+4>>2]!=(f|0)){k=f;f=x[d+24>>2];Lm(k,z[f>>1]|z[f+2>>1]<<16);f=x[e>>2]+4|0;x[e>>2]=f;Pe(d+24|0);continue}break}Vd(e);ib=d+32|0;oc(a,c);oc(i,c+4|0);oc(h,c+8|0);oc(j,zc(c));bg(c);c=x[a+8>>2]}Lm(c,z[b>>1]|z[b+2>>1]<<16);x[h>>2]=x[h>>2]+4;ib=g+48|0}function jp(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=ib-32|0;ib=d;x[d+28>>2]=0;a:{b:{c:{if(Qd(y[jm(d+24|0,a,0)|0])){f=d+16|0;ed(f,x[x[a>>2]-12>>2]+a|0);x[27524]=0;f=T(1125,f|0)|0;e=x[27524];x[27524]=0;d:{e:{if((e|0)==1){break e}e=Jo(d+8|0,a);g=sc(d);h=x[x[a>>2]-12>>2];g=x[g>>2];e=x[e>>2];x[27524]=0;ma(c|0,f|0,e|0,g|0,a+h|0,d+28|0,b|0);b=x[27524];x[27524]=0;if((b|0)==1){break e}_b(d+16|0);break d}b=V(0)|0;_b(d+16|0);_(b|0)|0;b=x[d+28>>2]|1;x[d+28>>2]=b;hm(x[x[a>>2]-12>>2]+a|0,b);if(x[(x[x[a>>2]-12>>2]+a|0)+20>>2]&1){x[27524]=0;Z(109);a=x[27524];x[27524]=0;if((a|0)!=1){break b}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)==1){break c}S(a|0);p()}$()}Kj(x[x[a>>2]-12>>2]+a|0,x[d+28>>2])}ib=d+32|0;break a}V(0)|0;Sb()}p()}return a}function UO(a,b){var c=E(0),d=E(0),e=E(0);a:{b:{c:{switch(b|0){case 0:Up(a,E(1));lk(a,E(3.725290298461914e-9));Tp(a,E(268435456));Sp(a,0);break b;case 1:Up(a,E(32));lk(a,E(4.656612873077393e-10));Tp(a,E(2147483648));Sp(a,0);break b;case 2:Up(a,E(2));lk(a,E(7.450580596923828e-9));Tp(a,E(134217728));Sp(a,1);break b;default:Up(a,E(1));lk(a,E(7.450580596923828e-9));Tp(a,E(134217728));Sp(a,1);Py(a,0);Oy(a,1);Ny(a,1);d=E(256);c=E(128);e=E(128);b=0;break a;case 4:case 5:break c}}Up(a,E(.75));lk(a,E(7.450580596923828e-9));Tp(a,E(134217728));Sp(a,1);Py(a,0);b=(b|0)==4;Oy(a,b?2:3);Ny(a,1);d=E(256);c=b?E(256):E(192);e=c;b=1;break a}Py(a,1);Oy(a,0);Ny(a,0);d=E(128);e=E(100);c=E(256);b=4}B[a+16>>2]=c;B[a+20>>2]=e;B[a+24>>2]=d;x[a+28>>2]=b}function wU(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;o=x[b>>2];while(1){if((i|0)==128){Dg(b,c);c=x[a+8>>2];d=c+d|0;i=z[e>>1];a:{b:{c:{if(!f){break c}j=f;f=h&65535;if((c+(j+(f<<11)|0)|0)!=(bh(x[a>>2])&-2)){break c}bd(a,c+(f<<10)|0);if(!TA(a,16,1)){break b}w[e>>1]=8;break b}if((h&65535)==(k&65535)){h=k;break a}f=k<<8&16776960;if(!g){if((bh(x[a>>2])|0)!=(d+D(f,i)|0)){break a}}bd(a,c+D(f,z[e>>1])|0);h=TA(a,64,1)?h:k}bd(a,c)}c=l&65535;d:{if(c>>>0>(h&65535)>>>0){if((d+(D(c,z[e>>1])<<8)|0)==(bh(x[a>>2])|0)){break d}}if(c>>>0>=255){SA(b,254,65534);SA(b,255,65535)}l=h}a=l&65535}else{j=z[bc(o,i)>>1];m=j+1|0;n=(h&65535)>>>0>j>>>0|j>>>0>127;k=n?k:c>>>0>i>>>0?m:k;l=(l&65535)>>>0>j>>>0?l:m;h=n?h:m;i=i+1|0;continue}break}return a}function uI(a,b,c,d){a:{switch(b-9|0){case 0:b=x[c>>2];x[c>>2]=b+4;x[a>>2]=x[b>>2];return;case 6:b=x[c>>2];x[c>>2]=b+4;b=w[b>>1];x[a>>2]=b;x[a+4>>2]=b>>31;return;case 7:b=x[c>>2];x[c>>2]=b+4;x[a>>2]=z[b>>1];x[a+4>>2]=0;return;case 8:b=x[c>>2];x[c>>2]=b+4;b=v[b|0];x[a>>2]=b;x[a+4>>2]=b>>31;return;case 9:b=x[c>>2];x[c>>2]=b+4;x[a>>2]=y[b|0];x[a+4>>2]=0;return;case 16:b=x[c>>2]+7&-8;x[c>>2]=b+8;C[a>>3]=C[b>>3];return;case 17:lb[d|0](a,c);default:return;case 1:case 4:case 14:b=x[c>>2];x[c>>2]=b+4;b=x[b>>2];x[a>>2]=b;x[a+4>>2]=b>>31;return;case 2:case 5:case 11:case 15:b=x[c>>2];x[c>>2]=b+4;x[a>>2]=x[b>>2];x[a+4>>2]=0;return;case 3:case 10:case 12:case 13:break a}}b=x[c>>2]+7&-8;x[c>>2]=b+8;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c}function Zn(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;g=ib-16|0;ib=g;if(e){x[e>>2]=0}a:{h=x[a+484344>>2];if(!Ce(h,x[a+484348>>2],b)){break a}i=Xb(h,b);k=x[i+48>>2];b=hd(x[i>>2],x[k+12>>2],c,d);f=y[b+5|0];b:{c:{d:{e:{j=y[b+3|0];switch(j-10|0){case 1:case 3:case 5:case 6:break a;case 0:break c;case 2:case 4:case 7:break d;default:break e}}if(j-35>>>0>=2){break a}}x[g+12>>2]=1;h=0;if((j|0)!=17){break b}h=x[a+480180>>2]==4;break b}x[g+12>>2]=2;h=0}x[g+8>>2]=x[i+12>>2]+(c^-1);d=0;c=x[Hb(g+8|0,g+12|0)>>2];a=c;while(1){f:{if(a){b=D(Cg(x[k+12>>2]),6)+b|0;if(y[b+3|0]==34){break f}c=d}f=(j-37&255)>>>0<254?f:c?f:f<<8;if(!e){break a}x[e>>2]=c;break a}i=f<<8;f=y[b+5|0]|(h?f>>>0<256?i+-8192|0:i:i);d=d+1|0;a=a-1|0;continue}}ib=g+16|0;return f}function $v(a,b,c,d){var e=0,f=0,g=0,h=0;e=ib+-64|0;ib=e;x[e+60>>2]=d;a:{f=x[b>>2];b:{if(!(lb[x[x[f>>2]+36>>2]](f,c,d)|0)){Oh(a);break b}Rl(e+40|0,x[b>>2],x[b+4>>2]);b=x[b>>2];d=x[x[b>>2]+24>>2];x[27524]=0;b=T(d|0,b|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break a}x[e+36>>2]=b-c;g=x[Hb(e+60|0,e+36|0)>>2];b=x[e+44>>2];x[e+16>>2]=x[e+40>>2];x[e+20>>2]=b;b=ib-16|0;ib=b;d=e+16|0;f=Rl(b+8|0,x[d>>2],x[d+4>>2]);x[27524]=0;h=x[f+4>>2];x[b>>2]=x[f>>2];x[b+4>>2]=h;X(176,e+48|0,b|0,c|0,g|0);c=x[27524];x[27524]=0;c:{if((c|0)!=1){Ud(d);ib=b+16|0;break c}a=P()|0;Ud(d);S(a|0);p()}b=Id(e+24|0);c=x[e+52>>2];x[e+8>>2]=x[e+48>>2];x[e+12>>2]=c;c=x[b+4>>2];x[e>>2]=x[b>>2];x[e+4>>2]=c;$o(a,e+8|0,e)}ib=e- -64|0;return}a=P()|0;Ud(e+40|0);S(a|0);p()}function eF(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;h=ib-32|0;ib=h;f=wf(h+16|0,1,0);a:{b:{while(1){j=h+8|0;e=vc(f);g=e;i=Eb(f)+e|0;e=y[b|0];c:{if((c|0)==10){LK(j,g,i,e);break c}k=c>>>0>e>>>0?1:D(c,c)>>>0>e>>>0?2:3;if((k|0)>(i-g|0)){x[j+4>>2]=61;x[j>>2]=i;break c}i=g+k|0;g=i;while(1){k=e&255;e=(k|0)/(c|0)|0;g=g-1|0;v[g|0]=y[(k-D(c,e)|0)+4898|0];if(e&255){continue}break}x[j+4>>2]=0;x[j>>2]=i}if(!x[h+12>>2]){break b}e=Og(Eb(f));x[27524]=0;R(59,f|0,e|0);e=x[27524];x[27524]=0;if((e|0)!=1){continue}break}break a}b=x[h+8>>2];c=vc(f);x[27524]=0;R(60,f|0,b-c|0);b=x[27524];x[27524]=0;d:{if((b|0)!=1){x[27524]=0;R(d|0,a|0,f|0);a=x[27524];x[27524]=0;if((a|0)!=1){break d}break a}break a}wb(f);ib=h+32|0;return}a=P()|0;wb(f);S(a|0);p()}function sea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{b:{c:{switch(b-850|0){default:d:{e:{if((b|0)!=437){if((b|0)==737){break e}if((b|0)==775){break d}if((b|0)==1252){break b}d=0;if((b|0)==65001){break a}f:{if((b|0)!=28591){if((b|0)==28605){break f}if((b|0)!=20127){break b}d=1;break a}d=2;break a}d=3;break a}d=4;break a}d=5;break a}d=6;break a;case 0:d=7;break a;case 2:d=8;break a;case 5:d=9;break a;case 7:d=10;break a;case 10:d=11;break a;case 11:d=12;break a;case 12:d=13;break a;case 13:d=14;break a;case 14:d=15;break a;case 15:d=16;break a;case 16:d=17;break a;case 19:d=18;break a;case 1:case 3:case 4:case 6:case 8:case 9:case 17:case 18:case 20:case 21:case 22:case 23:break b;case 24:break c}}d=19;break a}d=22}uD(a,d,c)}function hia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;g=ib-16|0;ib=g;e=x[b>>2];d=xg(e,x[b+4>>2]);a:{if(d>>>0<c>>>0){i=ib-32|0;ib=i;d=c-d|0;f=x[Db(b)>>2];e=x[b+4>>2];b:{if(d>>>0<=f-e>>5>>>0){f=ib-16|0;ib=f;e=rA(f,b,d);d=x[e+4>>2];h=x[e+8>>2];while(1){if((d|0)==(h|0)){ic(e);ib=f+16|0}else{sS(d);d=d+32|0;x[e+4>>2]=d;continue}break}break b}f=Db(b);e=Vt(i+8|0,oq(b,xg(x[b>>2],e)+d|0),xg(x[b>>2],x[b+4>>2]),f);h=ib-16|0;ib=h;d=tS(h,e+8|0,d);f=x[d>>2];while(1){if(x[d+4>>2]!=(f|0)){sS(f);f=x[d>>2]+32|0;x[d>>2]=f;continue}break}Vd(d);ib=h+16|0;Dd(b,e);uS(e)}ib=i+32|0;break a}if(c>>>0<d>>>0){Od(b,e+(c<<5)|0)}}if(Ob(x[a>>2],x[a+8>>2],c<<5)){c=x[b>>2];cc(g+8|0,c,xg(c,x[b+4>>2])<<5);sd(g,a,x[g+8>>2],x[g+12>>2])}ib=g+16|0}function DH(a,b,c,d,e,f){var g=0;g=ib-80|0;ib=g;a:{if((f|0)>=16384){Jd(g+32|0,b,c,d,e,0,0,0,2147352576);d=x[g+40>>2];e=x[g+44>>2];b=x[g+32>>2];c=x[g+36>>2];if(f>>>0<32767){f=f-16383|0;break a}Jd(g+16|0,b,c,d,e,0,0,0,2147352576);f=((f|0)>=49149?49149:f)-32766|0;d=x[g+24>>2];e=x[g+28>>2];b=x[g+16>>2];c=x[g+20>>2];break a}if((f|0)>-16383){break a}Jd(g- -64|0,b,c,d,e,0,0,0,7471104);d=x[g+72>>2];e=x[g+76>>2];b=x[g+64>>2];c=x[g+68>>2];if(f>>>0>4294934644){f=f+16269|0;break a}Jd(g+48|0,b,c,d,e,0,0,0,7471104);f=((f|0)<=-48920?-48920:f)+32538|0;d=x[g+56>>2];e=x[g+60>>2];b=x[g+48>>2];c=x[g+52>>2]}Jd(g,b,c,d,e,0,0,0,f+16383<<16);b=x[g+12>>2];x[a+8>>2]=x[g+8>>2];x[a+12>>2]=b;b=x[g+4>>2];x[a>>2]=x[g>>2];x[a+4>>2]=b;ib=g+80|0}function CZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;h=ib-16|0;ib=h;f=nd(b);d=xd(x[b+4>>2],y[b+11|0]);i=nd(c);g=xd(x[c+4>>2],y[c+11|0]);d=d+f|0;e=-1;a:{while(1){if((d|0)==(f|0)){break a}d=d-1|0;if(Au(i,g,y[d|0])){continue}break}e=d-f|0}b:{c:{if((e|0)!=-1){c=Wb(h+8|0,Yf(Yf(Ti(b),e),1));d=Wb(h,ir(b));BD(b,x[c>>2],x[d>>2]);break c}if(!Ik(x[b+4>>2],y[b+11|0])){break c}f=nd(b);d=xd(x[b+4>>2],y[b+11|0]);i=nd(c);g=xd(x[c+4>>2],y[c+11|0]);if(!d|!g){c=-1}else{c=f;e=d+c|0;g=g+i|0;while(1){d:{d=i;e:{if((c|0)!=(e|0)){while(1){if((d|0)==(g|0)){break e}j=y[d|0];d=d+1|0;if(!pc(y[c|0],j)){continue}break}}else{c=e}break d}c=c+1|0;continue}break}c=(c|0)==(e|0)?-1:c-f|0}if(c){break c}Kb(a);break b}$c(a,b)}ib=h+16|0}function Kda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=ib-32|0;ib=f;c=Cg(x[x[a+48>>2]+12>>2]);a:{if(!b){break a}c=D(b,c);b:{if(x[a+12>>2]!=(b|0)){break b}if((xk(x[a>>2],x[a+4>>2])|0)!=(c|0)){break b}b=ib-16|0;ib=b;d=Cb(x[a>>2]);a=Cb(x[a+4>>2]);Jj(b+8|0);e=mt(a,d);c=ib-16|0;ib=c;x[c+8>>2]=d;while(1){if((e|0)>0){a=x[c+8>>2];d=y[b+8|0]|y[b+9|0]<<8|(y[b+10|0]<<16|y[b+11|0]<<24);v[a|0]=d;v[a+1|0]=d>>>8;v[a+2|0]=d>>>16;v[a+3|0]=d>>>24;d=y[b+12|0]|y[b+13|0]<<8;v[a+4|0]=d;v[a+5|0]=d>>>8;e=e-1|0;Hk(c+8|0);continue}break}ib=c+16|0;ib=b+16|0;break a}e=f+8|0;Jj(e);c=QV(f+16|0,c,e);eO(a);x[a>>2]=x[c>>2];x[a+4>>2]=x[c+4>>2];e=Db(c);g=Db(a),h=x[e>>2],x[g>>2]=h;x[e>>2]=0;x[c>>2]=0;x[c+4>>2]=0;Ck(c);x[a+12>>2]=b}ib=f+32|0}function FF(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;f=ib+-64|0;ib=f;x[f+56>>2]=c;a=ge(a,f+56|0);c=sc(a+4|0);h=sc(a+24|0);i=sc(a+32|0);j=Nb(a+36|0);x[a+56>>2]=3;k=Nb(a+68|0);x[27524]=0;R(953,a|0,d|0);g=x[27524];x[27524]=0;a:{b:{c:{d:{if((g|0)!=1){he(f+24|0,x[b>>2],x[b+4>>2]);b=Id(f+16|0);x[27524]=0;g=x[b+4>>2];x[f+8>>2]=x[b>>2];x[f+12>>2]=g;Vr(e,f+32|0,x[f+24>>2],x[f+28>>2],f+8|0);b=x[27524];x[27524]=0;if((b|0)==1){break d}x[27524]=0;U(954,a|0,f+32|0,d|0);b=x[27524];x[27524]=0;if((b|0)==1){break c}yb(f+32|0);x[27524]=0;Y(955,a|0);b=x[27524];x[27524]=0;if((b|0)!=1){break a}}d=P()|0;break b}d=P()|0;break b}d=P()|0;yb(f+32|0)}ve(k);nf(j);hl(i);lh(h);kh(c);Xc(a);Xc(f+56|0);S(d|0);p()}Xc(f+56|0);ib=f- -64|0;return a}function ux(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=ib-16|0;ib=e;g=(q(a),j(2));c=g&2147483647;a:{if(c>>>0<=1305022426){h=+a;f=h*.6366197723675814+6755399441055744+-6755399441055744;d=h+f*-1.5707963109016418+f*-1.5893254773528196e-8;C[b>>3]=d;g=d<-.7853981852531433;if(F(f)<2147483648){c=~~f}else{c=-2147483648}if(g){d=f+-1;C[b>>3]=h+d*-1.5707963109016418+d*-1.5893254773528196e-8;c=c-1|0;break a}if(!(d>.7853981852531433)){break a}d=f+1;C[b>>3]=h+d*-1.5707963109016418+d*-1.5893254773528196e-8;c=c+1|0;break a}if(c>>>0>=2139095040){C[b>>3]=E(a-a);c=0;break a}i=c;c=(c>>>23|0)-150|0;C[e+8>>3]=(l(2,i-(c<<23)|0),r());c=zI(e+8|0,e,c,1,0);d=C[e>>3];if((g|0)<0){C[b>>3]=-d;c=0-c|0;break a}C[b>>3]=d}ib=e+16|0;return c}function kM(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0;f=c-b|0;a:{if((f|0)<=19){g=G(e);g=D(64-((g|0)==32?G(d|1)+32|0:g)|0,1233)>>12;i=(g<<3)+25808|0;j=f;f=x[i+4>>2];h=61;if((j|0)<(((e|0)==(f|0)&d>>>0>=A[i>>2]|e>>>0>f>>>0)+g|0)){break a}}b:{if(!e&d>>>0<=99999999){c=sx(b,d);break b}if((e|0)==2328306&d>>>0<=1874919423|e>>>0<2328306){f=b;b=soa(d,e,1e8,0);c=kb;e=sx(f,b);b=qoa(b,c,-1e8,0)+d|0;c=(b>>>0)/1e4|0;c=kj(kj(e,c),b+D(c,-1e4)|0);break b}f=b;b=soa(d,e,1874919424,2328306);c=kb;f=rx(f,b);b=qoa(b,c,-1874919424,-2328307)+d|0;c=e+kb|0;c=b>>>0<d>>>0?c+1|0:c;c=soa(b,c,1e8,0);d=kb;e=(c>>>0)/1e4|0;e=kj(kj(f,e),c+D(e,-1e4)|0);c=qoa(c,d,-1e8,0)+b|0;b=c;c=(c>>>0)/1e4|0;c=kj(kj(e,c),b+D(c,-1e4)|0)}h=0}x[a+4>>2]=h;x[a>>2]=c}function fha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=ib-16|0;ib=b;f=x[a+40>>2];g=x[a+36>>2];j=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;k=x[a+32>>2];l=x[a+28>>2];m=x[a+8>>2];n=x[a+12>>2];while(1){if(d){e=x[b+8>>2];o=e>>>18|0;p=((((x[b+12>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+j|0;e=0;while(1){if((e|0)!=2){h=(e<<1)+p|0;i=w[h>>1];x[(e<<2)+b>>2]=i+((D(w[h+4>>1]-i|0,o)|0)/16384|0);e=e+1|0;continue}break}g=g+l|0;x[c>>2]=x[c>>2]+D(x[b>>2],g>>12);f=f+k|0;x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],f>>12);Pb(b+8|0,m,n);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;ib=b+16|0}function q3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=x[b+44>>2];i=x[b+24>>2];if(h>>>0<i>>>0){x[b+44>>2]=i;h=i}l=-1;m=-1;n=f&24;a:{if(!n|(e|0)==1&(n|0)==24){break a}if(h){g=h-vc(b+32|0)|0;o=g;g=g>>31}b:{c:{switch(e|0){case 1:if(f&8){e=x[b+12>>2]-x[b+8>>2]|0;j=e;k=e>>31;break b}e=i-x[b+20>>2]|0;j=e;k=e>>31;break b;case 0:break b;case 2:break c;default:break a}}j=o;k=g}d=d+k|0;c=c+j|0;d=j>>>0>c>>>0?d+1|0:d;e=c;c=d;if((g|0)<=(d|0)&e>>>0>o>>>0|(d|0)>(g|0)|(d|0)<0){break a}d=f&8;d:{if(!(c|e)){break d}if(x[b+12>>2]?0:d){break a}if(!(f&16)){break d}if(!i){break a}}if(d){d=x[b+8>>2];Fn(b,d,d+e|0,h)}if(f&16){hx(b,x[b+20>>2],x[b+28>>2]);rs(b,e)}l=e;m=c}Nf(a,l,m)}function paa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=ib-16|0;ib=e;f=ib-32|0;ib=f;d=wf(f+16|0,1,0);a:{b:{c:{while(1){j=f+8|0;c=vc(d);i=Eb(d)+c|0;h=x[b>>2];g=x[b+4>>2];if(!((g|0)>0|(g|0)>=0|(c|0)==(i|0))){v[c|0]=45;h=pM(h,g);g=kb;c=c+1|0}kM(j,c,i,h,g);if(!x[f+12>>2]){break c}c=Og(Eb(d));x[27524]=0;R(59,d|0,c|0);c=x[27524];x[27524]=0;if((c|0)!=1){continue}break}break b}b=x[f+8>>2];c=vc(d);x[27524]=0;R(60,d|0,b-c|0);b=x[27524];x[27524]=0;d:{if((b|0)!=1){x[27524]=0;R(61,e|0,d|0);b=x[27524];x[27524]=0;if((b|0)!=1){break d}break b}break b}wb(d);ib=f+32|0;break a}a=P()|0;wb(d);S(a|0);p()}x[27524]=0;R(58,a|0,e|0);a=x[27524];x[27524]=0;if((a|0)!=1){wb(e);ib=e+16|0;return}a=P()|0;wb(e);S(a|0);p()}function B4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=ib-80|0;ib=d;x[27524]=0;e=T(1107,b|0)|0;f=x[27524];x[27524]=0;if((f|0)!=1){a:{b:{if(e){x[27524]=0;R(1108,d+56|0,b|0);b=x[27524];x[27524]=0;if((b|0)!=1){b=d- -64|0;_o(b,x[d+56>>2],x[d+60>>2]);e=zf(d+72|0,b);f=zf(d+48|0,c);g=x[e+4>>2];x[d+8>>2]=x[e>>2];x[d+12>>2]=g;e=x[f+4>>2];x[d>>2]=x[f>>2];x[d+4>>2]=e;$o(a,d+8|0,d);break b}break a}x[27524]=0;R(1109,d+56|0,b|0);b=x[27524];x[27524]=0;if((b|0)==1){break a}b=d- -64|0;_o(b,x[d+56>>2],x[d+60>>2]);e=zf(d+40|0,b);f=zf(d+32|0,c);g=x[e+4>>2];x[d+24>>2]=x[e>>2];x[d+28>>2]=g;e=x[f+4>>2];x[d+16>>2]=x[f>>2];x[d+20>>2]=e;$o(a,d+24|0,d+16|0)}Ud(b);Ud(d+56|0);Ud(c);ib=d+80|0;return}}a=P()|0;Ud(c);S(a|0);p()}function y5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=ib-80|0;ib=d;a=x[a+4>>2];aw(d+16|0,b);x[27524]=0;b=Q(1,d|0,17746)|0;e=x[27524];x[27524]=0;a:{b:{c:{d:{e:{f:{g:{h:{if((e|0)!=1){x[27524]=0;U(2,d+32|0,d+16|0,b|0);e=x[27524];x[27524]=0;if((e|0)==1){break h}x[27524]=0;U(481,d+48|0,d+32|0,c|0);c=x[27524];x[27524]=0;if((c|0)==1){break g}x[27524]=0;R(1021,d- -64|0,d+48|0);c=x[27524];x[27524]=0;if((c|0)==1){break f}c=x[x[a>>2]+8>>2];x[27524]=0;R(c|0,a|0,d- -64|0);a=x[27524];x[27524]=0;if((a|0)==1){break e}wb(d- -64|0);xb(d+48|0);xb(d+32|0);xb(b);xb(d+16|0);ib=d+80|0;return}a=P()|0;break a}a=P()|0;break b}a=P()|0;break c}a=P()|0;break d}a=P()|0;wb(d- -64|0)}xb(d+48|0)}xb(d+32|0)}xb(b)}xb(d+16|0);S(a|0);p()}function mU(a,b){var c=0,d=0,e=0;c=ib-32|0;ib=c;a:{if(!Ob(x[a>>2],x[a+8>>2],1024)){x[c+24>>2]=0;x[c+28>>2]=0;x[c+16>>2]=0;x[c+20>>2]=0;a=64;while(1){if(a){d=y[c+20|0]|y[c+21|0]<<8|(y[c+22|0]<<16|y[c+23|0]<<24);e=y[c+16|0]|y[c+17|0]<<8|(y[c+18|0]<<16|y[c+19|0]<<24);v[b|0]=e;v[b+1|0]=e>>>8;v[b+2|0]=e>>>16;v[b+3|0]=e>>>24;v[b+4|0]=d;v[b+5|0]=d>>>8;v[b+6|0]=d>>>16;v[b+7|0]=d>>>24;d=y[c+28|0]|y[c+29|0]<<8|(y[c+30|0]<<16|y[c+31|0]<<24);e=y[c+24|0]|y[c+25|0]<<8|(y[c+26|0]<<16|y[c+27|0]<<24);v[b+8|0]=e;v[b+9|0]=e>>>8;v[b+10|0]=e>>>16;v[b+11|0]=e>>>24;v[b+12|0]=d;v[b+13|0]=d>>>8;v[b+14|0]=d>>>16;v[b+15|0]=d>>>24;a=a-1|0;b=b+16|0;continue}break}break a}QA(c+8|0,b);sd(c+16|0,a,x[c+8>>2],x[c+12>>2])}ib=c+32|0}function SF(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=0;g=ib+-64|0;ib=g;x[g+56>>2]=d;a=ge(a,g+56|0);d=sc(a+4|0);h=sc(a+24|0);i=sc(a+32|0);j=Nb(a+36|0);x[a+56>>2]=3;k=Nb(a+68|0);x[27524]=0;R(953,a|0,e|0);l=x[27524];x[27524]=0;a:{b:{c:{d:{if((l|0)!=1){cc(g+24|0,b,c);b=Id(g+16|0);x[27524]=0;c=x[b+4>>2];x[g+8>>2]=x[b>>2];x[g+12>>2]=c;Vr(f,g+32|0,x[g+24>>2],x[g+28>>2],g+8|0);b=x[27524];x[27524]=0;if((b|0)==1){break d}x[27524]=0;U(954,a|0,g+32|0,e|0);b=x[27524];x[27524]=0;if((b|0)==1){break c}yb(g+32|0);x[27524]=0;Y(955,a|0);b=x[27524];x[27524]=0;if((b|0)!=1){break a}}e=P()|0;break b}e=P()|0;break b}e=P()|0;yb(g+32|0)}ve(k);nf(j);hl(i);lh(h);kh(d);Xc(a);Xc(g+56|0);S(e|0);p()}Xc(g+56|0);ib=g- -64|0;return a}function BF(a,b,c,d,e,f){var g=0,h=0,i=E(0),j=0;g=ib-80|0;ib=g;Wy(x[a+24>>2]);v[x[a+24>>2]+1298424|0]=x[a+52>>2]!=0;x[g+40>>2]=b;x[g+36>>2]=c;x[g+32>>2]=d;i=B[a+48>>2];j=x[a+32>>2];x[g+8>>2]=b;c=x[g+36>>2];x[g>>2]=x[g+32>>2];x[g+4>>2]=c;d=ib-16|0;ib=d;x[d+8>>2]=x[g+8>>2];c=x[g+4>>2];x[d>>2]=x[g>>2];x[d+4>>2]=c;c=FJ(g+48|0);x[c+8>>2]=j;x[c+4>>2]=0;x[c>>2]=f;f=x[d+4>>2];x[c+12>>2]=x[d>>2];x[c+16>>2]=f;x[c+20>>2]=x[d+8>>2];B[c+24>>2]=i;x[c>>2]=e;ib=d+16|0;while(1){if(b){d=x[a+24>>2];x[g+24>>2]=b;x[g+28>>2]=0;x[g+16>>2]=134217727;x[g+20>>2]=0;d=HJ(d,x[hr(g+24|0,g+16|0)>>2],c);h=d+h|0;b=b-d|0;if(d){continue}}break}if(!(x[a+52>>2]!=1|h)){a=x[a+24>>2];x[a+480208>>2]=x[a+480208>>2]&-513}ib=g+80|0;return h}function Dn(a,b,c,d,e,f,g,h,i,j){var k=0,l=0,m=0,n=0;l=ib-16|0;ib=l;v[l+15|0]=a;a:{b:{c:{k=x[d>>2];if((k|0)!=(c|0)){break c}m=43;n=a&255;if((n|0)!=y[j+24|0]){m=45;if(y[j+25|0]!=(n|0)){break c}}x[d>>2]=c+1;v[c|0]=m;break b}if(!(!Eb(g)|(a|0)!=(f|0))){a=0;b=x[i>>2];if((b-h|0)>159){break a}a=x[e>>2];x[i>>2]=b+4;x[b>>2]=a;break b}a=-1;f=Bi(j,j+26|0,l+15|0)-j|0;if((f|0)>23){break a}d:{e:{switch(b-8|0){case 0:case 2:if((b|0)>(f|0)){break d}break a;case 1:break d;default:break e}}if((b|0)!=16|(f|0)<22){break d}if((c|0)==(k|0)|(k-c|0)>2|y[k-1|0]!=48){break a}a=0;x[e>>2]=0;x[d>>2]=k+1;v[k|0]=y[f+98224|0];break a}x[d>>2]=k+1;v[k|0]=y[f+98224|0];x[e>>2]=x[e>>2]+1;a=0;break a}a=0;x[e>>2]=0}ib=l+16|0;return a}function gha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=ib-16|0;ib=b;f=x[a+40>>2];g=x[a+36>>2];j=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;k=x[a+32>>2];l=x[a+28>>2];m=x[a+8>>2];n=x[a+12>>2];while(1){if(d){e=x[b+8>>2];o=e>>>10&4194048;p=(((x[b+12>>2]&2147483647)<<1|e>>>31)&-2)+j|0;e=0;while(1){if((e|0)!=2){h=e+p|0;i=v[h|0];x[(e<<2)+b>>2]=((D(v[h+2|0]-i|0,o)|0)/16384|0)+(i<<8);e=e+1|0;continue}break}g=g+l|0;x[c>>2]=x[c>>2]+D(x[b>>2],g>>12);f=f+k|0;x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],f>>12);Pb(b+8|0,m,n);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;ib=b+16|0}function Ai(a,b,c,d){var e=0,f=0,g=0;x[a+20>>2]=d;x[a+16>>2]=c;x[a+12>>2]=b;x[a+4>>2]=0;x[a+8>>2]=0;x[a>>2]=44344;c=a+24|0;x[c>>2]=0;x[c+4>>2]=0;x[c+16>>2]=0;x[c+8>>2]=0;x[c+12>>2]=0;b=Nb(a+44|0);d=Nb(b+12|0);e=Nb(b+24|0);f=Nb(b+36|0);x[27524]=0;R(903,b|0,0);g=x[27524];x[27524]=0;if((g|0)==1){a=P()|0;uc(f);uc(e);ct(d);ct(b);S(a|0);p()}w[a+4204>>1]=0;x[a+4196>>2]=1065353216;x[a+4200>>2]=0;d=x[a+16>>2];x[d+946300>>2]=x[d+946300>>2]+1;x[x[a+20>>2]>>2]=a;x[27524]=0;d=T(904,a+92|0)|0;e=x[27524];x[27524]=0;a:{if((e|0)!=1){b=a+4200|0;x[c>>2]=d;c=x[a+16>>2]+906300|0;d=y[a+4200|0];e=x[a+20>>2];while(1){if((Nd(c,d)|0)==(e|0)|d>>>0>248){break a}d=d+1|0;v[b|0]=d;continue}}a=P()|0;vN(b);S(a|0);p()}return a}function Vga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=ib-16|0;ib=b;g=x[a+24>>2];h=x[a+20>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+8>>2];k=x[a+12>>2];while(1){if(d){f=x[b+8>>2];l=((((x[b+12>>2]&2147483647)<<1|f>>>31)&2147483646)<<1)+i|0;e=f>>>21&2040;m=w[e+39734>>1];n=w[e+39732>>1];o=w[e+39730>>1];p=w[e+39728>>1];e=0;while(1){if((e|0)!=2){f=(e<<1)+l|0;x[(e<<2)+b>>2]=(((D(w[f>>1],o)+D(w[f-4>>1],p)|0)+D(w[f+4>>1],n)|0)+D(w[f+8>>1],m)|0)/16384;e=e+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[b>>2],h);x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],g);Pb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;ib=b+16|0}function Dh(a,b){var c=E(0),d=E(0),e=E(0),f=E(0),g=E(0),h=0;f=PM(a);h=a+4208|0;c=E(E(B[Bb(h,4)>>2]*E(1.899999976158142))+E(.10000000149011612));g=B[a+4268>>2];d=ze(E(10),E(E(E(E(E(x[((b<<2)+a|0)+4292>>2])/g)*E(-60))/E(E(B[Bb(h,3)>>2]*E(19.899999618530273))+E(.10000000149011612)))/E(20)));c=E(E(ze(d,E(E(2)-E(E(2)/c)))+E(-1))/E(E(1)-Mp(c>E(1)?E(3.1415927410125732):E(f*E(E(6.2831854820251465)/g)))));a:{if(c==E(0)){break a}if(!um(c)){break a}g=E(c+c);f=E(E(-2)-g);c=E(E(f*f)+E(E(c*c)*E(-4)));if(c>E(0)){e=E(M(c))}c=E(E(e-f)/g);if(E(F(c))>E(1)){c=E(E(E(-f)-e)/g)}e=Tf(c)}b=(b<<3)+a|0;B[b+4404>>2]=e;B[b+4400>>2]=d;c=B[a+4272>>2];c=E(c*c);e=E(E(1)-c);d=E(d*d);return E(E(E(e*E(d/E(E(1)-E(c*d))))*e)+c)}function taa(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0;b=ib-48|0;ib=b;c=Kb(b+32|0);x[27524]=0;Y(946,b+16|0);a=x[27524];x[27524]=0;a:{b:{c:{d:{if((a|0)!=1){f=b,g=Cb(x[b+16>>2]),x[f+8>>2]=g;d=1;while(1){e=Cb(x[b+20>>2]);a=x[b+8>>2];if(!Mb(a,e)){a=mg(Jc(c));ve(b+16|0);wb(c);break b}if(!d){x[27524]=0;Q(947,c|0,14619)|0;a=x[27524];x[27524]=0;if((a|0)==1){break d}a=x[b+8>>2]}x[27524]=0;Q(806,c|0,a|0)|0;a=x[27524];x[27524]=0;if((a|0)==1){break d}yq(b+8|0);d=0;continue}}a=V(0)|0;break c}a=V(0)|0;ve(b+16|0)}wb(c);_(a|0)|0;a=0;x[27524]=0;X(945,6988,0,0,0);c=x[27524];x[27524]=0;if((c|0)==1){break a}$()}ib=b+48|0;return a|0}b=P()|0;x[27524]=0;Z(18);a=x[27524];x[27524]=0;if((a|0)==1){V(0)|0;Sb();p()}S(b|0);p()}function ZA(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=ib-16|0;ib=e;d=y[a|0];if(d&1){v[b+12|0]=y[b+12|0]|1;d=y[a|0]}if(d&2){v[b+12|0]=y[b+12|0]|4;d=y[a|0]}if(d&4){v[b+12|0]=y[b+12|0]|2;d=y[a|0]}if(d&16){v[b+12|0]=y[b+12|0]|16;d=y[a|0]}if(d&32){v[b+12|0]=y[b+12|0]|8}v[e+15|0]=y[a+1|0];v[e+14|0]=25;Zg(b,y[Ub(e+15|0,e+14|0)|0]);v[b+15|0]=y[a+2|0];v[b+16|0]=y[a+3|0];v[b+13|0]=y[a+4|0];v[b+14|0]=y[a+5|0];g=x[b>>2];i=$d(g,x[b+4>>2]);b=0;while(1){if((b|0)!=(i|0)){h=Bb(g,b);f=(b<<2)+a|0;d=y[f+6|0]|y[f+7|0]<<8;w[h>>1]=d;a:{if(!b){break a}j=d;d=z[Bb(g,b-1|0)>>1];if(j>>>0>=d>>>0){break a}w[h>>1]=d+1}k=h,l=Vb((y[f+8|0]|y[f+9|0]<<8)<<16>>16>>c,0,64),v[k+2|0]=l;b=b+1|0;continue}break}ib=e+16|0}function Via(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=ib-32|0;ib=d;md(c,2);v[d+16|0]=y[b+13|0];v[d|0]=64;e=d+16|0;i=c,j=y[Ub(e,d)|0]<<2,w[i+30>>1]=j;x[c+24>>2]=(y[b+14|0]|y[b+15|0]<<8)<<1;Bk(d,2,b+1|0);Fc(e,d);Fe(c+43|0,e);wb(e);e=Zc(a,8,1,0,2);a:{if((y[b|0]&3)!=1){break a}g=y[b+22|0]|y[b+23|0]<<8|(y[b+24|0]<<16|y[b+25|0]<<24);x[c>>2]=g;f=y[b+26|0]|y[b+27|0]<<8|(y[b+28|0]<<16|y[b+29|0]<<24);x[c+4>>2]=f;a=y[b+30|0]|y[b+31|0]<<8|(y[b+32|0]<<16|y[b+33|0]<<24);h=a-(a>>>0>f>>>0)|0;x[c+8>>2]=h;a=y[b|0];if(a&4){w[c+34>>1]=z[c+34>>1]|2;a=y[b|0]}if(a&8){w[c+34>>1]=z[c+34>>1]|4;a=y[b|0]}if(!(a&16)){break a}ne(e,16);jg(e,9);x[c+8>>2]=h>>>1;x[c+4>>2]=f>>>1;x[c>>2]=g>>>1}ib=d+32|0}function xH(a,b){var c=0,d=0,e=0;a:{if(y[b|0]){break a}b=$w(13859);if(y[b|0]?b:0){break a}b=$w(D(a,12)+94832|0);if(y[b|0]?b:0){break a}b=$w(14143);if(y[b|0]?b:0){break a}b=14752}b:{while(1){d=y[b+c|0];if(!(!d|(d|0)==47)){d=23;c=c+1|0;if((c|0)!=23){continue}break b}break}d=c}e=14752;c:{d:{c=y[b|0];e:{f:{if(!(y[b+d|0]|(c|0)==46)){e=b;if((c|0)!=67){break f}}if(!y[e+1|0]){break e}}if(!Ei(e,14752)){break e}if(Ei(e,13476)){break d}}if(!a){c=94904;if(y[e+1|0]==46){break c}}return 0}c=x[120815];if(c){while(1){if(!Ei(e,c+8|0)){break c}c=x[c+32>>2];if(c){continue}break}}c=Gd(36);if(c){x[c+4>>2]=20;x[c>>2]=94800;b=c+8|0;rc(b,e,d);v[b+d|0]=0;x[c+32>>2]=x[120815];x[120815]=c}c=a|c?c:94904}return c}function kfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;i=ib-16|0;ib=i;d=x[Wb(i+8|0,Cb(x[a+4>>2]))>>2];h=ib-32|0;ib=h;e=d;d=x[a>>2];f=(Do(e,Cb(d))<<1)+d|0;e=Oz(b,c);a:{if((e|0)<=0){break a}d=x[Db(a)>>2];g=x[a+4>>2];if((e|0)<=d-g>>1){k=g-f|0;j=k>>1;b:{if((e|0)<=(j|0)){d=c;break b}x[h+8>>2]=b;x[h+8>>2]=x[h+8>>2]+(j<<1);d=x[h+8>>2];AR(a,d,c,e-j|0);if((k|0)<=0){break a}}HR(a,f,g,(e<<1)+f|0);co(b,d,f);break a}d=Db(a);e=Uj(h+8|0,Vj(a,Oc(x[a>>2],g)+e|0),f-x[a>>2]>>1,d);g=ib-16|0;ib=g;c=Uo(g,e+8|0,Oz(b,c));d=x[c>>2];while(1){if(x[c+4>>2]!=(d|0)){Pj(d,z[b>>1]);d=x[c>>2]+2|0;x[c>>2]=d;b=b+2|0;continue}break}Vd(c);ib=g+16|0;f=GR(a,e,f);Ui(e)}Cb(f);ib=h+32|0;ib=i+16|0;return a|0}function s7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=ib-48|0;ib=e;x[e+40>>2]=c;a=ge(a,e+40|0);f=sc(a+4|0);g=sc(a+24|0);h=sc(a+32|0);i=Nb(a+36|0);x[a+56>>2]=3;j=Nb(a+68|0);x[27524]=0;R(953,a|0,d|0);c=x[27524];x[27524]=0;a:{b:{c:{d:{if((c|0)!=1){c=Id(e+8|0);x[27524]=0;k=x[c+4>>2];x[e>>2]=x[c>>2];x[e+4>>2]=k;U(1076,e+16|0,b|0,e|0);b=x[27524];x[27524]=0;if((b|0)==1){break d}x[27524]=0;U(954,a|0,e+16|0,d|0);b=x[27524];x[27524]=0;if((b|0)==1){break c}yb(e+16|0);x[27524]=0;Y(955,a|0);b=x[27524];x[27524]=0;if((b|0)!=1){break a}}d=P()|0;break b}d=P()|0;break b}d=P()|0;yb(e+16|0)}ve(j);nf(i);hl(h);lh(g);kh(f);Xc(a);Xc(e+40|0);S(d|0);p()}Xc(e+40|0);ib=e+48|0;return a|0}function uK(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=ib-16|0;ib=f;a:{b:{c:{d:{e:{if((b|0)>=0){g=a;a=x[a+32>>2];if((Cg(a)|0)>(b|0)){break e}}a=ba(8)|0;x[27524]=0;b=Q(55,f|0,10644)|0;c=x[27524];x[27524]=0;if((c|0)==1){break d}lc(a,b);x[27524]=0;U(123,a|0,50060,962);a=x[27524];x[27524]=0;if((a|0)!=1){break b}c=P()|0;wb(b);break c}d=(a+(b<<5)|0)+480280|0;c=c?134218752:0;x[d>>2]=c|x[d>>2]&-134218753;d=(a+D(b,872)|0)+1075080|0;x[d>>2]=c|x[d>>2]&-134218753;a=z[a+480188>>1];d=a>>>0<=256?256:a;b=b+1|0;g=x[g+32>>2];while(1){if((a|0)==(d|0)){break a}e=g+D(a,872)|0;if((b|0)==z[e+1075778>>1]){e=e+1075080|0;x[e>>2]=c|x[e>>2]&-134218753}a=a+1|0;continue}}c=P()|0;ca(a|0)}S(c|0)}p()}ib=f+16|0}function $ja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;b=ib-528|0;ib=b;e=-1;a:{if(!kg(a,1468)){break a}yl(a,1464);c=b+524|0;DU(a,c);if(!qe(c,26905)){e=0;if(!qe(b+524|0,15516)){break a}}yl(a,20);c=1;while(1){if((c&65535)>>>0<=31){if(AU(a,b)){c=c+1|0;d=XA(b)+d|0;continue}else{e=-1;break a}}break}e=0;if(d>>>0>40){break a}d=b+520|0;c=ib-16|0;ib=c;b:{if(!kg(a,2)){v[c|0]=0;TC(d,c);break b}Zm(c+8|0,d);WA(c,a,x[c+8>>2],x[c+12>>2])}ib=c+16|0;if(y[b+520|0]>128){break a}d=Lc(b+520|0);c=ib-16|0;ib=c;c:{if(!kg(a,512)){lU(b);break c}uC(c+8|0,b);WA(c,a,x[c+8>>2],x[c+12>>2])}ib=c+16|0;c=0;e=1;a=y[d|0];while(1){if((c|0)==512){break a}d=b+c|0;c=c+1|0;if(a>>>0>=y[d|0]){continue}break}e=0}ib=b+528|0;return e|0}function ao(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;a:{if(c){v[b+809|0]=c;break a}c=y[b+809|0]}e=x[a+480180>>2];d=e&202376205?(c&240?-16:15)&c:c;c=x[b+688>>2];b:{if(e&69206029){break b}g=d&255;f=d&15;if((f|0)==15){if(g>>>0>=16){$n(a,b,(d&240)>>>4|0,0);return}if(!(v[b+851|0]&1)){break b}c=y[a+480208|0]&2?c:c-60|0;break b}if((g&240)!=240){break b}if(f){_n(a,b,f,0);return}if(!(v[b+851|0]&1)){break b}c=y[a+480208|0]&2?c:c+60|0}c:{if(!(!(v[b+851|0]&1)|y[a+480208|0]&2)&(x[a+1074416>>2]!=1|(e|0)!=524288)){break c}a=d&15;d:{if(a){if((d&255)>>>0>15?e&16777248:0){break c}c=c-(a<<2)|0;break d}c=((d&255)>>>2&60)+c|0}if((e|0)!=1){break c}x[b+88>>2]=x[b+88>>2]|2097152}h=b,i=Vb(c,0,256),x[h+688>>2]=i}function Gfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;f=ib-16|0;ib=f;c=Af(a,c);Pd(f,x[a+36>>2]);i=a;a:{if(!c){Pc(f,a+32|0,5);d=0;if(zb(x[x[f>>2]>>2],x[f+4>>2])){break a}}g=x[a+36>>2];a=ib-16|0;ib=a;x[a+12>>2]=0;nH(g,a+12|0,1);e=x[a+12>>2];d=e>>>2&3;v[a+11|0]=d;if(d){v[a+4|0]=3;d=y[Ub(a+4|0,a+11|0)|0];v[a+4|0]=0;v[a|0]=0;v[a+10|0]=0;b:{if(!d){break b}si(g,a+4|0);if((d|0)==1){break b}si(g,a);if(d>>>0<3){break b}si(g,a+10|0);h=y[a+10|0]<<24}e=e&255|(y[a+4|0]<<8|y[a|0]<<16|h)}d=e>>>4|0;x[a+4>>2]=d;x[a>>2]=1e6;jy(b,x[Hb(a+4|0,a)>>2]);e=0;while(1){h=Eb(b);if(h>>>0<=e>>>0){if((d|0)!=(h|0)){em(g,d-h|0)}ib=a+16|0}else{ri(g,Qc(b,e),1);e=e+1|0;continue}break}d=c}af(i,d);ib=f+16|0}function vha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=ib-16|0;ib=b;i=x[a+16>>2];h=ag(1,2);e=kb;j=e;Pb(a,h,e);f=x[a+40>>2];g=x[a+36>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;k=x[a+32>>2];l=x[a+28>>2];m=x[a+8>>2];n=x[a+12>>2];while(1){if(d){d=d-1|0;o=((((x[b+12>>2]&2147483647)<<1|x[b+8>>2]>>>31)&2147483646)<<1)+i|0;e=0;while(1){if((e|0)!=2){x[(e<<2)+b>>2]=w[(e<<1)+o>>1];e=e+1|0;continue}break}g=g+l|0;x[c>>2]=x[c>>2]+D(x[b>>2],g>>12);f=f+k|0;x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],f>>12);Pb(b+8|0,m,n);c=c+8|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;sg(a,h,j);ib=b+16|0}function rY(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=ib-16|0;ib=e;md(b,0);x[b>>2]=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);c=cr(a+4|0,a);f=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[b+4>>2]=f;c=cr(a+8|0,a);c=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[b+8>>2]=c;v[e+15|0]=127;v[e+14|0]=y[a+15|0];g=b,h=(((y[Ub(e+15|0,e+14|0)|0]<<8|64)&65344)>>>0)/127|0,w[g+30>>1]=h;d=y[a+12|0];if(d>>>0>=16){w[b+34>>1]=32;w[b+28>>1]=d&240}d=(y[a+13|0]|y[a+14|0]<<8)<<1;x[b+24>>2]=d;d=y[a+13|0]|y[a+14|0]<<8?d:16726;x[b+24>>2]=d;g=b,h=(D(pv(0,y[a+12|0]<<28>>24),d)>>>0)/8363|0,x[g+24>>2]=h;if(c>>>0>f>>>0){w[b+34>>1]=z[b+34>>1]|2}if(y[a+16|0]&132){w[b+34>>1]=z[b+34>>1]|1}ib=e+16|0}function rz(a,b,c){var d=0,e=0,f=0,g=0;d=ib+-64|0;ib=d;e=x[a>>2];f=x[e-4>>2];g=x[e-8>>2];x[d+28>>2]=0;x[d+32>>2]=0;x[d+36>>2]=0;x[d+40>>2]=0;x[d+44>>2]=0;x[d+48>>2]=0;x[d+52>>2]=0;x[d+56>>2]=0;e=0;v[d+59|0]=0;v[d+60|0]=0;v[d+61|0]=0;v[d+62|0]=0;x[d+20>>2]=0;x[d+24>>2]=0;x[d+16>>2]=b;x[d+12>>2]=a;x[d+8>>2]=c;a=a+g|0;a:{if(gh(f,c,0)){x[d+56>>2]=1;lb[x[x[f>>2]+20>>2]](f,d+8|0,a,a,1,0);e=x[d+32>>2]==1?a:0;break a}lb[x[x[f>>2]+24>>2]](f,d+8|0,a,1,0);b:{switch(x[d+44>>2]){case 0:e=x[d+48>>2]==1?x[d+36>>2]==1?x[d+40>>2]==1?x[d+28>>2]:0:0:0;break a;case 1:break b;default:break a}}if(x[d+32>>2]!=1){if(x[d+48>>2]|x[d+36>>2]!=1|x[d+40>>2]!=1){break a}}e=x[d+24>>2]}ib=d- -64|0;return e}function vja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=ib+-64|0;ib=c;i=c,j=jf(a)>>>5|0,w[i+32>>1]=j;w[c+16>>1]=3999;h=b+480190|0;d=z[Tc(c+32|0,c+16|0)>>1];w[h>>1]=d;g=1;while(1){f=g&65535;if(f>>>0<=d>>>0){d=Oi(b,f);e=c+32|0;pu(a,e);md(d,0);Hj(c,2,e);e=c+16|0;Fc(e,c);Cc(((f<<5)+b|0)+946304|0,e);wb(e);x[d+24>>2]=8287;i=c,j=Fb(z[c+60>>1]),w[i+16>>1]=j;w[c>>1]=64;i=d,j=z[Tc(e,c)>>1]<<2,w[i+30>>1]=j;i=d,j=ac(x[c+52>>2])&-2,x[i>>2]=j;e=Fb(z[c+62>>1]);i=Bb(d+68|0,0),j=e,x[i>>2]=j;e=Fb(z[c+56>>1]);f=Fb(z[c+58>>1]);a:{if(f>>>0<2){break a}f=e+f<<1;if(f>>>0>A[d>>2]){break a}x[d+16>>2]=f;x[d+12>>2]=e<<1;w[d+34>>1]=z[d+34>>1]|8}g=g+1|0;d=z[h>>1];continue}break}ib=c- -64|0}function bja(a){a=a|0;var b=0,c=0,d=0,e=0;c=ib-192|0;ib=c;b=c+16|0;wi(b,a);x[27524]=0;R(89,c+32|0,b|0);a=x[27524];x[27524]=0;a:{b:{c:{d:{e:{if((a|0)!=1){x[27524]=0;a=Q(90,c+48|0,c+32|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break e}wb(c+32|0);wb(c+16|0);b=x[x[a>>2]-12>>2];x[27524]=0;d=ga(62)|0;e=x[27524];x[27524]=0;if((e|0)==1){break c}x[27524]=0;U(63,c+8|0,a+b|0,d|0);b=x[27524];x[27524]=0;if((b|0)==1){break c}_b(c+8|0);x[27524]=0;b=Q(91,a|0,c+32|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break c}a=jh(x[(b+x[x[b>>2]-12>>2]|0)+16>>2]);d=z[c+32>>1];Cf(b);ib=c+192|0;a=(a?0:d)&65535;break a}b=P()|0;break d}b=P()|0;wb(c+32|0)}wb(c+16|0);break b}b=P()|0;Cf(a)}S(b|0);p()}return a|0}function vh(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=ib+-64|0;ib=f;a:{b:{if((b|0)==65535|c-1025>>>0<4294966272){break b}d=x[a>>2];e=x[a+4>>2];if(Ce(d,e,b)){break b}c:{d:{if(Fk(d,e)>>>0<=b>>>0){d=Ey(f+8|0,a);x[27524]=0;U(205,a|0,b+1|0,d|0);e=x[27524];x[27524]=0;if((e|0)==1){break d}ll(d);d=x[a>>2]}x[27524]=0;R(215,hg(d,b)|0,c|0);c=x[27524];x[27524]=0;e:{if((c|0)!=1){c=hg(x[a>>2],b);x[c+16>>2]=0;x[c+20>>2]=0;c=x[a>>2];x[27524]=0;Y(216,hg(c,b)|0);c=x[27524];x[27524]=0;if((c|0)!=1){break e}}b=V(108196)|0;a=jb;break c}a=hg(x[a>>2],b);g=Mb(x[a>>2],x[a+4>>2]);break b}b=V(108196)|0;a=jb;ll(d)}if((da(108196)|0)!=(a|0)){break a}_(b|0)|0;$()}ib=f- -64|0;return g|0}S(b|0);p()}function Wga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=ib-16|0;ib=b;g=x[a+24>>2];h=x[a+20>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+8>>2];k=x[a+12>>2];while(1){if(d){f=x[b+8>>2];l=(((x[b+12>>2]&2147483647)<<1|f>>>31)&-2)+i|0;e=f>>>21&2040;m=w[e+39734>>1];n=w[e+39732>>1];o=w[e+39730>>1];p=w[e+39728>>1];e=0;while(1){if((e|0)!=2){f=e+l|0;x[(e<<2)+b>>2]=(((D(v[f|0],o)+D(v[f-2|0],p)|0)+D(v[f+2|0],n)|0)+D(v[f+4|0],m)<<8)/16384;e=e+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[b>>2],h);x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],g);Pb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;ib=b+16|0}function Z3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=ib-32|0;ib=d;e=x[a+28>>2];x[d+16>>2]=e;f=x[a+20>>2];x[d+28>>2]=c;x[d+24>>2]=b;b=f-e|0;x[d+20>>2]=b;f=b+c|0;i=2;b=d+16|0;a:{while(1){b:{c:{d:{if(!vx(gb(x[a+60>>2],b|0,i|0,d+12|0)|0)){g=x[d+12>>2];if((g|0)==(f|0)){break d}if((g|0)>=0){break c}break b}if((f|0)!=-1){break b}}b=x[a+44>>2];x[a+28>>2]=b;x[a+20>>2]=b;x[a+16>>2]=b+x[a+48>>2];a=c;break a}h=x[b+4>>2];j=h>>>0<g>>>0;e=(j<<3)+b|0;h=g-(j?h:0)|0;x[e>>2]=h+x[e>>2];b=(j?12:4)+b|0;x[b>>2]=x[b>>2]-h;f=f-g|0;i=i-j|0;b=e;continue}break}x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a>>2]=x[a>>2]|32;a=0;if((i|0)==2){break a}a=c-x[b+4>>2]|0}ib=d+32|0;return a|0}function Kha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;g=ib-16|0;ib=g;md(b,4);w[b+30>>1]=y[a+12|0]<<2;Mf(b+30|0,256);e=y[a+15|0];w[b+34>>1]=32;w[b+28>>1]=e;v[b+37|0]=y[a+13|0];v[b+36|0]=y[a+16|0];f=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);x[b>>2]=f;c=y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24);x[b+4>>2]=c;d=(y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24))+c|0;x[b+8>>2]=d;e=y[a+14|0];if(e&16){d=d>>>1|0;x[b+8>>2]=d;c=c>>>1|0;x[b+4>>2]=c;f=f>>>1|0;x[b>>2]=f;e=y[a+14|0]}if(e&32){d=d>>>1|0;x[b+8>>2]=d;c=c>>>1|0;x[b+4>>2]=c;x[b>>2]=f>>>1;e=y[a+14|0]}if(!(!(e&3)|c>>>0>=d>>>0)){w[b+34>>1]=34;w[b+34>>1]=y[a+14|0]&2?38:34}a=Kc(g,21631);Fe(b+43|0,a);wb(a);ib=g+16|0}function VN(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=E(0),j=E(0),k=0,l=E(0);g=ib-16|0;ib=g;e=w[d>>1];f=w[d+2>>1];if(!(!z[b>>1]|(e|0)>(f|0)|(!(B[c>>2]>E(0))|(f-e|0)>32766))){w[a>>1]=3;f=a+4|0;Ic(f);w[a+28>>1]=65472;x[g+12>>2]=1065353216;YN(f,g+12|0);x[a+32>>2]=0;w[a+30>>1]=0;Ic(a+16|0);h=w[d>>1];w[a+28>>1]=h;e=ib-16|0;ib=e;w[e+14>>1]=z[b>>1];w[e+12>>1]=32767;b=w[Tc(e+14|0,e+12|0)>>1];ib=e+16|0;w[a+30>>1]=b;i=E(F(B[c>>2]));B[a+32>>2]=i;i=ze(i,E(E(1)/E(b|0)));kk(f,(w[d+2>>1]-h|0)+1|0);b=x[a+4>>2];c=w[a+28>>1];e=w[d+2>>1];d=w[d>>1];while(1){if((d|0)>(e|0)){Qp(a)}else{j=ze(i,E(d|0));k=Bb(b,d-c|0),l=j,B[k>>2]=l;d=d+1|0;continue}break}h=1}ib=g+16|0;return h|0}function wha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=ib-16|0;ib=b;i=x[a+16>>2];h=ag(1,2);e=kb;j=e;Pb(a,h,e);f=x[a+40>>2];g=x[a+36>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;k=x[a+32>>2];l=x[a+28>>2];m=x[a+8>>2];n=x[a+12>>2];while(1){if(d){d=d-1|0;o=(((x[b+12>>2]&2147483647)<<1|x[b+8>>2]>>>31)&-2)+i|0;e=0;while(1){if((e|0)!=2){x[(e<<2)+b>>2]=v[e+o|0]<<8;e=e+1|0;continue}break}g=g+l|0;x[c>>2]=x[c>>2]+D(x[b>>2],g>>12);f=f+k|0;x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],f>>12);Pb(b+8|0,m,n);c=c+8|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;sg(a,h,j);ib=b+16|0}function rga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=ib-16|0;ib=f;g=x[a+24>>2];h=x[a+20>>2];i=x[a+16>>2];e=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=e;j=b+24|0;k=x[a+8>>2];l=x[a+12>>2];while(1){if(d){b=(x[f+12>>2]<<1)+i|0;e=(((x[f+8>>2]>>>16|0)+4&131064)<<1)+j|0;b=(((((D(w[b+4>>1],w[e+10>>1])+D(w[b+2>>1],w[e+8>>1])|0)+D(w[b+6>>1],w[e+12>>1])|0)+D(w[b+8>>1],w[e+14>>1])|0)/2|0)+((((D(w[b-4>>1],w[e+2>>1])+D(w[b-6>>1],w[e>>1])|0)+D(w[b-2>>1],w[e+4>>1])|0)+D(w[b>>1],w[e+6>>1])|0)/2|0)|0)/16384|0;x[c>>2]=x[c>>2]+D(b,h);x[c+4>>2]=x[c+4>>2]+D(b,g);Pb(f+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;ib=f+16|0}function daa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=ib-32|0;ib=d;x[27524]=0;Y(958,a|0);e=x[27524];x[27524]=0;a:{b:{c:{if((e|0)==1){break c}x[27524]=0;Y(959,b|0);e=x[27524];x[27524]=0;if((e|0)==1){break c}x[27524]=0;Y(959,c|0);f=x[27524];x[27524]=0;e=1;if((f|0)==1){break c}f=x[a+24>>2];b=qc(d+24|0,b);c=qc(d+16|0,c);g=x[c>>2];c=x[c+4>>2];x[27524]=0;h=x[b+4>>2];x[d+8>>2]=x[b>>2];x[d+12>>2]=h;Wr(980,f,d+8|0,g,c,1);b=x[27524];x[27524]=0;if((b|0)!=1){break b}}_(V(0)|0)|0;x[27524]=0;X(945,5510,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)==1){break a}$();e=0}ib=d+32|0;return e|0}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function d_(a){a=a|0;var b=0,c=0,d=0,e=0;c=ib-192|0;ib=c;b=c+16|0;wi(b,a);x[27524]=0;R(89,c+32|0,b|0);a=x[27524];x[27524]=0;a:{b:{c:{d:{e:{if((a|0)!=1){x[27524]=0;a=Q(90,c+48|0,c+32|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break e}wb(c+32|0);wb(c+16|0);b=x[x[a>>2]-12>>2];x[27524]=0;d=ga(62)|0;e=x[27524];x[27524]=0;if((e|0)==1){break c}x[27524]=0;U(63,c+8|0,a+b|0,d|0);b=x[27524];x[27524]=0;if((b|0)==1){break c}_b(c+8|0);x[27524]=0;b=Q(94,a|0,c+32|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break c}a=jh(x[(b+x[x[b>>2]-12>>2]|0)+16>>2]);d=x[c+32>>2];Cf(b);ib=c+192|0;a=a?0:d;break a}b=P()|0;break d}b=P()|0;wb(c+32|0)}wb(c+16|0);break b}b=P()|0;Cf(a)}S(b|0);p()}return a|0}function oia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=ib-16|0;ib=e;i=e,j=Ej(b),x[i>>2]=j;d=ib-16|0;ib=d;g=a;c=Td(a);a:{if(c){f=gc(g);while(1){a=c;c=a+13|0;if(_t(b,c)){f=a;c=x[a>>2];if(c){continue}break a}if(!_t(c,b)){break a}f=a+4|0;c=x[a+4>>2];if(c){continue}break}break a}a=gc(g);f=a}x[d+12>>2]=a;b=x[f>>2];if(!b){c=ib-16|0;ib=c;a=gc(g);h=sh(d,mc(20),th(c+8|0,a));b=x[h>>2];a=x[e>>2];a=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);v[b+17|0]=0;v[b+13|0]=a;v[b+14|0]=a>>>8;v[b+15|0]=a>>>16;v[b+16|0]=a>>>24;i=gc(h),j=1,v[i+4|0]=j;ib=c+16|0;Tg(g,x[d+12>>2],f,x[d>>2]);b=ce(d);zk(d);h=1}Sg(e+8|0,x[Wb(d,b)>>2],h);ib=d+16|0;ib=e+16|0;return x[e+8>>2]+17|0}function gy(a,b){var c=0,d=0,e=0,f=0,g=0;d=ib-16|0;ib=d;x[d>>2]=a;x[d+4>>2]=b;x[d+8>>2]=a;x[d+12>>2]=b;c=ib+-64|0;ib=c;a=0;a:{if(!x[d+4>>2]){break a}f=x[d>>2];g=x[d+4>>2];a=32240;while(1){if((a|0)==32640){b=32640;while(1){a=b;if((a|0)!=32688){x[c+40>>2]=f;x[c+44>>2]=g;b=qc(c+32|0,x[a+8>>2]);e=x[c+44>>2];x[c+8>>2]=x[c+40>>2];x[c+12>>2]=e;e=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=e;b=a+12|0;if(!vO(c+8|0,c)){continue}}break}a=(a|0)!=32688;break a}x[c+56>>2]=f;x[c+60>>2]=g;b=qc(c+48|0,x[a+4>>2]);e=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=e;e=x[b+4>>2];x[c+16>>2]=x[b>>2];x[c+20>>2]=e;a=a+8|0;if(!vO(c+24|0,c+16|0)){continue}break}a=1}ib=c- -64|0;ib=d+16|0;return a}function eh(a,b){var c=0,d=0,e=0,f=0;c=ib+-64|0;ib=c;d=x[x[a>>2]-12>>2]+a|0;e=x[d+16>>2]&-3;$f(d,e);a:{b:{if(Qd(y[jm(c+56|0,a,1)|0])){d=x[(x[x[a>>2]-12>>2]+a|0)+24>>2];x[27524]=0;f=x[b+12>>2];x[c+16>>2]=x[b+8>>2];x[c+20>>2]=f;f=x[b+4>>2];x[c+8>>2]=x[b>>2];x[c+12>>2]=f;U(112,c+40|0,d|0,c+8|0);b=x[27524];x[27524]=0;c:{if((b|0)!=1){b=gp(c+40|0,Nf(c+24|0,-1,-1))?e|4:e;break c}_(V(0)|0)|0;b=e|1;hm(x[x[a>>2]-12>>2]+a|0,b);if(x[(x[x[a>>2]-12>>2]+a|0)+20>>2]&1){x[27524]=0;Z(109);a=x[27524];x[27524]=0;if((a|0)!=1){break a}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)==1){break b}S(a|0);p()}$()}Kj(x[x[a>>2]-12>>2]+a|0,b)}ib=c- -64|0;return a}V(0)|0;Sb()}p()}function kQ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;g=ib-112|0;ib=g;x[g+108>>2]=0;e=Zn(a,e&65535,d,c,g+108|0);f=y[b+790|0];if(!x[g+108>>2]){d=(f|0)==15;c=d&!y[b+792|0];e=e<<8;a:{if(e){x[b+664>>2]=e;break a}e=0;if(d){break a}e=x[b+664>>2]}h=c?0:y[b+836|0]<<16}if((f|0)==15){c=y[b+792|0];b:{if(!c){c=x[b+76>>2];x[g>>2]=1;f=x[Yc(g,g+108|0)>>2]<<3;d=qoa(c,0,e,0);e=(256<<f>>>1|0)+d|0;c=kb;c=d>>>0>e>>>0?c+1|0:c;d=f+8|0;f=d&31;if((d&63)>>>0>=32){d=0;c=c>>>f|0}else{d=c>>>f|0;c=((1<<f)-1&c)<<32-f|e>>>f}e=Ec(c,d);break b}LB(g);if(c>>>0>9){break b}c=x[b+104>>2];if(!c){break b}e=x[Bb(c+68|0,y[b+792|0]-1|0)>>2]+e|0}x[b+664>>2]=e}bo(a,b,e+h|0);ib=g+112|0}function Yt(a,b){var c=0,d=0,e=0;c=ib-48|0;ib=c;d=c+24|0;AS(d,a+8|0,a+10|0,a+12|0,a+16|0,a+14|0);AS(c,b+8|0,b+10|0,b+12|0,b+16|0,b+14|0);a=x[d>>2];b=y[a|0]|y[a+1|0]<<8;a=x[c>>2];b=Xt(b,y[a|0]|y[a+1|0]<<8);a:{if(!Bj(b)){break a}a=x[d+4>>2];b=y[a|0]|y[a+1|0]<<8;a=x[c+4>>2];b=Xt(b,y[a|0]|y[a+1|0]<<8);if(!Bj(b)){break a}a=x[d+8>>2];b=y[a|0]|y[a+1|0]<<8;a=x[c+8>>2];b=Xt(b,y[a|0]|y[a+1|0]<<8);if(!Bj(b)){break a}a=x[c+12>>2];e=(y[a|0]|y[a+1|0]<<8)<<16>>16;a=x[d+12>>2];b=se((y[a|0]|y[a+1|0]<<8)<<16>>16);a=se(e);b=(a|0)!=(b|0)?(b|0)<(a|0)?-1:1:0;if(!Bj(b)){break a}a=x[d+16>>2];b=y[a|0]|y[a+1|0]<<8;a=x[c+16>>2];b=Xt(b,y[a|0]|y[a+1|0]<<8)}a=Ue(b);ib=c+48|0;return a}function $y(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=ib-16|0;ib=e;b=x[a>>2];if(!pc(b,x[a+4>>2])){b=Cb(b);x[e+8>>2]=b;c=Cb(x[a+4>>2]);while(1){if(Mb(b,c)){Xo(b,4194304,67108864);g=x[b>>2];f=g+f|0;b=d;b=f>>>0<g>>>0?b+1|0:b;d=b;b=x[Pe(e+8|0)>>2];continue}else{c=x[a>>2];b=tc(c,x[a+4>>2]);l=e,m=Cb(c),x[l>>2]=m;d=soa(f,d,b,0);h=d;g=((kb&1)<<31|d>>>1)&2147483647;f=b<<24;d=0;i=Cb(x[a+4>>2]);while(1){b=x[e>>2];if(Mb(b,i)){j=b;c=x[b>>2];b=c>>>8|0;c=g+(c<<24)|0;b=b+k|0;b=Ec(soa(c,c>>>0<g>>>0?b+1|0:b,h,k),kb);x[j>>2]=b;c=f;f=c-b|0;d=d-(b>>>0>c>>>0)|0;Pe(e);continue}else{d=x[a>>2];if(!tc(d,x[a+4>>2])){Av();p()}x[d>>2]=f+x[d>>2]}break}}break}}ib=e+16|0}function $H(a){a=a|0;var b=0,c=0,d=0,e=0;d=ib-16|0;ib=d;a:{b:{if(!x[(x[x[a>>2]-12>>2]+a|0)+24>>2]){break b}x[27524]=0;c=Q(1132,d+8|0,a|0)|0;b=x[27524];x[27524]=0;c:{if((b|0)!=1){d:{if(!Qd(y[c|0])){break d}b=x[(x[x[a>>2]-12>>2]+a|0)+24>>2];x[27524]=0;b=T(1133,b|0)|0;e=x[27524];x[27524]=0;if((e|0)!=1){if((b|0)!=-1){break d}b=x[x[a>>2]-12>>2];x[27524]=0;Y(1134,a+b|0);b=x[27524];x[27524]=0;if((b|0)!=1){break d}}b=V(0)|0;_H(c);break c}_H(c);break b}b=V(0)|0}_(b|0)|0;c=x[x[a>>2]-12>>2];x[27524]=0;Y(17,a+c|0);c=x[27524];x[27524]=0;if((c|0)==1){break a}$()}ib=d+16|0;return a|0}a=P()|0;x[27524]=0;Z(18);c=x[27524];x[27524]=0;if((c|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function sga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=ib-16|0;ib=f;g=x[a+24>>2];h=x[a+20>>2];i=x[a+16>>2];e=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=e;j=b+24|0;k=x[a+8>>2];l=x[a+12>>2];while(1){if(d){b=x[f+12>>2]+i|0;e=(((x[f+8>>2]>>>16|0)+4&131064)<<1)+j|0;b=(((((D(v[b+2|0],w[e+10>>1])+D(v[b+1|0],w[e+8>>1])|0)+D(v[b+3|0],w[e+12>>1])|0)+D(v[b+4|0],w[e+14>>1])<<8)/2|0)+((((D(v[b-2|0],w[e+2>>1])+D(v[b-3|0],w[e>>1])|0)+D(v[b-1|0],w[e+4>>1])|0)+D(v[b|0],w[e+6>>1])<<8)/2|0)|0)/16384|0;x[c>>2]=x[c>>2]+D(b,h);x[c+4>>2]=x[c+4>>2]+D(b,g);Pb(f+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;ib=f+16|0}
function Lz(a,b,c){var d=0,e=0,f=0,g=0;d=Kb(a);a=Eb(b);x[27524]=0;R(46,d|0,a|0);a=x[27524];x[27524]=0;if((a|0)!=1){a:{while(1){if(Eb(b)>>>0>e>>>0){f=x[Hi(b,e)>>2];g=f&-32;a=32;b:{while(1){c:{if((a|0)==256){a=0;break c}if((g|0)==128|x[(a<<2)+c>>2]!=(f|0)){a=a+1|0;continue}else{x[27524]=0;R(47,d|0,a<<24>>24);a=x[27524];x[27524]=0;if((a|0)!=1){break b}break a}}break}d:{while(1){if((a|0)==32){break d}if(x[(a<<2)+c>>2]!=(f|0)){a=a+1|0;continue}break}x[27524]=0;R(47,d|0,a<<24>>24);a=x[27524];x[27524]=0;if((a|0)!=1){break b}break a}x[27524]=0;R(47,d|0,63);a=x[27524];x[27524]=0;if((a|0)!=1){break b}break a}e=e+1|0;continue}break}return}}a=P()|0;wb(d);S(a|0);p()}function bna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=ib-32|0;ib=e;x[e+24>>2]=b;j=e,k=ke(a),x[j+8>>2]=k;f=Rn(e+24|0,e+8|0);a:{b:{h=Xh(c,d);if(!h){break b}if(!jt(a,c)){b=Eb(a);g=ad(a);c:{if(g-b>>>0>=h>>>0){g=vc(a);if((b|0)==(f|0)){break c}i=f+g|0;ai(i+h|0,i,b-f|0);break c}tm(a,g,(b+h|0)-g|0,b,f,0,h);g=x[a>>2]}b=b+h|0;Wh(a,b);v[e+8|0]=0;oe(b+g|0,e+8|0);b=f+g|0;while(1){if((c|0)==(d|0)){break b}oe(b,c);c=c+1|0;b=b+1|0;continue}}d=Zh(e+8|0,c,d);c=Jc(d);f=Eb(d);x[27524]=0;c=fa(360,a|0,b|0,c|0,c+f|0)|0;a=x[27524];x[27524]=0;if((a|0)!=1){wb(d);break a}a=P()|0;wb(d);S(a|0);p()}j=e,k=ke(a),x[j+8>>2]=k;c=Op(e+8|0,f)}ib=e+32|0;return c|0}function PN(a,b,c){var d=0,e=0,f=0,g=0,h=0;a:{e=ib-48|0;ib=e;d=Kb(e+32|0);x[27524]=0;R(895,b|0,e+24|0);g=x[27524];x[27524]=0;if((g|0)!=1){b:{g=x[e+28>>2];f=x[e+24>>2];Vf(d);x[27524]=0;g=!g&f>>>0>=255|g?255:f;R(60,d|0,g|0);f=x[27524];x[27524]=0;if((f|0)==1){break b}c:{while(1){if((g|0)==(h|0)){b=NX(Jc(d),Eb(d));if((b|0)==-1){break c}x[27524]=0;R(60,d|0,b|0);b=x[27524];x[27524]=0;if((b|0)!=1){break c}break b}f=Qc(d,h);x[27524]=0;Q(896,b|0,f|0)|0;f=x[27524];x[27524]=0;if((f|0)!=1){h=h+1|0;continue}break}break b}x[27524]=0;U(11,e+8|0,a|0,d|0);a=x[27524];x[27524]=0;if((a|0)==1){break b}a=e+8|0;Gb(c,a);xb(a);wb(d);ib=e+48|0;break a}}a=P()|0;wb(d);S(a|0);p()}}function LL(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=ib-32|0;ib=d;e=Nb(a);a=0;c=x[b+24>>2];c=Mt(x[c+484344>>2],x[c+484348>>2]);x[27524]=0;R(185,e|0,c|0);c=x[27524];x[27524]=0;a:{if((c|0)!=1){b:{c:{d:{e:{while(1){c=x[b+24>>2];f=x[c+484344>>2];if(Mt(f,x[c+484348>>2])>>>0<=a>>>0){break b}x[27524]=0;R(1028,d|0,Xb(f,a)|0);c=x[27524];x[27524]=0;if((c|0)!=1){c=x[b+24>>2];x[27524]=0;U(1015,d+16|0,c|0,d|0);c=x[27524];x[27524]=0;if((c|0)==1){break e}x[27524]=0;R(187,e|0,d+16|0);c=x[27524];x[27524]=0;if((c|0)==1){break d}a=a+1|0;wb(d+16|0);wb(d);continue}break}a=P()|0;break a}a=P()|0;break c}a=P()|0;wb(d+16|0)}wb(d);break a}ib=d+32|0;return}a=P()|0}ve(e);S(a|0);p()}function Tm(a){a=a|0;var b=0,c=0,d=0,e=0;d=ib-16|0;ib=d;a:{b:{if(!x[(x[x[a>>2]-12>>2]+a|0)+24>>2]){break b}x[27524]=0;c=Q(13,d+8|0,a|0)|0;b=x[27524];x[27524]=0;c:{if((b|0)!=1){d:{if(!y[c|0]){break d}b=x[(x[x[a>>2]-12>>2]+a|0)+24>>2];x[27524]=0;b=T(22,b|0)|0;e=x[27524];x[27524]=0;if((e|0)!=1){if((b|0)!=-1){break d}b=x[x[a>>2]-12>>2];x[27524]=0;R(16,a+b|0,1);b=x[27524];x[27524]=0;if((b|0)!=1){break d}}b=V(0)|0;Hl(c);break c}Hl(c);break b}b=V(0)|0}_(b|0)|0;c=x[x[a>>2]-12>>2];x[27524]=0;Y(17,a+c|0);c=x[27524];x[27524]=0;if((c|0)==1){break a}$()}ib=d+16|0;return a|0}a=P()|0;x[27524]=0;Z(18);c=x[27524];x[27524]=0;if((c|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function Tga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=ib-16|0;ib=b;f=x[a+40>>2];g=x[a+36>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+32>>2];k=x[a+28>>2];l=x[a+8>>2];m=x[a+12>>2];while(1){if(d){e=(x[b+12>>2]<<1)+i|0;h=x[b+8>>2]>>>21&2040;e=(((D(w[e>>1],w[h+39730>>1])+D(w[e-2>>1],w[h+39728>>1])|0)+D(w[e+2>>1],w[h+39732>>1])|0)+D(w[e+4>>1],w[h+39734>>1])|0)/16384|0;g=g+k|0;x[c>>2]=x[c>>2]+D(e,g>>12);f=f+j|0;x[c+4>>2]=x[c+4>>2]+D(e,f>>12);Pb(b+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;ib=b+16|0}function jI(a){var b=0,c=0,d=0,e=0,f=0;c=ib-192|0;ib=c;b=c+16|0;wi(b,a);x[27524]=0;R(89,c+32|0,b|0);a=x[27524];x[27524]=0;a:{b:{c:{d:{if((a|0)!=1){x[27524]=0;a=Q(90,c+48|0,c+32|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break d}wb(c+32|0);wb(c+16|0);b=x[x[a>>2]-12>>2];x[27524]=0;d=ga(62)|0;e=x[27524];x[27524]=0;if((e|0)==1){break b}x[27524]=0;U(63,c+8|0,a+b|0,d|0);b=x[27524];x[27524]=0;if((b|0)==1){break b}_b(c+8|0);x[27524]=0;b=Q(95,a|0,c+32|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break b}a=jh(x[(b+x[x[b>>2]-12>>2]|0)+16>>2]);f=C[c+32>>3];Cf(b);ib=c+192|0;return a?0:f}b=P()|0;break c}b=P()|0;wb(c+32|0)}wb(c+16|0);break a}b=P()|0;Cf(a)}S(b|0);p()}function Zla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;g=b;c=ib-48|0;ib=c;d=a;a:{if(Cu(x[d>>2],x[d+8>>2])){x[g>>2]=0;break a}vV(c+16|0,c+32|0);kc(c+24|0,x[d>>2],x[d+8>>2],x[c+16>>2],x[c+20>>2]);h=x[c+28>>2];i=y[c+32|0];f=i&127;x[g>>2]=f;a=f;b=0;while(1){if(a){b=b+1|0;a=a>>>1|0;continue}break}a=b;e=1;while(1){b=(D(h,7)+a|0)+D(e,-7)|0;b:{while(1){if(i<<24>>24>=0|e>>>0>=h>>>0){break b}i=y[(c+32|0)+e|0];f=i&127|f<<7;x[g>>2]=f;a=a+7|0;e=e+1|0;if((h|0)!=(e|0)){continue}break}Yb(d,h);vV(c+8|0,c+32|0);kc(c+24|0,x[d>>2],x[d+8>>2],x[c+8>>2],x[c+12>>2]);h=x[c+28>>2];f=x[g>>2];e=0;a=b;continue}break}Yb(d,e);if(a>>>0<33){break a}x[g>>2]=-1}ib=c+48|0}function VP(a,b,c,d,e){var f=0,g=0,h=0,i=0;a:{b:{c:{if(v[b+851|0]&1){f=y[b+848|0];g=c&240;if(g){f=f&15|g;v[b+848|0]=f}c=c&15;if(c){f=c|f&-16;v[b+848|0]=f}v[b+849|0]=(f&240)>>>4;if(x[a+480180>>2]!=32768){break a}break c}if(x[a+480180>>2]==32768){break c}c=y[b+849|0]-1|0;v[b+849|0]=c;if(c&255){break a}f=y[b+848|0];break b}f=y[b+848|0];if((f&240)==16){break b}if(!(y[a+480209|0]&16)){break a}}v[b+849|0]=(f&240)>>>4;c=f&15;c=d?c:0-c|0;d=x[b+656>>2];d:{if(Aj(d)){x[b+852>>2]=x[b+852>>2]+D(c,x[x[d+44>>2]+36>>2]);break d}h=b,i=nh(a,xt(a,x[b+700>>2],w[b+772>>1],x[b+704>>2])+c|0,w[b+772>>1],x[b+704>>2]),x[h+700>>2]=i}if(!e){break a}x[b>>2]=0;x[b+4>>2]=0}}function Cn(a,b,c,d,e,f,g,h,i,j){var k=0,l=0;a:{b:{k=x[d>>2];if((k|0)!=(c|0)){break b}l=43;if(x[j+96>>2]!=(a|0)){l=45;if(x[j+100>>2]!=(a|0)){break b}}x[d>>2]=c+1;v[c|0]=l;break a}c:{if(!(!Eb(g)|(a|0)!=(f|0))){g=0;a=x[i>>2];if((a-h|0)>159){break c}b=x[e>>2];x[i>>2]=a+4;x[a>>2]=b;break a}g=-1;f=Sw(j,j+104|0,a)-j|0;if((f|0)>92){break c}a=f>>2;d:{e:{switch(b-8|0){case 0:case 2:if((a|0)<(b|0)){break d}break c;case 1:break d;default:break e}}if((b|0)!=16|(f|0)<88){break d}if((c|0)==(k|0)|(k-c|0)>2|y[k-1|0]!=48){break c}x[e>>2]=0;x[d>>2]=k+1;v[k|0]=y[a+98224|0];return 0}x[d>>2]=k+1;v[k|0]=y[a+98224|0];x[e>>2]=x[e>>2]+1;g=0}return g}x[e>>2]=0;return 0}function zm(a,b,c,d){var e=0,f=0;e=ib-16|0;ib=e;f=a+1074312|0;Ab(e+8|0,f,84);a:{if(zb(x[x[e+8>>2]>>2],x[e+12>>2])){break a}b:{if(x[a+480208>>2]&16384){break b}if((d|0)!=8){Ab(e+8|0,f,10);if(!zb(x[x[e+8>>2]>>2],x[e+12>>2])){break b}}x[b+88>>2]=x[b+88>>2]&-257}c:{d:{e:{switch(d-4|0){case 0:c=((c<<8|8)>>>0)/15|0;break d;case 2:c=(c>>>0>=64?64:c)<<2;break d;default:break e}}if(!(x[a+480180>>2]&2107410)){break d}if(c>>>0<=128){c=c<<1;break d}if((c|0)!=164){break c}x[b+88>>2]=x[b+88>>2]|256;c=128}x[b+692>>2]=c}w[b+784>>1]=0;x[b+88>>2]=x[b+88>>2]|2097152;Ab(e+8|0,f,10);if(!zb(x[x[e+8>>2]>>2],x[e+12>>2])){break a}v[b+831|0]=0;w[b+778>>1]=0}ib=e+16|0}function xla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=ib-32|0;ib=d;x[d+28>>2]=0;wk(a,d+28|0);a:{b:{i=x[d+28>>2];c:{if(i>>>0>500){break c}d:{e:{while(1){if((f|0)==(i|0)){break c}g=Kb(d+16|0);x[27524]=0;w[d+14>>1]=0;e=W(487,a|0,g|0,255)|0;h=x[27524];x[27524]=0;if((h|0)==1){break b}if(!e){break d}x[27524]=0;R(476,a|0,d+14|0);e=x[27524];x[27524]=0;if((e|0)==1){break b}x[27524]=0;U(11,d|0,c|0,g|0);e=x[27524];x[27524]=0;if((e|0)!=1){x[27524]=0;e=Q(488,b|0,d+14|0)|0;h=x[27524];x[27524]=0;if((h|0)==1){break e}Gb(e,d);xb(d);wb(g);f=f+1|0;continue}break}f=P()|0;break a}f=P()|0;xb(d);break a}wb(g)}ib=d+32|0;return}f=P()|0}wb(g);S(f|0);p()}function _z(a,b,c,d,e){var f=0,g=0,h=0,i=0;g=ib-16|0;ib=g;i=sl(a,b);a:{if((i|0)==255){break a}if(qk(x[a>>2])){break a}b:{if(c>>>0>6208431){f=7;c=1023;break b}f=7;c:{if(c>>>0>3104215){break c}f=6;if(c>>>0>1552107){break c}f=5;if(c>>>0>776053){break c}f=4;if(c>>>0>388026){break c}f=3;if(c>>>0>194013){break c}f=2;if(c>>>0>97006){break c}f=c>>>0>48503}c=qoa(1<<20-f,0,c,0)+24858e3|0;h=kb;c=Ec(soa(c,c>>>0<24858e3?h+1|0:h,49716e3,0),kb)}if(e){w[g+14>>1]=(b&3)+c;w[g+12>>1]=1023;c=z[Tc(g+14|0,g+12|0)>>1]}h=Qt(i);e=Jb(a+8|0,i);v[e|0]=(f<<10|c)>>>8|(d?0:32);ph(x[a>>2],x[a+4>>2],b,h|160,c&255);ph(x[a>>2],x[a+4>>2],b,h|176,y[e|0]);v[a+534|0]=1}ib=g+16|0}function RF(a,b,c,d){var e=0,f=0,g=0;f=ib-32|0;ib=f;x[27524]=0;Y(958,a|0);e=x[27524];x[27524]=0;a:{b:{c:{d:{e:{f:{if((e|0)==1){break f}x[27524]=0;Y(959,b|0);e=x[27524];x[27524]=0;if((e|0)==1){break f}g=x[a+24>>2];x[27524]=0;e=Q(55,f|0,b|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break e}x[27524]=0;U(d|0,f+16|0,g|0,e|0);b=x[27524];x[27524]=0;if((b|0)==1){break d}a=f+16|0;b=mg(Jc(a));wb(a);wb(e);break b}b=V(0)|0;break c}b=V(0)|0;break c}b=V(0)|0;wb(e)}_(b|0)|0;b=0;x[27524]=0;X(945,c|0,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)==1){break a}$()}ib=f+32|0;return b}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function wla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=ib-32|0;ib=d;w[d+30>>1]=0;dg(a,d+30|0);a:{b:{i=z[d+30>>1];c:{if(i>>>0>500){break c}d:{e:{while(1){if((f|0)==(i|0)){break c}g=Kb(d+16|0);x[27524]=0;w[d+14>>1]=0;e=Q(489,a|0,g|0)|0;h=x[27524];x[27524]=0;if((h|0)==1){break b}if(!e){break d}x[27524]=0;R(476,a|0,d+14|0);e=x[27524];x[27524]=0;if((e|0)==1){break b}x[27524]=0;U(11,d|0,c|0,g|0);e=x[27524];x[27524]=0;if((e|0)!=1){x[27524]=0;e=Q(488,b|0,d+14|0)|0;h=x[27524];x[27524]=0;if((h|0)==1){break e}Gb(e,d);xb(d);wb(g);f=f+1|0;continue}break}f=P()|0;break a}f=P()|0;xb(d);break a}wb(g)}ib=d+32|0;return}f=P()|0}wb(g);S(f|0);p()}function Uga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=ib-16|0;ib=b;f=x[a+40>>2];g=x[a+36>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+32>>2];k=x[a+28>>2];l=x[a+8>>2];m=x[a+12>>2];while(1){if(d){e=x[b+12>>2]+i|0;h=x[b+8>>2]>>>21&2040;e=(((D(v[e|0],w[h+39730>>1])+D(v[e-1|0],w[h+39728>>1])|0)+D(v[e+1|0],w[h+39732>>1])|0)+D(v[e+2|0],w[h+39734>>1])<<8)/16384|0;g=g+k|0;x[c>>2]=x[c>>2]+D(e,g>>12);f=f+j|0;x[c+4>>2]=x[c+4>>2]+D(e,f>>12);Pb(b+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;ib=b+16|0}function S3(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=ib-48|0;ib=e;if(FI(1,e+24|0)){xs(x[12e4],12675);p()}c=Oe(e+16|0,e+24|0);g=jz(e+8|0,x[e+32>>2]);d=ib-32|0;ib=d;b=ib-16|0;ib=b;a=ib-16|0;ib=a;h=a,i=qoa(x[c>>2],x[c+4>>2],1e9,0),x[h>>2]=i;x[a+4>>2]=kb;c=Oe(a+8|0,a);f=x[c+4>>2];c=x[c>>2];ib=a+16|0;x[b+8>>2]=c;x[b+12>>2]=f;a=x[b+12>>2];x[d+8>>2]=x[b+8>>2];x[d+12>>2]=a;ib=b+16|0;f=x[d+8>>2];c=x[d+12>>2];a=x[g+4>>2];x[d>>2]=x[g>>2];x[d+4>>2]=a;a=d;c=x[a+4>>2]+c|0;b=x[a>>2];f=f+b|0;x[a+16>>2]=f;x[a+20>>2]=b>>>0>f>>>0?c+1|0:c;a=Oe(a+24|0,a+16|0);b=x[a+4>>2];a=x[a>>2];ib=d+32|0;a=Qz(e+40|0,a,b);b=x[a+4>>2];a=x[a>>2];ib=e+48|0;kb=b;return a|0}function $ea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=ib-80|0;ib=d;e=If(d+48|0);x[27524]=0;g=Q(803,b|0,e|0)|0;f=x[27524];x[27524]=0;a:{b:{c:{if((f|0)!=1){if(g){break c}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[27524]=0;T(804,a|0)|0;a=x[27524];x[27524]=0;if((a|0)!=1){break b}}break a}g=x[e+4>>2];x[27524]=0;U(194,d|0,b|0,g|0);f=x[27524];x[27524]=0;if((f|0)==1){break a}f=hc(d+24|0,d);fd(e+8|0,f);yb(f);yb(d);d:{if(c>>>0<2){break d}c=g&1;if(!c){break d}x[27524]=0;Q(192,b|0,2-c|0)|0;b=x[27524];x[27524]=0;if((b|0)!=1){break d}break a}Ek(a,e)}yd(e);ib=d+80|0;return}a=P()|0;yd(e);S(a|0);p()}function ff(a,b,c){var d=0,e=0,f=0;d=Kb(a);a=Eb(b);x[27524]=0;R(46,d|0,a|0);a=x[27524];x[27524]=0;if((a|0)!=1){a:{while(1){if(Eb(b)>>>0>e>>>0){f=x[Hi(b,e)>>2];a=32;b:{while(1){c:{if((a|0)==256){a=0;break c}if(x[(a<<2)+c>>2]==(f|0)){x[27524]=0;R(47,d|0,a<<24>>24);a=x[27524];x[27524]=0;if((a|0)!=1){break b}break a}else{a=a+1|0;continue}}break}d:{while(1){if((a|0)==32){break d}if(x[(a<<2)+c>>2]!=(f|0)){a=a+1|0;continue}break}x[27524]=0;R(47,d|0,a<<24>>24);a=x[27524];x[27524]=0;if((a|0)!=1){break b}break a}x[27524]=0;R(47,d|0,63);a=x[27524];x[27524]=0;if((a|0)!=1){break b}break a}e=e+1|0;continue}break}return}}a=P()|0;wb(d);S(a|0);p()}function U_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;if(gh(a,x[b+8>>2],f)){Jw(b,c,d,e);return}g=y[b+53|0];j=x[a+12>>2];v[b+53|0]=0;h=y[b+52|0];v[b+52|0]=0;m=a+16|0;Fw(x[m>>2],x[a+20>>2],b,c,d,e,f);k=y[b+53|0];g=g|k;l=y[b+52|0];h=h|l;i=a+24|0;j=(j<<3)+m|0;a:{if(i>>>0>=j>>>0){break a}while(1){h=h&1;g=g&1;if(y[b+54|0]){break a}b:{if(l){if(x[b+24>>2]==1){break a}if(y[a+8|0]&2){break b}break a}if(!k){break b}if(!(v[a+8|0]&1)){break a}}w[b+52>>1]=0;Fw(x[i>>2],x[i+4>>2],b,c,d,e,f);k=y[b+53|0];g=k|g;l=y[b+52|0];h=l|h;i=i+8|0;if(j>>>0>i>>>0){continue}break}}v[b+53|0]=(g&255)!=0;v[b+52|0]=(h&255)!=0}function Yea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=ib-48|0;ib=d;f=Jc(b);e=Eb(b);h=Jc(c);i=Eb(c);g=-1;a:{if(!e){break a}j=e+f|0;e=f;while(1){if((e|0)==(j|0)){break a}if(Np(h,i,y[e|0])){e=e+1|0;continue}break}g=e-f|0}b:{c:{if((g|0)!=-1){k=d,l=ke(b),x[k+32>>2]=l;f=pj(d+40|0,d+32|0);k=d,l=ke(b),x[k+8>>2]=l;k=d,l=Op(d+8|0,g),x[k+16>>2]=l;c=pj(d+24|0,d+16|0);AN(b,x[f>>2],x[c>>2]);break c}i=Eb(b);if(!i){break c}h=Jc(b);j=Eb(b);e=Jc(c);g=-1;f=Eb(c);if(f){c=h+j|0;d:{while(1){if((c|0)==(h|0)){break d}c=c-1|0;if(!Np(e,f,y[c|0])){continue}break}g=c-h|0}}if((i-1|0)!=(g|0)){break c}Kb(a);break b}$c(a,b)}ib=d+48|0}function r3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=ib-16|0;ib=g;a:{b:{if(!pc(b,-1)){i=x[a+8>>2];j=x[a+12>>2];d=x[a+24>>2];if((d|0)==x[a+28>>2]){e=-1;if(!(y[a+48|0]&16)){break a}h=x[a+20>>2];k=x[a+44>>2];x[27524]=0;c=a+32|0;R(47,c|0,0);f=x[27524];x[27524]=0;if((f|0)==1){break b}f=ad(c);x[27524]=0;R(60,c|0,f|0);f=x[27524];x[27524]=0;if((f|0)==1){break b}e=vc(c);hx(a,e,Eb(c)+e|0);rs(a,d-h|0);x[a+44>>2]=x[a+20>>2]+(k-h|0);d=x[a+24>>2]}x[g+12>>2]=d+1;d=x[Yc(g+12|0,a+44|0)>>2];x[a+44>>2]=d;if(y[a+48|0]&8){c=vc(a+32|0);Fn(a,c,c+(j-i|0)|0,d)}e=eI(a,zp(b));break a}e=gx(b);break a}_(V(0)|0)|0;$()}ib=g+16|0;return e|0}function mka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=E(0),g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;c=ib-16|0;ib=c;a:{b:{d=x[b+8>>2];if((d|0)==x[a+8>>2]){e=x[b+4>>2];if((e|0)!=x[a+4>>2]){break b}x[c+12>>2]=d;x[c+8>>2]=d;d=x[Hb(c+12|0,c+8|0)>>2];x[c+12>>2]=e;x[c+8>>2]=e;h=x[Hb(c+12|0,c+8|0)>>2];i=x[a>>2];j=x[b>>2];b=0;c:while(1){if((b|0)==(d|0)){break a}k=D(b,e);a=0;while(1)if((a|0)==(h|0)){b=b+1|0;continue c}else{l=(a+k<<1)+i|0;f=$h(E(Ld(B[x[(a<<2)+j>>2]+(b<<2)>>2],E(-1))*E(32768)));d:{if(E(F(f))<E(2147483648)){g=~~f;break d}g=-2147483648}m=l,n=dd(g),w[m>>1]=n;a=a+1|0;continue}}}aa(17313,8931,27,9458);p()}aa(17263,8931,28,9458);p()}ib=c+16|0}function ls(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;h=ib-16|0;ib=h;f=d?d:483252;d=x[f>>2];a:{b:{c:{if(!b){if(d){break c}break a}e=-2;if(!c){break a}i=a?a:h+12|0;d:{if(d){a=c;break d}a=y[b|0];d=a<<24>>24;if((d|0)>=0){x[i>>2]=a;e=(d|0)!=0;break a}if(!x[x[120026]>>2]){x[i>>2]=d&57343;e=1;break a}a=a-194|0;if(a>>>0>50){break c}d=x[(a<<2)+98016>>2];a=c-1|0;if(!a){break b}b=b+1|0}g=y[b|0];j=g>>>3|0;if((j-16|(d>>26)+j)>>>0>7){break c}while(1){a=a-1|0;d=g-128|d<<6;if((d|0)>=0){x[f>>2]=0;x[i>>2]=d;e=c-a|0;break a}if(!a){break b}b=b+1|0;g=y[b|0];if((g&192)==128){continue}break}}x[f>>2]=0;x[12e4]=25;e=-1;break a}x[f>>2]=d}ib=h+16|0;return e}function cma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=x[a>>2];d=Qq(c,x[a+4>>2]);if(d>>>0<b>>>0){f=ib-32|0;ib=f;c=b-d|0;b=x[Db(a)>>2];e=x[a+4>>2];a:{if(c>>>0<=(b-e|0)/40>>>0){d=ib-16|0;ib=d;b=nX(d,a,c);a=x[b+4>>2];c=x[b+8>>2];while(1){if((a|0)==(c|0)){ic(b);ib=d+16|0}else{qV(a);a=a+40|0;x[b+4>>2]=a;continue}break}break a}b=Db(a);d=kX(f+8|0,lX(a,Qq(x[a>>2],e)+c|0),Qq(x[a>>2],x[a+4>>2]),b);b=ib-16|0;ib=b;x[b>>2]=x[d+8>>2];e=x[d+8>>2];x[b+8>>2]=d+8;x[b+4>>2]=D(c,40)+e;c=x[b>>2];while(1){if(x[b+4>>2]!=(c|0)){qV(c);c=x[b>>2]+40|0;x[b>>2]=c;continue}break}Vd(b);ib=b+16|0;jX(a,d);iX(d)}ib=f+32|0;return}if(b>>>0<d>>>0){Od(a,c+D(b,40)|0)}}function SZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=ib-16|0;ib=g;e=nd(b);d=xd(x[b+4>>2],y[b+11|0]);i=nd(c);j=xd(x[c+4>>2],y[c+11|0]);f=-1;a:{if(!d){break a}h=d+e|0;d=e;while(1){if((d|0)==(h|0)){break a}if(Au(i,j,y[d|0])){d=d+1|0;continue}break}f=d-e|0}b:{c:{if((f|0)!=-1){c=Wb(g+8|0,Ti(b));d=Wb(g,Yf(Ti(b),f));BD(b,x[c>>2],x[d>>2]);break c}f=Ik(x[b+4>>2],y[b+11|0]);if(!f){break c}e=nd(b);i=xd(x[b+4>>2],y[b+11|0]);j=nd(c);d=-1;h=xd(x[c+4>>2],y[c+11|0]);if(h){c=e+i|0;d:{while(1){if((c|0)==(e|0)){break d}c=c-1|0;if(!Au(j,h,y[c|0])){continue}break}d=c-e|0}}if((f-1|0)!=(d|0)){break c}Kb(a);break b}$c(a,b)}ib=g+16|0}function wK(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;d=ib-16|0;ib=d;a:{b:{c:{d:{if((b|0)>=0){a=x[a+32>>2];if((Cg(a)|0)>(b|0)){break d}}a=ba(8)|0;x[27524]=0;d=Q(55,d|0,10644)|0;b=x[27524];x[27524]=0;if((b|0)==1){break c}lc(a,d);x[27524]=0;U(123,a|0,50060,962);a=x[27524];x[27524]=0;if((a|0)!=1){break a}b=P()|0;wb(d);break b}if(c<0|c>1){a=ba(8)|0;x[27524]=0;d=Q(55,d|0,11648)|0;b=x[27524];x[27524]=0;if((b|0)!=1){lc(a,d);x[27524]=0;U(123,a|0,50060,962);a=x[27524];x[27524]=0;if((a|0)!=1){break a}b=P()|0;wb(d);break b}b=P()|0;ca(a|0);break b}e=(a+D(b,872)|0)+1075740|0,f=Al(c*64),x[e>>2]=f;ib=d+16|0;return}b=P()|0;ca(a|0)}S(b|0)}p()}function YD(a){a=a|0;var b=0,c=0,d=0,e=0;b=hD(x[x[a>>2]-12>>2]+a|0,10);d=ib-16|0;ib=d;x[27524]=0;c=Q(13,d+8|0,a|0)|0;e=x[27524];x[27524]=0;a:{b:{c:{d:{if((e|0)!=1){e:{if(!y[c|0]){break e}e=Jo(d,a);x[27524]=0;b=Q(21,e|0,b|0)|0;e=x[27524];x[27524]=0;if((e|0)!=1){if(!sC(b)){break e}b=x[x[a>>2]-12>>2];x[27524]=0;R(16,a+b|0,1);b=x[27524];x[27524]=0;if((b|0)!=1){break e}}b=V(0)|0;Hl(c);break d}Hl(c);break c}b=V(0)|0}_(b|0)|0;c=x[x[a>>2]-12>>2];x[27524]=0;Y(17,a+c|0);c=x[27524];x[27524]=0;if((c|0)==1){break b}$()}ib=d+16|0;break a}a=P()|0;x[27524]=0;Z(18);d=x[27524];x[27524]=0;if((d|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}return Tm(a)|0}function lka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=E(0),g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;c=ib-16|0;ib=c;a:{b:{d=x[b+8>>2];if((d|0)==x[a+8>>2]){e=x[b+4>>2];if((e|0)!=x[a+4>>2]){break b}x[c+12>>2]=d;x[c+8>>2]=d;d=x[Hb(c+12|0,c+8|0)>>2];x[c+12>>2]=e;x[c+8>>2]=e;h=x[Hb(c+12|0,c+8|0)>>2];i=x[a>>2];j=x[b>>2];b=0;c:while(1){if((b|0)==(d|0)){break a}k=D(b,e);a=0;while(1)if((a|0)==(h|0)){b=b+1|0;continue c}else{l=(a+k|0)+i|0;f=$h(E(Ld(B[x[(a<<2)+j>>2]+(b<<2)>>2],E(-1))*E(128)));d:{if(E(F(f))<E(2147483648)){g=~~f;break d}g=-2147483648}m=l,n=FU(g),v[m|0]=n;a=a+1|0;continue}}}aa(17313,8931,27,9458);p()}aa(17263,8931,28,9458);p()}ib=c+16|0}function bfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=ib-80|0;ib=d;e=If(d+48|0);x[27524]=0;c=Q(799,b|0,e|0)|0;f=x[27524];x[27524]=0;a:{b:{c:{if((f|0)!=1){if(c){break c}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[27524]=0;T(800,a|0)|0;a=x[27524];x[27524]=0;if((a|0)!=1){break b}}break a}c=x[e+4>>2];x[27524]=0;c=ac(c);c=c?c:-1;U(194,d|0,b|0,c|0);f=x[27524];x[27524]=0;if((f|0)==1){break a}f=hc(d+24|0,d);fd(e+8|0,f);yb(f);yb(d);d:{c=c&1;if(!c){break d}x[27524]=0;Q(192,b|0,2-c|0)|0;b=x[27524];x[27524]=0;if((b|0)!=1){break d}break a}Ek(a,e)}yd(e);ib=d+80|0;return}a=P()|0;yd(e);S(a|0);p()}function TL(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=ib-32|0;ib=e;f=Nb(a);a=b;b=z[x[b+24>>2]+480192>>1];x[27524]=0;R(185,f|0,b|0);c=x[27524];x[27524]=0;b=1;a:{if((c|0)!=1){b:{c:{d:{e:{while(1){d=b&65535;c=x[a+24>>2];if(d>>>0>z[c+480192>>1]){break b}c=KO(c,d);x[27524]=0;c=Q(55,e|0,c|0)|0;d=x[27524];x[27524]=0;if((d|0)!=1){d=x[a+24>>2];x[27524]=0;U(1015,e+16|0,d|0,c|0);d=x[27524];x[27524]=0;if((d|0)==1){break e}x[27524]=0;R(187,f|0,e+16|0);d=x[27524];x[27524]=0;if((d|0)==1){break d}wb(e+16|0);wb(c);b=b+1|0;continue}break}b=P()|0;break a}b=P()|0;break c}b=P()|0;wb(e+16|0)}wb(c);break a}ib=e+32|0;return}b=P()|0}ve(f);S(b|0);p()}function Lv(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=ib-16|0;ib=f;v[f+15|0]=d;v[b+12|0]=y[b+12|0]&240|y[a|0]&15;i=a+1|0;e=f+15|0;Zg(b,y[Ub(i,e)|0]);g=y[Ub(a+2|0,e)|0];v[b+13|0]=g;k=b,l=Bd(y[a+3|0],g,d),v[k+14|0]=l;e=y[Ub(a+4|0,e)|0];v[b+15|0]=e;k=b,l=Bd(y[a+5|0],e,d),v[k+16|0]=l;g=x[b>>2];b=0;while(1){v[f+14|0]=25;if(b>>>0<y[Ub(f+14|0,i)|0]){e=D(b,3)+a|0;h=Vb(y[e+6|0]+c<<24>>24,0,64);d=Bb(g,b);v[d+2|0]=h;e=y[e+7|0]|y[e+8|0]<<8;w[d>>1]=e;a:{if(!b){break a}h=Bb(g,b-1|0);j=z[h>>1];if(e>>>0>255|e>>>0>=j>>>0){break a}e=e|j&65280;w[d>>1]=e;if(z[h>>1]<=(e&65535)>>>0){break a}w[d>>1]=e+256}b=b+1|0;continue}break}ib=f+16|0}function n4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=ib-32|0;ib=e;h=Kb(a);f=Kb(e+16|0);a=1;a:{b:{c:{while(1){d=a&65535;c=x[b+24>>2];if(d>>>0>z[c+480192>>1]){if(!(i&1)){break c}x[27524]=0;R(251,h|0,f|0);a=x[27524];x[27524]=0;if((a|0)!=1){break c}a=P()|0;break a}c=KO(c,d);x[27524]=0;c=Q(55,e|0,c|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break b}d=Qe(c);x[27524]=0;g=Q(806,f|0,c|0)|0;j=x[27524];x[27524]=0;d:{if((j|0)==1){break d}x[27524]=0;Q(947,g|0,21601)|0;g=x[27524];x[27524]=0;if((g|0)==1){break d}i=d^1|i;wb(c);a=a+1|0;continue}break}a=P()|0;wb(c);break a}wb(f);ib=e+32|0;return}a=P()|0}wb(f);wb(h);S(a|0);p()}function c_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=ib-32|0;ib=c;a:{b:{c:{d:{if(h=yh(x[b+4>>2],y[b+11|0]),i=1,j=x[b+12>>2],j?h:i){Kb(a);break d}e=Kb(c+16|0);d=xd(x[b+4>>2],y[b+11|0]);f=or(14314);g=nd(b);x[27524]=0;X(105,e|0,g|0,d|0,d+f|0);d=x[27524];x[27524]=0;e:{if((d|0)!=1){x[27524]=0;W(106,e|0,14314,f|0)|0;d=x[27524];x[27524]=0;if((d|0)!=1){break e}}a=P()|0;xb(e);S(a|0);p()}x[27524]=0;R(136,c|0,b+12|0);b=x[27524];x[27524]=0;if((b|0)==1){break c}x[27524]=0;U(2,a|0,c+16|0,c|0);a=x[27524];x[27524]=0;if((a|0)==1){break b}xb(c);xb(c+16|0)}ib=c+32|0;return}b=P()|0;break a}b=P()|0;xb(c)}xb(c+16|0);S(b|0);p()}function WD(a){var b=0,c=0,d=0,e=0,f=0,g=0;a:{if(Qb(a,3878,4)){break a}b=y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24);if(b>>>0<36){break a}c=y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24);if(c>>>0<36){break a}d=y[a+32|0]|y[a+33|0]<<8|(y[a+34|0]<<16|y[a+35|0]<<24);if(d>>>0<36){break a}e=y[a+12|0]|y[a+13|0]<<8|(y[a+14|0]<<16|y[a+15|0]<<24);if(e-1>>>0>858993458){break a}f=y[a+20|0]|y[a+21|0]<<8|(y[a+22|0]<<16|y[a+23|0]<<24);if(f-1>>>0>536870910){break a}a=y[a+28|0]|y[a+29|0]<<8|(y[a+30|0]<<16|y[a+31|0]<<24);if(D(e,-5)-1>>>0<b>>>0|a-1>>>0>1073741822|(f<<3^-1)>>>0<c>>>0){break a}g=(a<<2^-1)>>>0>=d>>>0}return g}function GL(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=ib-32|0;ib=e;f=Nb(a);a=b;b=z[x[b+24>>2]+480190>>1];x[27524]=0;R(185,f|0,b|0);d=x[27524];x[27524]=0;b=1;a:{if((d|0)!=1){b:{c:{d:{e:{while(1){c=b&65535;d=x[a+24>>2];if(c>>>0>z[d+480190>>1]){break b}x[27524]=0;d=Q(55,e|0,LO(d,c)|0)|0;c=x[27524];x[27524]=0;if((c|0)!=1){c=x[a+24>>2];x[27524]=0;U(1015,e+16|0,c|0,d|0);c=x[27524];x[27524]=0;if((c|0)==1){break e}x[27524]=0;R(187,f|0,e+16|0);c=x[27524];x[27524]=0;if((c|0)==1){break d}wb(e+16|0);wb(d);b=b+1|0;continue}break}b=P()|0;break a}b=P()|0;break c}b=P()|0;wb(e+16|0)}wb(d);break a}ib=e+32|0;return}b=P()|0}ve(f);S(b|0);p()}function m4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=ib-32|0;ib=e;h=Kb(a);f=Kb(e+16|0);a=1;a:{b:{c:{while(1){d=a&65535;c=x[b+24>>2];if(d>>>0>z[c+480190>>1]){if(!(i&1)){break c}x[27524]=0;R(251,h|0,f|0);a=x[27524];x[27524]=0;if((a|0)!=1){break c}a=P()|0;break a}x[27524]=0;c=Q(55,e|0,LO(c,d)|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break b}d=Qe(c);x[27524]=0;g=Q(806,f|0,c|0)|0;j=x[27524];x[27524]=0;d:{if((j|0)==1){break d}x[27524]=0;Q(947,g|0,21601)|0;g=x[27524];x[27524]=0;if((g|0)==1){break d}i=d^1|i;wb(c);a=a+1|0;continue}break}a=P()|0;wb(c);break a}wb(f);ib=e+32|0;return}a=P()|0}wb(f);wb(h);S(a|0);p()}function bV(a){var b=0,c=0,d=0,e=0,f=0;b=ib-32|0;ib=b;e=b,f=ac(y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24))+788|0,x[e>>2]=f;x[b+4>>2]=0;e=b,f=ac(y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24)),x[e+8>>2]=f;x[b+12>>2]=0;c=ac(y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24));x[b+16>>2]=c?c:52;x[b+20>>2]=0;e=b,f=ac(y[a+32|0]|y[a+33|0]<<8|(y[a+34|0]<<16|y[a+35|0]<<24))+80|0,x[e+24>>2]=f;x[b+28>>2]=0;a=b;d=We(a,4);a:{if((a|0)==(d|0)){break a}c=a;while(1){c=c+8|0;if((d|0)==(c|0)){break a}a=Gv(x[a>>2],x[a+4>>2],x[c>>2],x[c+4>>2])?c:a;continue}}ib=b+32|0;c=x[a>>2];b=c-52|0;kb=x[a+4>>2]-(c>>>0<52)|0;return b}function Oda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=ib-80|0;ib=d;e=If(d+48|0);x[27524]=0;g=Q(874,b|0,e|0)|0;f=x[27524];x[27524]=0;a:{b:{c:{if((f|0)!=1){if(g){break c}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[27524]=0;T(875,a|0)|0;a=x[27524];x[27524]=0;if((a|0)!=1){break b}}break a}g=x[e+4>>2];x[27524]=0;U(194,d|0,b|0,g|0);f=x[27524];x[27524]=0;if((f|0)==1){break a}f=hc(d+24|0,d);fd(e+8|0,f);yb(f);yb(d);d:{if(!(g&1)|c>>>0<2){break d}x[27524]=0;Q(192,b|0,1)|0;b=x[27524];x[27524]=0;if((b|0)!=1){break d}break a}Ek(a,e)}yd(e);ib=d+80|0;return}a=P()|0;yd(e);S(a|0);p()}function xI(a,b,c,d,e){var f=0,g=0,h=0,i=0;f=ib-208|0;ib=f;x[f+204>>2]=c;c=f+160|0;Rb(c,0,40);x[f+200>>2]=x[f+204>>2];a:{if((wI(0,b,f+200|0,f+80|0,c,d,e)|0)<0){e=-1;break a}i=x[a+76>>2]>=0;g=x[a>>2];if(x[a+72>>2]<=0){x[a>>2]=g&-33}b:{c:{d:{if(!x[a+48>>2]){x[a+48>>2]=80;x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;h=x[a+44>>2];x[a+44>>2]=f;break d}if(x[a+16>>2]){break c}}c=-1;if(_C(a)){break b}}c=wI(a,b,f+200|0,f+80|0,f+160|0,d,e)}if(h){lb[x[a+36>>2]](a,0,0)|0;x[a+48>>2]=0;x[a+44>>2]=h;x[a+28>>2]=0;b=x[a+20>>2];x[a+16>>2]=0;x[a+20>>2]=0;c=b?c:-1}b=a;a=x[a>>2];x[b>>2]=a|g&32;e=a&32?-1:c;if(!i){break a}}ib=f+208|0;return e}function qaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=ib-16|0;ib=e;i=e,j=Ej(b),x[i>>2]=j;c=ib-16|0;ib=c;g=a;d=Td(a);a:{if(d){f=gc(g);while(1){a=d;d=a+16|0;if(Jt(b,d)){f=a;d=x[a>>2];if(d){continue}break a}if(!Jt(d,b)){break a}f=a+4|0;d=x[a+4>>2];if(d){continue}break}break a}a=gc(g);f=a}x[c+12>>2]=a;b=x[f>>2];if(!b){a=ib-16|0;ib=a;b=gc(g);b=sh(c,mc(40),th(a+8|0,b));Kb($c(x[b>>2]+16|0,x[e>>2])+12|0);i=gc(b),j=1,v[i+4|0]=j;ib=a+16|0;Tg(g,x[c+12>>2],f,x[c>>2]);b=ce(c);a=x[c>>2];x[c>>2]=0;if(a){if(y[gc(c)+4|0]){Am(a+16|0)}Ib(a)}h=1}Sg(e+8|0,x[Wb(c,b)>>2],h);ib=c+16|0;a=ud(x[e+8>>2]);ib=e+16|0;return a+12|0}function dfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=ib-80|0;ib=d;e=If(d+48|0);x[27524]=0;c=Q(795,b|0,e|0)|0;f=x[27524];x[27524]=0;a:{b:{c:{if((f|0)!=1){if(c){break c}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[27524]=0;T(796,a|0)|0;a=x[27524];x[27524]=0;if((a|0)!=1){break b}}break a}c=x[e+4>>2];x[27524]=0;c=ac(c);U(194,d|0,b|0,c|0);f=x[27524];x[27524]=0;if((f|0)==1){break a}f=hc(d+24|0,d);fd(e+8|0,f);yb(f);yb(d);d:{c=c&1;if(!c){break d}x[27524]=0;Q(192,b|0,2-c|0)|0;b=x[27524];x[27524]=0;if((b|0)!=1){break d}break a}Ek(a,e)}yd(e);ib=d+80|0;return}a=P()|0;yd(e);S(a|0);p()}function _O(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=ib-16|0;ib=d;x[d+12>>2]=b;if(b>>>0<4294967280){a:{if(zl(a)>>>0>=b>>>0){break a}i=d,j=xd(x[a+4>>2],y[a+11|0]),x[i+8>>2]=j;e=Wg(x[Yc(d+12|0,d+8|0)>>2]);if((e|0)==(zl(a)|0)){break a}f=xd(x[a+4>>2],y[a+11|0]);b:{c:{if((e|0)==10){g=x[a>>2];h=1;b=a;c=f;break c}b=e+1|0;d:{if(zl(a)>>>0<e>>>0){b=mc(b);break d}x[27524]=0;b=T(52,b|0)|0;c=x[27524];x[27524]=0;if((c|0)!=1){break d}_(V(0)|0)|0;$();break b}c=y[a+11|0];h=Ue(c);g=nd(a);c=xd(x[a+4>>2],c)}b=Ae(b,g,c+1|0);if(h){Ib(g)}if((e|0)!=10){hf(a,e+1|0);vd(a,f);td(a,b);break b}ee(a,f)}}ib=d+16|0;return}of();p()}function VR(a,b,c){a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{b=b&15;switch(b-3|0){case 2:break j;case 1:break k;case 0:break l;case 10:case 11:break b;case 9:break c;case 8:break d;case 7:break e;case 6:break f;case 5:break g;case 4:break h;case 3:break i;default:break a}}v[a+798|0]=0;return}v[a+798|0]=1;return}v[a+798|0]=2;return}v[a+798|0]=3;return}v[a+730|0]=y[a+730|0]&254;return}v[a+730|0]=y[a+730|0]|1;return}v[a+738|0]=y[a+738|0]&254;return}v[a+738|0]=y[a+738|0]|1;return}v[a+746|0]=y[a+746|0]&254;return}v[a+746|0]=y[a+746|0]|1;return}if((c|0)!=16777216){break a}c=a;a=y[a+746|0];v[c+746|0]=(b|0)==13?a&238|1:a|17}}function x0(a){a=a|0;if(y[483680]){return x[120919]}if(!y[484784]){a=484496;while(1){a=Kb(a)+12|0;if((a|0)!=484784){continue}break}v[484784]=1}pd(484496,104488);pd(484508,104520);pd(484520,104556);pd(484532,104580);pd(484544,104604);pd(484556,104620);pd(484568,104640);pd(484580,104660);pd(484592,104688);pd(484604,104728);pd(484616,104760);pd(484628,104796);pd(484640,104832);pd(484652,104848);pd(484664,104864);pd(484676,104880);pd(484688,104604);pd(484700,104896);pd(484712,104912);pd(484724,104928);pd(484736,104944);pd(484748,104960);pd(484760,104976);pd(484772,104992);v[483680]=1;x[120919]=484496;return 484496}function kY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=ib-208|0;ib=d;zC(c,a);yC(c,d+16|0,D(y[a+4|0],3));a:{if(y[a+4|0]<2){break a}c=ib-16|0;ib=c;x[c+12>>2]=64;x[c+8>>2]=255;e=y[Hb(c+12|0,c+8|0)|0];ib=c+16|0;v[d+12|0]=e;Zg(b,y[Ub(a+4|0,d+12|0)|0]);v[b+13|0]=y[a+2|0];v[b+14|0]=y[a+3|0];a=y[a+1|0];v[b+15|0]=a;v[b+16|0]=a;e=x[b>>2];f=$d(e,x[b+4>>2]);a=0;while(1){if((a|0)==(f|0)){break a}b:{if(!a){b=y[d+18|0];c=Bb(e,0);break b}g=z[Bb(e,a-1|0)>>1];x[d+12>>2]=1;b=(d+16|0)+D(a,3)|0;x[d+8>>2]=(v[b+1|0]&1)<<8|y[b|0];h=Ve(d+12|0,d+8|0);c=Bb(e,a);w[c>>1]=z[h>>1]+g;b=y[b+2|0]}v[c+2|0]=b;a=a+1|0;continue}}ib=d+208|0}function FB(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=ib-16|0;ib=e;d=(c<<3)+a|0;f=y[d+356|0];v[b+12|0]=y[b+12|0]&248|f&1|f<<1&4|f>>>1&2;Zg(b,Bd(y[d+352|0],2,16));v[b+13|0]=y[d+354|0];v[b+14|0]=y[d+355|0];d=y[d+353|0];v[b+15|0]=d;v[b+16|0]=d;d=0;w[e+14>>1]=0;f=((c|0)!=0)<<1;h=x[b>>2];j=$d(h,x[b+4>>2]);k=(c<<6)+a|0;c=((c|0)==2?-1:0)&255;while(1){if((d|0)==(j|0)){EB(b,32);ib=e+16|0}else{a=k+(d<<2)|0;w[e+12>>1]=y[a+160|0]|y[a+161|0]<<8;g=pe(e+14|0,e+12|0);i=Bb(h,d);g=z[g>>1];w[i>>1]=g;w[e+14>>1]=g+1;v[e+11|0]=(c^y[a+162|0])>>>f;v[e+10|0]=64;l=i,m=y[Ub(e+11|0,e+10|0)|0],v[l+2|0]=m;d=d+1|0;continue}break}}function Caa(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0,f=0;d=ib-96|0;ib=d;x[d+88>>2]=c;c=x[a>>2];e=x[a+4>>2];f=x[a+12>>2];x[d+56>>2]=x[a+8>>2];x[d+60>>2]=f;x[d+48>>2]=c;x[d+52>>2]=e;a=Id(d+40|0);c=x[d+60>>2];x[d+24>>2]=x[d+56>>2];x[d+28>>2]=c;x[27524]=0;c=x[d+52>>2];x[d+16>>2]=x[d+48>>2];x[d+20>>2]=c;c=x[a+4>>2];x[d+8>>2]=x[a>>2];x[d+12>>2]=c;U(942,d- -64|0,d+16|0,d+8|0);a=x[27524];x[27524]=0;a:{b:{if((a|0)!=1){a=x[ge(d+32|0,d+88|0)>>2];x[27524]=0;b=+sa(943,d- -64|0,+b,a|0);a=x[27524];x[27524]=0;if((a|0)==1){break b}yb(d- -64|0);Xc(d+88|0);ib=d+96|0;return+b}a=P()|0;break a}a=P()|0;yb(d- -64|0)}Xc(d+88|0);S(a|0);p()}function lea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;h=ib-16|0;ib=h;f=c;e=ib-16|0;ib=e;g=b;d=Td(b);a:{if(d){c=gc(g);while(1){b=d;d=b+16|0;if(tO(f,d)){c=b;d=x[b>>2];if(d){continue}break a}if(!tO(d,f)){break a}c=b+4|0;d=x[b+4>>2];if(d){continue}break}break a}b=gc(g);c=b}x[e+12>>2]=b;b=x[c>>2];if(!b){b=ib-16|0;ib=b;d=gc(g);d=sh(e,mc(28),th(b+8|0,d));i=x[d>>2];x[27524]=0;R(852,i+16|0,f|0);f=x[27524];x[27524]=0;b:{if((f|0)!=1){j=gc(d),k=1,v[j+4|0]=k;ib=b+16|0;break b}a=P()|0;sO(d);S(a|0);p()}Tg(g,x[e+12>>2],c,x[e>>2]);b=ce(e);sO(e);i=1}c=h+8|0;Sg(c,x[Wb(e,b)>>2],i);ib=e+16|0;SR(a,c);ib=h+16|0}function jO(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;h=ib-16|0;ib=h;v[h+15|0]=b;v[h+14|0]=10;Zg(g,y[Ub(h+15|0,h+14|0)|0]);v[g+15|0]=c;v[g+16|0]=c;v[g+14|0]=e;v[g+13|0]=d;j=x[g>>2];k=$d(j,x[g+4>>2]);b=0;a:{while(1){if((b|0)==(k|0)){b:{b=y[g+12|0]&-2|a&1;if(a&2){break b}b=b&251;break a}}else{m=Bb(j,b);l=D(b,3)+f|0;i=(y[l|0]|y[l+1|0]<<8)>>>4|0;w[m>>1]=i;c:{if(b){n=z[Bb(j,b-1|0)>>1];if(i>>>0>=n>>>0){break c}i=n+1|0}else{i=0}o=Bb(j,b),p=i,w[o>>1]=p}o=m,p=Bd(y[l+2|0],0,64),v[o+2|0]=p;b=b+1|0;continue}break}b=b&-5|(c>>>0<=k>>>0)<<2}v[g+12|0]=(d>>>0<=e>>>0?a&4:0)?b&-3|(d>>>0<=k>>>0)<<1:b&253;ib=h+16|0}function Cea(a){a=a|0;var b=0,c=0,d=0;c=a+1298224|0;b=a+1074992|0;while(1){if((b|0)==(c|0)){st(a+484344|0);Vf(a+1298308|0);YA(a+1298320|0);Vf(a+1298332|0);Ic(a+1298412|0);b=a+900380|0;c=a+484380|0;while(1){if((b|0)==(c|0)){a:{c=a+901404|0;while(1){if((b|0)==(c|0)){b=a+906300|0;c=rj(b);while(1){if((b|0)==(c|0)){break a}TX(b);b=b+160|0;continue}}d=x[b>>2];if(d){Ib(wu(d))}x[b>>2]=0;b=b+4|0;continue}}}else{Jm(c);c=c+104|0;continue}break}x[a+480180>>2]=0;x[a+480184>>2]=0;a=a+480186|0;w[a>>1]=0;w[a+2>>1]=0;w[a+4>>1]=0;w[a+6>>1]=0}else{x[b+104>>2]=0;x[b+656>>2]=0;x[b+76>>2]=0;x[b+16>>2]=0;b=b+872|0;continue}break}}function lE(a,b){var c=0,d=0,e=0,f=0;c=x[a>>2];d=ah(c,x[a+4>>2]);if(d>>>0<b>>>0){f=ib-32|0;ib=f;c=b-d|0;b=x[Db(a)>>2];e=x[a+4>>2];a:{if(c>>>0<=b-e>>3>>>0){d=ib-16|0;ib=d;b=ur(d,a,c);a=x[b+4>>2];c=x[b+8>>2];while(1){if((a|0)==(c|0)){ic(b);ib=d+16|0}else{Zj(a);a=a+8|0;x[b+4>>2]=a;continue}break}break a}b=Db(a);d=wr(f+8|0,xr(a,ah(x[a>>2],e)+c|0),ah(x[a>>2],x[a+4>>2]),b);b=ib-16|0;ib=b;x[b>>2]=x[d+8>>2];e=x[d+8>>2];x[b+8>>2]=d+8;x[b+4>>2]=(c<<3)+e;c=x[b>>2];while(1){if(x[b+4>>2]!=(c|0)){Zj(c);c=x[b>>2]+8|0;x[b>>2]=c;continue}break}Vd(b);ib=b+16|0;Dd(a,d);vr(d)}ib=f+32|0;return}if(b>>>0<d>>>0){Od(a,c+(b<<3)|0)}}function F5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=ib+-64|0;ib=d;f=d+16|0;h=ib-16|0;ib=h;i=JR(h+8|0);while(1){if((j|0)==12){ib=h+16|0}else{g=ib+-64|0;ib=g;c=x[i+4>>2];e=x[i>>2];a:{if((c|0)==(e|0)){break a}c=(c-e|0)+1|0;if(!c){c=IJ(JJ(g+8|0,32));break a}e=G(c);e=JJ(g+8|0,(c<<e+1?32:31)-e|0);while(1){k=IJ(e);if(c>>>0<=k>>>0){continue}break}c=x[i>>2]+k|0}ib=g- -64|0;l=Bb(f,j),m=c,x[l>>2]=m;j=j+1|0;continue}break}f=UR(d,f,ZR(f));RR(a,f);Km(f);ib=d- -64|0;d=Rx(a+120|0,a,b);v[d+20|0]=1;x[27524]=0;R(1092,a|0,b|0);b=x[27524];x[27524]=0;if((b|0)==1){a=P()|0;Ln(d);S(a|0);p()}return a|0}function Y4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;g=ib-16|0;ib=g;a:{if(!(c&1024)){break a}i=g,j=Ti(b),x[i+8>>2]=j;c=Ik(x[b+4>>2],y[b+11|0]);b:{if(!c){break b}if(y[nd(b)|0]!=43){if(y[nd(b)|0]!=45){break b}}d=d+1|0;gK(g+8|0)}if(c>>>0>=d>>>0){break a}e=x[Wb(g,x[g+8>>2])>>2];c=d-Ik(x[b+4>>2],y[b+11|0])|0;c:{e=to(e,Ti(b));d=xd(x[b+4>>2],y[b+11|0]);if(e>>>0<=d>>>0){if(c){f=zl(b);d:{if(c>>>0<=f-d>>>0){f=nd(b);if((d|0)==(e|0)){break d}h=e+f|0;ai(c+h|0,h,d-e|0);break d}cz(b,f,(c+d|0)-f|0,d,e,c);f=x[b>>2]}hJ(e+f|0,c,48);c=c+d|0;zq(b,c);ne(c+f|0,0)}break c}yk();p()}Ti(b)}$c(a,b);ib=g+16|0}function uN(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=ib-16|0;ib=e;Ph(e+8|0,b);f=ib-16|0;ib=f;lg(f+8|0,x[e+8>>2],x[e+12>>2]);c=x[f+12>>2];b=x[f+8>>2];g=ib-16|0;ib=g;k=g,l=Cb(a),x[k+8>>2]=l;h=b;a=c;b=ib-16|0;ib=b;i=x[g+8>>2];c=i;d=x[c+12>>2];c=x[c+8>>2];a:{if((d|0)<0){break a}j=x[i+4>>2];if(!d&j>>>0<c>>>0|d){break a}x[b+8>>2]=j-c;x[b+12>>2]=0-(d+(c>>>0>j>>>0)|0);x[b>>2]=a;x[b+4>>2]=0;d=xC(b+8|0,b);if((Ht(x[d>>2],x[d+4>>2])|0)!=(a|0)){break a}ji(h,a+h|0,c+x[i>>2]|0);c=x[g+8>>2];h=c;d=a+x[c+8>>2]|0;c=x[c+12>>2];x[h+8>>2]=d;x[h+12>>2]=a>>>0>d>>>0?c+1|0:c}ib=b+16|0;ib=g+16|0;ib=f+16|0;ib=e+16|0}function i2(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=ib-48|0;ib=f;x[f+40>>2]=b;a:{if(!(x[c+4>>2]&1)){c=lb[x[x[a>>2]+24>>2]](a,b,c,d,e)|0;break a}a=f+24|0;ed(a,c);x[27524]=0;a=T(1147,a|0)|0;b=x[27524];x[27524]=0;b:{if((b|0)!=1){_b(f+24|0);c:{if(e){Uh(f+24|0,a);break c}Th(f+24|0,a)}g=f,h=ke(f+24|0),x[g+16>>2]=h;while(1){g=f,h=Eh(f+24|0),x[g+8>>2]=h;if(!Fi(f+16|0,f+8|0)){c=x[f+40>>2];wb(f+24|0);break a}a=v[x[f+16>>2]];x[27524]=0;Q(21,f+40|0,a|0)|0;a=x[27524];x[27524]=0;if((a|0)!=1){Ie(f+16|0);continue}break}c=P()|0;wb(f+24|0);break b}c=P()|0;_b(f+24|0)}S(c|0);p()}ib=f+48|0;return c|0}function t1(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=ib-16|0;ib=k;a:{if(a){a=IG(b);Xk(k,a);b=x[k>>2];v[c|0]=b;v[c+1|0]=b>>>8;v[c+2|0]=b>>>16;v[c+3|0]=b>>>24;Wk(k,a);aj(i,k);Gc(k);Th(k,a);aj(h,k);Gc(k);l=d,m=gj(a),x[l>>2]=m;l=e,m=hj(a),x[l>>2]=m;ih(k,a);Ac(f,k);wb(k);Uh(k,a);aj(g,k);Gc(k);a=Vk(a);break a}a=HG(b);Xk(k,a);b=x[k>>2];v[c|0]=b;v[c+1|0]=b>>>8;v[c+2|0]=b>>>16;v[c+3|0]=b>>>24;Wk(k,a);aj(i,k);Gc(k);Th(k,a);aj(h,k);Gc(k);l=d,m=gj(a),x[l>>2]=m;l=e,m=hj(a),x[l>>2]=m;ih(k,a);Ac(f,k);wb(k);Uh(k,a);aj(g,k);Gc(k);a=Vk(a)}x[j>>2]=a;ib=k+16|0}function Zia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=ib-32|0;ib=d;md(b,0);di(d,1,a);c=d+16|0;Fc(c,d);Fe(b+43|0,c);wb(c);x[b>>2]=y[a+48|0]|y[a+49|0]<<8|(y[a+50|0]<<16|y[a+51|0]<<24);x[b+4>>2]=y[a+52|0]|y[a+53|0]<<8|(y[a+54|0]<<16|y[a+55|0]<<24);x[b+8>>2]=y[a+56|0]|y[a+57|0]<<8|(y[a+58|0]<<16|y[a+59|0]<<24);x[b+24>>2]=y[a+62|0]|y[a+63|0]<<8;Cl(b,+((y[a+60|0]^8)-120|0)/192);v[d+16|0]=y[a+61|0];v[d|0]=64;f=b,g=y[Ub(c,d)|0]<<2,w[f+30>>1]=g;w[b+34>>1]=0;c=y[a+47|0];if(c&4){w[b+34>>1]=1;x[b>>2]=x[b>>2]>>>1;e=1;c=y[a+47|0]}if(c&32){e=e|4;w[b+34>>1]=e;c=y[a+47|0]}if(c<<24>>24<0){w[b+34>>1]=e|2}ib=d+32|0}function qia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);if(b){if(zh(119304647)>>>0<b>>>0){_c();p()}b=D(b,36);c=mc(b);x[a>>2]=c;x[a+4>>2]=c;f=Db(a),g=b+c|0,x[f>>2]=g;d=ib-16|0;ib=d;x[d>>2]=a;c=x[a+4>>2];x[d+4>>2]=c;x[d+8>>2]=b+c;b=x[d+4>>2];e=x[d+8>>2];while(1){if((b|0)==(e|0)){ic(d);ib=d+16|0}else{c=Rb(b,0,36);x[c>>2]=0;x[c+4>>2]=0;w[c+22>>1]=0;w[c+24>>1]=0;w[c+26>>1]=0;w[c+28>>1]=0;v[c+21|0]=64;v[c+19|0]=64;v[c+20|0]=100;v[c+15|0]=0;v[c+16|0]=0;v[c+17|0]=0;v[c+18|0]=0;x[c+8>>2]=0;x[c+12>>2]=0;w[c+30>>1]=0;w[c+32>>1]=0;b=b+36|0;x[d+4>>2]=b;continue}break}}return a|0}function dp(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a:{e=ib-16|0;ib=e;f=ib-32|0;ib=f;c=wf(f+16|0,1,0);b:{c:{d:{while(1){d=vc(c);ky(f+8|0,d,Eb(c)+d|0,x[b>>2]);if(!x[f+12>>2]){break d}d=Og(Eb(c));x[27524]=0;R(59,c|0,d|0);d=x[27524];x[27524]=0;if((d|0)!=1){continue}break}break c}b=x[f+8>>2];d=vc(c);x[27524]=0;R(60,c|0,b-d|0);b=x[27524];x[27524]=0;e:{if((b|0)!=1){x[27524]=0;R(72,e|0,c|0);b=x[27524];x[27524]=0;if((b|0)!=1){break e}break c}break c}wb(c);ib=f+32|0;break b}a=P()|0;wb(c);S(a|0);p()}x[27524]=0;R(71,a|0,e|0);a=x[27524];x[27524]=0;if((a|0)!=1){xb(e);ib=e+16|0;break a}a=P()|0;xb(e);S(a|0);p()}}function QW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a:{e=ib-16|0;ib=e;f=ib-32|0;ib=f;c=wf(f+16|0,1,0);b:{c:{d:{while(1){d=vc(c);hy(f+8|0,d,Eb(c)+d|0,x[b>>2]);if(!x[f+12>>2]){break d}d=Og(Eb(c));x[27524]=0;R(59,c|0,d|0);d=x[27524];x[27524]=0;if((d|0)!=1){continue}break}break c}b=x[f+8>>2];d=vc(c);x[27524]=0;R(60,c|0,b-d|0);b=x[27524];x[27524]=0;e:{if((b|0)!=1){x[27524]=0;R(72,e|0,c|0);b=x[27524];x[27524]=0;if((b|0)!=1){break e}break c}break c}wb(c);ib=f+32|0;break b}a=P()|0;wb(c);S(a|0);p()}x[27524]=0;R(71,a|0,e|0);a=x[27524];x[27524]=0;if((a|0)!=1){xb(e);ib=e+16|0;break a}a=P()|0;xb(e);S(a|0);p()}}function Es(a,b,c){var d=0,e=0;d=a,e=nj(E(E(B[c+1792>>2]*E(75038))+E(E(E(B[c+2048>>2]-B[c+1536>>2])*E(37489))+E(E(E(B[c+1280>>2]+B[c+2304>>2])*E(6574))+E(E(E(B[c+2560>>2]-B[c+1024>>2])*E(5153))+E(E(E(B[c+768>>2]+B[c+2816>>2])*E(2037))+E(E(E(B[c+3072>>2]-B[c+512>>2])*E(459))+E(E(E(B[c+256>>2]+B[c+3328>>2])*E(213))+E(E(B[c+3584>>2]-B[c>>2])*E(29)))))))))),w[d>>1]=e;d=(b<<5)+a|0,e=nj(E(E(B[c+8>>2]*E(-5))+E(E(B[c+520>>2]*E(146))+E(E(B[c+1032>>2]*E(-45))+E(E(B[c+1544>>2]*E(-9975))+E(E(B[c+2056>>2]*E(64019))+E(E(B[c+2568>>2]*E(9727))+E(E(B[c+3080>>2]*E(1567))+E(B[c+3592>>2]*E(104)))))))))),w[d>>1]=e}function A1(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=ib-16|0;ib=k;a:{if(a){a=LG(b);Xk(k,a);b=x[k>>2];v[c|0]=b;v[c+1|0]=b>>>8;v[c+2|0]=b>>>16;v[c+3|0]=b>>>24;Wk(k,a);Ac(i,k);wb(k);Th(k,a);Ac(h,k);wb(k);l=d,m=gj(a),v[l|0]=m;l=e,m=hj(a),v[l|0]=m;ih(k,a);Ac(f,k);wb(k);Uh(k,a);Ac(g,k);wb(k);a=Vk(a);break a}a=KG(b);Xk(k,a);b=x[k>>2];v[c|0]=b;v[c+1|0]=b>>>8;v[c+2|0]=b>>>16;v[c+3|0]=b>>>24;Wk(k,a);Ac(i,k);wb(k);Th(k,a);Ac(h,k);wb(k);l=d,m=gj(a),v[l|0]=m;l=e,m=hj(a),v[l|0]=m;ih(k,a);Ac(f,k);wb(k);Uh(k,a);Ac(g,k);wb(k);a=Vk(a)}x[j>>2]=a;ib=k+16|0}function M5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(A[a+4>>2]<A[Db(a)>>2]){c=ib-16|0;ib=c;a=Wt(c,a,1);Tx(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+16;ic(a);ib=c+16|0;return}e=ib-32|0;ib=e;c=Db(a);c=wS(e+8|0,xS(a,tk(x[a>>2],x[a+4>>2])+1|0),tk(x[a>>2],x[a+4>>2]),c);Tx(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+16;f=x[a>>2];d=x[a+4>>2];b=c+4|0;while(1){if((d|0)!=(f|0)){d=d-16|0;Tx(x[b>>2]-16|0,d);x[b>>2]=x[b>>2]-16;continue}break}oc(a,b);oc(a+4|0,c+8|0);oc(Db(a),zc(c));x[c>>2]=x[c+4>>2];a=x[c+4>>2];while(1){b=x[c+8>>2];if((b|0)!=(a|0)){b=b-16|0;x[c+8>>2]=b;Ps(b);continue}break}a=x[c>>2];if(a){ep(c);Ib(a)}ib=e+32|0}function Mka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=ib-16|0;ib=e;i=e,j=Ej(b),x[i>>2]=j;f=z[b>>1];d=ib-16|0;ib=d;g=a;c=Td(a);a:{if(c){b=gc(g);while(1){a=c;c=z[a+14>>1];if(ro(f,c)){b=a;c=x[a>>2];if(c){continue}break a}if(!ro(c,f)){break a}b=a+4|0;c=x[a+4>>2];if(c){continue}break}break a}a=gc(g);b=a}x[d+12>>2]=a;a=x[b>>2];if(!a){a=ib-16|0;ib=a;c=gc(g);f=sh(d,mc(20),th(a+8|0,c));c=x[f>>2];h=z[x[e>>2]>>1];w[c+16>>1]=0;w[c+14>>1]=h;i=gc(f),j=1,v[i+4|0]=j;ib=a+16|0;Tg(g,x[d+12>>2],b,x[d>>2]);a=ce(d);zk(d);h=1}Sg(e+8|0,x[Wb(d,a)>>2],h);ib=d+16|0;a=vo(x[e+8>>2]);ib=e+16|0;return a+2|0}function HT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=ib-16|0;ib=d;x[a>>2]=0;x[a+4>>2]=0;vk(a+8|0,0);e=x[b+4>>2];if(e){jr(a,e);wl(d+8|0,x[b>>2]);Im(d,x[b>>2],x[b+4>>2]);c=ib-32|0;ib=c;f=x[a+4>>2];e=x[d+8>>2];h=x[d+12>>2];b=x[d>>2];k=x[d+4>>2];g=f+FT(e,h,b,k)|0;x[a+4>>2]=g;a:{b:{if(!f){i=g-1|0;break b}i=g-1|0;if((i^f-1)>>>0>31){break b}x[c+24>>2]=e;x[c+28>>2]=h;j=x[a>>2];break a}j=x[a>>2];x[j+((g>>>0>=33?i>>>5|0:0)<<2)>>2]=0;x[c+24>>2]=e;x[c+28>>2]=h}So(c+16|0,j,f);e=x[c+28>>2];x[c>>2]=x[c+24>>2];x[c+4>>2]=e;GT(c+8|0,c,b,k,x[c+16>>2],x[c+20>>2]);ib=c+32|0}ib=d+16|0;return a|0}function $P(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=ib-16|0;ib=c;a:{if(y[b+791|0]!=27){a=v[b+831|0];break a}d=c+8|0;f=a+1074312|0;Ab(d,f,21);e=a;a=y[b+821|0];a=Uy(e,y[b+828|0],zb(x[x[c+8>>2]>>2],x[c+12>>2])?a:a+16>>>2|0);Ab(d,f,45);b:{if(!(!zb(x[x[c+8>>2]>>2],x[c+12>>2])|y[b+828|0]!=3)){d=y[b+821|0];c:{if(!(!d|d>>>0>=y[b+829|0])){a=y[b+832|0];e=d+1|0;break c}v[b+832|0]=a;e=1}v[b+821|0]=e;a=a<<24>>24;break b}v[b+821|0]=y[b+821|0]+y[b+829|0]}Ab(c+8|0,f,47);if(!zb(x[x[c+8>>2]>>2],x[c+12>>2])){break a}v[b+831|0]=a}if(a){g=b,h=Vb(x[b+684>>2]+((D(y[b+830|0],a)+2|0)/8|0)|0,0,256),x[g+684>>2]=h}ib=c+16|0}function qma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=ib-80|0;ib=d;e=If(d+48|0);x[27524]=0;c=Q(404,b|0,e|0)|0;f=x[27524];x[27524]=0;a:{b:{c:{d:{if((f|0)!=1){if(c){break d}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[27524]=0;T(405,a|0)|0;a=x[27524];x[27524]=0;if((a|0)!=1){break a}}break c}c=ib-16|0;ib=c;g=c,h=ac(x[e+4>>2]),x[g+12>>2]=h;x[c+8>>2]=8;f=x[Yc(c+12|0,c+8|0)>>2];ib=c+16|0;x[27524]=0;U(194,d|0,b|0,f-8|0);b=x[27524];x[27524]=0;if((b|0)!=1){break b}}a=P()|0;yd(e);S(a|0);p()}b=hc(d+24|0,d);fd(e+8|0,b);yb(b);yb(d);Ek(a,e)}yd(e);ib=d+80|0}function jW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=ib-16|0;ib=e;i=e,j=Ej(b),x[i>>2]=j;f=x[b>>2];d=ib-16|0;ib=d;g=a;c=Td(a);a:{if(c){b=gc(g);while(1){a=c;c=x[a+16>>2];if(fW(f,c)){b=a;c=x[a>>2];if(c){continue}break a}if(!fW(c,f)){break a}b=a+4|0;c=x[a+4>>2];if(c){continue}break}break a}a=gc(g);b=a}x[d+12>>2]=a;a=x[b>>2];if(!a){a=ib-16|0;ib=a;c=gc(g);f=sh(d,mc(24),th(a+8|0,c));c=x[f>>2];h=x[x[e>>2]>>2];x[c+20>>2]=0;x[c+16>>2]=h;i=gc(f),j=1,v[i+4|0]=j;ib=a+16|0;Tg(g,x[d+12>>2],b,x[d>>2]);a=ce(d);zk(d);h=1}Sg(e+8|0,x[Wb(d,a)>>2],h);ib=d+16|0;a=ud(x[e+8>>2]);ib=e+16|0;return a+4|0}function Lp(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=ib-16|0;ib=e;f=ib-32|0;ib=f;c=wf(f+16|0,1,0);a:{b:{c:{while(1){d=vc(c);ky(f+8|0,d,Eb(c)+d|0,x[b>>2]);if(!x[f+12>>2]){break c}d=Og(Eb(c));x[27524]=0;R(59,c|0,d|0);d=x[27524];x[27524]=0;if((d|0)!=1){continue}break}break b}b=x[f+8>>2];d=vc(c);x[27524]=0;R(60,c|0,b-d|0);b=x[27524];x[27524]=0;d:{if((b|0)!=1){x[27524]=0;R(61,e|0,c|0);b=x[27524];x[27524]=0;if((b|0)!=1){break d}break b}break b}wb(c);ib=f+32|0;break a}a=P()|0;wb(c);S(a|0);p()}x[27524]=0;R(58,a|0,e|0);a=x[27524];x[27524]=0;if((a|0)!=1){wb(e);ib=e+16|0;return}a=P()|0;wb(e);S(a|0);p()}function Iba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=ib-16|0;ib=e;f=ib-32|0;ib=f;c=wf(f+16|0,1,0);a:{b:{c:{while(1){d=vc(c);ky(f+8|0,d,Eb(c)+d|0,y[b|0]);if(!x[f+12>>2]){break c}d=Og(Eb(c));x[27524]=0;R(59,c|0,d|0);d=x[27524];x[27524]=0;if((d|0)!=1){continue}break}break b}b=x[f+8>>2];d=vc(c);x[27524]=0;R(60,c|0,b-d|0);b=x[27524];x[27524]=0;d:{if((b|0)!=1){x[27524]=0;R(61,e|0,c|0);b=x[27524];x[27524]=0;if((b|0)!=1){break d}break b}break b}wb(c);ib=f+32|0;break a}a=P()|0;wb(c);S(a|0);p()}x[27524]=0;R(58,a|0,e|0);a=x[27524];x[27524]=0;if((a|0)!=1){wb(e);ib=e+16|0;return}a=P()|0;wb(e);S(a|0);p()}function jha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=ib-16|0;ib=b;h=x[a+24>>2];i=x[a+20>>2];j=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;k=x[a+8>>2];l=x[a+12>>2];while(1){if(d){e=x[b+8>>2];m=e>>>18|0;n=((((x[b+12>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+j|0;e=0;while(1){if((e|0)!=2){f=(e<<1)+n|0;g=w[f>>1];x[(e<<2)+b>>2]=g+((D(w[f+4>>1]-g|0,m)|0)/16384|0);e=e+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[b>>2],i);x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],h);Pb(b+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;ib=b+16|0}function dda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(A[a+4>>2]<A[Db(a)>>2]){c=ib-16|0;ib=c;a=pA(c,a);wy(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+4;ic(a);ib=c+16|0;return}e=ib-32|0;ib=e;c=Db(a);c=cg(e+8|0,wg(a,tc(x[a>>2],x[a+4>>2])+1|0),tc(x[a>>2],x[a+4>>2]),c);wy(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+4;f=x[a>>2];d=x[a+4>>2];b=c+4|0;while(1){if((d|0)!=(f|0)){d=d-4|0;wy(x[b>>2]-4|0,d);x[b>>2]=x[b>>2]-4;continue}break}oc(a,b);oc(a+4|0,c+8|0);oc(Db(a),zc(c));x[c>>2]=x[c+4>>2];a=x[c+4>>2];while(1){b=x[c+8>>2];if((b|0)!=(a|0)){b=b-4|0;x[c+8>>2]=b;yg(b);continue}break}a=x[c>>2];if(a){mA(c);Ib(a)}ib=e+32|0}function ufa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=ib+-64|0;ib=c;f=fR(a,1<<b-1);x[f+12>>2]=b;b=1<<b;h=-6.283185307179586/+(b>>>0);a=1;g=b>>>2|0;b=g;while(1){if(b){e=x[10469];d=c+32|0;x[d+8>>2]=x[10468];x[d+12>>2]=e;e=x[10467];x[d>>2]=x[10466];x[d+4>>2]=e;Wz(d,h*+(b>>>0));aR(c+48|0,C[c+32>>3],C[c+40>>3]);d=Kd(x[f>>2],a);e=x[c+60>>2];x[d+8>>2]=x[c+56>>2];x[d+12>>2]=e;e=x[c+52>>2];x[d>>2]=x[c+48>>2];x[d+4>>2]=e;b=b>>>1|0;a=a<<1;continue}break}a=rl(c+16|0,1,0);b=x[a+12>>2];x[c+8>>2]=x[a+8>>2];x[c+12>>2]=b;b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;Jy(f,0,g,c);ib=c- -64|0;return f|0}function Tg(a,b,c,d){var e=0,f=0;x[d+8>>2]=b;x[d>>2]=0;x[d+4>>2]=0;x[c>>2]=d;b=x[x[a>>2]>>2];if(b){x[a>>2]=b;d=x[c>>2]}f=x[gc(a)>>2];v[d+12|0]=(f|0)==(d|0);while(1){a:{if((d|0)==(f|0)){break a}c=x[d+8>>2];if(y[c+12|0]){break a}b:{if(Hh(c)){b=x[c+8>>2];e=x[b+4>>2];if(!(!e|y[e+12|0])){break b}if(!Hh(d)){Fq(c);c=x[c+8>>2]}v[c+12|0]=1;b=x[c+8>>2];v[b+12|0]=0;Eq(b);break a}b=x[c+8>>2];e=x[b>>2];if(!(!e|y[e+12|0])){break b}if(Hh(d)){Eq(c);c=x[c+8>>2]}v[c+12|0]=1;b=x[c+8>>2];v[b+12|0]=0;Fq(b);break a}v[c+12|0]=1;d=b;v[d+12|0]=(d|0)==(f|0);v[e+12|0]=1;continue}break}a=Db(a);x[a>>2]=x[a>>2]+1}function Ok(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=ib-16|0;ib=e;f=a+36|0;c=x[a+32>>2];a:{b:{while(1){if((b|0)<=(c|0)){break b}c:{d=x[a+20>>2];if(d>>>0>=A[a+24>>2]){yn(e,f,qE(f));sd(e+8|0,a,x[e>>2],x[e+4>>2]);c=x[e+12>>2];x[a+24>>2]=c;x[a+20>>2]=0;if(!c){break c}d=0;c=x[a+32>>2]}x[a+20>>2]=d+1;g=y[(a+d|0)+36|0];d=c+8|0;x[a+32>>2]=d;x[a+28>>2]=x[a+28>>2]|g<<c;c=d;continue}break}a=ba(8)|0;x[27524]=0;b=T(171,a|0)|0;c=x[27524];x[27524]=0;if((c|0)!=1){break a}b=P()|0;ca(a|0);S(b|0);p()}x[a+32>>2]=c-b;d=a;a=x[a+28>>2];x[d+28>>2]=a>>>b;ib=e+16|0;return a&(-1<<b^-1)}ha(b|0,30496,172);p()}function GK(a,b){var c=0,d=0,e=0,f=0;a:{e=ib-16|0;ib=e;f=ib-32|0;ib=f;c=wf(f+16|0,1,0);b:{c:{d:{while(1){d=vc(c);Yx(f+8|0,d,Eb(c)+d|0,z[b>>1]);if(!x[f+12>>2]){break d}d=Og(Eb(c));x[27524]=0;R(59,c|0,d|0);d=x[27524];x[27524]=0;if((d|0)!=1){continue}break}break c}b=x[f+8>>2];d=vc(c);x[27524]=0;R(60,c|0,b-d|0);b=x[27524];x[27524]=0;e:{if((b|0)!=1){x[27524]=0;R(72,e|0,c|0);b=x[27524];x[27524]=0;if((b|0)!=1){break e}break c}break c}wb(c);ib=f+32|0;break b}a=P()|0;wb(c);S(a|0);p()}x[27524]=0;R(71,a|0,e|0);a=x[27524];x[27524]=0;if((a|0)!=1){xb(e);ib=e+16|0;break a}a=P()|0;xb(e);S(a|0);p()}}function Cm(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0;i=1;j=d&2147483647;l=j;k=(j|0)==2147418112;a:{if(k&!c?a|b:k&(c|0)!=0|j>>>0>2147418112){break a}j=h&2147483647;k=(j|0)==2147418112;if(k&!g?e|f:k&(g|0)!=0|j>>>0>2147418112){break a}if(!(a|e|(c|g)|(b|f|(j|l)))){return 0}i=d&h;if((i|0)>0|(i|0)>=0){i=-1;if((c|0)==(g|0)&(d|0)==(h|0)?(b|0)==(f|0)&a>>>0<e>>>0|b>>>0<f>>>0:c>>>0<g>>>0&(d|0)<=(h|0)|(d|0)<(h|0)){break a}return(a^e|c^g|(b^f|d^h))!=0}i=-1;if((c|0)==(g|0)&(d|0)==(h|0)?(b|0)==(f|0)&a>>>0>e>>>0|b>>>0>f>>>0:c>>>0>g>>>0&(d|0)>=(h|0)|(d|0)>(h|0)){break a}i=(a^e|c^g|(b^f|d^h))!=0}return i}function ZK(a,b){var c=0,d=0,e=0,f=0;a:{e=ib-16|0;ib=e;f=ib-32|0;ib=f;c=wf(f+16|0,1,0);b:{c:{d:{while(1){d=vc(c);LK(f+8|0,d,Eb(c)+d|0,y[b|0]);if(!x[f+12>>2]){break d}d=Og(Eb(c));x[27524]=0;R(59,c|0,d|0);d=x[27524];x[27524]=0;if((d|0)!=1){continue}break}break c}b=x[f+8>>2];d=vc(c);x[27524]=0;R(60,c|0,b-d|0);b=x[27524];x[27524]=0;e:{if((b|0)!=1){x[27524]=0;R(72,e|0,c|0);b=x[27524];x[27524]=0;if((b|0)!=1){break e}break c}break c}wb(c);ib=f+32|0;break b}a=P()|0;wb(c);S(a|0);p()}x[27524]=0;R(71,a|0,e|0);a=x[27524];x[27524]=0;if((a|0)!=1){xb(e);ib=e+16|0;break a}a=P()|0;xb(e);S(a|0);p()}}function RI(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;if(df(a)){fc(a,31);return 0}g=a,h=df(a),v[g+1375|0]=h;d=mj(a);b=mj(a);mj(a);g=a,h=mj(a),x[g+1112>>2]=h;mj(a);c=df(a);x[a+1116>>2]=c;if(!Bx(a,a+1120|0,c)){fc(a,10);return 0}x[a+1404>>2]=-2;a:{if((b&d)==-1){break a}b=x[a+1116>>2];while(1){if((b|0)<=0){break a}b=b-1|0;if(y[(b+a|0)+1120|0]==255){continue}break}x[a+1408>>2]=d;x[a+1404>>2]=b}if(y[a+1377|0]){b=0;e=x[a+1116>>2];f=(e|0)>0?e:0;c=0;while(1){if((b|0)!=(f|0)){c=y[(a+b|0)+1120|0]+c|0;b=b+1|0;continue}break}x[a- -64>>2]=d;x[a+60>>2]=(x[a+56>>2]+(c+e|0)|0)+27}x[a+1380>>2]=0;return 1}function K_(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=ib-32|0;ib=k;m=x[c>>2];l=x[c+8>>2];c=x[c+4>>2];x[k+8>>2]=c;x[k+12>>2]=l;x[k+24>>2]=c;x[k+28>>2]=l;x[k+20>>2]=m;x[k+16>>2]=d;x[27524]=0;c=x[k+20>>2];x[k>>2]=x[k+16>>2];x[k+4>>2]=c;a=Ka(1055,a|0,b|0,k|0)|0;b=x[27524];x[27524]=0;a:{b:{if((b|0)==1){_(V(0)|0)|0;x[27524]=0;ia(941,10353,e|0,f|0,g|0,h|0,i|0,j|0);a=x[27524];x[27524]=0;if((a|0)==1){break b}$();a=-255}ib=k+32|0;break a}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}return a|0}function q_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;a:{g=ib+-64|0;ib=g;qn(g+16|0,c);x[27524]=0;c=g+28|0;R(117,c|0,d|0);d=x[27524];x[27524]=0;b:{c:{d:{if((d|0)==1){break d}x[27524]=0;c=g+40|0;R(117,c|0,e|0);d=x[27524];x[27524]=0;if((d|0)==1){break d}x[27524]=0;c=g+52|0;R(117,c|0,f|0);d=x[27524];x[27524]=0;if((d|0)==1){break d}pw(g+8|0,g+16|0);x[27524]=0;X(118,a|0,b|0,x[g+8>>2],x[g+12>>2]);a=x[27524];x[27524]=0;if((a|0)==1){break c}OE(g+16|0);ib=g- -64|0;break a}a=P()|0;while(1){c=xb(c-12|0);if((c|0)!=(g+16|0)){continue}break}break b}a=P()|0;OE(g+16|0)}S(a|0);p()}}function kha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=ib-16|0;ib=b;h=x[a+24>>2];i=x[a+20>>2];j=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;k=x[a+8>>2];l=x[a+12>>2];while(1){if(d){e=x[b+8>>2];m=e>>>10&4194048;n=(((x[b+12>>2]&2147483647)<<1|e>>>31)&-2)+j|0;e=0;while(1){if((e|0)!=2){f=e+n|0;g=v[f|0];x[(e<<2)+b>>2]=((D(v[f+2|0]-g|0,m)|0)/16384|0)+(g<<8);e=e+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[b>>2],i);x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],h);Pb(b+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;ib=b+16|0}function Pd(a,b){var c=0,d=0,e=0;c=ib-32|0;ib=c;a=Nf(a,-1,-1);a:{b:{if(Qd(y[jm(c+24|0,b,1)|0])){d=x[(x[x[b>>2]-12>>2]+b|0)+24>>2];x[27524]=0;Wr(111,c+8|0,d,0,0,1);d=x[27524];x[27524]=0;c:{if((d|0)!=1){d=x[c+12>>2];x[a>>2]=x[c+8>>2];x[a+4>>2]=d;d=x[c+20>>2];x[a+8>>2]=x[c+16>>2];x[a+12>>2]=d;break c}_(V(0)|0)|0;e=1;hm(x[x[b>>2]-12>>2]+b|0,1);if(x[(x[x[b>>2]-12>>2]+b|0)+20>>2]&1){x[27524]=0;Z(109);a=x[27524];x[27524]=0;if((a|0)!=1){break a}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)==1){break b}S(a|0);p()}$()}Kj(x[x[b>>2]-12>>2]+b|0,e)}ib=c+32|0;return}V(0)|0;Sb()}p()}function rX(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;a:{if(!d){break a}i=y[e|0];if(!i){break a}j=2240>>>d&d>>>0<12;g=D(c,-6);k=(d-2&255)>>>0>2;while(1){if(!b){break a}c=a;a=c+g|0;f=y[a+3|0];b:{c:{if(!((f-2&255)>>>0>2|k)){f=1;if(y[(c+g|0)+5|0]<224){break c}break a}f=!(1<<f&2240)|(!j|f>>>0>11)?(d|0)==(f|0):1;if(k){break b}}h=c+g|0;if((y[h+2|0]-11&255)>>>0>2){break b}if(y[h+4|0]){break a}}d:{if(!j){break d}h=c+g|0;if((y[h+2|0]-3&255)>>>0>3){break d}if(y[h+4|0]){break a}}b=b-1|0;if(!f){continue}c=y[(c+g|0)+5|0];if(c?(c|0)!=(i|0):0){break a}if((c|0)!=(i|0)){continue}break}v[e|0]=0}}function iaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ib-32|0;ib=c;x[27524]=0;Y(958,a|0);d=x[27524];x[27524]=0;a:{b:{c:{if((d|0)==1){break c}x[27524]=0;Y(959,b|0);d=x[27524];x[27524]=0;if((d|0)==1){break c}d=x[a+24>>2];b=qc(c+8|0,b);x[27524]=0;e=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=e;X(971,c+16|0,d|0,c|0,1);b=x[27524];x[27524]=0;if((b|0)==1){break c}a=c+16|0;b=mg(Jc(a));wb(a);break b}_(V(0)|0)|0;b=0;x[27524]=0;X(945,5538,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)==1){break a}$()}ib=c+32|0;return b|0}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function jm(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;e=ib-32|0;ib=e;v[a|0]=0;a:{d=x[x[b>>2]-12>>2]+b|0;b:{if(fh(d)){d=x[d+72>>2];if(d){Tm(d)}c:{if(c){break c}c=x[x[b>>2]-12>>2]+b|0;if(!(x[c+4>>2]&4096)){break c}d=e+24|0;ed(d,c);x[27524]=0;f=T(19,d|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break a}_b(e+24|0);c=Jo(e+16|0,b);d=sc(e+8|0);while(1){d:{if(!yp(c,d)){break d}g=bl(x[c>>2]);if(!Bh(x[f+8>>2],1,g)){break d}im(c);continue}break}if(!jj(c,d)){break c}Kj(x[x[b>>2]-12>>2]+b|0,6)}h=a,i=fh(x[x[b>>2]-12>>2]+b|0),v[h|0]=i;break b}Kj(d,4)}ib=e+32|0;return a}a=P()|0;_b(e+24|0);S(a|0);p()}function Zg(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=x[a>>2];c=tc(d,x[a+4>>2]);if(c>>>0<b>>>0){e=ib-32|0;ib=e;b=b-c|0;c=x[Db(a)>>2];d=x[a+4>>2];a:{if(b>>>0<=c-d>>2>>>0){c=ib-16|0;ib=c;b=Fh(c,a,b);a=x[b+4>>2];d=x[b+8>>2];while(1){if((a|0)==(d|0)){ic(b);ib=c+16|0}else{Kv(a);a=a+4|0;x[b+4>>2]=a;continue}break}break a}c=Db(a);c=cg(e+8|0,wg(a,tc(x[a>>2],d)+b|0),tc(x[a>>2],x[a+4>>2]),c);f=ib-16|0;ib=f;b=Ym(f,c+8|0,b);d=x[b>>2];while(1){if(x[b+4>>2]!=(d|0)){Kv(d);d=x[b>>2]+4|0;x[b>>2]=d;continue}break}Vd(b);ib=f+16|0;Dd(a,c);bg(c)}ib=e+32|0;return}if(b>>>0<c>>>0){Od(a,d+(b<<2)|0)}}function Rw(a,b,c,d,e){var f=0,g=0;f=ib-16|0;ib=f;g=f+8|0;ed(g,b);x[27524]=0;b=T(1164,g|0)|0;g=x[27524];x[27524]=0;a:{if((g|0)==1){break a}x[27524]=0;X(1176,b|0,98224,98256,c|0);b=x[27524];x[27524]=0;if((b|0)==1){break a}x[27524]=0;b=T(1165,f+8|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break a}x[27524]=0;c=T(1177,b|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break a}x[d>>2]=c;x[27524]=0;c=T(1174,b|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break a}x[e>>2]=c;x[27524]=0;R(1175,a|0,b|0);a=x[27524];x[27524]=0;if((a|0)==1){break a}_b(f+8|0);ib=f+16|0;return}a=P()|0;_b(f+8|0);S(a|0);p()}function j0(a){a=a|0;if(y[483672]){return x[120917]}if(!y[484480]){a=484192;while(1){a=Kb(a)+12|0;if((a|0)!=484480){continue}break}v[484480]=1}od(484192,5037);od(484204,5028);od(484216,10784);od(484228,10528);od(484240,5264);od(484252,11548);od(484264,5121);od(484276,5612);od(484288,8834);od(484300,8817);od(484312,8825);od(484324,8844);od(484336,10011);od(484348,13210);od(484360,8907);od(484372,7662);od(484384,5264);od(484396,9700);od(484408,10416);od(484420,10796);od(484432,9197);od(484444,6466);od(484456,5495);od(484468,13128);v[483672]=1;x[120917]=484192;return 484192}function VD(a){var b=0,c=0,d=0;b=ib-16|0;ib=b;x[b+4>>2]=D(y[a+12|0]|y[a+13|0]<<8|(y[a+14|0]<<16|y[a+15|0]<<24),5)+(y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24));x[b+8>>2]=(y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24))+((y[a+20|0]|y[a+21|0]<<8|(y[a+22|0]<<16|y[a+23|0]<<24))<<3);x[b+12>>2]=(y[a+32|0]|y[a+33|0]<<8|(y[a+34|0]<<16|y[a+35|0]<<24))+((y[a+28|0]|y[a+29|0]<<8|(y[a+30|0]<<16|y[a+31|0]<<24))<<2);a=b+4|0;d=Bb(a,3);a:{if((a|0)==(d|0)){break a}c=a;while(1){c=c+4|0;if((d|0)==(c|0)){break a}a=qo(x[a>>2],x[c>>2])?c:a;continue}}ib=b+16|0;return x[a>>2]-36|0}function FI(a,b){var c=0,d=0,e=0,f=0,g=0;if(!y[480004]){f=480005,g=Da()|0,v[f|0]=g;v[480004]=1}a:{b:{c:{d:{switch(a|0){case 0:break b;case 1:case 4:break d;default:break c}}if(!y[480005]){break c}d=+Ca();break a}x[12e4]=28;return-1}d=+Ja()}c=d/1e3;e:{if(F(c)<0x8000000000000000){e=F(c)>=1?~~(c>0?H(J(c*2.3283064365386963e-10),4294967295):K((c-+(~~c>>>0>>>0))*2.3283064365386963e-10))>>>0:0;a=~~c>>>0;break e}e=-2147483648;a=0}x[b>>2]=a;x[b+4>>2]=e;c=(d-(+(qoa(a,e,1e3,0)>>>0)+ +(kb|0)*4294967296))*1e3*1e3;f:{if(F(c)<2147483648){a=~~c;break f}a=-2147483648}x[b+8>>2]=a;return 0}function pu(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ib-16|0;ib=c;cU(c+8|0,b);d=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Yb(a,x[c+12>>2])}ib=c+16|0;if((d|0)!=(e|0)){v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+24|0]=0;v[b+25|0]=0;v[b+26|0]=0;v[b+27|0]=0;v[b+28|0]=0;v[b+29|0]=0;v[b+30|0]=0;v[b+31|0]=0;v[b+16|0]=0;v[b+17|0]=0;v[b+18|0]=0;v[b+19|0]=0;v[b+20|0]=0;v[b+21|0]=0;v[b+22|0]=0;v[b+23|0]=0;v[b+8|0]=0;v[b+9|0]=0;v[b+10|0]=0;v[b+11|0]=0;v[b+12|0]=0;v[b+13|0]=0;v[b+14|0]=0;v[b+15|0]=0}}function gla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=ib-48|0;ib=e;d=x[a+8>>2];c=x[a>>2];x[27524]=0;d=W(160,c|0,d|0,1)|0;c=x[27524];x[27524]=0;a:{if((c|0)==1){break a}b:{if(!d){break b}x[27524]=0;Y(506,b|0);d=x[27524];x[27524]=0;if((d|0)==1){break a}x[27524]=0;d=T(210,a|0)|0;c=x[27524];x[27524]=0;c:{if((c|0)!=1){while(1){if(!(d&255)){break b}x[27524]=0;c=Q(507,a|0,e+8|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break c}d:{if(!c){break d}c=y[e+8|0];if(c>>>0>63){break d}rc(lV(x[b>>2],c),e+8|0,33)}d=d-1|0;continue}}break a}break a}yb(a);ib=e+48|0;return}b=P()|0;yb(a);S(b|0);p()}function I_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;f=c;c=ib-16|0;ib=c;x[27524]=0;Y(958,a|0);e=x[27524];x[27524]=0;a:{b:{c:{d:{if((e|0)==1){break d}x[27524]=0;Y(959,b|0);e=x[27524];x[27524]=0;if((e|0)==1){break d}e=x[a+24>>2];b=qc(c+8|0,b);x[27524]=0;g=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=g;Wr(979,e,c,f,d,1);d=x[27524];x[27524]=0;b=1;if((d|0)!=1){break c}}_(V(0)|0)|0;x[27524]=0;X(945,8590,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)==1){break b}$();b=0}ib=c+16|0;break a}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}return b|0}function Vw(a,b,c,d,e){var f=0,g=0;f=ib-16|0;ib=f;g=f+8|0;ed(g,b);x[27524]=0;b=T(19,g|0)|0;g=x[27524];x[27524]=0;a:{if((g|0)==1){break a}x[27524]=0;X(1162,b|0,98224,98256,c|0);b=x[27524];x[27524]=0;if((b|0)==1){break a}x[27524]=0;b=T(1147,f+8|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break a}x[27524]=0;c=T(1163,b|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break a}v[d|0]=c;x[27524]=0;c=T(1160,b|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break a}v[e|0]=c;x[27524]=0;R(1161,a|0,b|0);a=x[27524];x[27524]=0;if((a|0)==1){break a}_b(f+8|0);ib=f+16|0;return}a=P()|0;_b(f+8|0);S(a|0);p()}function S2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=ib-32|0;ib=c;a:{b:{c:{if(pc(b,-1)){break c}i=c,j=zp(b),v[i+23|0]=j;if(y[a+44|0]){d=-1;if((Dk(c+23|0,1,1,x[a+32>>2])|0)==1){break c}break a}f=c+24|0;x[c+16>>2]=f;h=c+32|0;d=c+23|0;while(1){e=ps(x[a+36>>2],x[a+40>>2],d,f,c+12|0,c+24|0,h,c+16|0);if(x[c+12>>2]==(d|0)){break b}if((e|0)==3){if((Dk(d,1,1,x[a+32>>2])|0)==1){break c}break b}if(e>>>0>1){break b}g=c+24|0;d=x[c+16>>2]-g|0;if((Dk(g,1,d,x[a+32>>2])|0)!=(d|0)){break b}d=x[c+12>>2];if((e|0)==1){continue}break}}d=gx(b);break a}d=-1}ib=c+32|0;return d|0}function AP(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;e=ib-16|0;ib=e;a:{if(x[a+480180>>2]!=1){break a}c=y[b+846|0];if(!c){break a}d=x[b+104>>2];if(!d){break a}if(!_d(x[d>>2],x[d+20>>2])){break a}f=z[d+34>>1];if(!(f&10)){break a}c=y[b+847|0]+y[(c&15)+33248|0]|0;v[b+847|0]=c;if(c<<24>>24>=0){break a}v[b+847|0]=0;h=f&2;c=x[(h?4:12)+d>>2];g=b;b=x[b+760>>2]+1|0;b=b>>>0<x[(h?8:16)+d>>2]-c>>>0?b:0;x[g+760>>2]=b;g=x[d+20>>2];c=b+c|0;b=Mk(f);cc(e+8|0,g+D(c,b)|0,b);b=x[e+8>>2];f=Jb(b,x[e+12>>2]);while(1){if((b|0)==(f|0)){yj(d,a)}else{v[b|0]=y[b|0]^-1;b=b+1|0;continue}break}}ib=e+16|0}function zha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=ib-16|0;ib=b;g=x[a+16>>2];f=ag(1,2);e=kb;h=e;Pb(a,f,e);i=x[a+24>>2];j=x[a+20>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;k=x[a+8>>2];l=x[a+12>>2];while(1){if(d){d=d-1|0;m=((((x[b+12>>2]&2147483647)<<1|x[b+8>>2]>>>31)&2147483646)<<1)+g|0;e=0;while(1){if((e|0)!=2){x[(e<<2)+b>>2]=w[(e<<1)+m>>1];e=e+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[b>>2],j);x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],i);Pb(b+8|0,k,l);c=c+8|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;sg(a,f,h);ib=b+16|0}function iha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=ib-16|0;ib=b;f=x[a+40>>2];g=x[a+36>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+32>>2];k=x[a+28>>2];l=x[a+8>>2];m=x[a+12>>2];while(1){if(d){h=x[b+12>>2]+i|0;e=v[h|0];e=((D(v[h+1|0]-e|0,x[b+8>>2]>>>10&4194048)|0)/16384|0)+(e<<8)|0;g=g+k|0;x[c>>2]=x[c>>2]+D(e,g>>12);f=f+j|0;x[c+4>>2]=x[c+4>>2]+D(e,f>>12);Pb(b+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;ib=b+16|0}function _1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=ib-32|0;ib=f;x[f+24>>2]=b;a:{if(!(x[c+4>>2]&1)){c=lb[x[x[a>>2]+24>>2]](a,b,c,d,e)|0;break a}a=f+8|0;ed(a,c);x[27524]=0;a=T(1165,a|0)|0;b=x[27524];x[27524]=0;b:{if((b|0)!=1){_b(f+8|0);c:{if(e){Uh(f+8|0,a);break c}Th(f+8|0,a)}g=f,h=ke(f+8|0),x[g>>2]=h;while(1){a=Zk(f+8|0);b=x[f>>2];if(!Mb(b,a)){c=x[f+24>>2];Gc(f+8|0);break a}a=x[b>>2];x[27524]=0;Q(1180,f+24|0,a|0)|0;a=x[27524];x[27524]=0;if((a|0)!=1){Pe(f);continue}break}c=P()|0;Gc(f+8|0);break b}c=P()|0;_b(f+8|0)}S(c|0);p()}ib=f+32|0;return c|0}function O2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=ib-32|0;ib=c;d=y[a+52|0];a:{if(pc(b,-1)){if(d){break a}b=x[a+48>>2];e=a,f=pc(b,-1)^1,v[e+52|0]=f;break a}b:{if(!d){break b}e=c,f=zp(x[a+48>>2]),v[e+19|0]=f;c:{d:{e:{d=c+20|0;switch(ps(x[a+36>>2],x[a+40>>2],c+19|0,d,c+12|0,c+24|0,c+32|0,d)-1|0){case 0:case 1:break c;case 2:break e;default:break d}}d=x[a+48>>2];x[c+20>>2]=c+25;v[c+24|0]=d}while(1){d=x[c+20>>2];if(d>>>0<=c+24>>>0){break b}d=d-1|0;x[c+20>>2]=d;if((ns(v[d|0],x[a+32>>2])|0)!=-1){continue}break}}b=-1;break a}v[a+52|0]=1;x[a+48>>2]=b}ib=c+32|0;return b|0}function kt(a,b,c){var d=0,e=0,f=0;d=ib-48|0;ib=d;e=x[x[a>>2]-12>>2]+a|0;f=x[e+16>>2]&-3;$f(e,f);a:{b:{if(Qd(y[jm(d+40|0,a,1)|0])){e=x[(x[x[a>>2]-12>>2]+a|0)+24>>2];x[27524]=0;Wr(111,d+24|0,e,b,0,c);b=x[27524];x[27524]=0;c:{if((b|0)!=1){c=gp(d+24|0,Nf(d+8|0,-1,-1))?f|4:f;break c}_(V(0)|0)|0;c=f|1;hm(x[x[a>>2]-12>>2]+a|0,c);if(x[(x[x[a>>2]-12>>2]+a|0)+20>>2]&1){x[27524]=0;Z(109);a=x[27524];x[27524]=0;if((a|0)!=1){break a}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)==1){break b}S(a|0);p()}$()}Kj(x[x[a>>2]-12>>2]+a|0,c)}ib=d+48|0;return a}V(0)|0;Sb()}p()}function waa(a){a=a|0;var b=0;b=7964;a:{b:{c:{switch(a-277|0){default:if((a|0)==357){break b}d:{if((a|0)!=257){if((a|0)==267){break d}if(a){break a}b=21631;break a}b=7997;break a}b=17531;break a;case 0:b=5014;break a;case 9:b=8020;break a;case 10:b=8034;break a;case 11:b=5391;break a;case 12:b=5411;break a;case 19:b=8046;break a;case 20:b=7978;break a;case 21:b=12794;break a;case 22:b=12117;break a;case 1:case 2:case 3:case 4:case 5:case 6:case 7:case 8:case 13:case 14:case 15:case 16:case 17:case 18:break a;case 23:break c}}b=6022;break a}b=7931}return mg(b)|0}function pja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;f=ib-32|0;ib=f;a:{c=x[a+12>>2];b:{if((c|0)==(b|0)){break b}d=b>>>0>c>>>0;c=D(Cg(x[x[a+48>>2]+12>>2]),d?b-c|0:c-b|0);e=Cb(x[a+4>>2]);c:{if(d){e=Wb(f+24|0,e);d=f+16|0;Jj(d);e=x[e>>2];x[27524]=0;X(642,a|0,e|0,c|0,d|0);c=x[27524];x[27524]=0;if((c|0)!=1){break c}a=V(108196)|0;if((jb|0)!=(da(108196)|0)){break a}_(a|0)|0;$();break b}c=Wb(f+8|0,PB(e,c));e=x[Wb(f,Cb(x[a+4>>2]))>>2];d=x[c>>2];c=x[a>>2];c=D(mt(d,Cb(c)),6)+c|0;if(Mb(d,e)){Od(a,fO(c+D(mt(e,d),6)|0,x[a+4>>2],c))}Cb(c)}x[a+12>>2]=b}ib=f+32|0;return}S(a|0);p()}function pN(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;a=Ai(a,b,c,d);v[a+4260|0]=e;x[a>>2]=46316;c=Nb(a+4264|0);d=Nb(a+4276|0);x[a+4328>>2]=0;b=a+4320|0;x[b>>2]=0;x[b+4>>2]=0;x[a+4312>>2]=0;x[a+4316>>2]=0;b=a+4208|0;f=Bb(b,0),g=1056964608,x[f>>2]=g;f=Bb(b,1),g=1036831949,x[f>>2]=g;f=Bb(b,2),g=1038174126,x[f>>2]=g;f=Bb(b,3),g=1065353216,x[f>>2]=g;f=Bb(b,4),g=1061158912,x[f>>2]=g;f=Bb(b,5),g=1059082943,x[f>>2]=g;f=Bb(b,6),g=1061997773,x[f>>2]=g;x[27524]=0;R(903,a+44|0,2);b=x[27524];x[27524]=0;if((b|0)!=1){return a|0}b=P()|0;uc(d);uc(c);Rf(a);S(b|0);p()}function hha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=ib-16|0;ib=b;f=x[a+40>>2];g=x[a+36>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+32>>2];k=x[a+28>>2];l=x[a+8>>2];m=x[a+12>>2];while(1){if(d){h=(x[b+12>>2]<<1)+i|0;e=w[h>>1];e=e+((D(w[h+2>>1]-e|0,x[b+8>>2]>>>18|0)|0)/16384|0)|0;g=g+k|0;x[c>>2]=x[c>>2]+D(e,g>>12);f=f+j|0;x[c+4>>2]=x[c+4>>2]+D(e,f>>12);Pb(b+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;ib=b+16|0}function Fo(a,b,c,d,e,f){var g=0;g=ib-16|0;ib=g;v[g+14|0]=d;v[g+15|0]=c;v[g+13|0]=e;v[g+12|0]=f;d=0;a:{b:{while(1){c=d&255;if(c>>>0>3){break b}e=y[g+15|0];$q(g+8|0,e,y[g+14|0],c>>>0>1);if(!(y[g+8|0]|!e)){d=d+1|0;Qi(g+15|0,g+13|0);Qi(g+14|0,g+12|0);continue}break}c=z[g+8>>1];v[b+2|0]=c;v[b+4|0]=c>>>8;c=y[g+13|0];v[b+5|0]=y[g+12|0];v[b+3|0]=c;v[g+7|0]=0;fe(a,0,g+7|0);break a}d=y[g+15|0];e=Ri(d);c=y[g+13|0];if(e>>>0>Ri(c)>>>0){Qi(g+15|0,g+13|0);Qi(g+14|0,g+12|0);d=y[g+15|0];c=y[g+13|0]}v[b+4|0]=0;v[b+2|0]=0;v[b+5|0]=y[g+12|0];v[b+3|0]=c;fe(a,d,g+14|0)}ib=g+16|0}function faa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=ib-16|0;ib=d;x[27524]=0;Y(958,a|0);e=x[27524];x[27524]=0;a:{b:{c:{if((e|0)==1){break c}x[27524]=0;Y(959,b|0);e=x[27524];x[27524]=0;if((e|0)==1){break c}e=x[a+24>>2];b=qc(d+8|0,b);x[27524]=0;f=x[b+4>>2];x[d>>2]=x[b>>2];x[d+4>>2]=f;X(976,e|0,d|0,(c|0)!=0|0,1);c=x[27524];x[27524]=0;b=1;if((c|0)!=1){break b}}_(V(0)|0)|0;x[27524]=0;X(945,9943,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)==1){break a}$();b=0}ib=d+16|0;return b|0}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function Sba(a){a=a|0;var b=0,c=0;c=ib-16|0;ib=c;b=x[x[a+16>>2]+24620>>2];b=Dc(roa(qoa(b,b>>31,3840,0),kb,1e3,0),kb);x[a+4316>>2]=b;x[27524]=0;x[c+12>>2]=0;U(909,a+4264|0,b|0,c+12|0);b=x[27524];x[27524]=0;a:{b:{c:{if((b|0)!=1){d:{if(!y[a+4260|0]){break d}b=x[a+4316>>2];x[27524]=0;x[c+12>>2]=0;U(909,a+4276|0,b|0,c+12|0);b=x[27524];x[27524]=0;if((b|0)!=1){break d}b=V(108196)|0;break c}x[c+12>>2]=0;b=c+12|0;kN(a+4288|0,b);x[c+12>>2]=0;kN(a+4300|0,b);break b}b=V(108196)|0}if((jb|0)!=(da(108196)|0)){break a}_(b|0)|0;x[a+4316>>2]=0;$()}ib=c+16|0;return}S(b|0);p()}function J_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=ib-16|0;ib=d;x[27524]=0;Y(958,a|0);c=x[27524];x[27524]=0;a:{b:{c:{d:{if((c|0)==1){break d}x[27524]=0;Y(959,b|0);c=x[27524];x[27524]=0;if((c|0)==1){break d}c=x[a+24>>2];e=qc(d+8|0,b);x[27524]=0;b=x[e+4>>2];x[d>>2]=x[e>>2];x[d+4>>2]=b;b=VF(c,d,1);e=x[27524];x[27524]=0;c=kb;if((e|0)!=1){break c}}_(V(0)|0)|0;x[27524]=0;X(945,8621,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)==1){break b}$();b=0;c=0}ib=d+16|0;a=c;break a}b=P()|0;x[27524]=0;Z(18);a=x[27524];x[27524]=0;if((a|0)!=1){S(b|0);p()}V(0)|0;Sb();p()}jb=a;return b|0}function TR(a,b){var c=0,d=0;v[a+15|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+20|0]=0;v[a+21|0]=0;v[a+22|0]=0;v[a+14|0]=5;w[a+12>>1]=0;x[a+8>>2]=128;x[a>>2]=256;x[a+4>>2]=64;x[a+28>>2]=0;v[a+27|0]=60;x[a+40>>2]=0;x[a+44>>2]=0;v[a+33|0]=2;v[a+34|0]=0;v[a+35|0]=0;v[a+36|0]=2;v[a+23|0]=0;v[a+24|0]=0;v[a+25|0]=255;v[a+26|0]=0;v[a+32|0]=0;kA(a+48|0);kA(a+68|0);kA(a+88|0);Rt(a+492|0);Rt(a+524|0);Tj(a,0,0);Sj(a,0,0);x[a+40>>2]=0;x[a+44>>2]=0;xu(a,b);b=a+108|0;d=OA(b);c=1;while(1){if((b|0)!=(d|0)){v[b|0]=c;c=c+1|0;b=b+1|0;continue}break}return a}function _2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=ib-32|0;ib=c;a:{b:{c:{if(Hn(b)){break c}x[c+20>>2]=b;if(y[a+44|0]){d=-1;if((Dk(c+20|0,4,1,x[a+32>>2])|0)==1){break c}break a}f=c+24|0;x[c+16>>2]=f;h=c+32|0;d=c+20|0;while(1){e=ps(x[a+36>>2],x[a+40>>2],d,f,c+12|0,c+24|0,h,c+16|0);if(x[c+12>>2]==(d|0)){break b}if((e|0)==3){if((Dk(d,1,1,x[a+32>>2])|0)==1){break c}break b}if(e>>>0>1){break b}g=c+24|0;d=x[c+16>>2]-g|0;if((Dk(g,1,d,x[a+32>>2])|0)!=(d|0)){break b}d=x[c+12>>2];if((e|0)==1){continue}break}}d=Hn(b)?0:b;break a}d=-1}ib=c+32|0;return d|0}function eaa(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;e=ib-16|0;ib=e;x[27524]=0;Y(958,a|0);d=x[27524];x[27524]=0;a:{b:{c:{if((d|0)==1){break c}x[27524]=0;Y(959,b|0);d=x[27524];x[27524]=0;if((d|0)==1){break c}d=x[a+24>>2];b=qc(e+8|0,b);x[27524]=0;f=x[b+4>>2];x[e>>2]=x[b>>2];x[e+4>>2]=f;Ya(978,d|0,e|0,+c,1);d=x[27524];x[27524]=0;b=1;if((d|0)!=1){break b}}_(V(0)|0)|0;x[27524]=0;X(945,5929,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)==1){break a}$();b=0}ib=e+16|0;return b|0}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function As(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0;h=ib-240|0;ib=h;x[h+236>>2]=d;x[h+232>>2]=c;x[h>>2]=a;a:{b:{c:{d:{if((c|0)!=1){j=a;k=1;break d}j=a;k=1;if(d){break d}i=a;break c}while(1){i=j-x[(e<<2)+g>>2]|0;if((lb[b|0](i,a)|0)<=0){i=j;break c}e:{if(!((e|0)<2|f)){f=x[((e<<2)+g|0)-8>>2];l=j-4|0;if((lb[b|0](l,i)|0)>=0){break e}if((lb[b|0](l-f|0,i)|0)>=0){break e}}x[(k<<2)+h>>2]=i;c=DI(c,d);Bs(h+232|0,c);k=k+1|0;e=c+e|0;f=0;j=i;d=x[h+236>>2];c=x[h+232>>2];if(d|(c|0)!=1){continue}break b}break}i=j;break b}if(f){break a}}CI(h,k);xx(i,b,e,g)}ib=h+240|0}function Aha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=ib-16|0;ib=b;g=x[a+16>>2];f=ag(1,2);e=kb;h=e;Pb(a,f,e);i=x[a+24>>2];j=x[a+20>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;k=x[a+8>>2];l=x[a+12>>2];while(1){if(d){d=d-1|0;m=(((x[b+12>>2]&2147483647)<<1|x[b+8>>2]>>>31)&-2)+g|0;e=0;while(1){if((e|0)!=2){x[(e<<2)+b>>2]=v[e+m|0]<<8;e=e+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[b>>2],j);x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],i);Pb(b+8|0,k,l);c=c+8|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;sg(a,f,h);ib=b+16|0}function V2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=ib-32|0;ib=c;d=y[a+52|0];a:{if(Hn(b)){if(d){break a}b=x[a+48>>2];e=a,f=Hn(b)^1,v[e+52|0]=f;break a}b:{if(!d){break b}x[c+16>>2]=x[a+48>>2];c:{d:{e:{d=c+20|0;switch(ps(x[a+36>>2],x[a+40>>2],c+16|0,d,c+12|0,c+24|0,c+32|0,d)-1|0){case 0:case 1:break c;case 2:break e;default:break d}}d=x[a+48>>2];x[c+20>>2]=c+25;v[c+24|0]=d}while(1){d=x[c+20>>2];if(d>>>0<=c+24>>>0){break b}d=d-1|0;x[c+20>>2]=d;if((ns(v[d|0],x[a+32>>2])|0)!=-1){continue}break}}b=-1;break a}v[a+52|0]=1;x[a+48>>2]=b}ib=c+32|0;return b|0}function Pea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=ib-16|0;ib=d;x[d+12>>2]=b;if(b>>>0<1073741808){a:{if(xn(a)>>>0>=b>>>0){break a}h=d,i=Eb(a),x[h+8>>2]=i;e=fm(x[Yc(d+12|0,d+8|0)>>2]);if((e|0)==(xn(a)|0)){break a}f=1;c=xn(a);g=Eb(a);b:{c:{if((e|0)==1){b=a;c=x[a>>2];break c}b=e+1|0;d:{if(c>>>0<e>>>0){b=Ii(b);break d}x[27524]=0;b=T(1254,b|0)|0;c=x[27524];x[27524]=0;if((c|0)!=1){break d}_(V(0)|0)|0;$();break b}f=kf(a);c=vc(a)}ui(b,c,Eb(a)+1|0);if(f){Ib(c)}if((e|0)!=1){hf(a,e+1|0);vd(a,g);td(a,b);break b}ee(a,g)}}ib=d+16|0;return}of();p()}function $T(a){var b=0,c=0,d=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=1196314451){break a}c=y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24);if(c>>>0<1108){break a}b=a+1104|0;if((c-1108|0)!=(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))|c>>>0>262144){break a}c=a+1094|0;if(y[c|0]|y[c+1|0]<<8){break a}b=a+1096|0;if((y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))-5>>>0<4294967292){break a}if(!nu(a+8|0)){break a}a=a+40|0;while(1){d=(a|0)==(c|0);if(d|y[a+32|0]>15|y[a+33|0]>64){break a}b=nu(a);a=a+34|0;if(b){continue}break}}return d}function yB(a,b){var c=0,d=0;a:{b:{c:{d:{e:{f:{g:{h:{d=y[a+3|0];switch(d|0){case 9:break d;case 10:break e;case 16:case 17:break g;case 0:case 1:case 2:case 3:case 11:case 12:case 13:case 14:case 15:break h;default:break a}}if(!y[a|0]){break a}switch(d|0){case 9:break d;case 10:break e;case 0:case 1:case 2:case 3:case 11:case 12:case 13:case 14:case 15:break f;case 16:case 17:break g;default:break c}}c=8;break c}c=y[a|0];if(!(c&7)){break c}}c=b+1>>>1|0;b=((d|0)==10)<<4;break b}c=16}c=D(c>>>3|0,b);b=((d|0)==10)<<4}c=b+D(Bq(y[a+1|0]),c)|0}return c}function It(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=ib-16|0;ib=c;x[c+12>>2]=b;if(b>>>0<4294967280){a:{if(ad(a)>>>0>=b>>>0){break a}h=c,i=Eb(a),x[h+8>>2]=i;d=Wg(x[Yc(c+12|0,c+8|0)>>2]);if((d|0)==(ad(a)|0)){break a}f=Eb(a);b:{c:{if((d|0)==10){g=1;b=a;e=x[a>>2];break c}b=d+1|0;d:{if(ad(a)>>>0<d>>>0){b=mc(b);break d}x[27524]=0;b=T(1253,b|0)|0;e=x[27524];x[27524]=0;if((e|0)!=1){break d}_(V(0)|0)|0;$();break b}g=kf(a);e=vc(a)}b=Ae(b,e,Eb(a)+1|0);if(g){Ib(e)}if((d|0)!=10){hf(a,d+1|0);vd(a,f);td(a,b);break b}ee(a,f)}}ib=c+16|0;return}of();p()}function Dr(a,b){a=a|0;b=b|0;var c=0,d=0;d=ib-16|0;ib=d;a=Kb(a);a:{b:{c:{switch(b|0){case 0:x[27524]=0;b=Q(1,d|0,15838)|0;c=x[27524];x[27524]=0;if((c|0)==1){break a}Gb(a,b);xb(b);break b;case 1:x[27524]=0;b=Q(1,d|0,15863)|0;c=x[27524];x[27524]=0;if((c|0)!=1){Gb(a,b);xb(b);break b}break a;case 2:x[27524]=0;b=Q(1,d|0,15811)|0;c=x[27524];x[27524]=0;if((c|0)!=1){Gb(a,b);xb(b);break b}break a;case 3:break c;default:break b}}x[27524]=0;b=Q(1,d|0,15785)|0;c=x[27524];x[27524]=0;if((c|0)==1){break a}Gb(a,b);xb(b)}ib=d+16|0;return}b=P()|0;xb(a);S(b|0);p()}function xha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=ib-16|0;ib=b;j=x[a+16>>2];h=ag(1,2);e=kb;k=e;Pb(a,h,e);e=x[a+40>>2];f=x[a+36>>2];g=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=g;g=x[a+32>>2];l=x[a+28>>2];m=x[a+8>>2];n=x[a+12>>2];while(1){if(d){i=w[(x[b+12>>2]<<1)+j>>1];f=f+l|0;x[c>>2]=x[c>>2]+D(i,f>>12);e=e+g|0;x[c+4>>2]=x[c+4>>2]+D(e>>12,i);Pb(b+8|0,m,n);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=e;x[a+20>>2]=f>>12;x[a+36>>2]=f;x[a+24>>2]=e>>12;sg(a,h,k);ib=b+16|0}function Mfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=ib-16|0;ib=g;h=z[c>>1];i=c;e=ib-16|0;ib=e;f=b;d=Td(b);a:{if(d){c=gc(f);while(1){b=d;d=z[b+14>>1];if(Lk(h,d)){c=b;d=x[b>>2];if(d){continue}break a}if(!Lk(d,h)){break a}c=b+4|0;d=x[b+4>>2];if(d){continue}break}break a}b=gc(f);c=b}x[e+12>>2]=b;b=x[c>>2];if(!b){b=ib-16|0;ib=b;d=gc(f);d=sh(e,mc(16),th(b+8|0,d));Pj(x[d>>2]+14|0,z[i>>1]);k=gc(d),l=1,v[k+4|0]=l;ib=b+16|0;Tg(f,x[e+12>>2],c,x[e>>2]);b=ce(e);zk(e);j=1}c=g+8|0;Sg(c,x[Wb(e,b)>>2],j);ib=e+16|0;SR(a,c);ib=g+16|0}function pD(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=ib-16|0;ib=f;x[f+8>>2]=e;x[f+12>>2]=d;Vf(a);It(a,c);d=0;e=0;a:while(1){if(c>>>0>d>>>0){i=c-d|0;x[f+4>>2]=i;g=x[Hb(f+12|0,f+4|0)>>2];h=g+e|0;l=e>>>0>h>>>0?e:h;j=av(Xr(a,b+d|0,g),1,13);while(1)if((e|0)==(l|0)){x[f+4>>2]=i-g;e=h+1|0;d=x[Hb(f+8|0,f+4|0)>>2]+(d+g|0)|0;continue a}else{b:{c:{d:{k=v[Qc(j,e)|0];switch(k-10|0){case 1:case 2:break b;case 0:case 3:break c;default:break d}}if(k){break b}}m=Qc(j,e),n=32,v[m|0]=n}e=e+1|0;continue}}break}ib=f+16|0}function Cia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);if(b){c=ib-16|0;ib=c;x[c+12>>2]=477218588;x[c+8>>2]=2147483647;d=x[Hb(c+12|0,c+8|0)>>2];ib=c+16|0;if(b>>>0>d>>>0){_c();p()}b=D(b,9);c=mc(b);x[a>>2]=c;x[a+4>>2]=c;e=Db(a),f=b+c|0,x[e>>2]=f;c=ib-16|0;ib=c;x[c>>2]=a;d=x[a+4>>2];x[c+4>>2]=d;x[c+8>>2]=b+d;b=x[c+4>>2];d=x[c+8>>2];while(1){if((b|0)==(d|0)){ic(c);ib=c+16|0}else{v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+8|0]=0;b=b+9|0;x[c+4>>2]=b;continue}break}}return a|0}function yha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=ib-16|0;ib=b;j=x[a+16>>2];h=ag(1,2);e=kb;k=e;Pb(a,h,e);e=x[a+40>>2];f=x[a+36>>2];g=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=g;g=x[a+32>>2];l=x[a+28>>2];m=x[a+8>>2];n=x[a+12>>2];while(1){if(d){i=v[x[b+12>>2]+j|0]<<8;f=f+l|0;x[c>>2]=x[c>>2]+D(i,f>>12);e=e+g|0;x[c+4>>2]=x[c+4>>2]+D(e>>12,i);Pb(b+8|0,m,n);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=e;x[a+20>>2]=f>>12;x[a+36>>2]=f;x[a+24>>2]=e>>12;sg(a,h,k);ib=b+16|0}function jaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=ib-16|0;ib=c;x[27524]=0;Y(958,a|0);d=x[27524];x[27524]=0;a:{b:{c:{if((d|0)==1){break c}x[27524]=0;Y(959,b|0);d=x[27524];x[27524]=0;if((d|0)==1){break c}d=x[a+24>>2];b=qc(c+8|0,b);x[27524]=0;f=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=f;e=+ra(969,d|0,c|0,1);b=x[27524];x[27524]=0;if((b|0)!=1){break b}}_(V(0)|0)|0;x[27524]=0;X(945,5966,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)==1){break a}$();e=0}ib=c+16|0;return+e}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function Xma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=ib-16|0;ib=f;g=z[Ml(x[a>>2],x[a+4>>2],b)>>1];a:{b:{if(!Sq(a,b)){break b}c=x[a+24>>2];d=Cb(x[c+484360>>2]);x[f+8>>2]=d;h=Cb(x[c+484364>>2]);while(1){if(!Mb(d,h)){break b}e=0;i=Gl(x[d>>2],x[d+4>>2]);while(1){if((e|0)!=(i|0)){c:{if(!((a|0)!=(d|0)|(b|0)!=(e|0))|z[bc(x[d>>2],e)>>1]!=(g|0)){break c}c=fU(x[a+24>>2]+484344|0,g);if((c|0)==65535){break c}j=Ml(x[a>>2],x[a+4>>2],b),k=c,w[j>>1]=k;break a}e=e+1|0;continue}break}d=x[gA(f+8|0)>>2];continue}}c=g}ib=f+16|0;return c&65535}function kaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=ib-16|0;ib=d;x[27524]=0;Y(958,a|0);c=x[27524];x[27524]=0;a:{b:{c:{if((c|0)==1){break c}x[27524]=0;Y(959,b|0);c=x[27524];x[27524]=0;if((c|0)==1){break c}c=x[a+24>>2];b=qc(d+8|0,b);x[27524]=0;e=x[b+4>>2];x[d>>2]=x[b>>2];x[d+4>>2]=e;b=W(965,c|0,d|0,1)|0;c=x[27524];x[27524]=0;if((c|0)!=1){break b}}_(V(0)|0)|0;x[27524]=0;X(945,9974,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)==1){break a}$();b=0}ib=d+16|0;return b|0}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function Tn(a,b,c,d){var e=0,f=0;e=ib-16|0;ib=e;a:{b:{c:{if(!d){break c}d=c>>31;d=(d^c)-d|0;if(d>>>0<224){break c}Ab(e+8|0,a+1074312|0,3);if(zb(x[x[e+8>>2]>>2],x[e+12>>2])){break c}if(!(v[(D(b,872)+a|0)+1075843|0]&1)){break a}c=D((c>>31)+((c|0)>0)|0,d&15);c=d>>>0>239?c<<2:c;break b}if(v[(D(b,872)+a|0)+1075843|0]&1){Ab(e+8|0,a+1074312|0,3);if(!zb(x[x[e+8>>2]>>2],x[e+12>>2])){break a}}c=c<<2}if(!c){break a}f=D(b,872)+a|0;d=x[f+1075648>>2];a=_p(a,x[f+1075080>>2],d);if(!a){break a}lb[x[x[a>>2]+84>>2]](a,c,(d?y[d+33|0]:13)<<24>>24,b)}ib=e+16|0}function UL(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=ib-32|0;ib=c;a:{f=a+36|0;b=x[f>>2];d=x[a+40>>2];b:{if(Mb(b,d)){sc(c+24|0);break b}b=c+8|0;Nn(b,a);x[27524]=0;b=T(1018,b|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break a}x[c+24>>2]=b;nf(c+8|0);d=x[a+40>>2];b=x[a+36>>2]}b=(g=f,h=x[c+24>>2],i=Mb(b,d),i?g:h);a=x[a+8>>2];c:{if((a|0)==-1){g=c,h=Cb(x[b>>2]),x[g+8>>2]=h;a=Cb(x[b+4>>2]);while(1){b=x[c+8>>2];if(!Mb(b,a)){break c}e=e+C[b>>3];xy(c+8|0);continue}}e=C[sf(x[b>>2],a)>>3]}el(c+24|0);ib=c+32|0;return+e}a=P()|0;nf(c+8|0);S(a|0);p()}function Ex(a,b,c){var d=0,e=0,f=E(0),g=E(0),h=E(0),i=E(0),j=0,k=E(0),l=E(0),m=E(0);e=ib-32|0;ib=e;g=B[a+24>>2];f=B[a+12>>2];h=B[a+48>>2];i=B[a+36>>2];VI(E(-B[a>>2]),E(g+f),E(h+i),e+20|0);VI(B[a+60>>2],E(h-i),E(g-f),e+8|0);B[e+12>>2]=-B[e+12>>2];a=0;while(1){if((a|0)!=3){d=a<<2;j=d+c|0;g=B[j>>2];f=B[d+(e+20|0)>>2];h=B[d+86496>>2];i=B[d+86508>>2];k=B[d+(e+8|0)>>2];B[j>>2]=E(f*h)-E(i*k);j=b+d|0;l=B[(0-a<<2)+86504>>2];d=5-a<<2;m=B[d+86496>>2];f=E(E(f*i)+E(k*h));B[j>>2]=E(g*l)-E(m*f);B[b+d>>2]=E(g*m)+E(f*l);a=a+1|0;continue}break}ib=e+32|0}function Aea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=ib-208|0;ib=e;w[a+480212>>1]=0;x[a+480240>>2]=65536;x[a+480244>>2]=65536;bP(a+946304|0);f=a+906300|0;g=rj(f);d=e+48|0;Rb(d,0,160);d=dP(d);x[27524]=0;U(826,f|0,g|0,d|0);f=x[27524];x[27524]=0;a:{if((f|0)!=1){ez(d);d=te(e+24|0,b);x[27524]=0;f=x[d+12>>2];x[e+8>>2]=x[d+8>>2];x[e+12>>2]=f;x[e+16>>2]=x[d+16>>2];f=x[d+4>>2];x[e>>2]=x[d>>2];x[e+4>>2]=f;a=W(827,a|0,e|0,c|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){a=P()|0;break a}yb(b);ib=e+208|0;return a|0}a=P()|0;ez(d)}yb(b);S(a|0);p()}function nda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=ib-16|0;ib=e;g=Af(a,c);Pd(e,x[a+36>>2]);a:{b:{if(!g){Pc(e,a+32|0,5);c=-1;if(!zb(x[x[e>>2]>>2],x[e+4>>2])){break b}break a}c=x[g+16>>2]}f=x[a+36>>2];c:{if(!((c|0)!=4&(c|0)!=-1)){d=ib-16|0;ib=d;x[d+8>>2]=0;Pp(f,d+8|0);B[b>>2]=B[d+8>>2];break c}d=ib-16|0;ib=d;x[d+12>>2]=c;x[d+8>>2]=4;h=x[Hb(d+12|0,d+8|0)>>2];c=ib-16|0;ib=c;Pw(c+8|0,f);if(Ir(-1,2147483647,h,0)^1){f=Ir(h,0,0,-2147483648)^1}else{f=0}if(f){kt(x[c+12>>2],h,1)}ib=c+16|0;x[b>>2]=0}ib=d+16|0;d=g}af(a,d);ib=e+16|0}function ri(a,b,c){var d=0,e=0;e=ib-16|0;ib=e;x[a+4>>2]=0;d=4;a:{b:{c:{if(!Qd(y[jm(e+8|0,a,1)|0])){break c}d=x[(x[x[a>>2]-12>>2]+a|0)+24>>2];x[27524]=0;b=W(110,d|0,b|0,c|0)|0;d=x[27524];x[27524]=0;if((d|0)!=1){x[a+4>>2]=b;d=(b|0)!=(c|0)?6:0;break c}_(V(0)|0)|0;d=1;hm(x[x[a>>2]-12>>2]+a|0,1);if(x[(x[x[a>>2]-12>>2]+a|0)+20>>2]&1){x[27524]=0;Z(109);a=x[27524];x[27524]=0;if((a|0)!=1){break a}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)==1){break b}S(a|0);p()}$()}Kj(x[x[a>>2]-12>>2]+a|0,d);ib=e+16|0;return a}V(0)|0;Sb()}p()}function Xga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=ib-16|0;ib=b;g=x[a+24>>2];h=x[a+20>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+8>>2];k=x[a+12>>2];while(1){if(d){e=(x[b+12>>2]<<1)+i|0;f=x[b+8>>2]>>>21&2040;e=(((D(w[e>>1],w[f+39730>>1])+D(w[e-2>>1],w[f+39728>>1])|0)+D(w[e+2>>1],w[f+39732>>1])|0)+D(w[e+4>>1],w[f+39734>>1])|0)/16384|0;x[c>>2]=x[c>>2]+D(e,h);x[c+4>>2]=x[c+4>>2]+D(e,g);Pb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;ib=b+16|0}function BN(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=0,f=0;qy(a);c=Ld(c,E(0));a:{switch(b|0){case 0:B[a+4220>>2]=c;return;case 1:B[a+4224>>2]=c;return;case 2:B[a+4228>>2]=c;et(a);return;case 3:v[a+4240|0]=c>=E(.5);et(a);return;case 4:b=ib-16|0;ib=b;e=b,f=Yh(E(c*E(32))),x[e+12>>2]=f;x[b+8>>2]=0;x[b+4>>2]=5;d=x[Oj(b+12|0,b+8|0,b+4|0)>>2];ib=b+16|0;x[a+4232>>2]=d;return;case 5:v[a+4241|0]=c>=E(.5);return;case 6:v[a+4242|0]=c>=E(.5);return;case 7:v[a+4244|0]=c>=E(.5);return;case 8:if(c==E(0)){py(a)}C[a+4256>>3]=c;break;default:break a}}}function D1(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=ib-416|0;ib=h;d=h+416|0;x[h+12>>2]=d;c=ib-144|0;ib=c;x[c+28>>2]=c+132;i=c+32|0;PG(x[a+8>>2],i,c+28|0,e,f,g);x[c+16>>2]=0;x[c+20>>2]=0;x[c+12>>2]=i;e=h+16|0;g=tc(e,x[h+12>>2]);f=ib-16|0;ib=f;i=qi(f+8|0,x[a+8>>2]);a=sH(e,c+12|0,g,c+16|0);pi(i);ib=f+16|0;if((a|0)==-1){ms(12557);p()}x[h+12>>2]=(a<<2)+e;ib=c+144|0;c=x[h+12>>2];a=ib-16|0;ib=a;x[a+8>>2]=b;while(1){if((c|0)!=(e|0)){VH(a+8|0,x[e>>2]);e=e+4|0;continue}break}ib=a+16|0;ib=d;return x[a+8>>2]}function ZY(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=ib-16|0;ib=c;x[c+12>>2]=x[x[a+1060>>2]>>2]-x[a+1064>>2];x[c+8>>2]=16384;d=x[Hb(c+12|0,c+8|0)>>2];x[a+1072>>2]=d;x[c+4>>2]=17;while(1){a:{if(!d){break a}e=x[c+4>>2];if((e|0)>17){break a}f=1<<e-1;d=Ok(a,e);b:{c:{d:{if((e|0)<=6){if((d|0)!=(f|0)){break d}mr(c+4|0,Ok(a,4));break b}if(e>>>0>16){break c}e=f-8|0;if((e|0)>(d|0)|(d|0)>(f+7|0)){break d}mr(c+4|0,d-e|0);break b}HD(a,d,f,b);break b}e=d&(f^-1);if(d&f){x[c+4>>2]=e+1;break b}HD(a,e,0,b)}d=x[a+1072>>2];continue}break}ib=c+16|0}function mz(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=ib-16|0;ib=d;g=Dt(a,a+1074376|0,b,c);a:{if(!g){break a}h=a+1074312|0;Ab(d+8|0,h,117);if(zb(x[x[d+8>>2]>>2],x[d+12>>2])){break a}e=D(b,872)+a|0;i=e+1075648|0;c=x[i>>2];if(!c|!y[c+33|0]){break a}f=a;a=e+1074992|0;e=_p(f,x[a+88>>2],c);if(!e){break a}Ab(d+8|0,h,34);f=!zb(x[x[d+8>>2]>>2],x[d+12>>2]);c=Ag(y[a+797|0]-w[a+770>>1]|0);b:{if(f|(c<<24)-16777216>>24<0){break b}a=x[a+656>>2];if(!a){break b}c=y[Jb(a+108|0,c-1|0)|0]}lb[x[x[e>>2]+88>>2]](e,g,c&255,v[x[i>>2]+33|0],b)}ib=d+16|0}function RO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=ib-16|0;ib=e;x[e+12>>2]=16777216;h=e+12|0;d=x[a>>2];c=tc(d,x[a+4>>2]);a:{if(c>>>0<b>>>0){f=ib-32|0;ib=f;b=b-c|0;c=x[Db(a)>>2];d=x[a+4>>2];b:{if(b>>>0<=c-d>>2>>>0){ZC(a,b,h);break b}c=Db(a);c=cg(f+8|0,wg(a,tc(x[a>>2],d)+b|0),tc(x[a>>2],x[a+4>>2]),c);g=ib-16|0;ib=g;b=Ym(g,c+8|0,b);d=x[b>>2];while(1){if(x[b+4>>2]!=(d|0)){pq(d,x[h>>2]);d=x[b>>2]+4|0;x[b>>2]=d;continue}break}Vd(b);ib=g+16|0;Dd(a,c);bg(c)}ib=f+32|0;break a}if(b>>>0<c>>>0){Od(a,d+(b<<2)|0)}}$y(a);ib=e+16|0}function sK(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=ib-16|0;ib=d;a:{b:{c:{a=x[a+32>>2];e=Ip(a);d:{if(!e){if(Hp(a)>>>0<=b>>>0){break d}a=Oi(a,b+1&65535);w[a+34>>1]=z[a+34>>1]&64511|(c?1024:0);break b}if(b>>>0<e>>>0){break c}}a=ba(8)|0;x[27524]=0;b=Q(55,d|0,6003)|0;c=x[27524];x[27524]=0;e:{if((c|0)!=1){lc(a,b);x[27524]=0;U(123,a|0,50060,962);a=x[27524];x[27524]=0;if((a|0)!=1){break a}c=P()|0;wb(b);break e}c=P()|0;ca(a|0)}S(c|0);p()}a=x[(a+(b<<2)|0)+900384>>2];if(!a){break b}v[a+15|0]=y[a+15|0]&253|(c?2:0)}ib=d+16|0;return}p()}function YY(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=ib-16|0;ib=c;x[c+12>>2]=x[x[a+1060>>2]>>2]-x[a+1064>>2];x[c+8>>2]=32768;d=x[Hb(c+12|0,c+8|0)>>2];x[a+1072>>2]=d;x[c+4>>2]=9;while(1){a:{if(!d){break a}e=x[c+4>>2];if((e|0)>9){break a}f=1<<e-1;d=Ok(a,e);b:{c:{d:{if((e|0)<=6){if((d|0)!=(f|0)){break d}mr(c+4|0,Ok(a,3));break b}if(e>>>0>8){break c}e=f-4|0;if((e|0)>(d|0)|(d|0)>(f+3|0)){break d}mr(c+4|0,d-e|0);break b}GD(a,d,f,b);break b}e=d&(f^-1);if(d&f){x[c+4>>2]=e+1;break b}GD(a,e,0,b)}d=x[a+1072>>2];continue}break}ib=c+16|0}function eea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=ib-48|0;ib=d;c=d+24|0;Gj(c,b,1819307379);fd(a+40|0,c);yb(c);Gj(c,b,1953721961);fd(a+60|0,c);yb(c);Gj(c,b,543520099);fd(a+120|0,c);yb(c);Gj(c,b,1414744396);x[27524]=0;c=Q(406,c|0,13763)|0;e=x[27524];x[27524]=0;a:{if((e|0)!=1){b:{if(c){x[27524]=0;U(776,d|0,d+24|0,2);c=x[27524];x[27524]=0;if((c|0)==1){break b}lu(a+140|0,d);Zd(d)}x[27524]=0;U(777,d|0,b|0,1634890872);b=x[27524];x[27524]=0;if((b|0)!=1){break a}}}a=P()|0;yb(d+24|0);S(a|0);p()}fd(a+80|0,d);yb(d);yb(d+24|0);ib=d+48|0}function Yga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=ib-16|0;ib=b;g=x[a+24>>2];h=x[a+20>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+8>>2];k=x[a+12>>2];while(1){if(d){e=x[b+12>>2]+i|0;f=x[b+8>>2]>>>21&2040;e=(((D(v[e|0],w[f+39730>>1])+D(v[e-1|0],w[f+39728>>1])|0)+D(v[e+1|0],w[f+39732>>1])|0)+D(v[e+2|0],w[f+39734>>1])<<8)/16384|0;x[c>>2]=x[c>>2]+D(e,h);x[c+4>>2]=x[c+4>>2]+D(e,g);Pb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;ib=b+16|0}function Cna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;md(b,0);g=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);x[b>>2]=g;e=y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24);x[b+12>>2]=e;f=y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24);x[b+16>>2]=f;c=y[a+12|0]|y[a+13|0]<<8;w[b+32>>1]=64;x[b+24>>2]=c;c=y[a+14|0];w[b+30>>1]=c?c+1|0:256;d=z[b+34>>1]&32767|!y[a+14|0]<<15;w[b+34>>1]=d;c=y[a+15|0];if(!(!(c&1)|e>>>0>=f>>>0)){d=d|8;w[b+34>>1]=d;c=y[a+15|0]}if(c&2){x[b+16>>2]=f>>>1;x[b+12>>2]=e>>>1;x[b>>2]=g>>>1;w[b+34>>1]=d|1}}function Vi(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=ib-16|0;ib=f;o(+b);g=j(1)|0;d=j(0)|0;c=g&2147483647;e=c+-1048576|0;a:{if((e|0)==2145386495|e>>>0<2145386495){h=d<<28;e=c>>>4|0;c=(c&15)<<28|d>>>4;d=e+1006632960|0;break a}if((c|0)==2146435072|c>>>0>2146435072){h=d<<28;c=(g&15)<<28|d>>>4;d=g>>>4|2147418112;break a}if(!(c|d)){c=0;d=0;break a}e=c;c=c?G(c):G(d)+32|0;Sf(f,d,e,0,0,c+49|0);i=x[f>>2];h=x[f+4>>2];e=15372-c<<16;c=x[f+8>>2];d=e|x[f+12>>2]^65536}x[a>>2]=i;x[a+4>>2]=h;x[a+8>>2]=c;x[a+12>>2]=g&-2147483648|d;ib=f+16|0}function Uy(a,b,c){var d=0,e=0;e=ib-16|0;ib=e;Ab(e+8|0,a+1074312|0,21);a:{if(zb(x[x[e+8>>2]>>2],x[e+12>>2])){c=c&255;b:{switch((b&3)-1|0){default:d=v[c+33456|0];break a;case 0:d=64-(c+1>>>1|0)|0;break a;case 1:d=(c>>>0<128)<<6;break a;case 2:break b}}d=zO(Xn(a))+-64|0;break a}d=v[(c>>>1&31)+32144|0];if(z[a+480182>>1]&1032){break a}a=c&63;c:{switch((b&3)-1|0){default:d=v[a+33328|0];break a;case 0:d=(a>>>0>=32?255:0)-(a<<2)|0;break a;case 1:d=a>>>0<32?127:-127;break a;case 2:break c}}d=v[a+33392|0]}a=d;ib=e+16|0;return a}function EY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=ib-32|0;ib=d;md(b,0);di(d,1,a+33|0);e=d+16|0;Fc(e,d);Fe(b+43|0,e);wb(e);f=y[a+50|0]|y[a+51|0]<<8|(y[a+52|0]<<16|y[a+53|0]<<24);x[b>>2]=f;x[b+24>>2]=y[a+54|0]|y[a+55|0]<<8;v[d+16|0]=y[a+56|0];v[d|0]=64;h=b,i=y[Ub(e,d)|0]<<2,w[h+30>>1]=i;e=y[a+57|0]|y[a+58|0]<<8|(y[a+59|0]<<16|y[a+60|0]<<24);x[b+4>>2]=e;g=y[a+61|0]|y[a+62|0]<<8|(y[a+63|0]<<16|y[a+64|0]<<24);c=c?e?f:g:g;x[b+8>>2]=c;if(!(!y[a|0]|c>>>0<=e+2>>>0|c>>>0>f>>>0)){w[b+34>>1]=z[b+34>>1]|2}ib=d+32|0}function fT(a,b,c,d,e,f){b=y[(b&15)+27040|0];v[a+3|0]=b;a:{b:{switch(b-11|0){case 0:b=y[a+5|0];c=b&15;if(c){v[a+5|0]=c;return}v[a+5|0]=b&240;return;case 3:b=y[a+5|0];b=D(b&240,10)|b&15;v[a+5|0]=b;d=b&255;b=z[e>>1];if(!(d|(b|0)==65535)){v[a+5|0]=b;v[a+3|0]=12;w[e>>1]=65535}wc(f,c);return;case 1:w[e>>1]=y[a+5|0];x[f>>2]=63;v[a+3|0]=0;return;case 5:b=y[a+5|0];if(d>>>0<=20){c=((b&255)>>>0)/10|0;b=c<<4|D(c,-10)+b;v[a+5|0]=b}if(b&255){break a}v[a+3|0]=0;return;case 7:break a;default:break b}}if(y[a+5|0]){break a}v[a+3|0]=0}}function bka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=ib-608|0;ib=f;b=ib-16|0;ib=b;d=f+8|0;oU(b+8|0,d);c=x[b+12>>2];ld(b,a,x[b+8>>2],x[b+12>>2]);e=x[b+4>>2];if((e|0)==(c|0)){gd(a,x[b+12>>2])}ib=b+16|0;c=(c|0)==(e|0);if(!c){nU(d)}b=-1;a:{if(!c){break a}b=0;if(!pU(f+8|0)){break a}b=-1;if(!kg(a,1024)){break a}b=0;d=ib-1024|0;ib=d;c=ib-16|0;ib=c;QA(c+8|0,d);e=x[c+12>>2];ld(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((e|0)==(g|0)){gd(a,x[c+12>>2])}ib=c+16|0;if((e|0)==(g|0)){b=RA(d,0)>>>0<17}ib=d+1024|0}ib=f+608|0;return b|0}function efa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;if(x[a+4>>2]!=x[Db(a)>>2]){c=ib-16|0;ib=c;x[c>>2]=a;a=x[a+4>>2];x[c+4>>2]=a;x[c+8>>2]=a+7;zQ(x[c+4>>2],b);x[c+4>>2]=x[c+4>>2]+7;ic(c);ib=c+16|0;return}f=ib-32|0;ib=f;g=Db(a);h=f+8|0;d=Mz(x[a>>2],x[a+4>>2])+1|0;c=ib-16|0;ib=c;x[c+12>>2]=d;a:{e=zh(613566756);if(d>>>0<=e>>>0){d=Nz(a);if(d>>>0<e>>>1>>>0){x[c+8>>2]=d<<1;e=x[Yc(c+8|0,c+12|0)>>2]}ib=c+16|0;break a}_c();p()}c=CQ(h,e,Mz(x[a>>2],x[a+4>>2]),g);zQ(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+7;BQ(a,c);AQ(c);ib=f+32|0}function zja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=ib-80|0;ib=c;d=If(c+48|0);x[27524]=0;e=Q(630,b|0,d|0)|0;f=x[27524];x[27524]=0;a:{b:{c:{d:{if((f|0)!=1){if(e){break d}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[27524]=0;T(631,a|0)|0;a=x[27524];x[27524]=0;if((a|0)!=1){break a}}break c}e=x[d+4>>2];x[27524]=0;U(194,c|0,b|0,(e>>>0>=9?e-8|0:0)|0);b=x[27524];x[27524]=0;if((b|0)!=1){break b}}a=P()|0;yd(d);S(a|0);p()}b=hc(c+24|0,c);fd(d+8|0,b);yb(b);yb(c);Ek(a,d)}yd(d);ib=c+80|0}function Iu(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=ib-16|0;ib=g;x[g+12>>2]=0;x[g+8>>2]=a;i=ib-16|0;ib=i;b=dc(i+8|0,x[g+8>>2],x[g+12>>2]);e=ib-16|0;ib=e;d=119;x[e+12>>2]=119;c=x[b+4>>2];a:{if(!c){c=x[b>>2];break a}f=32-c|0;x[e+8>>2]=f;d=x[b>>2];j=x[d>>2];h=f;f=x[Hb(e+8|0,e+12|0)>>2];x[d>>2]=(-1<<c&-1>>>h-f^-1)&j;j=x[e+12>>2];c=d+4|0;x[b>>2]=c;d=j-f|0}h=c;c=d>>>5<<2;Rb(h,0,c);f=d&31;x[e+12>>2]=f;if((d&-32)!=(d|0)){h=b;b=c+x[b>>2]|0;x[h>>2]=b;x[b>>2]=x[b>>2]&(-1>>>32-f^-1)}ib=e+16|0;ib=i+16|0;ib=g+16|0;return a}function Eaa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;v[a+4202|0]=1;c=rk(E(E(A[x[a+16>>2]+24620>>2])*E(.04500000178813934)));d=rk(E(E(c>>>0)*E(1.1892070770263672)));e=rk(E(E(d>>>0)*E(1.1892070770263672)));h=rk(E(E(e>>>0)*E(1.1892070770263672)));f=rk(E(E(c+e>>>0)*E(.11546666920185089)));g=rk(E(E(d+h>>>0)*E(.11546666920185089)));b=a+4272|0;i=Bb(b,0),j=c-f|0,x[i>>2]=j;i=Bb(b,1),j=e-f|0,x[i>>2]=j;i=Bb(b,2),j=d-g|0,x[i>>2]=j;i=Bb(b,3),j=h-g|0,x[i>>2]=j;i=Bb(b,4),j=f,x[i>>2]=j;i=Bb(b,5),j=g,x[i>>2]=j;LM(a);KM(a)}function Zka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=ib-80|0;ib=c;d=If(c+48|0);x[27524]=0;e=Q(511,b|0,d|0)|0;f=x[27524];x[27524]=0;a:{b:{c:{d:{if((f|0)!=1){if(e){break d}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[27524]=0;T(512,a|0)|0;a=x[27524];x[27524]=0;if((a|0)!=1){break a}}break c}e=z[d+2>>1]|z[d+4>>1]<<16;x[27524]=0;U(194,c|0,b|0,e|0);b=x[27524];x[27524]=0;if((b|0)!=1){break b}}a=P()|0;yd(d);S(a|0);p()}b=hc(c+24|0,c);fd(d+8|0,b);yb(b);yb(c);dV(a,d)}yd(d);ib=c+80|0}function wP(a,b,c){var d=0,e=0,f=0,g=0;d=ib-16|0;ib=d;a:{if(b){v[c|0]=b;break a}b=y[c|0]}e=x[a+480180>>2];c=e&1048580?(b&240?-16:15)&b:b;b=c&255;c=c&15;b:{c:{d:{if(!((c|0)!=15|b>>>0<16)){if(!(y[a+480209|0]&16)){break b}b=b>>>3&30;break d}f=x[a+480208>>2]&4096;g=b&240;if(!(!c|(g|0)!=240)){if(!f){break b}b=0-(c<<1)|0;break c}if(f){break b}if(g){if(c?e&59314208:0){break b}b=b>>>3&30;break d}b=0-(c<<1)|0}if(!b){break b}}a=a+1074456|0;x[d+12>>2]=x[a>>2]+(b<<!(e&59314208));re(d+12|0,0,256);x[a>>2]=x[d+12>>2]}ib=d+16|0}function Dda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;f=ib-16|0;ib=f;x[f+12>>2]=b;a:{if(rt(a)>>>0>=b>>>0){e=x[a>>2];g=Fk(e,x[a+4>>2]);x[f+8>>2]=g;d=x[Hb(f+12|0,f+8|0)>>2];while(1){if(d){d=d-1|0;e=dO(e,c)+52|0;continue}break}if(b>>>0>g>>>0){Dy(a,b-g|0,c);break a}aO(a,x[a>>2]+D(b,52)|0);break a}if(x[a>>2]){st(a);d=x[a>>2];rt(a);Ib(d);h=Db(a),i=0,x[h>>2]=i;x[a>>2]=0;x[a+4>>2]=0}d=$N(a,b);if(zh(82595524)>>>0<d>>>0){_c();p()}e=_N(d);x[a>>2]=e;x[a+4>>2]=e;h=Db(a),i=e+D(d,52)|0,x[h>>2]=i;Dy(a,b,c)}ib=f+16|0}function Zda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;a:{f=ib-32|0;ib=f;a=Nb(a);b:{c:{d:{e:{while(1){e=x[b+8>>2];g=x[b>>2];x[27524]=0;e=W(160,g|0,e|0,8)|0;g=x[27524];x[27524]=0;if((g|0)==1){break c}if(e){x[27524]=0;U(872,f|0,b|0,c|0);e=x[27524];x[27524]=0;if((e|0)==1){break e}x[27524]=0;R(873,a|0,f|0);e=x[27524];x[27524]=0;if((e|0)==1){break d}yd(f);e=HB(x[a+4>>2]);ci(f,x[e>>2],x[e+4>>2]);if(x[f>>2]!=(d|0)){continue}}break}ib=f+32|0;break a}b=P()|0;break b}b=P()|0;yd(f);break b}b=P()|0}Zd(a);S(b|0);p()}}function gM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ib-32|0;ib=c;e=Nb(a);a=b;b=0;a:{b:{c:{d:{e:{while(1){d=x[a+24>>2];if(z[d+480188>>1]<=b>>>0){break a}x[27524]=0;R(1014,c|0,(d+(b<<5)|0)+480289|0);d=x[27524];x[27524]=0;if((d|0)!=1){d=x[a+24>>2];x[27524]=0;U(1015,c+16|0,d|0,c|0);d=x[27524];x[27524]=0;if((d|0)==1){break e}x[27524]=0;R(187,e|0,c+16|0);d=x[27524];x[27524]=0;if((d|0)==1){break d}b=b+1|0;wb(c+16|0);wb(c);continue}break}b=P()|0;break b}b=P()|0;break c}b=P()|0;wb(c+16|0)}wb(c)}ve(e);S(b|0);p()}ib=c+32|0}function __(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(gh(a,x[b+8>>2],e)){Iw(b,c,d);return}a:{if(gh(a,x[b>>2],e)){if(!(x[b+16>>2]!=(c|0)&x[b+20>>2]!=(c|0))){if((d|0)!=1){break a}x[b+32>>2]=1;return}x[b+32>>2]=d;b:{if(x[b+44>>2]==4){break b}w[b+52>>1]=0;a=x[a+8>>2];lb[x[x[a>>2]+20>>2]](a,b,c,c,1,e);if(y[b+53|0]){x[b+44>>2]=3;if(!y[b+52|0]){break b}break a}x[b+44>>2]=4}x[b+20>>2]=c;x[b+40>>2]=x[b+40>>2]+1;if(x[b+36>>2]!=1|x[b+24>>2]!=2){break a}v[b+54|0]=1;return}a=x[a+8>>2];lb[x[x[a>>2]+24>>2]](a,b,c,d,e)}}function NR(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;j=b?33:32;c=y[a+16|0];k=c?-1:1;l=c?1:-1;e=x[a+8>>2]-1|0;m=c?e-(y[a+17|0]!=0&(e|0)!=0)|0:0;f=x[a+12>>2];n=(f|0)>0?f:0;o=c?0:e;h=x[a>>2]+D(f,62)|0;d=b?1:-1;p=D(f,d)<<1;c=e;a:while(1){if((i|0)!=(j|0)){g=D(c,f);q=x[a+4>>2];b=0;while(1)if((b|0)==(n|0)){b:{if((c|0)==(e|0)){b=m;g=k;if((d|0)>0){break b}}b=c+d|0;c=!c&(d|0)<0;b=c?o:b;g=c?l:d}h=h+p|0;i=i+1|0;c=b;d=g;continue a}else{w[(b<<1)+h>>1]=z[q+(b+g<<1)>>1];b=b+1|0;continue}}break}}function mea(a){a=a|0;var b=0,c=0;b=32240;a=Nb(a);a:{b:{while(1){c:{if((b|0)==32640){b=32640;break c}d:{c=x[a+4>>2];if(!pc(x[a>>2],c)){if(!Ei(x[b+4>>2],x[Fj(c)>>2])){break d}}x[27524]=0;R(850,a|0,b+4|0);c=x[27524];x[27524]=0;if((c|0)!=1){break d}break b}b=b+8|0;continue}break}while(1){if((b|0)==32688){break a}e:{c=x[a+4>>2];f:{if(!pc(x[a>>2],c)){if(!Ei(x[b+8>>2],x[Fj(c)>>2])){break f}}x[27524]=0;R(850,a|0,b+8|0);c=x[27524];x[27524]=0;if((c|0)==1){break e}}b=b+12|0;continue}break}}b=P()|0;uc(a);S(b|0);p()}}function Lma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{d=ib-32|0;ib=d;a=Nb(a);b:{c:{d:{e:{while(1){c=x[b+8>>2];e=x[b>>2];x[27524]=0;c=W(160,e|0,c|0,8)|0;e=x[27524];x[27524]=0;if((e|0)==1){break c}if(c){x[27524]=0;R(402,d|0,b|0);c=x[27524];x[27524]=0;if((c|0)==1){break e}x[27524]=0;R(403,a|0,d|0);c=x[27524];x[27524]=0;if((c|0)==1){break d}yd(d);c=HB(x[a+4>>2]);ci(d,x[c>>2],x[c+4>>2]);if((ac(x[d>>2])|0)!=1162757187){continue}}break}ib=d+32|0;break a}b=P()|0;break b}b=P()|0;yd(d);break b}b=P()|0}Zd(a);S(b|0);p()}}function ZJ(a,b){var c=0,d=0;c=x[a>>2];x[a>>2]=b;if(c){x[27524]=0;Y(819,c|0);a=x[27524];x[27524]=0;a:{if((a|0)!=1){a=x[c+4>>2];if(a){if(x[a>>2]){d=x[a>>2];b=x[a+4>>2];while(1){if((b|0)!=(d|0)){b=b-4|0;yg(b);continue}break}x[a+4>>2]=d;b=x[a>>2];_h(a);Ib(b)}Ib(a)}x[c+4>>2]=0;hP(c+1298412|0);iz(c+1298344|0);wb(c+1298332|0);xb(c+1298320|0);wb(c+1298308|0);hz(c+1298304|0);gz(c+1298300|0);Ft(c+1298264|0);uz(c+1074376|0);gP(c+906300|0);fA(c+484360|0);ZO(c+484344|0);uc(c+480248|0);break a}V(0)|0;Sb();p()}Ib(c)}}function Nja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ib-16|0;ib=c;cc(c+8|0,b,26);d=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Yb(a,x[c+12>>2])}ib=c+16|0;if((d|0)!=(e|0)){v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+24|0]=0;v[b+25|0]=0;v[b+16|0]=0;v[b+17|0]=0;v[b+18|0]=0;v[b+19|0]=0;v[b+20|0]=0;v[b+21|0]=0;v[b+22|0]=0;v[b+23|0]=0;v[b+8|0]=0;v[b+9|0]=0;v[b+10|0]=0;v[b+11|0]=0;v[b+12|0]=0;v[b+13|0]=0;v[b+14|0]=0;v[b+15|0]=0}}function pda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=E(0);e=ib-16|0;ib=e;f=Af(a,c);Pd(e,x[a+36>>2]);h=a;a:{if(!f){Pc(e,a+32|0,5);c=0;if(zb(x[x[e>>2]>>2],x[e+4>>2])){break a}}c=0;d=ib-32|0;ib=d;g=x[a+36>>2];Qk(g,d+24|0);i=d,j=Ec(x[d+24>>2],x[d+28>>2]),x[i+16>>2]=j;x[d+12>>2]=256;kk(b,x[Hb(d+16|0,d+12|0)>>2]);a=x[b>>2];while(1){if(tc(a,x[b+4>>2])>>>0<=c>>>0){ib=d+32|0}else{x[d+16>>2]=0;Pp(g,d+16|0);a=x[b>>2];i=Bb(a,c),k=B[d+16>>2],B[i>>2]=k;c=c+1|0;continue}break}c=f}af(h,c);ib=e+16|0}function Wea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=ib-16|0;ib=e;f=Kb(a);a=0;a:{b:{c:{d:{while(1){d=x[b>>2];if(wd(d,x[b+4>>2])>>>0<=a>>>0){break c}e:{if(!a){d=Cd(d,0);break e}x[27524]=0;Q(806,f|0,c|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break b}d=Cd(x[b>>2],a)}x[27524]=0;R(807,e|0,d|0);d=x[27524];x[27524]=0;if((d|0)!=1){x[27524]=0;Q(806,f|0,e|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break d}a=a+1|0;wb(e);continue}break}a=P()|0;break a}a=P()|0;wb(e);break a}ib=e+16|0;return}a=P()|0}wb(f);S(a|0);p()}function ED(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=y[a+8|0];h=x[a>>2];e=x[a+4>>2];f=Jc(b);a=Eb(b);b=ib-16|0;ib=b;x[b+8>>2]=a;x[b+12>>2]=e;a=h;g=x[Hb(b+12|0,b+8|0)>>2];c=g;while(1){a:{if(!c){c=0;break a}i=y[f|0];v[a|0]=i;if(!i){break a}f=f+1|0;a=a+1|0;c=c-1|0;continue}break}b:{if((d-1&255)>>>0<=1){v[b+7|0]=0;sm(a,((a+e|0)-g|0)+c|0,b+7|0);break b}if((d-3&255)>>>0>1){break b}v[b+6|0]=32;sm(a,((a+e|0)-g|0)+c|0,b+6|0)}c:{switch(d-1|0){case 0:case 3:v[(x[b+12>>2]+h|0)-1|0]=0;break;default:break c}}ib=b+16|0}function aja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=ib-80|0;ib=c;d=If(c+48|0);x[27524]=0;e=Q(665,b|0,d|0)|0;f=x[27524];x[27524]=0;a:{b:{c:{d:{if((f|0)!=1){if(e){break d}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[27524]=0;T(666,a|0)|0;a=x[27524];x[27524]=0;if((a|0)!=1){break a}}break c}e=x[d+4>>2];x[27524]=0;U(194,c|0,b|0,e|0);b=x[27524];x[27524]=0;if((b|0)!=1){break b}}a=P()|0;yd(d);S(a|0);p()}b=hc(c+24|0,c);fd(d+8|0,b);yb(b);yb(c);Ek(a,d)}yd(d);ib=c+80|0}function Zq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if((a|0)!=(b|0)){if(!kf(a)){if(!kf(b)){c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;x[a+8>>2]=x[b+8>>2];return}d=Jc(b);b=Eb(b);c=ib-16|0;ib=c;a:{if(b>>>0<=10){ee(a,b);a=Ae(a,d,b);v[c+15|0]=0;oe(a+b|0,c+15|0);break a}f=a;a=y[a+11|0];qp(f,10,b-10|0,a,0,a,b,d)}ib=c+16|0;return}d=Jc(b);b=Eb(b);c=ib-16|0;ib=c;e=Kl(a);b:{if(e>>>0>b>>>0){e=x[a>>2];vd(a,b);a=Ae(e,d,b);v[c+15|0]=0;oe(a+b|0,c+15|0);break b}f=a;a=x[a+4>>2];qp(f,e-1|0,(b-e|0)+1|0,a,0,a,b,d)}ib=c+16|0}}function VZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=ib-16|0;ib=e;f=Kb(a);a=0;a:{b:{c:{d:{while(1){d=x[b>>2];if(wd(d,x[b+4>>2])>>>0<=a>>>0){break c}e:{if(!a){d=Cd(d,0);break e}x[27524]=0;Q(99,f|0,c|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break b}d=Cd(x[b>>2],a)}x[27524]=0;R(157,e|0,d|0);d=x[27524];x[27524]=0;if((d|0)!=1){x[27524]=0;Q(99,f|0,e|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break d}a=a+1|0;xb(e);continue}break}a=P()|0;break a}a=P()|0;xb(e);break a}ib=e+16|0;return}a=P()|0}xb(f);S(a|0);p()}function xna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=ib-32|0;ib=c;md(b,0);di(c,1,a);d=c+16|0;Fc(d,c);Fe(b+43|0,d);wb(d);x[b+24>>2]=y[a+32|0]|y[a+33|0]<<8|(y[a+34|0]<<16|y[a+35|0]<<24);w[b+34>>1]=z[b+34>>1]&65533|(y[a+13|0]|y[a+14|0]<<8)<<1&2;x[b>>2]=y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24);x[b+4>>2]=y[a+20|0]|y[a+21|0]<<8|(y[a+22|0]<<16|y[a+23|0]<<24);x[b+8>>2]=y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24);v[c+16|0]=y[a+15|0];v[c|0]=64;e=b,f=y[Ub(d,c)|0]<<2,w[e+30>>1]=f;ib=c+32|0}function kH(a,b,c,d){var e=0,f=0,g=0;f=ib-16|0;ib=f;a:{b:{if((a|0)!=(b|0)){c:{g=x[12e4];x[12e4]=0;Fd();d=jH(a,f+12|0,d);e=kb;d:{a=x[12e4];if(a){if(x[f+12>>2]!=(b|0)){break c}if((a|0)!=68){break d}x[c>>2]=4;a=2147483647;if(!!d&(e|0)>=0|(e|0)>0){break a}break b}x[12e4]=g;if(x[f+12>>2]==(b|0)){break d}break c}if((e|0)<0&d>>>0<=2147483647|(e|0)<-1){x[c>>2]=4;break b}if((e|0)>=0&d>>>0>=2147483648|(e|0)>0){x[c>>2]=4;a=2147483647;break a}a=d;break a}}x[c>>2]=4;a=0;break a}a=-2147483648}ib=f+16|0;return a}function I8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=E(0);x[27524]=0;Y(958,a|0);d=x[27524];x[27524]=0;a:{if((d|0)==1){break a}x[27524]=0;Y(1030,c|0);d=x[27524];x[27524]=0;if((d|0)==1){break a}d=x[a+24>>2];e=B[d+48>>2];d=x[d+24>>2];x[27524]=0;b=Xa(1031,d|0,E(e),b|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break a}x[c>>2]=b;return 1}_(V(0)|0)|0;x[27524]=0;X(945,10291,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)!=1){$();return 0}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function xm(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;a:{if(f&64){c=f+-64|0;b=c&31;if((c&63)>>>0>=32){c=0;b=e>>>b|0}else{c=e>>>b|0;b=((1<<b)-1&e)<<32-b|d>>>b}d=0;e=0;break a}if(!f){break a}i=d;h=64-f|0;g=h&31;if((h&63)>>>0>=32){h=i<<g;j=0}else{h=(1<<g)-1&i>>>32-g|e<<g;j=i<<g}i=b;b=f&31;if((f&63)>>>0>=32){g=0;b=c>>>b|0}else{g=c>>>b|0;b=((1<<b)-1&c)<<32-b|i>>>b}b=j|b;c=g|h;g=d;d=f&31;if((f&63)>>>0>=32){h=0;d=e>>>d|0}else{h=e>>>d|0;d=((1<<d)-1&e)<<32-d|g>>>d}e=h}x[a>>2]=b;x[a+4>>2]=c;x[a+8>>2]=d;x[a+12>>2]=e}function sla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(x[a+4>>2]!=x[Db(a)>>2]){c=ib-16|0;ib=c;a=lw(c,a);d=x[a+4>>2];x[27524]=0;R(492,d|0,b|0);b=x[27524];x[27524]=0;a:{if((b|0)!=1){x[a+4>>2]=x[a+4>>2]+12;ic(a);ib=c+16|0;break a}b=P()|0;ic(a);S(b|0);p()}return}d=ib-32|0;ib=d;c=Db(a);c=Pk(d+8|0,on(a,wd(x[a>>2],x[a+4>>2])+1|0),wd(x[a>>2],x[a+4>>2]),c);e=x[c+8>>2];x[27524]=0;R(492,e|0,b|0);b=x[27524];x[27524]=0;b:{if((b|0)!=1){x[c+8>>2]=x[c+8>>2]+12;Hr(a,c);kw(c);ib=d+32|0;break b}a=P()|0;kw(c);S(a|0);p()}}
function lja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{d=ib-32|0;ib=d;a=Nb(a);b:{c:{d:{e:{while(1){c=x[b+8>>2];e=x[b>>2];x[27524]=0;c=W(160,e|0,c|0,8)|0;e=x[27524];x[27524]=0;if((e|0)==1){break c}if(c){x[27524]=0;R(659,d|0,b|0);c=x[27524];x[27524]=0;if((c|0)==1){break e}x[27524]=0;R(660,a|0,d|0);c=x[27524];x[27524]=0;if((c|0)==1){break d}yd(d);c=HB(x[a+4>>2]);ci(d,x[c>>2],x[c+4>>2]);if(x[d>>2]!=1413891155){continue}}break}ib=d+32|0;break a}b=P()|0;break b}b=P()|0;yd(d);break b}b=P()|0}Zd(a);S(b|0);p()}}function Rm(a,b,c){var d=0;d=512;a:{if(b){break a}d=0;if(!(y[a+35|0]&2)){break a}Ro(a)}d=z[a+34>>1]&-513|d;w[a+34>>1]=d;if(b){x[a>>2]=4;w[a+34>>1]=d&65470;Xg(a);b=y[c+8|0]|y[c+9|0]<<8|(y[c+10|0]<<16|y[c+11|0]<<24);v[a+76|0]=b;v[a+77|0]=b>>>8;v[a+78|0]=b>>>16;v[a+79|0]=b>>>24;b=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);c=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[a+68|0]=c;v[a+69|0]=c>>>8;v[a+70|0]=c>>>16;v[a+71|0]=c>>>24;v[a+72|0]=b;v[a+73|0]=b>>>8;v[a+74|0]=b>>>16;v[a+75|0]=b>>>24}}function Fna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);if(b){if(zh(715827882)>>>0<b>>>0){_c();p()}d=D(b,6);c=mc(d);x[a>>2]=c;x[a+4>>2]=c;f=Db(a),g=c+d|0,x[f>>2]=g;d=ib-16|0;ib=d;c=Rq(d,a,b);b=x[c+4>>2];e=x[c+8>>2];while(1){if((b|0)==(e|0)){ic(c);ib=d+16|0}else{v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+4|0]=6;v[b+5|0]=0;v[b|0]=0;v[b+1|0]=0;v[b+2|0]=8;v[b+3|0]=4;b=b+6|0;x[c+4>>2]=b;continue}break}}v[a+16|0]=6;x[a+12>>2]=2015363072;return a|0}function hca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=ib-16|0;ib=d;v[d+15|0]=b;b=y[a+11|0];a:{b:{c:{if(!Ue(b)){c=10;b=Ke(b);if((b|0)==10){break c}ee(a,b+1|0);c=a;break a}b=x[a+4>>2];c=Ju(x[a+8>>2])-1|0;if((b|0)!=(c|0)){break b}}e=ib-16|0;ib=e;g=nd(a);f=-17;b=c;if(b>>>0<=2147483622){x[e+8>>2]=b<<1;x[e+12>>2]=b+1;f=Wg(x[Yc(e+12|0,e+8|0)>>2])+1|0}c=mc(f);if(b){Ae(c,g,b)}if((b|0)!=10){Ib(g)}td(a,c);hf(a,f);ib=e+16|0}c=x[a>>2];vd(a,b+1|0)}a=b+c|0;oe(a,d+15|0);v[d+14|0]=0;oe(a+1|0,d+14|0);ib=d+16|0}function hR(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=Ot(b);x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Vz(a,2048);g=ib-16|0;ib=g;f=ur(g,a,2048);d=x[f+4>>2];i=x[f+8>>2];while(1){if((d|0)==(i|0)){ic(f);ib=g+16|0}else{x[d>>2]=0;x[d+4>>2]=0;d=d+8|0;x[f+4>>2]=d;continue}break}while(1){a:{c=1;if((e|0)!=1024){if((e|0)==2048){break a}c=+(e-1024|0);j=Ot(M(c*c*-9.5367431640625e-7+1)*b);c=c*.0372006759294457;c=j*Ki(c)/(h*c)}k=We(x[a>>2],e),l=c*.011841342921061943,C[k>>3]=l;e=e+1|0;continue}break}}function z0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=x[a>>2];c=tc(d,x[a+4>>2]);if(c>>>0<b>>>0){f=ib-32|0;ib=f;d=b-c|0;c=x[Db(a)>>2];b=x[a+4>>2];a:{if(d>>>0<=c-b>>2>>>0){Tt(a,d);break a}c=Nw(a);g=wg(a,tc(x[a>>2],b)+d|0);e=tc(x[a>>2],x[a+4>>2]);b=f+8|0;tg(b+12|0,c);if(g){c=zG(x[b+16>>2],g)}else{c=0}x[b>>2]=c;e=c+(e<<2)|0;x[b+8>>2]=e;x[b+4>>2]=e;h=zc(b),i=c+(g<<2)|0,x[h>>2]=i;WN(b,d);Dd(a,b);$R(b);a=x[b>>2];if(a){BG(x[b+16>>2],a,mA(b))}}ib=f+32|0;return}if(b>>>0<c>>>0){Od(a,d+(b<<2)|0)}}function vaa(a){a=a|0;var b=0,c=0,d=0;b=ib-32|0;ib=b;a:{b:{if(!a){a=mg(21631);break b}x[27524]=0;c=Q(55,b|0,a|0)|0;a=x[27524];x[27524]=0;c:{d:{if((a|0)!=1){x[27524]=0;R(944,b+16|0,c|0);a=x[27524];x[27524]=0;if((a|0)==1){break d}d=b+16|0;a=mg(Jc(d));wb(d);wb(c);break b}a=V(0)|0;break c}a=V(0)|0;wb(c)}_(a|0)|0;a=0;x[27524]=0;X(945,10924,0,0,0);c=x[27524];x[27524]=0;if((c|0)==1){break a}$()}ib=b+32|0;return a|0}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function q1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;h=ib-16|0;ib=h;d=Eb(a);e=xn(a);g=$d(b,c);a:{if(!g){break a}b:{f=vc(a);if(f>>>0<=b>>>0){f=(Eb(a)<<2)+f>>>0>=b>>>0}else{f=0}if(!f){if(e-d>>>0<g>>>0){GG(a,e,(d+g|0)-e|0,d,d)}e=vc(a)+(d<<2)|0;while(1){if((b|0)==(c|0)){break b}td(e,x[b>>2]);b=b+4|0;e=e+4|0;continue}}b=pH(h,b,c);c=vc(b);d=Eb(b);x[27524]=0;W(1200,a|0,c|0,d|0)|0;c=x[27524];x[27524]=0;if((c|0)!=1){Gc(b);break a}a=P()|0;Gc(b);S(a|0);p()}td(e,0);Wh(a,d+g|0)}ib=h+16|0;return a|0}function rK(a,b){a=a|0;b=b|0;var c=0,d=0;d=ib-16|0;ib=d;a:{b:{c:{a=x[a+32>>2];c=Ip(a);d:{if(!c){if(Hp(a)>>>0<=b>>>0){break d}c=(y[Oi(a,b+1&65535)+35|0]&4)>>>2|0;break b}if(b>>>0<c>>>0){break c}}a=ba(8)|0;x[27524]=0;b=Q(55,d|0,6003)|0;c=x[27524];x[27524]=0;e:{if((c|0)!=1){lc(a,b);x[27524]=0;U(123,a|0,50060,962);a=x[27524];x[27524]=0;if((a|0)!=1){break a}c=P()|0;wb(b);break e}c=P()|0;ca(a|0)}S(c|0);p()}a=x[(a+(b<<2)|0)+900384>>2];c=1;if(!a){break b}c=(y[a+15|0]&2)>>>1|0}ib=d+16|0;return c|0}p()}function Xd(a){var b=0,c=0,d=0;b=ib-16|0;ib=b;x[b+4>>2]=1158;x[b>>2]=a;x[b+8>>2]=0;c=ib-16|0;ib=c;if(x[a>>2]!=-1){a:{d=Wb(c,uf(c+8|0,b));while(1){if(x[a>>2]==1){continue}break}b:{if(!x[a>>2]){td(a,1);x[27524]=0;Y(1159,d|0);d=x[27524];x[27524]=0;if((d|0)==1){break b}x[a>>2]=-1}break a}_(V(0)|0)|0;td(a,0);x[27524]=0;Z(109);a=x[27524];x[27524]=0;c:{if((a|0)==1){a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){break c}V(0)|0;Sb()}p()}S(a|0);p()}}ib=c+16|0;ib=b+16|0;return x[a+4>>2]-1|0}function oF(a,b,c,d){var e=0,f=0,g=0;e=ib-80|0;ib=e;f=If(e+48|0);x[27524]=0;d=Q(d|0,b|0,f|0)|0;g=x[27524];x[27524]=0;a:{b:{c:{d:{if((g|0)!=1){if(d){break d}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[27524]=0;T(c|0,a|0)|0;a=x[27524];x[27524]=0;if((a|0)!=1){break a}}break c}c=x[f+4>>2];x[27524]=0;U(194,e|0,b|0,ac(c)|0);b=x[27524];x[27524]=0;if((b|0)!=1){break b}}a=P()|0;yd(f);S(a|0);p()}b=hc(e+24|0,e);fd(f+8|0,b);yb(b);yb(e);Ek(a,f)}yd(f);ib=e+80|0}function ho(a){var b=0,c=0,d=0,e=0;d=z[x[a+4>>2]+28>>1]>>>(!y[a+77|0]<<1)|0;b=((d&3)<<4)+27840|0;x[a+40>>2]=b;e=z[a+24>>1];d=d>>>2|0;c=e+d|0;w[a+36>>1]=c>>>0<12?1:1<<c-12;c=12-c|0;c=c>>>0<=12?c:0;w[a+32>>1]=c;w[a+34>>1]=-1<<c^-1;if((e|0)==15){w[a+36>>1]=4095}x[a+52>>2]=b;x[a+64>>2]=b;b=d+z[a+26>>1]|0;w[a+48>>1]=b>>>0<12?1:1<<b-12;b=12-b|0;c=b>>>0<=12?b:0;w[a+44>>1]=c;b=d+z[a+30>>1]|0;w[a+60>>1]=b>>>0<12?1:1<<b-12;b=12-b|0;b=b>>>0<=12?b:0;w[a+56>>1]=b;w[a+46>>1]=-1<<c^-1;w[a+58>>1]=-1<<b^-1}function fja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=ib-32|0;ib=d;md(b,0);QB(d,a+1|0);c=d+16|0;Fc(c,d);Fe(b+43|0,c);wb(c);x[b+24>>2]=y[a+73|0]|y[a+74|0]<<8|(y[a+75|0]<<16|y[a+76|0]<<24);c=y[a+54|0]|y[a+55|0]<<8|(y[a+56|0]<<16|y[a+57|0]<<24);x[b>>2]=c;x[b+4>>2]=y[a+58|0]|y[a+59|0]<<8|(y[a+60|0]<<16|y[a+61|0]<<24);e=y[a+62|0]|y[a+63|0]<<8|(y[a+64|0]<<16|y[a+65|0]<<24);if(e){x[b+8>>2]=e+1}w[b+30>>1]=(y[a+68|0]<<1)+2;w[b+34>>1]=z[b+34>>1]&65533|y[a|0]>>>6&2;wc(b+8|0,c);wc(b+4|0,x[b+8>>2]);ib=d+32|0}function mK(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;d=ib-32|0;ib=d;C[d+24>>3]=c;a:{b:{c:{if(b>>>0>=256){b=ba(8)|0;x[27524]=0;d=Q(55,d+8|0,10644)|0;a=x[27524];x[27524]=0;if((a|0)==1){break c}lc(b,d);x[27524]=0;U(123,b|0,50060,962);a=x[27524];x[27524]=0;if((a|0)!=1){break a}a=P()|0;wb(d);break b}a=x[a+32>>2];x[d+8>>2]=0;x[d+12>>2]=-1074790400;x[d>>2]=0;x[d+4>>2]=1072693248;e=(a+D(b,872)|0)+1075684|0,f=Al(C[Qg(d+24|0,d+8|0,d)>>3]*128+128),x[e>>2]=f;ib=d+32|0;return}a=P()|0;ca(b|0)}S(a|0)}p()}function Qy(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a:{if((c|0)<2){break a}k=c-2>>>1|0;f=d-a|0;if((k|0)<f>>1){break a}h=f+1|0;e=(h<<1)+a|0;g=z[e>>1];i=f+2|0;if((i|0)<(c|0)){j=z[e+2>>1];f=Vp(b,g&65535,j);e=f?e+2|0:e;h=f?i:h;g=f?j:g}i=z[d>>1];if(Vp(b,g&65535,i)){break a}while(1){b:{f=e;w[d>>1]=g;if((h|0)>(k|0)){break b}d=h<<1;h=d|1;e=(h<<1)+a|0;g=z[e>>1];j=d+2|0;if((j|0)<(c|0)){l=z[e+2>>1];d=Vp(b,g&65535,l);e=d?e+2|0:e;h=d?j:h;g=d?l:g}d=f;if(!Vp(b,g&65535,i)){continue}}break}w[f>>1]=i}}function OR(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;j=b?33:32;c=x[a+8>>2]-1|0;e=x[a+12>>2];f=x[a>>2]+D(e,31)|0;g=b?1:-1;d=g;a:while(1){b:{b=0;if((h|0)==(j|0)){break b}while(1)if((b|0)>=(e|0)){b=D(e,g);i=x[a+8>>2]-1|0;c:{if(!((i|0)!=(c|0)|(d|0)<=0)){if(!y[a+16|0]){d=1;c=0;break c}d=-1;c=c-(y[a+17|0]!=0&(c|0)!=0)|0;break c}if(!((d|0)>=0|c)){c=y[a+16|0];d=c?1:-1;c=c?0:i;break c}c=c+d|0}f=b+f|0;h=h+1|0;continue a}else{v[b+f|0]=y[x[a+4>>2]+(D(c,e)+b|0)|0];b=b+1|0;e=x[a+12>>2];continue}}break}}function IO(a,b){var c=0,d=0,e=0,f=0,g=0;d=ib-32|0;ib=d;a:{f=b-4e3&65535;if(f>>>0<61537){break a}c=D(b,104)+a|0;e=c+484380|0;if(!_d(x[e>>2],x[c+484400>>2])){break a}g=a+1298224|0;c=a+1074992|0;while(1){if((c|0)==(g|0)){Jm(e);x[e>>2]=0;a=(D(b,104)+a|0)+484414|0;w[a>>1]=z[a>>1]&65470;x[d+24>>2]=0;x[d+8>>2]=0;x[d+16>>2]=0;x[d+20>>2]=0;x[d>>2]=0;x[d+4>>2]=0;Rm(e,0,d);break a}if(x[c+104>>2]==(e|0)){x[c+76>>2]=0;x[c>>2]=0;x[c+4>>2]=0;x[c+16>>2]=0}c=c+872|0;continue}}ib=d+32|0;return f>>>0>61536}function fM(a){a=a|0;var b=0,c=0,d=0,e=0;c=ib-32|0;ib=c;e=Nb(a);Yd(c+24|0);a=0;b=x[c+28>>2];d=x[c+24>>2];x[27524]=0;R(185,e|0,bJ(d,b)|0);b=x[27524];x[27524]=0;a:{if((b|0)!=1){b:{while(1){b=x[c+24>>2];if((bJ(b,x[c+28>>2])|0)<=(a|0)){ib=c+32|0;return}b=x[b+(a<<3)>>2];x[27524]=0;b=Q(55,c+8|0,b|0)|0;d=x[27524];x[27524]=0;if((d|0)!=1){x[27524]=0;R(187,e|0,b|0);d=x[27524];x[27524]=0;if((d|0)==1){break b}wb(b);a=a+1|0;continue}break}a=P()|0;break a}a=P()|0;wb(b);break a}a=P()|0}ve(e);S(a|0);p()}function lA(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=ib-16|0;ib=d;f=a+14|0;c=x[a>>2];e=x[a+4>>2];if(pc(c,e)){b=c}else{w[c>>1]=0;Ff(c+2|0,b);g=d,h=Dm(Cb(x[a>>2]),1),x[g+8>>2]=h;while(1){e=Cb(x[a+4>>2]);c=x[d+8>>2];if(Mb(c,e)){g=c,h=z[pe(c,Dm(c,-1))>>1],w[g>>1]=h;Ff(c+2|0,b);OS(d+8|0);continue}else{e=x[a+4>>2];b=x[a>>2]}break}}Ff(f,$d(b,e)-1&255);Ff(a+13|0,y[a+14|0]);Ff(a+16|0,$d(x[a>>2],x[a+4>>2])-1&255);Ff(a+15|0,y[a+16|0]);if(y[a+17|0]!=255){Ff(a+17|0,$d(x[a>>2],x[a+4>>2])-1&255)}ib=d+16|0}function ds(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;i=ib-16|0;ib=i;a:{b:{if(!a){break b}h=x[e+12>>2];g=c-b|0;if((g|0)>0){g=g>>>2|0;if((Co(a,b,g)|0)!=(g|0)){break b}}b=d-b>>2;b=(b|0)<(h|0)?h-b|0:0;if((b|0)>0){f=XG(i,b,f);h=vc(f);x[27524]=0;h=W(1183,a|0,h|0,b|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break a}Gc(f);if((b|0)!=(h|0)){break b}}b=d-c|0;if((b|0)>0){b=b>>>2|0;if((Co(a,c,b)|0)!=(b|0)){break b}}Tq(e);j=a}ib=i+16|0;return j|0}a=P()|0;Gc(f);S(a|0);p()}function IJ(a){var b=0,c=0,d=0,e=0,f=0;while(1){d=x[a+16>>2];if(d>>>0<=e>>>0){while(1){if(!(A[a+12>>2]<=d>>>0)){while(1){e=dz(x[a>>2]);c=kb;f=x[a+36>>2];if((c|0)==(f|0)&A[a+32>>2]<=e>>>0|c>>>0>f>>>0){continue}break}c=b;b=x[a+8>>2];b=(e&x[a+48>>2])+(b>>>0<31?c<<b+1:0)|0;d=d+1|0;continue}break}}else{while(1){d=dz(x[a>>2]);c=kb;f=x[a+28>>2];if((c|0)==(f|0)&A[a+24>>2]<=d>>>0|c>>>0>f>>>0){continue}break}c=b;b=x[a+8>>2];b=(d&x[a+40>>2])+(b>>>0<32?c<<b:0)|0;e=e+1|0;continue}break}return b}function cia(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a:{f=ib-48|0;ib=f;Vq(f+8|0,c);x[27524]=0;c=f+20|0;R(581,c|0,d|0);d=x[27524];x[27524]=0;b:{c:{d:{if((d|0)==1){break d}x[27524]=0;c=f+32|0;R(581,c|0,e|0);d=x[27524];x[27524]=0;if((d|0)==1){break d}gw(f,f+8|0);x[27524]=0;X(300,a|0,b|0,x[f>>2],x[f+4>>2]);a=x[27524];x[27524]=0;if((a|0)==1){break c}CS(f+8|0);ib=f+48|0;break a}a=P()|0;while(1){c=wb(c-12|0);if((c|0)!=(f+8|0)){continue}break}break b}a=P()|0;CS(f+8|0)}S(a|0);p()}}function ZZ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a:{f=ib-48|0;ib=f;dp(f+8|0,c);x[27524]=0;c=f+20|0;R(143,c|0,d|0);d=x[27524];x[27524]=0;b:{c:{d:{if((d|0)==1){break d}x[27524]=0;c=f+32|0;R(143,c|0,e|0);d=x[27524];x[27524]=0;if((d|0)==1){break d}gw(f,f+8|0);x[27524]=0;X(118,a|0,b|0,x[f>>2],x[f+4>>2]);a=x[27524];x[27524]=0;if((a|0)==1){break c}Er(f+8|0);ib=f+48|0;break a}a=P()|0;while(1){c=xb(c-12|0);if((c|0)!=(f+8|0)){continue}break}break b}a=P()|0;Er(f+8|0)}S(a|0);p()}}function Yka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(A[a+4>>2]<A[Db(a)>>2]){c=ib-16|0;ib=c;a=KX(c,a);iB(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+28;ic(a);ib=c+16|0;return}e=ib-32|0;ib=e;c=Db(a);c=IX(e+8|0,JX(a,Wq(x[a>>2],x[a+4>>2])+1|0),Wq(x[a>>2],x[a+4>>2]),c);iB(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+28;f=x[a>>2];d=x[a+4>>2];b=c+4|0;while(1){if((d|0)!=(f|0)){d=d-28|0;iB(x[b>>2]-28|0,d);x[b>>2]=x[b>>2]-28;continue}break}oc(a,b);oc(a+4|0,c+8|0);oc(Db(a),zc(c));x[c>>2]=x[c+4>>2];HX(c);ib=e+32|0}function Ij(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(A[a+4>>2]<A[Db(a)>>2]){c=ib-16|0;ib=c;a=KX(c,a);mC(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+28;ic(a);ib=c+16|0;return}e=ib-32|0;ib=e;c=Db(a);c=IX(e+8|0,JX(a,Wq(x[a>>2],x[a+4>>2])+1|0),Wq(x[a>>2],x[a+4>>2]),c);mC(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+28;f=x[a>>2];d=x[a+4>>2];b=c+4|0;while(1){if((d|0)!=(f|0)){d=d-28|0;mC(x[b>>2]-28|0,d);x[b>>2]=x[b>>2]-28;continue}break}oc(a,b);oc(a+4|0,c+8|0);oc(Db(a),zc(c));x[c>>2]=x[c+4>>2];HX(c);ib=e+32|0}function _J(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;if((e|0)==10){hy(a,b,c,d);return}g=d;i=D(e,e);k=D(i,e);j=D(i,i);a:{while(1){h=f|1;if(e>>>0>g>>>0){break a}h=f|2;if(g>>>0<i>>>0){break a}h=f|3;if(g>>>0<k>>>0){break a}if(g>>>0<j>>>0){h=f+4|0}else{f=f+4|0;g=(g>>>0)/(j>>>0)|0;continue}break}}f=h;if((f|0)>(c-b|0)){x[a+4>>2]=61;x[a>>2]=c;return}f=b+f|0;c=f;while(1){c=c-1|0;b=(d>>>0)/(e>>>0)|0;v[c|0]=y[(d-D(b,e)|0)+4898|0];g=d>>>0>=e>>>0;d=b;if(g){continue}break}x[a+4>>2]=0;x[a>>2]=f}function Tr(a,b,c,d,e,f){var g=0,h=0,i=0;g=ib-16|0;ib=g;a=iL(a);x[a+8>>2]=0;x[a>>2]=49260;x[27524]=0;i=T(818,104)|0;h=x[27524];x[27524]=0;a:{b:{c:{d:{if((h|0)!=1){x[27524]=0;d=T(1060,d|0)|0;h=x[27524];x[27524]=0;if((h|0)==1){break d}x[g>>2]=d;d=x[ge(g+8|0,g)>>2];x[27524]=0;b=ja(f|0,i|0,b|0,c|0,d|0,e|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break c}x[a+8>>2]=b;Xc(g);b=x[a+8>>2];vd(a,b?b+8|0:0);ib=g+16|0;return a}b=P()|0;break a}b=P()|0;break b}b=P()|0;Xc(g)}Ib(i)}om(a);S(b|0);p()}function Ila(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=ib-32|0;ib=c;e=c+8|0;f=Nb(e+8|0);x[27524]=0;d=T(206,b|0)|0;g=x[27524];x[27524]=0;a:{b:{if((g|0)==1){break b}x[27524]=0;U(248,e|0,b|0,d|0);d=x[27524];x[27524]=0;if((d|0)==1){break b}d=x[e>>2];x[27524]=0;Q(192,b|0,d|0)|0;b=x[27524];x[27524]=0;if((b|0)!=1){break a}}a=P()|0;ec(f);S(a|0);p()}lv(c,e);x[27524]=0;U(467,a|0,x[c>>2],x[c+4>>2]);a=x[27524];x[27524]=0;if((a|0)!=1){Rc(c+8|0);ib=c+32|0;return}a=P()|0;Rc(c+8|0);S(a|0);p()}function eT(a){var b=0,c=0;a:{if(Qb(a+60|0,13818,4)){break a}b=y[a+28|0]|y[a+29|0]<<8;b:{if(b>>>0<=63){if((b|0)==26){break b}break a}if(b>>>0>2112){break a}}b=y[a+42|0];if(b>>>0>64&(b|0)!=88|(y[a+48|0]|y[a+49|0]<<8)>>>0>64|(y[a+50|0]|y[a+51|0]<<8)>>>0>96){break a}b=y[a+52|0]|y[a+53|0]<<8;if(b>>>0>129&(b|0)!=257|(y[a+30|0]|y[a+31|0]<<8)|(y[a+38|0]|y[a+39|0]<<8|(y[a+40|0]<<16|y[a+41|0]<<24)|(y[a+44|0]|y[a+45|0]<<8|(y[a+46|0]<<16|y[a+47|0]<<24))!=1)){break a}c=hT(a+20|0)}return c}function dO(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;if((a|0)!=(b|0)){c=ib-16|0;ib=c;d=x[b>>2];f=x[b+4>>2];e=xk(d,f);a:{if(e>>>0<=Wu(a)>>>0){g=f;h=x[a>>2];i=xk(h,x[a+4>>2]);j=i>>>0>=e>>>0;if(!j){x[c+12>>2]=d;x[c+12>>2]=x[c+12>>2]+D(i,6);g=x[c+12>>2]}d=fO(d,g,h);if(!j){Fy(a,g,f,e-xk(x[a>>2],x[a+4>>2])|0);break a}Od(a,d);break a}eO(a);Hu(a,pB(a,e));Fy(a,d,f,e)}ib=c+16|0}x[a+12>>2]=x[b+12>>2];x[a+16>>2]=x[b+16>>2];x[a+20>>2]=x[b+20>>2];cO(a+24|0,b+24|0);Zq(a+36|0,b+36|0);return a}function Sf(a,b,c,d,e,f){var g=0,h=0,i=0;a:{if(f&64){d=b;e=f+-64|0;b=e&31;if((e&63)>>>0>=32){e=d<<b;d=0}else{e=(1<<b)-1&d>>>32-b|c<<b;d=d<<b}b=0;c=0;break a}if(!f){break a}g=d;d=f&31;if((f&63)>>>0>=32){h=g<<d;i=0}else{h=(1<<d)-1&g>>>32-d|e<<d;i=g<<d}g=b;e=64-f|0;d=e&31;if((e&63)>>>0>=32){e=0;b=c>>>d|0}else{e=c>>>d|0;b=((1<<d)-1&c)<<32-d|g>>>d}d=i|b;e=e|h;b=f&31;if((f&63)>>>0>=32){h=g<<b;b=0}else{h=(1<<b)-1&g>>>32-b|c<<b;b=g<<b}c=h}x[a>>2]=b;x[a+4>>2]=c;x[a+8>>2]=d;x[a+12>>2]=e}function Su(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=ib-16|0;ib=g;h=Jb(b,0);f=(y[h|0]&15)<<8|y[Jb(b,1)|0];d=0;a:{if(!f){break a}d=0;if((f|0)==4095){break a}while(1){d=108;if((e|0)==84){break a}b:{d=z[(e<<1)+32688>>1];if(d>>>0<=f>>>0){if(!e|(f|0)==(d|0)|(z[(e<<1)+32686>>1]-f|0)>=(f-d|0)){break b}d=e+24|0;break a}e=e+1|0;continue}break}d=e+25|0}v[c|0]=d;e=Jb(b,2);d=y[e|0];f=y[h|0];v[c+3|0]=0;v[c+1|0]=f&16|d>>>4;c=y[e|0];i=g,j=y[Jb(b,3)|0],v[i+15|0]=j;fe(a,c&15,g+15|0);ib=g+16|0}function Jy(a,b,c,d){var e=0,f=0,g=0,h=0;e=ib-48|0;ib=e;a:{if(!c){b=Kd(x[a>>2],b);a=x[d+12>>2];x[b+8>>2]=x[d+8>>2];x[b+12>>2]=a;a=x[d+4>>2];x[b>>2]=x[d>>2];x[b+4>>2]=a;break a}f=x[d+12>>2];x[e+24>>2]=x[d+8>>2];x[e+28>>2]=f;f=x[d+4>>2];x[e+16>>2]=x[d>>2];x[e+20>>2]=f;f=c>>>1|0;Jy(a,b,f,e+16|0);g=C[d>>3];h=C[d+8>>3];d=Kd(x[a>>2],c);Di(e+32|0,g,h,C[d>>3],C[d+8>>3]);d=x[e+44>>2];x[e+8>>2]=x[e+40>>2];x[e+12>>2]=d;d=x[e+36>>2];x[e>>2]=x[e+32>>2];x[e+4>>2]=d;Jy(a,b|c,f,e)}ib=e+48|0}function MD(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=ib-16|0;ib=f;g=x[b+16>>2];x[a+4>>2]=0;x[a>>2]=g;a:{if(!g){break a}e=b+80|0;c=x[b+84>>2];if(c>>>0<=15){d=x[e>>2]}else{x[f+12>>2]=c-16;d=x[Yc(e,f+12|0)>>2]}x[a+8>>2]=d;c=x[b+88>>2];if(!(c&2)){break a}d=c;c=x[b+104>>2];b:{if(!(!LD(d,c)|x[e>>2]!=x[c+12>>2])){e=1;d=x[b+84>>2];if((d|0)==x[c+16>>2]){break b}}e=0;d=x[b+84>>2];if((d|0)!=x[c+8>>2]){break a}}h=a,i=D((x[c>>2]-d|0)+(e?112:48)|0,Mk(z[c+34>>1]))+g|0,x[h+4>>2]=i}ib=f+16|0}function ew(a){var b=0,c=0,d=0;if(A[a+4>>2]<A[Db(a)>>2]){b=ib-16|0;ib=b;a=gE(b,a);c=x[a+4>>2];x[27524]=0;Y(174,c|0);c=x[27524];x[27524]=0;a:{if((c|0)!=1){x[a+4>>2]=x[a+4>>2]+36;ic(a);ib=b+16|0;break a}b=P()|0;ic(a);S(b|0);p()}return}c=ib-32|0;ib=c;b=Db(a);b=eE(c+8|0,fE(a,tr(x[a>>2],x[a+4>>2])+1|0),tr(x[a>>2],x[a+4>>2]),b);d=x[b+8>>2];x[27524]=0;Y(174,d|0);d=x[27524];x[27524]=0;b:{if((d|0)!=1){x[b+8>>2]=x[b+8>>2]+36;dE(a,b);Wv(b);ib=c+32|0;break b}a=P()|0;Wv(b);S(a|0);p()}}function WO(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=x[a+104>>2];e=(g<<3)+a|0;c=((g+7>>>0)%12<<3)+a|0;f=x[c>>2];c=x[c+4>>2];h=x[a+96>>2];i=x[a+100>>2];a:{if(!(h|i)){b=x[e+4>>2];d=x[e>>2];j=(b|0)==(c|0)&d>>>0>f>>>0|c>>>0<b>>>0;break a}b=x[e+4>>2];d=x[e>>2];j=!(c|f)|((b|0)==(c|0)&d>>>0>=f>>>0|c>>>0<b>>>0)}b=b+i|0;d=h+d|0;b=d>>>0<h>>>0?b+1|0:b;x[e>>2]=f-d;x[e+4>>2]=c-(b+(f>>>0<d>>>0)|0)&65535;x[a+104>>2]=(g+1>>>0)%12;x[a+96>>2]=j;x[a+100>>2]=0;kb=x[e+4>>2];return x[e>>2]}function Sr(a,b,c,d,e){var f=0,g=0,h=0;f=ib-16|0;ib=f;a=iL(a);x[a+8>>2]=0;x[a>>2]=49260;x[27524]=0;h=T(818,104)|0;g=x[27524];x[27524]=0;a:{b:{c:{d:{if((g|0)!=1){x[27524]=0;c=T(1060,c|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break d}x[f>>2]=c;c=x[ge(f+8|0,f)>>2];x[27524]=0;b=fa(e|0,h|0,b|0,c|0,d|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break c}x[a+8>>2]=b;Xc(f);b=x[a+8>>2];vd(a,b?b+8|0:0);ib=f+16|0;return a}b=P()|0;break a}b=P()|0;break b}b=P()|0;Xc(f)}Ib(h)}om(a);S(b|0);p()}function gda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=ib-48|0;ib=f;d=x[a+36>>2];$f(x[x[d>>2]-12>>2]+d|0,0);e=x[b>>2];d=x[e+12>>2];g=x[e+8>>2];if(d|g){h=x[a+36>>2];d=x[a+20>>2]+d|0;e=x[a+16>>2];g=g+e|0;e=Nf(f+32|0,g,e>>>0>g>>>0?d+1|0:d);d=x[e+12>>2];x[f+8>>2]=x[e+8>>2];x[f+12>>2]=d;d=x[e+4>>2];x[f>>2]=x[e>>2];x[f+4>>2]=d;eh(h,f)}d=f+16|0;Pd(d,x[a+36>>2]);bA(x[a+36>>2],c,x[x[b>>2]+16>>2]);c=x[b>>2];b=Tk(d,Jb(x[a+40>>2],x[c>>2]),z[c+20>>1]);af(a,c);Zb(b);ib=f+48|0}function RJ(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=ib-16|0;ib=d;x[d+12>>2]=c;a:{if(!b){a=a+120|0;Ln(a);g=NJ(a,x[d+12>>2]),h=0,v[g+20|0]=h;break a}e=ib-16|0;ib=e;x[e+12>>2]=c;b:{if((b|0)==1){b=a+120|0;Ln(b);g=Rx(b,a,x[e+12>>2]),h=1,v[g+20|0]=h;break b}f=ib-16|0;ib=f;x[f+12>>2]=c;c:{if((b|0)==2){a=a+120|0;Ln(a);a=NJ(a,x[f+12>>2]);Id(a+12|0);v[a+20|0]=2;break c}b=ib-16|0;ib=b;x[b+12>>2]=c;c=a+120|0;Ln(c);g=Rx(c,a,x[b+12>>2]),h=3,v[g+20|0]=h;ib=b+16|0}ib=f+16|0}ib=e+16|0}ib=d+16|0}function r5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=ib-16|0;ib=c;a:{d=Yh(E(B[a+24>>2]*E(65536)));if((d|0)==65536){break a}j=d>>31;k=x[b>>2];g=x[b+4>>2];l=x[b+8>>2];b:while(1){if((f|0)==(l|0)){break a}m=D(f,g);e=0;while(1)if((e|0)==(g|0)){f=f+1|0;continue b}else{h=(e+m<<2)+k|0;i=x[h>>2];n=h,o=Dc(roa(qoa(i,i>>31,d,j),kb,65536,0),kb),x[n>>2]=o;e=e+1|0;continue}}}x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;EJ(a,c);ib=c+16|0}function h5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=ib-16|0;ib=c;a:{d=Yh(E(B[a+24>>2]*E(65536)));if((d|0)==65536){break a}j=d>>31;k=x[b>>2];g=x[b+4>>2];l=x[b+8>>2];b:while(1){if((f|0)==(l|0)){break a}m=D(f,g);e=0;while(1)if((e|0)==(g|0)){f=f+1|0;continue b}else{h=(e+m<<2)+k|0;i=x[h>>2];n=h,o=Dc(roa(qoa(i,i>>31,d,j),kb,65536,0),kb),x[n>>2]=o;e=e+1|0;continue}}}x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;yJ(a,c);ib=c+16|0}function K6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=ib-32|0;ib=e;d=wf(e+16|0,1,0);a:{b:{while(1){f=vc(d);hK(e+8|0,f,Eb(d)+f|0,y[b|0],c);if(!x[e+12>>2]){break b}f=Og(Eb(d));x[27524]=0;R(59,d|0,f|0);f=x[27524];x[27524]=0;if((f|0)!=1){continue}break}break a}b=x[e+8>>2];c=vc(d);x[27524]=0;R(60,d|0,b-c|0);b=x[27524];x[27524]=0;c:{if((b|0)!=1){x[27524]=0;R(61,a|0,d|0);a=x[27524];x[27524]=0;if((a|0)!=1){break c}break a}break a}wb(d);ib=e+32|0;return}a=P()|0;wb(d);S(a|0);p()}function GU(a,b,c,d){var e=0,f=0,g=0;f=ib-16|0;ib=f;while(1){a:{e=z[c>>1]<<1;w[c>>1]=e;v[b|0]=(e&65534)>>>0>255;e=y[c|0];w[c>>1]=e;if(!e){if(!vf(a,f+15|0)){break a}e=y[f+15|0];w[c>>1]=e<<1|1;v[b|0]=e>>>7;w[c>>1]=y[c|0]}v[d|0]=y[b|0]+(y[d|0]<<1);e=z[c>>1]<<1;w[c>>1]=e;v[b|0]=(e&65534)>>>0>255;e=y[c|0];w[c>>1]=e;if(!e){e=vf(a,f+14|0);if(e){g=y[f+14|0];w[c>>1]=g<<1|1;v[b|0]=g>>>7;w[c>>1]=y[c|0]}if(!e){break a}if(y[b|0]){continue}break a}if(y[b|0]){continue}}break}ib=f+16|0}function qla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=ib-16|0;ib=e;i=e,j=Ej(b),x[i>>2]=j;g=z[b>>1];c=ib-16|0;ib=c;f=a;d=Td(a);a:{if(d){b=gc(f);while(1){a=d;d=z[a+16>>1];if(ro(g,d)){b=a;d=x[a>>2];if(d){continue}break a}if(!ro(d,g)){break a}b=a+4|0;d=x[a+4>>2];if(d){continue}break}break a}a=gc(f);b=a}x[c+12>>2]=a;a=x[b>>2];if(!a){GV(c,f,e);Tg(f,x[c+12>>2],b,x[c>>2]);a=ce(c);FV(c);h=1}Sg(e+8|0,x[Wb(c,a)>>2],h);ib=c+16|0;a=ud(x[e+8>>2]);ib=e+16|0;return a+4|0}function Uda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=ib-32|0;ib=d;Pi(d,2,a+2|0);e=d+16|0;Fc(e,d);Cc(b+492|0,e);f=b+236|0;g=c+1|0;wb(e);c=0;while(1){if((c|0)==120){x[b>>2]=(y[a+223|0]|y[a+224|0]<<8)<<5;a=a+158|0;jO(y[a|0]&15,y[a+1|0]&15,y[a+2|0]&15,y[a+3|0]&15,y[a+4|0]&15,a+5|0,b+48|0);jO(y[a|0]>>>4|0,y[a+1|0]>>>4|0,y[a+2|0]>>>4|0,y[a+3|0]>>>4|0,y[a+4|0]>>>4|0,a+35|0,b+68|0);ib=d+32|0}else{h=bc(f,c),i=y[(a+c|0)+31|0]+g|0,w[h>>1]=i;c=c+1|0;continue}break}}function UN(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=ib-16|0;ib=e;i=e,j=Ej(b),x[i>>2]=j;g=z[b>>1];c=ib-16|0;ib=c;f=a;d=Td(a);a:{if(d){b=gc(f);while(1){a=d;d=z[a+16>>1];if(lt(g,d)){b=a;d=x[a>>2];if(d){continue}break a}if(!lt(d,g)){break a}b=a+4|0;d=x[a+4>>2];if(d){continue}break}break a}a=gc(f);b=a}x[c+12>>2]=a;a=x[b>>2];if(!a){GV(c,f,e);Tg(f,x[c+12>>2],b,x[c>>2]);a=ce(c);FV(c);h=1}Sg(e+8|0,x[Wb(c,a)>>2],h);ib=c+16|0;a=ud(x[e+8>>2]);ib=e+16|0;return a+4|0}function _H(a){var b=0,c=0;a:{b=x[a+4>>2];b=x[x[b>>2]-12>>2]+b|0;b:{if(!x[b+24>>2]){break b}if(!fh(b)|!(x[b+4>>2]&8192)){break b}if(qI()){break b}b=x[a+4>>2];b=x[(x[x[b>>2]-12>>2]+b|0)+24>>2];x[27524]=0;b=T(1133,b|0)|0;c=x[27524];x[27524]=0;if((c|0)!=1){if((b|0)!=-1){break b}a=x[a+4>>2];b=x[x[a>>2]-12>>2];x[27524]=0;Y(1134,a+b|0);a=x[27524];x[27524]=0;if((a|0)!=1){break b}}_(V(0)|0)|0;x[27524]=0;Z(18);a=x[27524];x[27524]=0;if((a|0)==1){break a}}return}V(0)|0;Sb();p()}function GY(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=ib-32|0;ib=d;md(b,0);di(d,1,a+33|0);c=d+16|0;Fc(c,d);Fe(b+43|0,c);wb(c);e=y[a+50|0]|y[a+51|0]<<8;x[b>>2]=e;x[b+24>>2]=y[a+52|0]|y[a+53|0]<<8;v[d+16|0]=y[a+54|0];v[d|0]=64;g=b,h=y[Ub(c,d)|0]<<2,w[g+30>>1]=h;f=y[a+55|0]|y[a+56|0]<<8;x[b+4>>2]=f;c=y[a+57|0]|y[a+58|0]<<8;x[b+8>>2]=c;a:{if((c|0)==65535){x[b+4>>2]=0;x[b+8>>2]=0;break a}if(!y[a|0]|c>>>0<=f+2>>>0|c>>>0>e>>>0){break a}w[b+34>>1]=z[b+34>>1]|2}ib=d+32|0}function cp(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if((a|0)!=(b|0)){if(!Ue(y[a+11|0])){c=y[b+11|0];if(!Ue(c)){d=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=d;x[a+8>>2]=x[b+8>>2];return}d=nd(b);b=xd(x[b+4>>2],c);a:{if(b>>>0<=10){ee(a,b);ne(Ae(a,d,b)+b|0,0);break a}e=a;a=Ke(y[a+11|0]);wq(e,10,b-10|0,a,0,a,b,d)}return}d=nd(b);b=xd(x[b+4>>2],y[b+11|0]);c=Ju(x[a+8>>2]);b:{if(b>>>0<c>>>0){c=x[a>>2];vd(a,b);ne(Ae(c,d,b)+b|0,0);break b}e=a;a=x[a+4>>2];wq(e,c-1|0,(b-c|0)+1|0,a,0,a,b,d)}}}
function wz(a,b,c){var d=0,e=0;d=ib-16|0;ib=d;e=x[a+480180>>2];a:{if((e|0)!=1048576){if((e|0)!=4){break a}e=y[b+813|0];if(c){v[b+813|0]=e&240|c&15;break a}c=e&15;break a}if(c){v[b+813|0]=c;break a}c=y[b+813|0]}b:{if(!(v[b+851|0]&1)|!x[b+700>>2]){break b}c=c&255;if(!c){break b}mk(a,b,b+700|0,0-(c<<2)|0,0);if(x[b+700>>2]<65536){break b}Ab(d+8|0,a+1074312|0,7);if(zb(x[x[d+8>>2]>>2],x[d+12>>2])|(x[a+480180>>2]!=4?y[a+480208|0]&16:0)){break b}x[b+700>>2]=65535}ib=d+16|0}function fda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;g=ib-48|0;ib=g;e=x[a+36>>2];$f(x[x[e>>2]-12>>2]+e|0,0);f=x[b>>2];e=x[f+12>>2];h=x[f+8>>2];if(e|h){i=x[a+36>>2];e=x[a+20>>2]+e|0;f=x[a+16>>2];h=h+f|0;f=Nf(g+32|0,h,f>>>0>h>>>0?e+1|0:e);e=x[f+12>>2];x[g+8>>2]=x[f+8>>2];x[g+12>>2]=e;e=x[f+4>>2];x[g>>2]=x[f>>2];x[g+4>>2]=e;eh(i,g)}e=g+16|0;Pd(e,x[a+36>>2]);MN(c,x[a+36>>2],d);c=x[b>>2];b=Tk(e,Jb(x[a+40>>2],x[c>>2]),z[c+20>>1]);af(a,c);Zb(b);ib=g+48|0}
function Hl(a){var b=0,c=0;a:{b=x[a+4>>2];b=x[x[b>>2]-12>>2]+b|0;b:{if(!x[b+24>>2]){break b}if(!fh(b)|!(x[b+4>>2]&8192)){break b}if(qI()){break b}b=x[a+4>>2];b=x[(x[x[b>>2]-12>>2]+b|0)+24>>2];x[27524]=0;b=T(22,b|0)|0;c=x[27524];x[27524]=0;if((c|0)!=1){if((b|0)!=-1){break b}a=x[a+4>>2];b=x[x[a>>2]-12>>2];x[27524]=0;R(16,a+b|0,1);a=x[27524];x[27524]=0;if((a|0)!=1){break b}}_(V(0)|0)|0;x[27524]=0;Z(18);a=x[27524];x[27524]=0;if((a|0)==1){break a}}return}V(0)|0;Sb();p()}function Ef(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0;h=qoa(b,c,h,i);i=kb;j=h;h=qoa(d,e,f,g);e=j+h|0;d=kb+i|0;i=e;h=i>>>0<h>>>0?d+1|0:d;j=i;k=g;e=0;l=c;d=0;i=qoa(g,e,c,d);g=j+i|0;c=kb+h|0;j=g;g=g>>>0<i>>>0?c+1|0:c;h=f;i=b;f=qoa(h,0,i,0);b=kb;c=0;d=qoa(h,c,l,d);b=b+d|0;c=kb+c|0;c=b>>>0<d>>>0?c+1|0:c;h=c;c=c+j|0;d=g;d=c>>>0<h>>>0?d+1|0:d;h=c;c=d;d=qoa(i,m,k,e)+b|0;e=kb;e=b>>>0>d>>>0?e+1|0:e;g=a;i=e;h=i+h|0;x[g+8>>2]=h;x[g+12>>2]=h>>>0<i>>>0?c+1|0:c;x[g>>2]=f;x[g+4>>2]=d}function hda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;g=ib-48|0;ib=g;e=x[a+36>>2];$f(x[x[e>>2]-12>>2]+e|0,0);f=x[b>>2];e=x[f+12>>2];h=x[f+8>>2];if(e|h){i=x[a+36>>2];e=x[a+20>>2]+e|0;f=x[a+16>>2];h=h+f|0;f=Nf(g+32|0,h,f>>>0>h>>>0?e+1|0:e);e=x[f+12>>2];x[g+8>>2]=x[f+8>>2];x[g+12>>2]=e;e=x[f+4>>2];x[g>>2]=x[f>>2];x[g+4>>2]=e;eh(i,g)}e=g+16|0;Pd(e,x[a+36>>2]);PN(d,x[a+36>>2],c);c=x[b>>2];b=Tk(e,Jb(x[a+40>>2],x[c>>2]),z[c+20>>1]);af(a,c);Zb(b);ib=g+48|0}function vz(a,b,c){var d=0,e=0;d=ib-16|0;ib=d;e=x[a+480180>>2];a:{if((e|0)!=1048576){if((e|0)!=4){break a}e=y[b+814|0];if(c){v[b+814|0]=e&240|c&15;break a}c=e&15;break a}if(c){v[b+813|0]=c;break a}c=y[b+813|0]}b:{if(!(v[b+851|0]&1)|!x[b+700>>2]){break b}c=c&255;if(!c){break b}mk(a,b,b+700|0,0-c|0,0);if(x[b+700>>2]<65536){break b}Ab(d+8|0,a+1074312|0,7);if(zb(x[x[d+8>>2]>>2],x[d+12>>2])|(x[a+480180>>2]!=4?y[a+480208|0]&16:0)){break b}x[b+700>>2]=65535}ib=d+16|0}function Mca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=Ai(a,b,c,d);x[a>>2]=44108;b=Nb(a+4208|0);x[a+4236>>2]=-1;x[a+4240>>2]=0;x[a+4228>>2]=1049926264;x[a+4232>>2]=0;x[a+4220>>2]=1056964608;x[a+4224>>2]=1056964608;v[a+4244|0]=0;Rb(a+4248|0,0,48);x[27524]=0;Z(816);c=x[27524];x[27524]=0;a:{if((c|0)==1){break a}e=a,f=cP(),x[e+4296>>2]=f;et(a);dt(a);x[27524]=0;R(903,a+44|0,2);c=x[27524];x[27524]=0;if((c|0)==1){break a}return a|0}c=P()|0;ec(b);Rf(a);S(c|0);p()}function dv(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;i=ib-16|0;ib=i;a:{b:{if(!a){break b}g=x[e+12>>2];h=c-b|0;if((h|0)>0){if((Co(a,b,h)|0)!=(h|0)){break b}}b=d-b|0;b=(b|0)<(g|0)?g-b|0:0;if((b|0)>0){f=wf(i,b,f);g=vc(f);x[27524]=0;g=W(23,a|0,g|0,b|0)|0;h=x[27524];x[27524]=0;if((h|0)==1){break a}wb(f);if((b|0)!=(g|0)){break b}}b=d-c|0;if((b|0)>0){if((Co(a,c,b)|0)!=(b|0)){break b}}Tq(e);j=a}ib=i+16|0;return j|0}a=P()|0;wb(f);S(a|0);p()}function at(a,b,c){var d=0,e=0;d=(c|0)!=0;a:{b:{c:{if(!(a&3)|!c){break c}e=b&255;while(1){if((e|0)==y[a|0]){break b}c=c-1|0;d=(c|0)!=0;a=a+1|0;if(!(a&3)){break c}if(c){continue}break}}if(!d){break a}if(!(y[a|0]==(b&255)|c>>>0<4)){d=D(b&255,16843009);while(1){e=d^x[a>>2];if((e^-1)&e-16843009&-2139062144){break b}a=a+4|0;c=c-4|0;if(c>>>0>3){continue}break}}if(!c){break a}}b=b&255;while(1){if((b|0)==y[a|0]){return a}a=a+1|0;c=c-1|0;if(c){continue}break}}return 0}function hH(a,b,c,d){var e=0,f=0,g=0,h=0;e=ib-16|0;ib=e;a:{b:{if((a|0)!=(b|0)){c:{d:{f=y[a|0];if((f|0)!=45){break d}a=a+1|0;if((b|0)!=(a|0)){break d}break c}h=x[12e4];x[12e4]=0;Fd();a=Ww(a,e+12|0,d);d=kb;g=x[12e4];e:{if(g){if(x[e+12>>2]!=(b|0)){break c}if(!d&a>>>0>65535|d|(g|0)==68){break e}break b}x[12e4]=h;if((b|0)!=x[e+12>>2]){break c}if(!d&a>>>0<65536){break b}}x[c>>2]=4;a=65535;break a}}x[c>>2]=4;a=0;break a}a=(f|0)==45?0-a|0:a}ib=e+16|0;return a&65535}function dF(a,b,c,d){var e=0,f=0,g=0;f=ib-32|0;ib=f;e=wf(f+16|0,1,0);a:{b:{while(1){g=vc(e);hK(f+8|0,g,Eb(e)+g|0,x[b>>2],c);if(!x[f+12>>2]){break b}g=Og(Eb(e));x[27524]=0;R(59,e|0,g|0);g=x[27524];x[27524]=0;if((g|0)!=1){continue}break}break a}b=x[f+8>>2];c=vc(e);x[27524]=0;R(60,e|0,b-c|0);b=x[27524];x[27524]=0;c:{if((b|0)!=1){x[27524]=0;R(d|0,a|0,e|0);a=x[27524];x[27524]=0;if((a|0)!=1){break c}break a}break a}wb(e);ib=f+32|0;return}a=P()|0;wb(e);S(a|0);p()}function cF(a,b,c,d){var e=0,f=0,g=0;f=ib-32|0;ib=f;e=wf(f+16|0,1,0);a:{b:{while(1){g=vc(e);_J(f+8|0,g,Eb(e)+g|0,x[b>>2],c);if(!x[f+12>>2]){break b}g=Og(Eb(e));x[27524]=0;R(59,e|0,g|0);g=x[27524];x[27524]=0;if((g|0)!=1){continue}break}break a}b=x[f+8>>2];c=vc(e);x[27524]=0;R(60,e|0,b-c|0);b=x[27524];x[27524]=0;c:{if((b|0)!=1){x[27524]=0;R(d|0,a|0,e|0);a=x[27524];x[27524]=0;if((a|0)!=1){break c}break a}break a}wb(e);ib=f+32|0;return}a=P()|0;wb(e);S(a|0);p()}function YN(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=x[a>>2];c=tc(d,x[a+4>>2]);if(c>>>0<=127){f=ib-32|0;ib=f;c=128-c|0;e=x[Db(a)>>2];d=x[a+4>>2];a:{if(c>>>0<=e-d>>2>>>0){Cy(a,c,b);break a}e=Db(a);d=cg(f+8|0,wg(a,tc(x[a>>2],d)+c|0),tc(x[a>>2],x[a+4>>2]),e);g=ib-16|0;ib=g;c=Ym(g,d+8|0,c);e=x[c>>2];while(1){if(x[c+4>>2]!=(e|0)){lk(e,B[b>>2]);e=x[c>>2]+4|0;x[c>>2]=e;continue}break}Vd(c);ib=g+16|0;Dd(a,d);bg(d)}ib=f+32|0;return}if((c|0)!=128){Od(a,d+512|0)}}function PF(a,b,c,d,e,f,g,h){var i=0,j=0;i=ib-16|0;ib=i;x[27524]=0;Y(958,a|0);j=x[27524];x[27524]=0;a:{b:{if((j|0)!=1){c:{j=x[a+24>>2];x[27524]=0;ia(h|0,i|0,j|0,b|0,c|0,d|0,e|0,(f|0)!=0|0);b=x[27524];x[27524]=0;if((b|0)==1){break c}b=mg(Jc(i));wb(i);break b}}_(V(0)|0)|0;b=0;x[27524]=0;X(945,g|0,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)==1){break a}$()}ib=i+16|0;return b}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function iF(a,b,c,d,e,f){var g=0;a:{g=ib-48|0;ib=g;qn(g+8|0,c);x[27524]=0;c=g+20|0;R(f|0,c|0,d|0);d=x[27524];x[27524]=0;b:{c:{d:{if((d|0)==1){break d}x[27524]=0;c=g+32|0;R(117,c|0,e|0);d=x[27524];x[27524]=0;if((d|0)==1){break d}gw(g,g+8|0);x[27524]=0;X(118,a|0,b|0,x[g>>2],x[g+4>>2]);a=x[27524];x[27524]=0;if((a|0)==1){break c}Er(g+8|0);ib=g+48|0;break a}a=P()|0;while(1){c=xb(c-12|0);if((c|0)!=(g+8|0)){continue}break}break b}a=P()|0;Er(g+8|0)}S(a|0);p()}}function R4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=ib-16|0;ib=d;a:{g=x[c+12>>2];if(!g){break a}e=Nk(d,c+16|0);f=Ik(x[b+4>>2],y[b+11|0]);h=f-1|0;c=0;while(1){if((c|0)==(f|0)){xb(e);break a}b:{c:{if(!c|(c>>>0)%(g>>>0)){break c}if((c|0)==(h|0)){if(y[nd(b)|0]==43){break c}if(y[nd(b)|0]==45){break c}}x[27524]=0;W(84,b|0,f-c|0,e|0)|0;i=x[27524];x[27524]=0;if((i|0)==1){break b}}c=c+1|0;continue}break}a=P()|0;xb(e);S(a|0);p()}$c(a,b);ib=d+16|0}function U3(){var a=0,b=0,c=0,d=0,e=0,f=0;c=ib-48|0;ib=c;if(FI(0,c+24|0)){xs(x[12e4],12638);p()}a=Oe(c+8|0,c+24|0);f=jz(c,x[c+32>>2]/1e3|0);b=ib-32|0;ib=b;a=tt(b+8|0,a);e=x[a>>2];d=x[a+4>>2];a=x[f+4>>2];x[b>>2]=x[f>>2];x[b+4>>2]=a;d=x[b+4>>2]+d|0;a=x[b>>2];e=e+a|0;x[b+16>>2]=e;x[b+20>>2]=a>>>0>e>>>0?d+1|0:d;a=Oe(b+24|0,b+16|0);d=x[a+4>>2];a=x[a>>2];ib=b+32|0;x[c+16>>2]=a;x[c+20>>2]=d;b=Oe(c+40|0,c+16|0);a=x[b+4>>2];b=x[b>>2];ib=c+48|0;kb=a;return b|0}function pQ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=ib-16|0;ib=d;j=d,k=Ej(b),x[j>>2]=k;c=ib-16|0;ib=c;g=pz(a,c+12|0,y[b|0],x[b+4>>2]);b=x[g>>2];if(!b){e=ib-16|0;ib=e;b=gc(a);h=sh(c,mc(28),th(e+8|0,b));b=x[h>>2];f=x[d>>2];i=x[f+4>>2];f=x[f>>2];x[b+24>>2]=0;x[b+16>>2]=f;x[b+20>>2]=i;j=gc(h),k=1,v[j+4|0]=k;ib=e+16|0;Tg(a,x[c+12>>2],g,x[c>>2]);b=ce(c);zk(c);e=1}Sg(d+8|0,x[Wb(c,b)>>2],e);ib=c+16|0;a=ud(x[d+8>>2]);ib=d+16|0;return a+8|0}function ila(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=Cb(x[b>>2]);h=Cb(x[b+4>>2]);g=ib-16|0;ib=g;x[g+8>>2]=d;while(1){a:{if(!Mb(d,h)){break a}e=ib-16|0;ib=e;f=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);v[e+8|0]=f;v[e+9|0]=f>>>8;v[e+10|0]=f>>>16;v[e+11|0]=f>>>24;f=y[d+4|0]|y[d+5|0]<<8;v[e+12|0]=f;v[e+13|0]=f>>>8;ib=e+16|0;if(z[e+8>>1]==(c|0)){break a}d=x[Qm(g+8|0)>>2];continue}break}ib=g+16|0;if(pc(d,Cb(x[b+4>>2]))){Oh(a);return}Eo(a,d)}function OF(a,b,c,d,e,f,g){var h=0,i=0;h=ib-16|0;ib=h;x[27524]=0;Y(958,a|0);i=x[27524];x[27524]=0;a:{b:{if((i|0)!=1){c:{i=x[x[a+24>>2]+24>>2];x[27524]=0;ma(g|0,h|0,i|0,b|0,c|0,d|0,e|0);b=x[27524];x[27524]=0;if((b|0)==1){break c}b=mg(Jc(h));wb(h);break b}}_(V(0)|0)|0;b=0;x[27524]=0;X(945,f|0,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)==1){break a}$()}ib=h+16|0;return b}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function zia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ib+-64|0;ib=c;Fm(c+48|0,b);he(c+16|0,x[c+48>>2],x[c+52>>2]);b=Id(c+8|0);x[27524]=0;d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;b=Mg(170,c+24|0,x[c+16>>2],x[c+20>>2],c);d=x[27524];x[27524]=0;a:{if((d|0)!=1){d=Nb(a);a=x[c+52>>2];e=x[c+48>>2];x[27524]=0;U(709,b|0,d|0,cd(e,a)>>>5|0);a=x[27524];x[27524]=0;if((a|0)==1){a=P()|0;Li(d);yb(b);break a}yb(b);ec(c+48|0);ib=c- -64|0;return}a=P()|0}ec(c+48|0);S(a|0);p()}function wia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ib+-64|0;ib=c;Fm(c+48|0,b);he(c+16|0,x[c+48>>2],x[c+52>>2]);b=Id(c+8|0);x[27524]=0;d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;b=Mg(170,c+24|0,x[c+16>>2],x[c+20>>2],c);d=x[27524];x[27524]=0;a:{if((d|0)!=1){d=Nb(a);a=x[c+52>>2];e=x[c+48>>2];x[27524]=0;U(710,b|0,d|0,cd(e,a)>>>2|0);a=x[27524];x[27524]=0;if((a|0)==1){a=P()|0;uc(d);yb(b);break a}yb(b);ec(c+48|0);ib=c- -64|0;return}a=P()|0}ec(c+48|0);S(a|0);p()}function via(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ib+-64|0;ib=c;Fm(c+48|0,b);he(c+16|0,x[c+48>>2],x[c+52>>2]);b=Id(c+8|0);x[27524]=0;d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;b=Mg(170,c+24|0,x[c+16>>2],x[c+20>>2],c);d=x[27524];x[27524]=0;a:{if((d|0)!=1){d=Nb(a);a=x[c+52>>2];e=x[c+48>>2];x[27524]=0;U(711,b|0,d|0,cd(e,a)>>>8|0);a=x[27524];x[27524]=0;if((a|0)==1){a=P()|0;fu(d);yb(b);break a}yb(b);ec(c+48|0);ib=c- -64|0;return}a=P()|0}ec(c+48|0);S(a|0);p()}function uia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ib+-64|0;ib=c;Fm(c+48|0,b);he(c+16|0,x[c+48>>2],x[c+52>>2]);b=Id(c+8|0);x[27524]=0;d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;b=Mg(170,c+24|0,x[c+16>>2],x[c+20>>2],c);d=x[27524];x[27524]=0;a:{if((d|0)!=1){d=Nb(a);a=x[c+52>>2];e=x[c+48>>2];x[27524]=0;U(712,b|0,d|0,cd(e,a)>>>4|0);a=x[27524];x[27524]=0;if((a|0)==1){a=P()|0;Gm(d);yb(b);break a}yb(b);ec(c+48|0);ib=c- -64|0;return}a=P()|0}ec(c+48|0);S(a|0);p()}function mha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=ib-16|0;ib=b;g=x[a+24>>2];h=x[a+20>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+8>>2];k=x[a+12>>2];while(1){if(d){f=x[b+12>>2]+i|0;e=v[f|0];e=((D(v[f+1|0]-e|0,x[b+8>>2]>>>10&4194048)|0)/16384|0)+(e<<8)|0;x[c>>2]=x[c>>2]+D(e,h);x[c+4>>2]=x[c+4>>2]+D(e,g);Pb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;ib=b+16|0}function pY(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=ib-16|0;ib=d;a:{b:{if(!kg(a,7)){break b}c=0;if(!RC(a,17804)){break a}if(!kg(a,1)){break b}c=-1;if(!gd(a,_q(a))){break a}c=ib-16|0;ib=c;f=d+8|0;Lo(c+8|0,f);e=x[c+12>>2];ld(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(e|0)){gd(a,x[c+12>>2])}ib=c+16|0;e=(e|0)==(g|0);if(!e){jv(f)}c=-1;if(!e){break a}c=0;if(!EC(y[d+8|0],y[d+9|0])){break a}c=Ee(a,b,DC(d+8|0),kb);break a}c=-1}ib=d+16|0;return c|0}function w1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=ib-16|0;ib=f;d=Eb(a);e=ad(a);g=Xh(b,c);a:{if(!g){break a}b:{if(!jt(a,b)){if(e-d>>>0<g>>>0){tm(a,e,(d+g|0)-e|0,d,d,0,0)}e=vc(a)+d|0;while(1){if((b|0)==(c|0)){break b}oe(e,b);b=b+1|0;e=e+1|0;continue}}b=Zh(f,b,c);c=Jc(b);d=Eb(b);x[27524]=0;W(1089,a|0,c|0,d|0)|0;c=x[27524];x[27524]=0;if((c|0)!=1){wb(b);break a}a=P()|0;wb(b);S(a|0);p()}v[f+15|0]=0;oe(e,f+15|0);Wh(a,d+g|0)}ib=f+16|0;return a|0}function rea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=ib-16|0;ib=e;d=z[a+30>>1];if(d){b=zy(b<<16>>16,d<<16>>16)}w[e+14>>1]=b;a=a+52|0;a:{if(!yh(x[c+4>>2],y[c+11|0])){cp(UN(a,e+14|0),c);break a}b=Ay(a,e+14|0);if(!Rg(b,Gf(a))){break a}c=ib-16|0;ib=c;b=x[Wb(c,b)>>2];d=ib-16|0;ib=d;f=Ug(Wb(d+8|0,b));if((b|0)==x[a>>2]){x[a>>2]=x[f>>2]}g=Db(a);x[g>>2]=x[g>>2]-1;TN(x[gc(a)>>2],b);a=x[f>>2];ib=d+16|0;rB(ud(b));Ib(b);Wb(c+8|0,a);ib=c+16|0}ib=e+16|0}function eH(a,b,c,d){var e=0,f=0,g=0,h=0;e=ib-16|0;ib=e;a:{if((a|0)!=(b|0)){b:{c:{f=y[a|0];if((f|0)!=45){break c}a=a+1|0;if((b|0)!=(a|0)){break c}break b}h=x[12e4];x[12e4]=0;Fd();a=Ww(a,e+12|0,d);d=kb;d:{g=x[12e4];if(g){if(x[e+12>>2]!=(b|0)){break b}if((g|0)!=68){break d}x[c>>2]=4;b=-1;a=-1;break a}x[12e4]=h;if(x[e+12>>2]==(b|0)){break d}break b}c=(f|0)==45;b=c?0-a|0:a;a=c?0-(d+((a|0)!=0)|0)|0:d;break a}}x[c>>2]=4;b=0;a=0}ib=e+16|0;kb=a;return b}function R3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=ib-32|0;ib=e;x[e+16>>2]=b;d=x[a+48>>2];x[e+20>>2]=c-((d|0)!=0);f=x[a+44>>2];x[e+28>>2]=d;x[e+24>>2]=f;a:{b:{if(vx(db(x[a+60>>2],e+16|0,2,e+12|0)|0)){b=32}else{d=x[e+12>>2];if((d|0)>0){break b}b=d?32:16}x[a>>2]=b|x[a>>2];break a}g=d;f=x[e+20>>2];if(f>>>0>=d>>>0){break a}d=x[a+44>>2];x[a+4>>2]=d;x[a+8>>2]=d+(g-f|0);if(x[a+48>>2]){x[a+4>>2]=d+1;v[(b+c|0)-1|0]=y[d|0]}g=c}ib=e+32|0;return g|0}function lha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=ib-16|0;ib=b;g=x[a+24>>2];h=x[a+20>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+8>>2];k=x[a+12>>2];while(1){if(d){f=(x[b+12>>2]<<1)+i|0;e=w[f>>1];e=e+((D(w[f+2>>1]-e|0,x[b+8>>2]>>>18|0)|0)/16384|0)|0;x[c>>2]=x[c>>2]+D(e,h);x[c+4>>2]=x[c+4>>2]+D(e,g);Pb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;ib=b+16|0}function eja(a,b){a=a|0;b=b|0;var c=0,d=0;d=ib-32|0;ib=d;md(b,0);QB(d,a+1|0);c=d+16|0;Fc(c,d);Fe(b+43|0,c);wb(c);x[b+24>>2]=y[a+78|0]|y[a+79|0]<<8;c=y[a+58|0]|y[a+59|0]<<8|(y[a+60|0]<<16|y[a+61|0]<<24);x[b>>2]=c;x[b+4>>2]=y[a+62|0]|y[a+63|0]<<8|(y[a+64|0]<<16|y[a+65|0]<<24);x[b+8>>2]=y[a+66|0]|y[a+67|0]<<8|(y[a+68|0]<<16|y[a+69|0]<<24);w[b+30>>1]=(y[a+73|0]<<1)+2;w[b+34>>1]=z[b+34>>1]&65533|y[a|0]>>>6&2;wc(b+8|0,c);wc(b+4|0,x[b+8>>2]);ib=d+32|0}function aD(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=x[a>>2];c=Oc(d,x[a+4>>2]);if(c>>>0<b>>>0){e=ib-32|0;ib=e;b=b-c|0;c=x[Db(a)>>2];d=x[a+4>>2];a:{if(b>>>0<=c-d>>1>>>0){UC(a,b);break a}c=Db(a);c=Uj(e+8|0,Vj(a,Oc(x[a>>2],d)+b|0),Oc(x[a>>2],x[a+4>>2]),c);f=ib-16|0;ib=f;b=Uo(f,c+8|0,b);d=x[b>>2];while(1){if(x[b+4>>2]!=(d|0)){Nv(d);d=x[b>>2]+2|0;x[b>>2]=d;continue}break}Vd(b);ib=f+16|0;Dd(a,c);Ui(c)}ib=e+32|0;return}if(b>>>0<c>>>0){Od(a,d+(b<<1)|0)}}function nc(a,b){var c=0,d=0,e=0;c=x[a+1396>>2];if((c|0)>=0){a:{b:{if((b|0)<=(c|0)){break b}if((b|0)>24){return nc(a,24)+(nc(a,b-24|0)<<24)|0}if(!c){x[a+1392>>2]=0}while(1){if((b|0)<=(c|0)){break b}c=-1;e=Ds(a);d=0;if((e|0)==-1){break a}d=x[a+1396>>2];c=d+8|0;x[a+1396>>2]=c;x[a+1392>>2]=x[a+1392>>2]+(e<<d);continue}}if((b|0)>(c|0)){aa(10015,13154,1632,6833);p()}d=x[a+1392>>2];x[a+1392>>2]=d>>>b;c=c-b|0;d=d&(-1<<b^-1)}x[a+1396>>2]=c}return d}function mg(a){var b=0,c=0,d=0;d=tq(xf(a)+1|0,1);if(d){a:{c=d;b:{if((c^a)&3){b=y[a|0];break b}if(a&3){while(1){b=y[a|0];v[c|0]=b;if(!b){break a}c=c+1|0;a=a+1|0;if(a&3){continue}break}}b=x[a>>2];if((b^-1)&b-16843009&-2139062144){break b}while(1){x[c>>2]=b;b=x[a+4>>2];c=c+4|0;a=a+4|0;if(!(b-16843009&(b^-1)&-2139062144)){continue}break}}v[c|0]=b;if(!(b&255)){break a}while(1){b=y[a+1|0];v[c+1|0]=b;c=c+1|0;a=a+1|0;if(b){continue}break}}}return d}function b_(a,b){a=a|0;b=b|0;var c=0;a=Kb(a);a:{if(y[b+16|0]){x[27524]=0;Q(137,a|0,4948)|0;c=x[27524];x[27524]=0;if((c|0)==1){break a}}if(y[b+17|0]){x[27524]=0;Q(137,a|0,12504)|0;c=x[27524];x[27524]=0;if((c|0)==1){break a}}if(yh(x[a+4>>2],y[a+11|0])){x[27524]=0;Q(137,a|0,10005)|0;c=x[27524];x[27524]=0;if((c|0)==1){break a}}if(y[b+18|0]){x[27524]=0;Q(137,a|0,11041)|0;b=x[27524];x[27524]=0;if((b|0)==1){break a}}return}b=P()|0;xb(a);S(b|0);p()}function Zs(a){var b=0,c=0,d=0,e=0;a:{while(1){if(!a){b=0;if(x[27394]){b=Zs(x[27394])}if(!x[27320]){break a}c=b|c;a=x[27320];continue}break}d=x[a+76>>2]>=0;b:{c:{if(x[a+20>>2]==x[a+28>>2]){break c}lb[x[a+36>>2]](a,0,0)|0;if(x[a+20>>2]){break c}b=-1;if(d){break b}break a}b=x[a+8>>2];e=x[a+4>>2];if((b|0)!=(e|0)){b=e-b|0;lb[x[a+40>>2]](a,b,b>>31,1)|0}b=0;x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;if(!d){break a}}}return b|c}function Qk(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=ib-16|0;ib=e;x[b>>2]=0;x[b+4>>2]=0;v[e+15|0]=0;Sh(a,e+15|0);c=y[e+15|0];f=(c&252)>>>2|0;i=-1<<(c&3)^-1;while(1){x[b>>2]=f;x[b+4>>2]=d;if(!g&(h|0)==(i|0)){ib=e+16|0}else{v[e+15|0]=0;Sh(a,e+15|0);c=x[b>>2];j=x[b+4>>2];f=y[e+15|0];d=g;g=h+1|0;d=g?d:d+1|0;h=g;g=d;k=c;d=(h<<3)-2|0;c=d&31;if((d&63)>>>0>=32){d=f<<c;c=0}else{d=(1<<c)-1&f>>>32-c;c=f<<c}f=k|c;d=d|j;continue}break}}function uD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;a:{d=ib-16|0;ib=d;b:{c:{if(!b){b=Jc(c);e=b;f=Eb(c)+b|0;c=Xh(b,f);if(c>>>0<4294967280){d:{if(Dl(c)){ee(a,c);break d}g=Wg(c)+1|0;b=mc(g);td(a,b);hf(a,g);vd(a,c);a=b}while(1){if((e|0)!=(f|0)){ne(a,y[e|0]);a=a+1|0;e=e+1|0;continue}break}ne(a,0);break c}of();p()}jR(d,b,c);x[27524]=0;R(50,a|0,d|0);a=x[27524];x[27524]=0;if((a|0)==1){break b}Gc(d)}ib=d+16|0;break a}a=P()|0;Gc(d);S(a|0);p()}}function oO(a,b,c,d,e,f,g,h){var i=0,j=0;i=ib-16|0;ib=i;x[i+12>>2]=d;a:{if(!(y[a+12|0]|y[a+13|0]<<8|(y[a+14|0]<<16|y[a+15|0]<<24))){break a}x[i+8>>2]=y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24);j=b;b=x[Hb(i+8|0,i+12|0)>>2];x[j>>2]=b;b=Bd(y[a+12|0]|y[a+13|0]<<8|(y[a+14|0]<<16|y[a+15|0]<<24),b,d);x[c>>2]=((h^1)&b>>>0<d>>>0)+b;b=z[e>>1]|f;w[e>>1]=b;if((y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24))!=1){break a}w[e>>1]=b|g}ib=i+16|0}function u6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=ib-16|0;ib=d;a:{g=x[c+12>>2];if(!g){break a}e=Pg(d,c+16|0);f=Eb(b);h=f-1|0;c=0;while(1){if((c|0)==(f|0)){wb(e);break a}b:{c:{if(!c|(c>>>0)%(g>>>0)){break c}if((c|0)==(h|0)){if(y[Qc(b,0)|0]==43){break c}if(y[Qc(b,0)|0]==45){break c}}x[27524]=0;W(77,b|0,f-c|0,e|0)|0;i=x[27524];x[27524]=0;if((i|0)==1){break b}}c=c+1|0;continue}break}a=P()|0;wb(e);S(a|0);p()}$c(a,b);ib=d+16|0}function Cda(a,b){a=a|0;b=b|0;var c=0,d=0;a:{x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);c=xk(x[b>>2],x[b+4>>2]);if(c){Hu(a,c);Fy(a,x[b>>2],x[b+4>>2],c)}x[a+20>>2]=x[b+20>>2];c=x[b+16>>2];x[a+12>>2]=x[b+12>>2];x[a+16>>2]=c;x[27524]=0;c=Q(884,a+24|0,b+24|0)|0;d=x[27524];x[27524]=0;b:{c:{if((d|0)!=1){x[27524]=0;Q(54,a+36|0,b+36|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break c}x[a+48>>2]=x[b+48>>2];break a}b=P()|0;break b}b=P()|0;uc(c)}Ck(a);S(b|0);p()}}function tx(a,b){a:{if(a){if(b>>>0<=127){break a}b:{if(!x[x[120026]>>2]){if((b&-128)==57216){break a}break b}if(b>>>0<=2047){v[a+1|0]=b&63|128;v[a|0]=b>>>6|192;return 2}if(!((b&-8192)!=57344&b>>>0>=55296)){v[a+2|0]=b&63|128;v[a|0]=b>>>12|224;v[a+1|0]=b>>>6&63|128;return 3}if(b-65536>>>0<=1048575){v[a+3|0]=b&63|128;v[a|0]=b>>>18|240;v[a+2|0]=b>>>6&63|128;v[a+1|0]=b>>>12&63|128;return 4}}x[12e4]=25;a=-1}else{a=1}return a}v[a|0]=b;return 1}function xia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=ib-4096|0;ib=c;Fm(a,b);a:while(1){if(cd(x[a>>2],x[a+4>>2])>>>12>>>0>f>>>0){g=f<<12;b=0;d=0;while(1)if((b|0)==2048){h=g|2048;b=0;while(1){e=x[a>>2];if((b|0)!=2048){e=Jb(e,b+h|0);i=Jb(c,b<<1);d=y[e|0]+d|0;v[i|0]=d;b=b+1|0;continue}break}wh(c,MS(c),Yf(Cb(e),g));f=f+1|0;continue a}else{e=Jb(x[a>>2],b+g|0);h=Jb(c,b<<1|1);d=y[e|0]+d|0;v[h|0]=d;b=b+1|0;continue}}break}ib=c+4096|0}function Yi(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=x[a>>2];c=cd(d,x[a+4>>2]);if(c>>>0<b>>>0){e=ib-32|0;ib=e;b=b-c|0;c=x[Db(a)>>2];d=x[a+4>>2];a:{if(b>>>0<=c-d>>>0){XE(a,b);break a}c=Db(a);c=am(e+8|0,Zl(a,cd(x[a>>2],d)+b|0),cd(x[a>>2],x[a+4>>2]),c);f=ib-16|0;ib=f;b=qw(f,c+8|0,b);d=x[b>>2];while(1){if(x[b+4>>2]!=(d|0)){WE(d);d=x[b>>2]+1|0;x[b>>2]=d;continue}break}Vd(b);ib=f+16|0;Dd(a,c);$l(c)}ib=e+32|0;return}if(b>>>0<c>>>0){Od(a,b+d|0)}}function _x(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;b=ib-48|0;ib=b;x[b+40>>2]=e;x[b+44>>2]=f;c=dc(b+32|0,c,d);d=x[c+4>>2];x[b+8>>2]=x[c>>2];x[b+12>>2]=d;a:{a=pt(a,b+8|0,b+40|0);if(a+1>>>0>=3){a=ba(8)|0;x[27524]=0;b=Q(55,b+16|0,8005)|0;c=x[27524];x[27524]=0;b:{if((c|0)!=1){lc(a,b);x[27524]=0;U(123,a|0,50060,962);a=x[27524];x[27524]=0;if((a|0)!=1){break a}c=P()|0;wb(b);break b}c=P()|0;ca(a|0)}S(c|0);p()}ib=b+48|0;return a|0}p()}function y0(a){a=a|0;if(y[483664]){return x[120915]}if(!y[484184]){a=484016;while(1){a=Kb(a)+12|0;if((a|0)!=484184){continue}break}v[484184]=1}pd(484016,104148);pd(484028,104176);pd(484040,104204);pd(484052,104236);pd(484064,104276);pd(484076,104312);pd(484088,104340);pd(484100,104376);pd(484112,104392);pd(484124,104408);pd(484136,104424);pd(484148,104440);pd(484160,104456);pd(484172,104472);v[483664]=1;x[120915]=484016;return 484016}function tma(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=ib-32|0;ib=g;a:{if(z[a+480192>>1]<b>>>0){break a}b=x[((b<<2)+a|0)+900380>>2];if(!b){break a}h=g+16|0;mW(h,b);i=g,j=Cb(x[g+16>>2]),x[i+8>>2]=j;h=eg(h);while(1){b=x[g+8>>2];if(Mb(b,h)){b=z[vo(b)>>1];if(b>>>0<=z[a+480190>>1]){b=D(b,104)+a|0;v[b+484421|0]=f;v[b+484418|0]=c;v[b+484420|0]=e;v[b+484419|0]=d}Ug(g+8|0);continue}else{Nu(g+16|0)}break}}ib=g+32|0}function bO(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=ib-16|0;ib=e;d=ad(a);a:{b:{c:{f=Xh(b,c);if(d>>>0<f>>>0){if(jt(a,b)){break c}g=d;h=f-d|0;d=Eb(a);tm(a,g,h,d,0,d,0)}d=vc(a);while(1){if((b|0)==(c|0)){break b}oe(d,b);b=b+1|0;d=d+1|0;continue}}b=Zh(e,b,c);c=Jc(b);d=Eb(b);x[27524]=0;U(57,a|0,c|0,d|0);c=x[27524];x[27524]=0;if((c|0)!=1){wb(b);break a}a=P()|0;wb(b);S(a|0);p()}v[e+15|0]=0;oe(d,e+15|0);Wh(a,f)}ib=e+16|0;return a|0}function P9(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;var f=0,g=0;x[27524]=0;Y(983,a|0);f=x[27524];x[27524]=0;a:{b:{if((f|0)!=1){f=x[a+28>>2];g=x[x[f>>2]+72>>2];x[27524]=0;b=Ta(g|0,f|0,b|0,c|0,+d,+e)|0;c=x[27524];x[27524]=0;if((c|0)!=1){break b}}_(V(0)|0)|0;x[27524]=0;X(945,11194,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function KQ(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=ib-16|0;ib=e;j=e,k=Ej(b),x[j>>2]=k;c=ib-16|0;ib=c;f=Sz(a,c+12|0,z[b>>1],x[b+4>>2]);b=x[f>>2];if(!b){b=ib-16|0;ib=b;d=gc(a);g=sh(c,mc(36),th(b+8|0,d));d=x[g>>2]+16|0;h=x[e>>2];i=x[h+4>>2];x[d>>2]=x[h>>2];x[d+4>>2]=i;Nb(d+8|0);j=gc(g),k=1,v[j+4|0]=k;ib=b+16|0;Tg(a,x[c+12>>2],f,x[c>>2]);b=ce(c);PQ(c);d=1}Sg(e+8|0,x[Wb(c,b)>>2],d);ib=c+16|0;a=ud(x[e+8>>2]);ib=e+16|0;return a+8|0}function pV(a,b){var c=0,d=0,e=0,f=0;d=x[a>>2];c=tc(d,x[a+4>>2]);if(c>>>0<b>>>0){e=ib-32|0;ib=e;b=b-c|0;c=x[Db(a)>>2];d=x[a+4>>2];a:{if(b>>>0<=c-d>>2>>>0){lB(a,b);break a}c=Db(a);c=cg(e+8|0,wg(a,tc(x[a>>2],d)+b|0),tc(x[a>>2],x[a+4>>2]),c);f=ib-16|0;ib=f;b=Ym(f,c+8|0,b);d=x[b>>2];while(1){if(x[b+4>>2]!=(d|0)){Ho(d);d=x[b>>2]+4|0;x[b>>2]=d;continue}break}Vd(b);ib=f+16|0;Dd(a,c);bg(c)}ib=e+32|0;return}if(b>>>0<c>>>0){Od(a,d+(b<<2)|0)}}function X9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=ib-32|0;ib=e;x[e+24>>2]=c;c=x[ge(e+16|0,e+24|0)>>2];x[27524]=0;f=x[b+12>>2];x[e+8>>2]=x[b+8>>2];x[e+12>>2]=f;f=x[b+4>>2];x[e>>2]=x[b>>2];x[e+4>>2]=f;fa(952,a+8|0,e|0,c|0,d|0)|0;b=x[27524];x[27524]=0;if((b|0)!=1){a=Xx(a);b=Wx(a+88|0);c=Vx(a+92|0);d=Ux(a+96|0);x[a>>2]=49340;x[b>>2]=49456;x[c>>2]=49536;x[d>>2]=49576;Xc(e+24|0);ib=e+32|0;return a|0}a=P()|0;Xc(e+24|0);S(a|0);p()}function kR(a,b,c,d,e){var f=0,g=0,h=0;h=-1;g=d&2147483647;f=(g|0)==2147418112;a:{if(f&!c?a|b:f&(c|0)!=0|g>>>0>2147418112){break a}f=e&2147483647;if(((f|0)==2147418112&0|f>>>0>2147418112)&(f|0)!=2147418112){break a}if(!(a|c|(f|g|b))){return 0}f=d&e;if((f|0)>0|(f|0)>=0){if(((c|0)!=0|(d|0)!=(e|0))&(d|0)<(e|0)){break a}return(a|c|(d^e|b))!=0}if(!c&(d|0)==(e|0)?a|b:(c|0)!=0&(d|0)>=(e|0)|(d|0)>(e|0)){break a}h=(a|c|(d^e|b))!=0}return h}function aF(a,b,c,d,e){var f=0,g=0,h=0;a:{f=ib-32|0;ib=f;h=Nb(a);b:{c:{d:{e:{while(1){a=x[b+8>>2];g=x[b>>2];x[27524]=0;a=W(160,g|0,a|0,8)|0;g=x[27524];x[27524]=0;if((g|0)==1){break c}if(!a){break d}x[27524]=0;U(e|0,f|0,b|0,c|0);a=x[27524];x[27524]=0;if((a|0)!=1){x[27524]=0;R(d|0,h|0,f|0);a=x[27524];x[27524]=0;if((a|0)==1){break e}yd(f);continue}break}a=P()|0;break b}a=P()|0;yd(f);break b}ib=f+32|0;break a}a=P()|0}Zd(h);S(a|0);p()}}function Cfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=x[a>>2];d=xg(e,x[a+4>>2]);if(d>>>0<b>>>0){e=ib-32|0;ib=e;a:{b:{d=b-d|0;b=x[Db(a)>>2];f=x[a+4>>2];c:{if(d>>>0<=b-f>>5>>>0){eA(a,d,c);break c}b=Db(a);b=Vt(e+8|0,oq(a,xg(x[a>>2],f)+d|0),xg(x[a>>2],x[a+4>>2]),b);x[27524]=0;U(763,b|0,d|0,c|0);c=x[27524];x[27524]=0;if((c|0)==1){break b}zR(a,b);cA(b)}ib=e+32|0;break a}a=P()|0;cA(b);S(a|0);p()}return}if(b>>>0<d>>>0){BR(a,e+(b<<5)|0)}}function iia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=ib-16|0;ib=c;d=Zc(c+8|0,16,1,1,0);x[c+4>>2]=0;md(a,0);yc(b);a:{b:{if(dr(b,13755)){bd(b,12);if(!Go(b)){Qo(d,2)}bd(b,24);break b}if(Lh(b,13627)){yc(b);x[c+4>>2]=4;e=1;break a}ne(d,8)}e=0}f=a,g=(jf(b)>>>0)/(D(y[d|0],Bq(y[d+1|0]))>>>3>>>0)|0,x[f>>2]=g;b=Eg(d,a,b);if(!(!b|!e)){d=x[a+20>>2];f=c,g=Nj(x[a>>2],z[a+34>>1]),x[f>>2]=g;Rb(d,0,x[Hb(c+4|0,c)>>2])}ib=c+16|0;return(b|0)!=0|0}function lp(a,b,c,d,e){var f=0,g=0,h=0;a:{f=ib-32|0;ib=f;h=Nb(a);b:{c:{d:{e:{while(1){a=x[b+8>>2];g=x[b>>2];x[27524]=0;a=W(160,g|0,a|0,e|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break c}if(!a){break d}x[27524]=0;R(d|0,f|0,b|0);a=x[27524];x[27524]=0;if((a|0)!=1){x[27524]=0;R(c|0,h|0,f|0);a=x[27524];x[27524]=0;if((a|0)==1){break e}yd(f);continue}break}a=P()|0;break b}a=P()|0;yd(f);break b}ib=f+32|0;break a}a=P()|0}Zd(h);S(a|0);p()}}function xka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);if(b){if(zh(178956970)>>>0<b>>>0){_c();p()}d=D(b,24);c=mc(d);x[a>>2]=c;x[a+4>>2]=c;g=Db(a),h=c+d|0,x[g>>2]=h;d=ib-16|0;ib=d;b=RE(d,a,b);c=x[b+4>>2];e=x[b+8>>2];a:{while(1){if((c|0)==(e|0)){break a}x[27524]=0;Y(582,c|0);f=x[27524];x[27524]=0;if((f|0)!=1){c=c+24|0;x[b+4>>2]=c;continue}break}a=P()|0;ic(b);S(a|0);p()}ic(b);ib=d+16|0}return a|0}function s4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=ib+-64|0;ib=e;f=x[b+292>>2];$f(x[x[f>>2]-12>>2]+f|0,0);f=e+48|0;Pd(f,x[b+292>>2]);a:{if(!gp(f,Nf(e+32|0,-1,-1))){b:{if(x[e+56>>2]!=(c|0)|x[e+60>>2]){break b}break a}}f=x[b+292>>2];c=Nf(e+16|0,c,0);g=x[c+12>>2];x[e+8>>2]=x[c+8>>2];x[e+12>>2]=g;g=x[c+4>>2];x[e>>2]=x[c>>2];x[e+4>>2]=g;eh(f,e)}c=x[d>>2];ri(x[b+292>>2],c,x[d+4>>2]);cc(a,c,x[x[b+292>>2]+4>>2]);ib=e- -64|0}function fX(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=x[a+1064>>2];a:{while(1){if((b|0)>255){break a}f=(D(b,6)+a|0)+1072|0,g=Ok(a,7),v[f|0]=g;d=Ok(a,1);e=Ok(a,1);c=x[a+1060>>2];if((c|0)>255){break a}b=x[a+1064>>2]+1|0;x[a+1060>>2]=b;x[a+1064>>2]=b;b:{if(d){w[(D(c,6)+a|0)+1068>>1]=b;fX(a);b=x[a+1064>>2];break b}w[(D(c,6)+a|0)+1068>>1]=65535}x[a+1060>>2]=b;if(e){w[(D(c,6)+a|0)+1070>>1]=b;continue}break}w[(D(c,6)+a|0)+1070>>1]=65535}}function fG(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0;i=ib-16|0;ib=i;if(1073741806-b>>>0>=c>>>0){j=vc(a);k=1073741807;if(b>>>0<=536870886){x[i+8>>2]=b<<1;x[i+12>>2]=b+c;k=fm(x[Yc(i+12|0,i+8|0)>>2])+1|0}c=Ii(k);if(e){ui(c,j,e)}if(g){ui(c+(e<<2)|0,h,g)}l=e+f|0;h=d-l|0;if((d|0)!=(l|0)){d=e<<2;ui((d+c|0)+(g<<2)|0,(d+j|0)+(f<<2)|0,h)}if((b|0)!=1){Ib(j)}td(a,c);hf(a,k);b=a;a=h+(e+g|0)|0;vd(b,a);td(c+(a<<2)|0,0);ib=i+16|0;return}of();p()}function P3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=ib-16|0;ib=e;while(1){a:{if((c|0)<=(f|0)){break a}g=x[a+16>>2];d=x[a+12>>2];b:{if(g>>>0>d>>>0){x[e+12>>2]=2147483647;x[e+8>>2]=g-d;x[e+4>>2]=c-f;g=d;d=x[rd(e+12|0,rd(e+8|0,e+4|0))>>2];b=Ae(b,g,d);x[a+12>>2]=x[a+12>>2]+d;b=b+d|0;break b}d=lb[x[x[a>>2]+40>>2]](a)|0;if((d|0)==-1){break a}h=b,i=zp(d),v[h|0]=i;d=1;b=b+1|0}f=d+f|0;continue}break}ib=e+16|0;return f|0}function dr(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ib-32|0;ib=c;a:{if(!y[b+7|0]){while(1){if((d|0)==7){d=0;v[c+27|0]=0;v[c+28|0]=0;v[c+29|0]=0;v[c+30|0]=0;x[c+24>>2]=0;e=dc(c+8|0,c+24|0,7);kc(c+16|0,x[a>>2],x[a+8>>2],x[e>>2],x[e+4>>2]);b:{if(x[c+20>>2]!=7){break b}if(Qb(c+24|0,b,7)){break b}Yb(a,7);d=1}ib=c+32|0;break a}e=b+d|0;d=d+1|0;if(y[e|0]){continue}break}aa(17442,9027,414,13118);p()}aa(17421,9027,412,13118);p()}return d|0}function S9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;x[27524]=0;Y(983,a|0);e=x[27524];x[27524]=0;a:{b:{if((e|0)!=1){e=x[a+28>>2];f=x[x[e>>2]+12>>2];x[27524]=0;b=fa(f|0,e|0,b|0,c|0,d|0)|0;c=x[27524];x[27524]=0;if((c|0)!=1){break b}}_(V(0)|0)|0;x[27524]=0;X(945,11339,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function dT(a){var b=0,c=0,d=0;b=ib-16|0;ib=b;x[b+4>>2]=((y[a+48|0]|y[a+49|0]<<8)<<1)+((y[a+32|0]|y[a+33|0]<<8)<<4);x[b+8>>2]=((y[a+50|0]|y[a+51|0]<<8)<<1)+((y[a+34|0]|y[a+35|0]<<8)<<4);x[b+12>>2]=(D(y[a+52|0]|y[a+53|0]<<8,5)+((y[a+36|0]|y[a+37|0]<<8)<<4)|0)+32;a=b+4|0;d=Bb(a,3);a:{if((a|0)==(d|0)){break a}c=a;while(1){c=c+4|0;if((d|0)==(c|0)){break a}a=tp(x[a>>2],x[c>>2])?c:a;continue}}ib=b+16|0;a=x[a>>2];kb=a>>31;return a}function Ys(a,b){var c=0,d=0,e=0,f=0,g=0;e=ib-16|0;ib=e;c=Td(a);d=gc(a);f=ib-16|0;ib=f;while(1){if(c){g=Jt(c+16|0,b);d=g?d:c;c=x[(g?c+4|0:c)>>2];continue}break}c=x[Wb(f+8|0,d)>>2];ib=f+16|0;a:{if(Mb(c,eg(a))){if(!Jt(b,ud(c))){break a}}c=eg(a)}if(!pc(c,eg(a))){b=x[Wb(e+8|0,c)>>2];c=ib-16|0;ib=c;d=Ug(Wb(c+8|0,b));if((b|0)==x[a>>2]){x[a>>2]=x[d>>2]}d=Db(a);x[d>>2]=x[d>>2]-1;TN(x[gc(a)>>2],b);ib=c+16|0;Am(ud(b));Ib(b)}ib=e+16|0}function R9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;x[27524]=0;Y(983,a|0);e=x[27524];x[27524]=0;a:{b:{if((e|0)!=1){e=x[a+28>>2];f=x[x[e>>2]+8>>2];x[27524]=0;b=fa(f|0,e|0,b|0,c|0,d|0)|0;c=x[27524];x[27524]=0;if((c|0)!=1){break b}}_(V(0)|0)|0;x[27524]=0;X(945,11375,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function Bha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=ib-16|0;ib=b;i=x[a+16>>2];f=ag(1,2);g=kb;Pb(a,f,g);j=x[a+24>>2];k=x[a+20>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;e=x[a+8>>2];l=x[a+12>>2];while(1){if(d){h=w[(x[b+12>>2]<<1)+i>>1];x[c>>2]=x[c>>2]+D(h,k);x[c+4>>2]=x[c+4>>2]+D(j,h);Pb(b+8|0,e,l);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;sg(a,f,g);ib=b+16|0}function J4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;e=Tl(a);x[e>>2]=76492;d=zc(e);a=ib-16|0;ib=a;c=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=c;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;b=ib-16|0;ib=b;c=x[a+12>>2];x[b+8>>2]=x[a+8>>2];x[b+12>>2]=c;c=x[a+4>>2];x[b>>2]=x[a>>2];x[b+4>>2]=c;d=kJ(d,lJ(b));x[d>>2]=76656;c=x[a+4>>2];x[d+24>>2]=x[a>>2];x[d+28>>2]=c;c=x[a+12>>2];x[d+32>>2]=x[a+8>>2];x[d+36>>2]=c;ib=b+16|0;ib=a+16|0;return e|0}function fK(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=ib-16|0;ib=g;x[g+8>>2]=b;j=g,k=ke(a),x[j>>2]=k;b=Rn(g+8|0,g);h=ib-16|0;ib=h;a:{f=Eb(a);if(b>>>0<=f>>>0){if(c){e=ad(a);b:{if(e-f>>>0>=c>>>0){e=vc(a);if((b|0)==(f|0)){break b}i=b+e|0;ai(i+c|0,i,f-b|0);break b}tm(a,e,(c+f|0)-e|0,f,b,0,c);e=x[a>>2]}SB(b+e|0,c,d);b=c+f|0;Wh(a,b);v[h+15|0]=0;oe(b+e|0,h+15|0)}ib=h+16|0;break a}yk();p()}ke(a);ib=g+16|0}function fH(a,b,c,d){var e=0,f=0,g=0,h=0;e=ib-16|0;ib=e;a:{b:{if((a|0)!=(b|0)){c:{d:{f=y[a|0];if((f|0)!=45){break d}a=a+1|0;if((b|0)!=(a|0)){break d}break c}h=x[12e4];x[12e4]=0;Fd();a=Ww(a,e+12|0,d);d=kb;g=x[12e4];e:{if(g){if(x[e+12>>2]!=(b|0)){break c}if((g|0)==68|d){break e}break b}x[12e4]=h;if((b|0)!=x[e+12>>2]){break c}if(!d){break b}}x[c>>2]=4;a=-1;break a}}x[c>>2]=4;a=0;break a}a=(f|0)==45?0-a|0:a}ib=e+16|0;return a}function dla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=x[a>>2];c=Kf(d,x[a+4>>2]);if(c>>>0<b>>>0){d=ib-32|0;ib=d;a:{b:{c=b-c|0;b=x[Db(a)>>2];e=x[a+4>>2];c:{if(c>>>0<=(b-e|0)/20>>>0){YC(a,c);break c}b=Db(a);b=UB(d+8|0,VB(a,Kf(x[a>>2],e)+c|0),Kf(x[a>>2],x[a+4>>2]),b);x[27524]=0;R(510,b|0,c|0);c=x[27524];x[27524]=0;if((c|0)==1){break b}TB(a,b);Ru(b)}ib=d+32|0;break a}a=P()|0;Ru(b);S(a|0);p()}return}if(b>>>0<c>>>0){WC(a,d+D(b,20)|0)}}function kca(a,b){a=a|0;b=b|0;var c=0,d=0;d=ib-16|0;ib=d;c=ib-32|0;ib=c;wi(c,b);x[27524]=0;U(923,c+16|0,0,c|0);b=x[27524];x[27524]=0;a:{b:{c:{if((b|0)!=1){x[27524]=0;R(924,d|0,c+16|0);b=x[27524];x[27524]=0;if((b|0)==1){break c}Gc(c+16|0);wb(c);ib=c+32|0;break a}a=P()|0;break b}a=P()|0;Gc(c+16|0)}wb(c);S(a|0);p()}x[27524]=0;Q(921,a|0,d|0)|0;a=x[27524];x[27524]=0;if((a|0)!=1){xb(d);ib=d+16|0;return}a=P()|0;xb(d);S(a|0);p()}function T4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=ib-16|0;ib=e;x[e+4>>2]=1;g=e,h=mc(56),x[g+8>>2]=h;c=Tl(x[e+8>>2]);x[c>>2]=76992;f=zc(c);c=ib-16|0;ib=c;d=x[b+12>>2];x[c+8>>2]=x[b+8>>2];x[c+12>>2]=d;d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;d=rJ(f);x[d>>2]=77156;b=x[c+4>>2];x[d+24>>2]=x[c>>2];x[d+28>>2]=b;b=x[c+12>>2];x[d+32>>2]=x[c+8>>2];x[d+36>>2]=b;v[d+40|0]=0;ib=c+16|0;b=a;a=kn(e);jn(b,zc(a),a);Ul(e);ib=e+16|0}function N9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;x[27524]=0;Y(983,a|0);d=x[27524];x[27524]=0;e=1;a:{b:{if((d|0)!=1){d=x[a+28>>2];f=x[x[d>>2]+64>>2];x[27524]=0;U(f|0,d|0,b|0,(c|0)!=0|0);b=x[27524];x[27524]=0;if((b|0)!=1){break b}}_(V(0)|0)|0;x[27524]=0;X(945,6663,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function L9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;x[27524]=0;Y(983,a|0);d=x[27524];x[27524]=0;e=1;a:{b:{if((d|0)!=1){d=x[a+28>>2];f=x[x[d>>2]+56>>2];x[27524]=0;U(f|0,d|0,b|0,(c|0)!=0|0);b=x[27524];x[27524]=0;if((b|0)!=1){break b}}_(V(0)|0)|0;x[27524]=0;X(945,6717,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function Dg(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=ib-16|0;ib=d;w[d+12>>1]=65535;w[d+14>>1]=b;f=d+12|0;b=z[Tc(42988,d+14|0)>>1];e=x[a>>2];c=Oc(e,x[a+4>>2]);a:{if(b>>>0>c>>>0){e=ib-32|0;ib=e;b=b-c|0;c=x[Db(a)>>2];g=x[a+4>>2];b:{if(b>>>0<=c-g>>1>>>0){No(a,b,f);break b}c=Db(a);c=Uj(e+8|0,Vj(a,Oc(x[a>>2],g)+b|0),Oc(x[a>>2],x[a+4>>2]),c);mD(c,b,f);Dd(a,c);Ui(c)}ib=e+32|0;break a}if(b>>>0<c>>>0){Od(a,e+(b<<1)|0)}}ib=d+16|0}function Cha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=ib-16|0;ib=b;i=x[a+16>>2];f=ag(1,2);g=kb;Pb(a,f,g);j=x[a+24>>2];k=x[a+20>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;e=x[a+8>>2];l=x[a+12>>2];while(1){if(d){h=v[x[b+12>>2]+i|0]<<8;x[c>>2]=x[c>>2]+D(h,k);x[c+4>>2]=x[c+4>>2]+D(j,h);Pb(b+8|0,e,l);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;sg(a,f,g);ib=b+16|0}function ft(a){var b=0,c=0,d=0;b=y[a+4266|0];B[a+4236>>2]=E(b>>>0)*E(.00390625);B[a+4240>>2]=E(256-b|0)*E(.00390625);c=y[a+4267|0];b=y[a+4265|0];B[a+4244>>2]=E(D(c,b)|0)*E(152587890625e-16);d=c|-256;B[a+4256>>2]=E(D(d,b|-256)|0)*E(152587890625e-16);B[a+4252>>2]=E(D(b,d)|0)*E(152587890625e-16);B[a+4248>>2]=E(D(256-b|0,c)|0)*E(152587890625e-16);b=a;c=x[a+4232>>2];a=y[a+4264|0];x[b+4228>>2]=(D(c,(a?a:-89)&255)+250>>>0)/500}function M_(a,b,c,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0;x[27524]=0;m=a;a=0;a=UF(1054,m|a,b,c,d,a|e,f);b=x[27524];x[27524]=0;a:{b:{if((b|0)==1){_(V(0)|0)|0;x[27524]=0;ia(941,8791,g|0,h|0,i|0,j|0,k|0,l|0);a=x[27524];x[27524]=0;if((a|0)==1){break b}$();a=-255}break a}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}return a|0}function uL(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=ib-16|0;ib=h;a:{b:{c:{if(g?!f|(!d|!e):1){a=ba(8)|0;x[27524]=0;b=Q(55,h|0,8148)|0;c=x[27524];x[27524]=0;if((c|0)==1){break c}lc(a,b);x[27524]=0;U(123,a|0,50060,962);a=x[27524];x[27524]=0;if((a|0)!=1){break a}d=P()|0;wb(b);break b}il(a,b,4);c=Px(a,c,d,e,f,g);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);ib=h+16|0;return c|0}d=P()|0;ca(a|0)}S(d|0)}p()}function BL(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=ib-16|0;ib=h;a:{b:{c:{if(g?!f|(!d|!e):1){a=ba(8)|0;x[27524]=0;b=Q(55,h|0,8148)|0;c=x[27524];x[27524]=0;if((c|0)==1){break c}lc(a,b);x[27524]=0;U(123,a|0,50060,962);a=x[27524];x[27524]=0;if((a|0)!=1){break a}d=P()|0;wb(b);break b}il(a,b,4);c=Ox(a,c,d,e,f,g);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);ib=h+16|0;return c|0}d=P()|0;ca(a|0)}S(d|0)}p()}function NI(a){var b=0,c=E(0),d=E(0),e=E(0),f=E(0),g=E(0),h=E(0),i=0,j=0,k=0,l=E(0),m=E(0),n=E(0),o=E(0),p=0;c=B[a>>2];i=a-16|0;d=B[i>>2];e=E(c+d);b=a-8|0;f=B[b>>2];j=a-24|0;g=B[j>>2];h=E(f+g);B[a>>2]=e+h;B[b>>2]=e-h;b=a-12|0;h=B[b>>2];k=a-28|0;l=B[k>>2];e=E(h+l);p=b;b=a-4|0;m=B[b>>2];a=a-20|0;n=B[a>>2];o=E(m+n);B[p>>2]=o-e;f=E(f-g);g=E(m-n);B[k>>2]=f+g;c=E(c-d);d=E(h-l);B[i>>2]=c+d;B[j>>2]=c-d;B[b>>2]=e+o;B[a>>2]=g-f}function Ws(a,b,c,d,e){var f=0,g=0;a:{if(!Fs(b)){break a}f=x[a+484344>>2];if(!Ce(f,x[a+484348>>2],b&65535)){break a}b=Xb(f,b);if(x[b+12>>2]<=(c|0)|e>>>0>5|z[a+480188>>1]<=d>>>0|(c|d)<0){break a}b=hd(x[b>>2],x[x[b+48>>2]+12>>2],c,d&65535);b:{c:{switch(e|0){case 1:b=b+1|0;break b;case 2:b=b+2|0;break b;case 3:b=b+3|0;break b;case 4:b=b+4|0;break b;case 0:break b;case 5:break c;default:break a}}b=b+5|0}g=y[b|0]}return g}function Ee(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=ib-16|0;ib=e;g=bh(a);a:{b:{if(!b){i=e,j=bh(a),x[i+8>>2]=j;x[e+12>>2]=0;break b}f=x[b+4>>2];h=x[b>>2];x[e+8>>2]=h;x[e+12>>2]=f;a=x[a+12>>2];x[e>>2]=2048;x[e+4>>2]=0;b=a+c|0;d=a>>>0>b>>>0?d+1|0:d;a=hr(e+8|0,e);c=x[a>>2];a=x[a+4>>2];if(!a&c>>>0>g>>>0|a){a=-1;if(!d&b>>>0<=g>>>0){break b}break a}a=0;if((d|0)==(f|0)&b>>>0>h>>>0|d>>>0>f>>>0){break a}}a=1}ib=e+16|0;return a}function B3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=ib-16|0;ib=e;while(1){a:{if((c|0)<=(g|0)){break a}d=x[a+12>>2];f=x[a+16>>2];b:{if(d>>>0<f>>>0){x[e+12>>2]=2147483647;x[e+8>>2]=f-d>>2;x[e+4>>2]=c-g;f=d;d=x[rd(e+12|0,rd(e+8|0,e+4|0))>>2];ui(b,f,d);f=d<<2;x[a+12>>2]=f+x[a+12>>2];b=b+f|0;break b}d=lb[x[x[a>>2]+40>>2]](a)|0;if((d|0)==-1){break a}x[b>>2]=d;d=1;b=b+4|0}g=d+g|0;continue}break}ib=e+16|0;return g|0}function y9(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;x[27524]=0;Y(983,a|0);d=x[27524];x[27524]=0;e=1;a:{b:{if((d|0)!=1){d=x[a+28>>2];f=x[x[d>>2]+96>>2];x[27524]=0;ua(f|0,d|0,b|0,+c);b=x[27524];x[27524]=0;if((b|0)!=1){break b}}_(V(0)|0)|0;x[27524]=0;X(945,11512,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function w9(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;x[27524]=0;Y(983,a|0);d=x[27524];x[27524]=0;e=1;a:{b:{if((d|0)!=1){d=x[a+28>>2];f=x[x[d>>2]+88>>2];x[27524]=0;ua(f|0,d|0,b|0,+c);b=x[27524];x[27524]=0;if((b|0)!=1){break b}}_(V(0)|0)|0;x[27524]=0;X(945,10975,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function TX(a){a=a|0;var b=0,c=0,d=0;b=x[a>>2];if(b){sN(x[b+12>>2],b);b=x[a>>2];lb[x[x[b>>2]+8>>2]](b);x[a>>2]=0}a=a+4|0;Ic(a);b=ib-32|0;ib=b;a:{b:{d=sp(a);c=cd(x[a>>2],x[a+4>>2]);c:{if(d>>>0<=c>>>0){break c}x[27524]=0;c=fa(912,b+8|0,c|0,c|0,Db(a)|0)|0;d=x[27524];x[27524]=0;if((d|0)!=1){Dd(a,c);$l(c);break c}_(V(0)|0)|0;x[27524]=0;Z(18);a=x[27524];x[27524]=0;if((a|0)==1){break b}}ib=b+32|0;break a}V(0)|0;Sb();p()}}function Qla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=x[a>>2];d=xk(e,x[a+4>>2]);if(d>>>0<b>>>0){e=ib-32|0;ib=e;d=b-d|0;b=x[Db(a)>>2];f=x[a+4>>2];a:{if(d>>>0<=(b-f|0)/6>>>0){uB(a,d,c);break a}b=Db(a);b=BV(e+8|0,pB(a,xk(x[a>>2],f)+d|0),xk(x[a>>2],x[a+4>>2]),b);AV(b,d,c);c=b+4|0;yV(x[a>>2],x[a+4>>2],c);oc(a,c);oc(a+4|0,b+8|0);oc(Db(a),zc(b));x[b>>2]=x[b+4>>2];zV(b)}ib=e+32|0;return}if(b>>>0<d>>>0){Od(a,e+D(b,6)|0)}}function J9(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;x[27524]=0;Y(983,a|0);d=x[27524];x[27524]=0;e=1;a:{b:{if((d|0)!=1){d=x[a+28>>2];f=x[x[d>>2]+48>>2];x[27524]=0;ua(f|0,d|0,b|0,+c);b=x[27524];x[27524]=0;if((b|0)!=1){break b}}_(V(0)|0)|0;x[27524]=0;X(945,11574,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function l_(a){a=a|0;var b=0,c=0,d=0,e=0;c=ib-32|0;ib=c;b=xc(c,16748);x[27524]=0;U(124,c+16|0,a|0,b|0);a=x[27524];x[27524]=0;a:{if((a|0)!=1){xb(b);a=0;b=0;while(1){d=x[c+16>>2];if(!(b>>>0<=3&wd(d,x[c+20>>2])>>>0>b>>>0)){Wl(c+16|0);ib=c+32|0;return a|0}x[27524]=0;d=T(125,Cd(d,b)|0)|0;e=x[27524];x[27524]=0;if((e|0)!=1){a=(d&255)<<24-(b<<3)|a;b=b+1|0;continue}break}a=P()|0;Wl(c+16|0);break a}a=P()|0;xb(b)}S(a|0);p()}function AN(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=ib-32|0;ib=d;x[d+16>>2]=c;x[d+24>>2]=b;i=d,j=ke(a),x[i+8>>2]=j;c=d+24|0;b=Rn(c,d+8|0);c=Rn(d+16|0,c);a:{if(Eb(a)>>>0>=b>>>0){if((c|0)==-1){wN(a,b);break a}f=a;e=ib-16|0;ib=e;x[e+12>>2]=c;if(c){g=Eb(f);h=vc(f);c=g-b|0;x[e+8>>2]=c;a=x[Hb(e+12|0,e+8|0)>>2];b:{if((c|0)==(a|0)){a=c;break b}b=b+h|0;ai(b,a+b|0,c-a|0)}ny(f,h,g-a|0)}ib=e+16|0;break a}yk();p()}ib=d+32|0}function V7(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0;d=ib+-64|0;ib=d;x[d+56>>2]=c;c=Id(d+24|0);x[27524]=0;e=x[c+4>>2];x[d+8>>2]=x[c>>2];x[d+12>>2]=e;U(1076,d+32|0,a|0,d+8|0);a=x[27524];x[27524]=0;a:{b:{if((a|0)!=1){a=x[ge(d+16|0,d+56|0)>>2];x[27524]=0;b=+sa(943,d+32|0,+b,a|0);a=x[27524];x[27524]=0;if((a|0)==1){break b}yb(d+32|0);Xc(d+56|0);ib=d- -64|0;return+b}c=P()|0;break a}c=P()|0;yb(d+32|0)}Xc(d+56|0);S(c|0);p()}function MI(a,b){var c=0,d=0,e=0;if(!y[b+21|0]){fc(a,21);return-1}if(x[a+1396>>2]<=9){dl(a)}d=x[a+1392>>2];c=w[(((d&1023)<<1)+b|0)+36>>1];a:{if((c|0)>=0){e=d;d=c&65535;c=y[d+x[b+8>>2]|0];x[a+1392>>2]=e>>>c;c=x[a+1396>>2]-c|0;x[a+1396>>2]=(c|0)>0?c:0;c=(c|0)<0?-1:d;break a}c=lm(a,b)}if(!((c|0)>=x[b+2092>>2]?y[b+23|0]:0)){if(!(!(x[a+1384>>2]?y[a+1376|0]:1)|(c|0)>=0)){fc(a,21)}return c}aa(7514,13154,1793,5753);p()}function Nba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=Ai(a,b,c,d);x[a>>2]=45188;c=Nb(a+4256|0);b=a+4208|0;e=Bb(b,0),f=1056964608,x[e>>2]=f;e=Bb(b,1),f=1017370378,x[e>>2]=f;e=Bb(b,2),f=1028670828,x[e>>2]=f;e=Bb(b,3),f=1059760811,x[e>>2]=f;e=Bb(b,4),f=1017370378,x[e>>2]=f;e=Bb(b,5),f=1065353216,x[e>>2]=f;x[27524]=0;R(903,a+44|0,2);b=x[27524];x[27524]=0;if((b|0)!=1){return a|0}b=P()|0;uc(c);Rf(a);S(b|0);p()}function Cx(a){var b=0,c=0,d=0;a:{b:{if(!x[a+1384>>2]){b=x[a+1380>>2];if((b|0)==-1){x[a+1388>>2]=x[a+1116>>2]-1;if(!Cs(a)){x[a+1384>>2]=1;return 0}if(!(v[a+1375|0]&1)){break b}b=x[a+1380>>2]}d=b+1|0;x[a+1380>>2]=d;c=y[(a+b|0)+1120|0];if((c|0)!=255){x[a+1388>>2]=b;x[a+1384>>2]=1}if(x[a+1116>>2]<=(d|0)){x[a+1380>>2]=-1}if(y[a+1376|0]){break a}v[a+1376|0]=c}return c}fc(a,32);return 0}aa(15733,13154,1564,6039);p()}function nw(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=nd(a);a=xd(x[a+4>>2],y[a+11|0]);d=nd(b);b=xd(x[b+4>>2],y[b+11|0]);a:{if(a>>>0>=c>>>0){if(!b){break a}c=c+e|0;a=a+e|0;b=b+d|0;b:{if((b|0)==(d|0)){break b}c:{b=b-d|0;if((b|0)>(a-c|0)){break c}g=1-b|0;h=y[d|0];while(1){f=a-c|0;if((f|0)<(b|0)){break c}c=Au(c,g+f|0,h);if(!c){break c}if(!jw(c,d,b)){break b}c=c+1|0;continue}}c=a}c=(a|0)==(c|0)?-1:c-e|0}else{c=-1}}return c}function k0(a){a=a|0;if(y[483656]){return x[120913]}if(!y[484008]){a=483840;while(1){a=Kb(a)+12|0;if((a|0)!=484008){continue}break}v[484008]=1}od(483840,5243);od(483852,5250);od(483864,5216);od(483876,5224);od(483888,5207);od(483900,5257);od(483912,5234);od(483924,9696);od(483936,9902);od(483948,11190);od(483960,12826);od(483972,5506);od(483984,10706);od(483996,6590);v[483656]=1;x[120913]=483840;return 483840}function xY(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=ib-16|0;ib=d;x[d+12>>2]=-1;if(Hg(a,d+8|0)){x[d+4>>2]=y[d+8|0];f=x[Hb(d+4|0,d+12|0)>>2];c=ib+-64|0;ib=c;e=c+40|0;Wf(e,a,f);g=x[c+40>>2];a=c+8|0;ig(a,3,Le(e),g);x[27524]=0;R(226,c+24|0,a|0);a=x[27524];x[27524]=0;a:{if((a|0)!=1){dc(c,b,11);a=c+24|0;Ol(c,a);wb(a);Rc(c+40|0);ib=c- -64|0;e=!f|(g|0)!=0;break a}a=P()|0;Rc(c+40|0);S(a|0);p()}}ib=d+16|0;return e|0}function wF(a,b,c,d,e,f){var g=0,h=0;g=ib-256|0;ib=g;x[g+248>>2]=37;x[g+252>>2]=0;h=g+248|0;fs(h|1,10525,f,x[b+4>>2]);f=Fd();x[g>>2]=d;x[g+4>>2]=e;d=g+224|0;e=hh(d,24,f,h,g)+d|0;f=ej(d,e,b);h=g+16|0;ed(h,b);x[27524]=0;ia(1181,d|0,f|0,e|0,g+32|0,g+28|0,g+24|0,h|0);d=x[27524];x[27524]=0;a:{if((d|0)!=1){_b(g+16|0);a=ds(a,g+32|0,x[g+28>>2],x[g+24>>2],b,c);ib=g+256|0;break a}a=P()|0;_b(g+16|0);S(a|0);p()}return a}function WQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=ib-32|0;ib=d;x[a+4>>2]=0;a:{if(b){b:{if(Ut(a)>>>0>=b>>>0){x[a+4>>2]=b;break b}e=ko(d+16|0);x[27524]=0;f=Q(734,a|0,b|0)|0;g=x[27524];x[27524]=0;if((g|0)==1){break a}x[27524]=0;R(735,e|0,f|0);f=x[27524];x[27524]=0;if((f|0)==1){break a}x[e+4>>2]=b;bu(a,e);$e(e)}wl(d+8|0,x[a>>2]);Jv(x[d+8>>2],x[d+12>>2],b,y[c|0])}ib=d+32|0;return}a=P()|0;$e(e);S(a|0);p()}function yF(a,b,c,d,e,f){var g=0,h=0;g=ib-112|0;ib=g;x[g+104>>2]=37;x[g+108>>2]=0;h=g+104|0;fs(h|1,10525,f,x[b+4>>2]);f=Fd();x[g>>2]=d;x[g+4>>2]=e;d=g+80|0;e=hh(d,24,f,h,g)+d|0;f=ej(d,e,b);h=g+16|0;ed(h,b);x[27524]=0;ia(1178,d|0,f|0,e|0,g+32|0,g+28|0,g+24|0,h|0);d=x[27524];x[27524]=0;a:{if((d|0)!=1){_b(g+16|0);a=dv(a,g+32|0,x[g+28>>2],x[g+24>>2],b,c);ib=g+112|0;break a}a=P()|0;_b(g+16|0);S(a|0);p()}return a}function jja(a){a=a|0;var b=0,c=0,d=0;b=ib-16|0;ib=b;v[b+15|0]=128;a=Io(a,127,b+15|0);x[27524]=0;v[b+14|0]=64;d=W(583,a+12|0,127,b+14|0)|0;c=x[27524];x[27524]=0;a:{b:{if((c|0)!=1){x[27524]=0;v[b+13|0]=0;Q(658,a+24|0,b+13|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break b}x[a+36>>2]=-1;x[a+40>>2]=108855296;x[a+44>>2]=0;x[a+48>>2]=0;w[a+52>>1]=0;ib=b+16|0;return a|0}b=P()|0;break a}b=P()|0;ec(d)}ec(a);S(b|0);p()}function a5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=ib-16|0;ib=c;g=x[a+4>>2];x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;uJ(a,c);a:{if(B[a+24>>2]==E(1)){break a}d=x[b+4>>2];h=x[b+8>>2];b:while(1){if((e|0)==(h|0)){break a}i=D(x[a+16>>2],e+g|0);j=x[a+12>>2];b=0;while(1)if((b|0)==(d|0)){e=e+1|0;continue b}else{f=(b+i<<2)+j|0;B[f>>2]=B[a+24>>2]*B[f>>2];b=b+1|0;continue}}}ib=c+16|0}function l5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=ib-16|0;ib=c;g=x[a+4>>2];x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;AJ(a,c);a:{if(B[a+24>>2]==E(1)){break a}d=x[b+4>>2];h=x[b+8>>2];b:while(1){if((e|0)==(h|0)){break a}i=e+g|0;j=x[a+12>>2];b=0;while(1)if((b|0)==(d|0)){e=e+1|0;continue b}else{f=x[(b<<2)+j>>2]+(i<<2)|0;B[f>>2]=B[a+24>>2]*B[f>>2];b=b+1|0;continue}}}ib=c+16|0}function v9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[27524]=0;Y(983,a|0);c=x[27524];x[27524]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+84>>2];x[27524]=0;R(e|0,c|0,b|0);b=x[27524];x[27524]=0;if((b|0)!=1){break b}}_(V(0)|0)|0;x[27524]=0;X(945,12226,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function t9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[27524]=0;Y(983,a|0);c=x[27524];x[27524]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+80>>2];x[27524]=0;R(e|0,c|0,b|0);b=x[27524];x[27524]=0;if((b|0)!=1){break b}}_(V(0)|0)|0;x[27524]=0;X(945,11065,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function s9(a,b){a=a|0;b=+b;var c=0,d=0,e=0;x[27524]=0;Y(983,a|0);c=x[27524];x[27524]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+104>>2];x[27524]=0;oa(e|0,c|0,+b);c=x[27524];x[27524]=0;if((c|0)!=1){break b}}_(V(0)|0)|0;x[27524]=0;X(945,15128,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;x[27524]=0;Z(18);d=x[27524];x[27524]=0;if((d|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function Q9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[27524]=0;Y(983,a|0);c=x[27524];x[27524]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+76>>2];x[27524]=0;R(e|0,c|0,b|0);b=x[27524];x[27524]=0;if((b|0)!=1){break b}}_(V(0)|0)|0;x[27524]=0;X(945,11204,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function A9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[27524]=0;Y(983,a|0);c=x[27524];x[27524]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+16>>2];x[27524]=0;R(e|0,c|0,b|0);b=x[27524];x[27524]=0;if((b|0)!=1){break b}}_(V(0)|0)|0;x[27524]=0;X(945,12743,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function z9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[27524]=0;Y(983,a|0);c=x[27524];x[27524]=0;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+100>>2];x[27524]=0;d=+ta(e|0,c|0,b|0);b=x[27524];x[27524]=0;if((b|0)!=1){break b}}_(V(0)|0)|0;x[27524]=0;X(945,11530,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)==1){break a}$();d=0}return+d}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function xB(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=c;c=0;a:{if(!b){break a}if(!Ob(x[a>>2],x[a+8>>2],b)){break a}if(b>>>0<=3){c=ib-16|0;ib=c;if(Ob(x[a>>2],x[a+8>>2],b)){while(1){if((d|0)==4){cm(c,x[c+12>>2]);d=x[c>>2]}else{v[c+11|0]=0;b:{if(b>>>0>d>>>0){Hg(a,c+11|0);e=v[c+11|0];g=e>>>31|0;break b}e=0-g|0}v[(c+12|0)+d|0]=e;d=d+1|0;continue}break}}ib=c+16|0;c=d;break a}c=Jg(a);Yb(a,b-4|0)}v[f|0]=c}function qp(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0;i=ib-16|0;ib=i;if(-18-b>>>0>=c>>>0){j=vc(a);k=-17;if(b>>>0<=2147483622){x[i+8>>2]=b<<1;x[i+12>>2]=b+c;k=Wg(x[Yc(i+12|0,i+8|0)>>2])+1|0}c=mc(k);if(e){Ae(c,j,e)}if(g){Ae(c+e|0,h,g)}l=e+f|0;h=d-l|0;if((d|0)!=(l|0)){Ae((c+e|0)+g|0,(e+j|0)+f|0,h)}if((b|0)!=10){Ib(j)}td(a,c);hf(a,k);b=a;a=h+(e+g|0)|0;vd(b,a);v[i+7|0]=0;oe(a+c|0,i+7|0);ib=i+16|0;return}of();p()}function H9(a,b){a=a|0;b=+b;var c=0,d=0,e=0;x[27524]=0;Y(983,a|0);c=x[27524];x[27524]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+40>>2];x[27524]=0;oa(e|0,c|0,+b);c=x[27524];x[27524]=0;if((c|0)!=1){break b}}_(V(0)|0)|0;x[27524]=0;X(945,11612,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;x[27524]=0;Z(18);d=x[27524];x[27524]=0;if((d|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function B9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[27524]=0;Y(983,a|0);c=x[27524];x[27524]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+20>>2];x[27524]=0;R(e|0,c|0,b|0);b=x[27524];x[27524]=0;if((b|0)!=1){break b}}_(V(0)|0)|0;x[27524]=0;X(945,9260,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function x9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[27524]=0;Y(983,a|0);c=x[27524];x[27524]=0;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+92>>2];x[27524]=0;d=+ta(e|0,c|0,b|0);b=x[27524];x[27524]=0;if((b|0)!=1){break b}}_(V(0)|0)|0;x[27524]=0;X(945,10995,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)==1){break a}$();d=0}return+d}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function K9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[27524]=0;Y(983,a|0);c=x[27524];x[27524]=0;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+52>>2];x[27524]=0;d=+ta(e|0,c|0,b|0);b=x[27524];x[27524]=0;if((b|0)!=1){break b}}_(V(0)|0)|0;x[27524]=0;X(945,11593,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)==1){break a}$();d=0}return+d}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function E9(a,b){a=a|0;b=+b;var c=0,d=0,e=0;x[27524]=0;Y(983,a|0);c=x[27524];x[27524]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+32>>2];x[27524]=0;oa(e|0,c|0,+b);c=x[27524];x[27524]=0;if((c|0)!=1){break b}}_(V(0)|0)|0;x[27524]=0;X(945,7725,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;x[27524]=0;Z(18);d=x[27524];x[27524]=0;if((d|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function C9(a,b){a=a|0;b=+b;var c=0,d=0,e=0;x[27524]=0;Y(983,a|0);c=x[27524];x[27524]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+24>>2];x[27524]=0;oa(e|0,c|0,+b);c=x[27524];x[27524]=0;if((c|0)!=1){break b}}_(V(0)|0)|0;x[27524]=0;X(945,7673,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;x[27524]=0;Z(18);d=x[27524];x[27524]=0;if((d|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function Xea(a){a=a|0;var b=0;a=Kb(a);x[27524]=0;R(46,a|0,4);b=x[27524];x[27524]=0;a:{b:{if((b|0)==1){break b}x[27524]=0;R(47,a|0,32);b=x[27524];x[27524]=0;if((b|0)==1){break b}x[27524]=0;R(47,a|0,10);b=x[27524];x[27524]=0;if((b|0)==1){break b}x[27524]=0;R(47,a|0,13);b=x[27524];x[27524]=0;if((b|0)==1){break b}x[27524]=0;R(47,a|0,9);b=x[27524];x[27524]=0;if((b|0)!=1){break a}}b=P()|0;wb(a);S(b|0);p()}}function Rda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=ib-32|0;ib=d;Se(d,2,a+6|0);e=d+16|0;Fc(e,d);Cc(b+492|0,e);f=b+236|0;g=c+1|0;wb(e);c=0;while(1){if((c|0)==128){x[b>>2]=(y[a+226|0]|y[a+227|0]<<8)<<5;Gy(a+180|0,b+48|0,0);Gy(a+228|0,b+88|0,2);Gy(a+276|0,b+68|0,1);if(!(y[a+324|0]|y[a+325|0]<<8)){Rb(f,0,256)}ib=d+32|0}else{h=bc(f,c),i=y[(a+c|0)+38|0]+g|0,w[h>>1]=i;c=c+1|0;continue}break}}function N3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=ib-16|0;ib=e;while(1){a:{if((c|0)<=(f|0)){break a}g=x[a+28>>2];d=x[a+24>>2];if(g>>>0<=d>>>0){if(((i=a,j=Ke(v[b|0]),h=x[x[a>>2]+52>>2],lb[h](i|0,j|0)|0)|0)==-1){break a}f=f+1|0;b=b+1|0}else{x[e+12>>2]=g-d;x[e+8>>2]=c-f;g=d;d=x[rd(e+12|0,e+8|0)>>2];Ae(g,b,d);x[a+24>>2]=d+x[a+24>>2];f=f+d|0;b=b+d|0}continue}break}ib=e+16|0;return f|0}function Gha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=ib-16|0;ib=d;a:{c=x[b+4>>2];if(!c){break a}f=a+480190|0;w[d>>1]=z[f>>1];w[d+14>>1]=c-1;c=z[Tc(d,d+14|0)>>1];while(1){if(!c){break a}Ab(d,x[b>>2],c);b:{if(zb(x[x[d>>2]>>2],x[d+4>>2])){break b}if(IO(a,c&65535)){e=Kc(d,21631);Cc(((c<<5)+a|0)+946304|0,e);wb(e)}if(c>>>0<2){break b}e=z[f>>1];if((e|0)!=(c|0)){break b}w[f>>1]=e-1}c=c-1|0;continue}}ib=d+16|0}function F4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=ib-32|0;ib=e;a:{if(y[b+8|0]){f=x[b+12>>2];h=e,i=cd(f,x[b+16>>2])-c|0,x[h+28>>2]=i;x[e+24>>2]=x[d+4>>2];g=x[Hb(e+28|0,e+24|0)>>2];f=Yf(Cb(f),c);c=Yf(Yf(Cb(x[b+12>>2]),c),g);b=x[d>>2];wh(f,c,b);cc(a,b,g);break a}g=x[d+4>>2];d=x[d>>2];x[e+16>>2]=d;x[e+20>>2]=g;f=x[x[b>>2]+40>>2];x[e+8>>2]=d;x[e+12>>2]=g;lb[f|0](a,b,c,e+8|0)}ib=e+32|0}function gf(a){var b=0,c=0,d=0;b=ib-16|0;ib=b;o(+a);d=j(1)|0;j(0)|0;d=d&2147483647;a:{if(d>>>0<=1072243195){c=1;if(d>>>0<1044816030){break a}c=np(a,0);break a}c=a-a;if(d>>>0>=2146435072){break a}b:{switch($F(a,b)&3){case 0:c=np(C[b>>3],C[b+8>>3]);break a;case 1:c=-op(C[b>>3],C[b+8>>3],1);break a;case 2:c=-np(C[b>>3],C[b+8>>3]);break a;default:break b}}c=op(C[b>>3],C[b+8>>3],1)}a=c;ib=b+16|0;return a}function UZ(a){a=a|0;var b=0;a=Kb(a);x[27524]=0;R(73,a|0,4);b=x[27524];x[27524]=0;a:{b:{if((b|0)==1){break b}x[27524]=0;R(51,a|0,32);b=x[27524];x[27524]=0;if((b|0)==1){break b}x[27524]=0;R(51,a|0,10);b=x[27524];x[27524]=0;if((b|0)==1){break b}x[27524]=0;R(51,a|0,13);b=x[27524];x[27524]=0;if((b|0)==1){break b}x[27524]=0;R(51,a|0,9);b=x[27524];x[27524]=0;if((b|0)!=1){break a}}b=P()|0;xb(a);S(b|0);p()}}function O9(a,b){a=a|0;b=b|0;var c=0,d=0;x[27524]=0;Y(983,a|0);c=x[27524];x[27524]=0;a:{b:{if((c|0)!=1){c=x[a+28>>2];d=x[x[c>>2]+68>>2];x[27524]=0;b=Q(d|0,c|0,b|0)|0;c=x[27524];x[27524]=0;if((c|0)!=1){break b}}_(V(0)|0)|0;x[27524]=0;X(945,6690,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function M9(a,b){a=a|0;b=b|0;var c=0,d=0;x[27524]=0;Y(983,a|0);c=x[27524];x[27524]=0;a:{b:{if((c|0)!=1){c=x[a+28>>2];d=x[x[c>>2]+60>>2];x[27524]=0;b=Q(d|0,c|0,b|0)|0;c=x[27524];x[27524]=0;if((c|0)!=1){break b}}_(V(0)|0)|0;x[27524]=0;X(945,6741,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function xF(a,b,c,d,e){var f=0,g=0,h=0;f=ib-160|0;ib=f;x[f+152>>2]=37;x[f+156>>2]=0;g=f+152|0;fs(g|1,10692,e,x[b+4>>2]);e=Fd();x[f>>2]=d;d=f+139|0;e=hh(d,13,e,g,f)+d|0;g=ej(d,e,b);h=f+16|0;ed(h,b);x[27524]=0;ia(1181,d|0,g|0,e|0,f+32|0,f+28|0,f+24|0,h|0);d=x[27524];x[27524]=0;a:{if((d|0)!=1){_b(f+16|0);a=ds(a,f+32|0,x[f+28>>2],x[f+24>>2],b,c);ib=f+160|0;break a}a=P()|0;_b(f+16|0);S(a|0);p()}return a}function tL(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=ib-16|0;ib=f;a:{b:{c:{if(!(e?d:0)){a=ba(8)|0;x[27524]=0;b=Q(55,f|0,8148)|0;c=x[27524];x[27524]=0;if((c|0)==1){break c}lc(a,b);x[27524]=0;U(123,a|0,50060,962);a=x[27524];x[27524]=0;if((a|0)!=1){break a}e=P()|0;wb(b);break b}il(a,b,2);c=Px(a,c,d,e,0,0);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);ib=f+16|0;return c|0}e=P()|0;ca(a|0)}S(e|0)}p()}function AZ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;f=ib-16|0;ib=f;x[f+4>>2]=1;i=f,j=mc(32),x[i+8>>2]=j;e=Tl(x[f+8>>2]);x[e>>2]=43e3;g=zc(e);e=ib-16|0;ib=e;b=Rl(e+8|0,x[b>>2],x[b+4>>2]);d=x[d>>2];c=x[c>>2];h=x[b+4>>2];x[e>>2]=x[b>>2];x[e+4>>2]=h;b=hn(g);x[b>>2]=43136;Rl(b+4|0,x[e>>2],x[e+4>>2]);x[b+16>>2]=d;x[b+12>>2]=c;Ud(e);ib=e+16|0;b=a;a=kn(f);jn(b,zc(a),a);Ul(f);ib=f+16|0}function AL(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=ib-16|0;ib=f;a:{b:{c:{if(!(e?d:0)){a=ba(8)|0;x[27524]=0;b=Q(55,f|0,8148)|0;c=x[27524];x[27524]=0;if((c|0)==1){break c}lc(a,b);x[27524]=0;U(123,a|0,50060,962);a=x[27524];x[27524]=0;if((a|0)!=1){break a}e=P()|0;wb(b);break b}il(a,b,2);c=Ox(a,c,d,e,0,0);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);ib=f+16|0;return c|0}e=P()|0;ca(a|0)}S(e|0)}p()}function bz(a,b){a=a|0;b=b|0;var c=E(0),d=0,e=0,f=0;v[a+1074368|0]=b;UO(a+1074332|0,b);a=a+906300|0;f=rj(a);while(1){if((a|0)!=(f|0)){b=x[a>>2];if(b){c=E(1);d=x[b+20>>2];if(d){c=E(E(y[d+26|0])*E(.10000000149011612))}c=c<E(.10000000149011612)?E(1):c;if(lb[x[x[b>>2]+140>>2]](b)|0){d=x[b+16>>2];e=d+1074332|0;c=E(E(c/B[e+8>>2])*E(E(A[d+480232>>2])/B[e+20>>2]))}B[b+4196>>2]=c}a=a+160|0;continue}break}}function Fla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=ib-16|0;ib=e;c=Af(a,c);Pd(e,x[a+36>>2]);a:{b:{if(!c){Pc(e,a+32|0,5);d=-1;if(!zb(x[x[e>>2]>>2],x[e+4>>2])){break b}break a}d=x[c+16>>2]}f=x[a+36>>2];c:{d:{switch(d+1|0){case 0:case 2:d=ib-32|0;ib=d;v[d+24|0]=0;fj(d+8|0,d+24|0);Bn(d+16|0,f,x[d+8>>2],x[d+12>>2]);v[b|0]=y[d+24|0];ib=d+32|0;break c;default:break d}}EV(f,b,d)}f=c}af(a,f);ib=e+16|0}function RC(a,b){var c=0,d=0,e=0;c=ib-32|0;ib=c;a:{if(!y[b+7|0]){while(1){if((d|0)==7){d=0;v[c+27|0]=0;v[c+28|0]=0;v[c+29|0]=0;v[c+30|0]=0;x[c+24>>2]=0;e=dc(c+8|0,c+24|0,7);ld(c+16|0,a,x[e>>2],x[e+4>>2]);b:{if(x[c+20>>2]!=7){break b}if(Qb(c+24|0,b,7)){break b}gd(a,7);d=1}ib=c+32|0;break a}e=b+d|0;d=d+1|0;if(y[e|0]){continue}break}aa(17442,9027,414,13118);p()}aa(17421,9027,412,13118);p()}return d}function Pt(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=ib-16|0;ib=e;x[b+40>>2]=0;x[b+44>>2]=0;f=b- -64|0;x[f>>2]=0;x[f+4>>2]=0;x[b+56>>2]=0;x[b+60>>2]=0;x[b+48>>2]=0;x[b+52>>2]=0;while(1){if((d|0)==1e4){a:{d=Cb(x[c>>2]);x[e+8>>2]=d;f=Cb(x[c+4>>2]);while(1){if(!Mb(d,f)){break a}g=d,h=_Q(b,C[d>>3]),C[g>>3]=h;d=x[Nt(e+8|0)>>2];continue}}}else{_Q(b,C[We(x[c>>2],0)>>3]);d=d+1|0;continue}break}xl(a,c);ib=e+16|0}function KF(a,b,c,d,e,f,g,h,i){var j=0;x[27524]=0;Y(958,a|0);j=x[27524];x[27524]=0;a:{b:{if((j|0)!=1){j=x[a+24>>2];x[27524]=0;b=va(i|0,j|0,b|0,c|0,d|0,e|0,f|0,g|0)|0;c=x[27524];x[27524]=0;if((c|0)!=1){break b}}_(V(0)|0)|0;x[27524]=0;X(945,h|0,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)==1){break a}$();b=0}return b}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function yja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ib-16|0;ib=c;b=-1;a:{if(!kg(a,8)){break a}b=ib-32|0;ib=b;x[b+24>>2]=0;x[b+28>>2]=0;d=dc(b+8|0,b+24|0,8);ld(b+16|0,a,x[d>>2],x[d+4>>2]);b:{if(x[b+20>>2]!=8){break b}if(Qb(b+24|0,14134,8)){break b}gd(a,8);e=1}ib=b+32|0;b=0;if(!e){break a}b=-1;if(!Xj(a,c+8|0)){break a}b=0;if(!ac(x[c+12>>2])){break a}b=!(ac(x[c+8>>2])&-2139062144)}ib=c+16|0;return b|0}function aP(a,b){var c=0,d=0,e=0,f=0;c=x[a>>2];x[a>>2]=b;if(c){b=ib-16|0;ib=b;d=Cb(x[c>>2]);x[b+8>>2]=d;f=Cb(x[c+4>>2]);while(1){a:{b:{if(Mb(d,f)){while(1){a=x[d>>2];e=x[a>>2];if(!e){break b}sN(a,e);a=x[x[e>>2]+8>>2];x[27524]=0;Y(a|0,e|0);a=x[27524];x[27524]=0;if((a|0)!=1){continue}break}V(0)|0;Sb();p()}a=uc(c);ib=b+16|0;break a}$b(a+20|0);$b(a+8|0);Ib(a);d=x[Pe(b+8|0)>>2];continue}break}Ib(a)}}function wo(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=ib-16|0;ib=f;x[f+12>>2]=c;a:{if(!Ob(x[b>>2],x[b+8>>2],c)){break a}wc(f+12|0,65535);Dg(a,z[f+12>>1]);c=Cb(x[a>>2]);x[f>>2]=c;h=Cb(x[a+4>>2]);while(1){if(!Mb(c,h)){break a}a=f+11|0;if(!Hg(b,a)){Jh(a)}a=y[f+11|0];w[c>>1]=a;g=65535;b:{if((a|0)!=(d|0)){g=65534;if((a|0)!=(e|0)){break b}}w[c>>1]=g}c=x[Ye(f)>>2];continue}}ib=f+16|0}function tK(a,b){a=a|0;b=b|0;var c=0;c=ib-16|0;ib=c;a:{b:{c:{d:{if((b|0)>=0){a=x[a+32>>2];if((Cg(a)|0)>(b|0)){break d}}b=ba(8)|0;x[27524]=0;c=Q(55,c|0,10644)|0;a=x[27524];x[27524]=0;if((a|0)==1){break c}lc(b,c);x[27524]=0;U(123,b|0,50060,962);a=x[27524];x[27524]=0;if((a|0)!=1){break a}a=P()|0;wb(c);break b}ib=c+16|0;return(x[(a+D(b,872)|0)+1075080>>2]&134218752)!=0|0}a=P()|0;ca(b|0)}S(a|0)}p()}function m8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;x[27524]=0;Y(958,a|0);d=x[27524];x[27524]=0;e=1;a:{b:{if((d|0)!=1){d=x[a+24>>2];x[27524]=0;U(1053,d|0,b|0,c|0);b=x[27524];x[27524]=0;if((b|0)!=1){break b}}_(V(0)|0)|0;x[27524]=0;X(945,10259,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function Lha(a,b){a=a|0;b=b|0;var c=0,d=0;if(A[a+4>>2]<A[Db(a)>>2]){c=ib-16|0;ib=c;a=pA(c,a);cm(x[a+4>>2],y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24));x[a+4>>2]=x[a+4>>2]+4;ic(a);ib=c+16|0;return}d=ib-32|0;ib=d;c=Db(a);c=cg(d+8|0,wg(a,tc(x[a>>2],x[a+4>>2])+1|0),tc(x[a>>2],x[a+4>>2]),c);cm(x[c+8>>2],y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24));x[c+8>>2]=x[c+8>>2]+4;Dd(a,c);bg(c);ib=d+32|0}function zF(a,b,c,d,e){var f=0,g=0,h=0;f=ib-80|0;ib=f;x[f+72>>2]=37;x[f+76>>2]=0;g=f+72|0;fs(g|1,10692,e,x[b+4>>2]);e=Fd();x[f>>2]=d;d=f+59|0;e=hh(d,13,e,g,f)+d|0;g=ej(d,e,b);h=f+16|0;ed(h,b);x[27524]=0;ia(1178,d|0,g|0,e|0,f+32|0,f+28|0,f+24|0,h|0);d=x[27524];x[27524]=0;a:{if((d|0)!=1){_b(f+16|0);a=dv(a,f+32|0,x[f+28>>2],x[f+24>>2],b,c);ib=f+80|0;break a}a=P()|0;_b(f+16|0);S(a|0);p()}return a}function R1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=ib-208|0;ib=a;f=Fd();x[a>>2]=e;g=a+176|0;i=hh(g,20,f,9210,a);e=i+g|0;g=ej(g,e,c);f=a+8|0;ed(f,c);x[27524]=0;f=T(1164,f|0)|0;h=x[27524];x[27524]=0;if((h|0)!=1){_b(a+8|0);h=f;f=a+16|0;_G(h,a+176|0,e,f);h=b;b=f+(i<<2)|0;b=ds(h,f,(e|0)==(g|0)?b:((g-a<<2)+a|0)-688|0,b,c,d);ib=a+208|0;return b|0}b=P()|0;_b(a+8|0);S(b|0);p()}function L_(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;x[27524]=0;a=Ia(1056,a|0,b|0,c|0,d|0)|0;b=x[27524];x[27524]=0;a:{b:{if((b|0)==1){_(V(0)|0)|0;x[27524]=0;ia(941,11088,e|0,f|0,g|0,h|0,i|0,j|0);a=x[27524];x[27524]=0;if((a|0)==1){break b}$();a=-255}break a}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}return a|0}function q5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=E(0),g=0,h=0,i=0,j=0,k=0,l=0;c=ib-16|0;ib=c;a:{f=B[a+24>>2];if(f==E(1)){break a}i=x[b>>2];j=+f;g=x[b+4>>2];k=x[b+8>>2];b:while(1){if((e|0)==(k|0)){break a}l=D(e,g);d=0;while(1)if((d|0)==(g|0)){e=e+1|0;continue b}else{h=(d+l<<3)+i|0;C[h>>3]=C[h>>3]*j;d=d+1|0;continue}}}x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;DJ(a,c);ib=c+16|0}function pd(a,b){var c=0,d=0,e=0,f=0,g=0;a:{e=uH(b);c=xn(a);if(e>>>0<=c>>>0){f=vc(a);d=f;c=e;if(c){b:{if((b|0)==(d|0)){break b}if(d-b>>>0>=c<<2>>>0){if(!c){break b}while(1){x[d>>2]=x[b>>2];d=d+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}break b}if(!c){break b}while(1){c=c-1|0;g=c<<2;x[g+d>>2]=x[b+g>>2];if(c){continue}break}}}Wh(a,e);td((e<<2)+f|0,0);break a}d=a;a=Eb(a);fG(d,c,e-c|0,a,0,a,e,b)}}function o8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;x[27524]=0;Y(958,a|0);d=x[27524];x[27524]=0;a:{b:{if((d|0)!=1){d=x[a+24>>2];x[27524]=0;e=+ra(1049,d|0,b|0,c|0);b=x[27524];x[27524]=0;if((b|0)!=1){break b}}_(V(0)|0)|0;x[27524]=0;X(945,5353,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)==1){break a}$();e=0}return+e}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function k5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=E(0),g=0,h=0,i=0,j=0,k=0,l=0;c=ib-16|0;ib=c;a:{f=B[a+24>>2];if(f==E(1)){break a}i=x[b>>2];j=+f;g=x[b+4>>2];k=x[b+8>>2];b:while(1){if((e|0)==(k|0)){break a}l=D(e,g);d=0;while(1)if((d|0)==(g|0)){e=e+1|0;continue b}else{h=(d+l<<3)+i|0;C[h>>3]=C[h>>3]*j;d=d+1|0;continue}}}x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;zJ(a,c);ib=c+16|0}function g5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=E(0),g=0,h=0,i=0,j=0,k=0,l=0;c=ib-16|0;ib=c;a:{f=B[a+24>>2];if(f==E(1)){break a}i=x[b>>2];j=+f;g=x[b+4>>2];k=x[b+8>>2];b:while(1){if((e|0)==(k|0)){break a}l=D(e,g);d=0;while(1)if((d|0)==(g|0)){e=e+1|0;continue b}else{h=(d+l<<3)+i|0;C[h>>3]=C[h>>3]*j;d=d+1|0;continue}}}x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;xJ(a,c);ib=c+16|0}function cV(a){var b=0;a:{if(Qb(a,14275,3)|(y[a+3|0]-52&255)>>>0<252){break a}if(ac(y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24))+788>>>0<840){break a}if(ac(y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24))>>>0<52){break a}if(ac(y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24))-1>>>0<51){break a}b=ac(y[a+32|0]|y[a+33|0]<<8|(y[a+34|0]<<16|y[a+35|0]<<24))>>>0<4294967216}return b}function WT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ib-32|0;ib=c;a:{if(!y[b+8|0]){while(1){if((d|0)==8){x[c+24>>2]=0;x[c+28>>2]=0;d=dc(c+8|0,c+24|0,8);kc(c+16|0,x[a>>2],x[a+8>>2],x[d>>2],x[d+4>>2]);d=0;b:{if(x[c+20>>2]!=8){break b}if(Qb(c+24|0,b,8)){break b}Yb(a,8);d=1}ib=c+32|0;break a}e=b+d|0;d=d+1|0;if(y[e|0]){continue}break}aa(17442,9027,414,13118);p()}aa(17421,9027,412,13118);p()}return d|0}function Tha(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=ib-16|0;ib=b;w[b+12>>1]=0;w[b+14>>1]=1;Mf(b+14|0,z[x[x[a+24>>2]+8>>2]+12>>1]);e=b+12|0;d=ib-16|0;ib=d;c=z[b+14>>1];x[d+12>>2]=c;a:{if(_m(a)>>>0>=c>>>0){g=x[a>>2];f=Oc(g,x[a+4>>2]);x[d+8>>2]=f;tu(g,x[Hb(d+12|0,d+8|0)>>2],e);if(c>>>0>f>>>0){No(a,c-f|0,e);break a}Od(a,x[a>>2]+(c<<1)|0);break a}LR(a);sq(a,Vj(a,c));No(a,c,e)}ib=d+16|0;ib=b+16|0}function Mu(a,b){var c=0;c=ib-16|0;ib=c;x[c+12>>2]=b;a:{b:{switch(a|0){case 0:a=b;b=a>>31<<6|a>>>26;a=a<<6;a=Dc(roa(a- -8192|0,b-((a>>>0<4294959104)-1|0)|0,16384,0),kb);break a;case 1:a=b>>31;a=a<<6|b>>>26;b=(b<<6)+2048|0;a=b>>>0<2048?a+1|0:a;a=Dc(roa(b,a,4096,0),kb);break a;default:break b}}x[c+8>>2]=1;a=Al(YG(8192/+x[Ve(c+12|0,c+8|0)>>2])*24+8)}ib=c+16|0;a=(a|0)>=64?64:a;return(a|0)>0?a:0}function $4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=E(0),g=0,h=0,i=0,j=0,k=0,l=0;c=ib-16|0;ib=c;a:{f=B[a+24>>2];if(f==E(1)){break a}i=x[b>>2];j=+f;g=x[b+4>>2];k=x[b+8>>2];b:while(1){if((e|0)==(k|0)){break a}l=D(e,g);d=0;while(1)if((d|0)==(g|0)){e=e+1|0;continue b}else{h=(d+l<<3)+i|0;C[h>>3]=C[h>>3]*j;d=d+1|0;continue}}}x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;tJ(a,c);ib=c+16|0}function Ki(a){var b=0,c=0;b=ib-16|0;ib=b;o(+a);c=j(1)|0;j(0)|0;c=c&2147483647;a:{if(c>>>0<=1072243195){if(c>>>0<1045430272){break a}a=op(a,0,0);break a}if(c>>>0>=2146435072){a=a-a;break a}b:{switch($F(a,b)&3){case 0:a=op(C[b>>3],C[b+8>>3],1);break a;case 1:a=np(C[b>>3],C[b+8>>3]);break a;case 2:a=-op(C[b>>3],C[b+8>>3],1);break a;default:break b}}a=-np(C[b>>3],C[b+8>>3])}ib=b+16|0;return a}function I9(a){a=a|0;var b=0,c=0,d=0;x[27524]=0;Y(983,a|0);b=x[27524];x[27524]=0;a:{b:{if((b|0)!=1){b=x[a+28>>2];d=x[x[b>>2]+44>>2];x[27524]=0;c=+la(d|0,b|0);b=x[27524];x[27524]=0;if((b|0)!=1){break b}}_(V(0)|0)|0;x[27524]=0;X(945,11630,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function vK(a,b){a=a|0;b=b|0;var c=0;c=ib-16|0;ib=c;a:{b:{c:{d:{if((b|0)>=0){a=x[a+32>>2];if((Cg(a)|0)>(b|0)){break d}}b=ba(8)|0;x[27524]=0;c=Q(55,c|0,10644)|0;a=x[27524];x[27524]=0;if((a|0)==1){break c}lc(b,c);x[27524]=0;U(123,b|0,50060,962);a=x[27524];x[27524]=0;if((a|0)!=1){break a}a=P()|0;wb(c);break b}ib=c+16|0;return+(+x[(a+D(b,872)|0)+1075740>>2]*.015625)}a=P()|0;ca(b|0)}S(a|0)}p()}function qY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=ib-16|0;ib=d;x[a>>2]=0;x[a+4>>2]=0;if(!Ob(x[b>>2],x[b+8>>2],c)){c=jf(b)}x[a>>2]=c;c=x[b>>2];a:{if(lb[x[x[c>>2]+16>>2]](c)|0){c=a;a=x[b>>2];e=c,f=(lb[x[x[a>>2]+20>>2]](a)|0)+x[b+8>>2]|0,x[e+4>>2]=f;break a}Yi(a+8|0,x[a>>2]);c=x[a+8>>2];a=x[a+12>>2];if(pc(c,a)){break a}he(d+8|0,c,a);kc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2])}ib=d+16|0}function G9(a){a=a|0;var b=0,c=0,d=0;x[27524]=0;Y(983,a|0);b=x[27524];x[27524]=0;a:{b:{if((b|0)!=1){b=x[a+28>>2];d=x[x[b>>2]+36>>2];x[27524]=0;c=+la(d|0,b|0);b=x[27524];x[27524]=0;if((b|0)!=1){break b}}_(V(0)|0)|0;x[27524]=0;X(945,7742,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function D9(a){a=a|0;var b=0,c=0,d=0;x[27524]=0;Y(983,a|0);b=x[27524];x[27524]=0;a:{b:{if((b|0)!=1){b=x[a+28>>2];d=x[x[b>>2]+28>>2];x[27524]=0;c=+la(d|0,b|0);b=x[27524];x[27524]=0;if((b|0)!=1){break b}}_(V(0)|0)|0;x[27524]=0;X(945,7690,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function wq(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0;i=ib-16|0;ib=i;if(-18-b>>>0>=c>>>0){j=nd(a);k=-17;if(b>>>0<=2147483622){x[i+8>>2]=b<<1;x[i+12>>2]=b+c;k=Wg(x[Yc(i+12|0,i+8|0)>>2])+1|0}c=mc(k);if(e){Ae(c,j,e)}if(g){Ae(c+e|0,h,g)}l=e+f|0;h=d-l|0;if((d|0)!=(l|0)){Ae((c+e|0)+g|0,(e+j|0)+f|0,h)}if((b|0)!=10){Ib(j)}td(a,c);hf(a,k);b=a;a=h+(e+g|0)|0;vd(b,a);ne(a+c|0,0);ib=i+16|0;return}of();p()}function Lx(a,b,c){var d=0,e=0;d=ib-32|0;ib=d;a:{if(y[a+20|0]){break a}b=b+c|0;b=b>>>0<c>>>0?-1:b;c=x[a+16>>2];if(b>>>0<=c>>>0){break a}b=nJ(b,4096);mJ(a,b-c|0);c=x[a+16>>2];b=dc(d+16|0,Jb(x[a+4>>2],c),b-c|0);c=x[x[a>>2]+44>>2];e=x[b+4>>2];x[d+8>>2]=x[b>>2];x[d+12>>2]=e;lb[c|0](d+24|0,a,d+8|0);x[a+16>>2]=x[a+16>>2]+x[d+28>>2];if(!(lb[x[x[a>>2]+40>>2]](a)|0)){break a}v[a+20|0]=1}ib=d+32|0}function Gr(a){var b=0,c=0;en(a,1,13559);x[27524]=0;b=ga(130)|0;c=x[27524];x[27524]=0;a:{if((c|0)==1){break a}x[a+12>>2]=b;x[27524]=0;b=ga(131)|0;c=x[27524];x[27524]=0;if((c|0)==1){break a}v[a+16|0]=b;x[27524]=0;b=ga(132)|0;c=x[27524];x[27524]=0;if((c|0)==1){break a}v[a+18|0]=0;v[a+17|0]=b;x[27524]=0;Y(133,a+20|0);b=x[27524];x[27524]=0;if((b|0)==1){break a}return}b=P()|0;xb(a);S(b|0);p()}function wC(a,b,c){var d=0,e=0,f=0;d=x[c+16>>2];a:{if(!d){if(_C(c)){break a}d=x[c+16>>2]}f=x[c+20>>2];if(d-f>>>0<b>>>0){return lb[x[c+36>>2]](c,a,b)|0}b:{if(x[c+80>>2]<0){d=0;break b}e=b;while(1){d=e;if(!d){d=0;break b}e=d-1|0;if(y[e+a|0]!=10){continue}break}e=lb[x[c+36>>2]](c,a,d)|0;if(e>>>0<d>>>0){break a}a=a+d|0;b=b-d|0;f=x[c+20>>2]}rc(f,a,b);x[c+20>>2]=x[c+20>>2]+b;e=b+d|0}return e}function zU(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+22|0]=0;v[a+23|0]=0;v[a+24|0]=0;v[a+25|0]=0;v[a+26|0]=0;v[a+27|0]=0;v[a+28|0]=0;v[a+29|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+20|0]=0;v[a+21|0]=0;v[a+22|0]=0;v[a+23|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function vL(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=ib-16|0;ib=e;a:{b:{c:{if(!d){a=ba(8)|0;x[27524]=0;c=Q(55,e|0,8148)|0;b=x[27524];x[27524]=0;if((b|0)==1){break c}lc(a,c);x[27524]=0;U(123,a|0,50060,962);a=x[27524];x[27524]=0;if((a|0)!=1){break a}b=P()|0;wb(c);break b}il(a,b,1);c=Px(a,c,d,0,0,0);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);ib=e+16|0;return c|0}b=P()|0;ca(a|0)}S(b|0)}p()}function sS(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+24|0]=0;v[a+25|0]=0;v[a+26|0]=0;v[a+27|0]=0;v[a+28|0]=0;v[a+29|0]=0;v[a+30|0]=0;v[a+31|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+20|0]=0;v[a+21|0]=0;v[a+22|0]=0;v[a+23|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function hna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ib-16|0;ib=c;cc(c+8|0,b,15);d=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Yb(a,x[c+12>>2])}ib=c+16|0;if((d|0)!=(e|0)){v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+7|0]=0;v[b+8|0]=0;v[b+9|0]=0;v[b+10|0]=0;v[b+11|0]=0;v[b+12|0]=0;v[b+13|0]=0;v[b+14|0]=0}}function JF(a,b,c,d,e,f,g){var h=0;x[27524]=0;Y(958,a|0);h=x[27524];x[27524]=0;a:{b:{if((h|0)!=1){h=x[a+24>>2];x[27524]=0;b=ja(g|0,h|0,b|0,c|0,d|0,e|0)|0;c=x[27524];x[27524]=0;if((c|0)!=1){break b}}_(V(0)|0)|0;x[27524]=0;X(945,f|0,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)==1){break a}$();b=0}return b}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function D4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=nd(c);c=xd(x[c+4>>2],y[c+11|0]);a:{d=xd(x[a+4>>2],y[a+11|0]);if(d>>>0>=b>>>0){e=zl(a);if(c>>>0<=e-d>>>0){if(!c){break a}e=nd(a);h=e+b|0;if((b|0)!=(d|0)){g=b+e|0;ai(c+g|0,g,d-b|0);f=(f>>>0>=g>>>0?d+e>>>0>f>>>0?c:0:0)+f|0}ai(h,f,c);b=c+d|0;zq(a,b);ne(b+e|0,0);break a}wq(a,e,(c+d|0)-e|0,d,b,0,c,f);break a}yk();p()}return a|0}function CL(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=ib-16|0;ib=e;a:{b:{c:{if(!d){a=ba(8)|0;x[27524]=0;c=Q(55,e|0,8148)|0;b=x[27524];x[27524]=0;if((b|0)==1){break c}lc(a,c);x[27524]=0;U(123,a|0,50060,962);a=x[27524];x[27524]=0;if((a|0)!=1){break a}b=P()|0;wb(c);break b}il(a,b,1);c=Ox(a,c,d,0,0,0);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);ib=e+16|0;return c|0}b=P()|0;ca(a|0)}S(b|0)}p()}function ona(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);if(zh(1073741823)>>>0<=8191){_c();p()}b=mc(32768);x[a>>2]=b;x[a+4>>2]=b;e=Db(a),f=b+32768|0,x[e>>2]=f;b=ib-16|0;ib=b;x[b>>2]=a;c=x[a+4>>2];x[b+4>>2]=c;x[b+8>>2]=c+32768;c=x[b+4>>2];d=x[b+8>>2];while(1){if((c|0)==(d|0)){ic(b);ib=b+16|0}else{w[c>>1]=0;w[c+2>>1]=0;c=c+4|0;x[b+4>>2]=c;continue}break}return a|0}function fla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ib-16|0;ib=c;cc(c+8|0,b,14);d=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Yb(a,x[c+12>>2])}ib=c+16|0;if((d|0)!=(e|0)){v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+8|0]=0;v[b+9|0]=0;v[b+10|0]=0;v[b+11|0]=0;v[b+12|0]=0;v[b+13|0]=0}}function Xca(a){a=a|0;var b=0,c=0;b=x[a+20>>2];x[b+148>>2]=-1;x[27524]=0;R(289,b+4|0,8);b=x[27524];x[27524]=0;if((b|0)!=1){b=x[a+4264>>2];c=x[x[a+20>>2]+4>>2];a=x[a+4260>>2];v[c|0]=a;v[c+1|0]=a>>>8;v[c+2|0]=a>>>16;v[c+3|0]=a>>>24;v[c+4|0]=b;v[c+5|0]=b>>>8;v[c+6|0]=b>>>16;v[c+7|0]=b>>>24;return}b=V(108196)|0;if((jb|0)==(da(108196)|0)){_(b|0)|0;Ic(x[a+20>>2]+4|0);$();return}S(b|0);p()}function $1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=ib-96|0;ib=a;f=Fd();x[a>>2]=e;g=a- -64|0;i=hh(g,20,f,9210,a);e=i+g|0;g=ej(g,e,c);f=a+8|0;ed(f,c);x[27524]=0;f=T(19,f|0)|0;h=x[27524];x[27524]=0;if((h|0)!=1){_b(a+8|0);h=f;f=a+16|0;cH(h,a- -64|0,e,f);h=b;b=f+i|0;b=dv(h,f,(e|0)==(g|0)?b:((g-a|0)+a|0)-48|0,b,c,d);ib=a+96|0;return b|0}b=P()|0;_b(a+8|0);S(b|0);p()}function r8(a,b){a=a|0;b=b|0;var c=0,d=0;x[27524]=0;Y(958,a|0);c=x[27524];x[27524]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+24>>2];x[27524]=0;R(1048,c|0,b|0);b=x[27524];x[27524]=0;if((b|0)!=1){break b}}_(V(0)|0)|0;x[27524]=0;X(945,10809,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function nL(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=ib-32|0;ib=b;c=dc(b+24|0,c,d);d=x[c+4>>2];x[b>>2]=x[c>>2];x[b+4>>2]=d;a:{a=pt(a,b,0);if(a+1>>>0>=3){a=ba(8)|0;x[27524]=0;b=Q(55,b+8|0,8005)|0;c=x[27524];x[27524]=0;b:{if((c|0)!=1){lc(a,b);x[27524]=0;U(123,a|0,50060,962);a=x[27524];x[27524]=0;if((a|0)!=1){break a}c=P()|0;wb(b);break b}c=P()|0;ca(a|0)}S(c|0);p()}ib=b+32|0;return a|0}p()}function kK(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;d=ib-16|0;ib=d;a:{b:{c:{if(b>>>0>=256){b=ba(8)|0;x[27524]=0;d=Q(55,d|0,10644)|0;a=x[27524];x[27524]=0;if((a|0)==1){break c}lc(b,d);x[27524]=0;U(123,b|0,50060,962);a=x[27524];x[27524]=0;if((a|0)!=1){break a}a=P()|0;wb(d);break b}e=(x[a+32>>2]+D(b,872)|0)+1075766|0,f=wA(c*32768),w[e>>1]=f;ib=d+16|0;return}a=P()|0;ca(b|0)}S(a|0)}p()}function hF(a,b,c,d,e){var f=0,g=0;a:{f=ib-80|0;ib=f;YA(b);g=f+56|0;Wf(g,a,c);a=x[f+56>>2];c=f+8|0;ig(c,e,Le(g),a);x[27524]=0;R(226,f+24|0,c|0);a=x[27524];x[27524]=0;b:{c:{if((a|0)!=1){x[27524]=0;U(11,f+40|0,d|0,f+24|0);a=x[27524];x[27524]=0;if((a|0)==1){break c}a=f+40|0;Gb(b,a);xb(a);wb(f+24|0);Rc(f+56|0);ib=f+80|0;break a}a=P()|0;break b}a=P()|0;wb(f+24|0)}Rc(f+56|0);S(a|0);p()}}function wba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Ai(a,b,c,d);x[a>>2]=45808;b=Nb(a+4208|0);x[a+4240>>2]=0;x[a+4244>>2]=0;c=x[c+24620>>2];x[a+4260>>2]=0;x[a+4256>>2]=c;x[a+4236>>2]=0;c=a+4228|0;x[c>>2]=1048550822;x[c+4>>2]=1048550822;x[a+4220>>2]=1056964608;x[a+4224>>2]=1056964608;x[27524]=0;R(903,a+44|0,2);c=x[27524];x[27524]=0;if((c|0)!=1){return a|0}c=P()|0;uc(b);Rf(a);S(c|0);p()}function dja(a,b){a=a|0;b=b|0;var c=0,d=0;a:{a=DA(a,b);x[27524]=0;c=Q(663,a+12|0,b+12|0)|0;d=x[27524];x[27524]=0;b:{c:{if((d|0)!=1){x[27524]=0;Q(664,a+24|0,b+24|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break c}c=x[b+40>>2];x[a+36>>2]=x[b+36>>2];x[a+40>>2]=c;w[a+52>>1]=z[b+52>>1];c=x[b+48>>2];x[a+44>>2]=x[b+44>>2];x[a+48>>2]=c;break a}b=P()|0;break b}b=P()|0;ec(c)}ec(a);S(b|0);p()}}function dH(a,b,c){var d=0,e=0,f=E(0),g=0,h=E(0);e=ib-16|0;ib=e;a:{b:{c:{if((a|0)!=(b|0)){g=x[12e4];x[12e4]=0;Fd();d=ib-16|0;ib=d;_w(d,a,e+12|0,0);f=GE(x[d>>2],x[d+4>>2],x[d+8>>2],x[d+12>>2]);ib=d+16|0;a=x[12e4];if(!a){break c}if(x[e+12>>2]!=(b|0)){break b}h=f;if((a|0)!=68){break a}break b}x[c>>2]=4;break a}x[12e4]=g;if(x[e+12>>2]==(b|0)){break a}}x[c>>2]=4;f=h}ib=e+16|0;return f}function cj(a,b,c,d,e){var f=0,g=0,h=0;f=ib-16|0;ib=f;x[f+8>>2]=b;b=0;g=6;a:{b:{if(jj(a,f+8|0)){break b}h=bl(x[a>>2]);g=4;if(!Bh(x[d+8>>2],64,h)){break b}b=An(d,h);while(1){c:{b=b-48|0;h=im(a);if(!yp(h,f+8|0)|(e|0)<2){break c}g=bl(x[h>>2]);if(!Bh(x[d+8>>2],64,g)){break a}e=e-1|0;b=An(d,g)+D(b,10)|0;continue}break}g=2;if(!jj(h,f+8|0)){break a}}x[c>>2]=x[c>>2]|g}ib=f+16|0;return b}function una(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=ib-16|0;ib=d;a:{e=Re(a);b:{if(e>>>0>1){break b}c:{if(e){x[27524]=0;U(333,d|0,a|0,c|0);a=x[27524];x[27524]=0;if((a|0)!=1){Om(b,d);ec(d);break c}a=V(30496)|0;if((jb|0)!=(da(30496)|0)){break a}_(a|0)|0;$();break b}if(!Ob(x[a>>2],x[a+8>>2],c)){break b}qv(a,b,c)}f=cd(x[b>>2],x[b+4>>2])>>>0>=c>>>0}ib=d+16|0;return f|0}S(a|0);p()}function rn(a,b,c,d,e,f){var g=0;x[27524]=0;Y(958,a|0);g=x[27524];x[27524]=0;a:{b:{if((g|0)!=1){g=x[a+24>>2];x[27524]=0;b=fa(f|0,g|0,b|0,c|0,d|0)|0;c=x[27524];x[27524]=0;if((c|0)!=1){break b}}_(V(0)|0)|0;x[27524]=0;X(945,e|0,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)==1){break a}$();b=0}return b}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function U9(a){a=a|0;var b=0;x[27524]=0;Y(983,a|0);b=x[27524];x[27524]=0;if((b|0)!=1){x[a+24>>2]=0;b=x[a+28>>2];if(b){lb[x[x[b>>2]+4>>2]](b)}x[a+28>>2]=0;b=x[a+20>>2];if(b){Ib(b);x[a+20>>2]=0}Ib(a);return}_(V(0)|0)|0;x[27524]=0;X(945,5054,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)!=1){$();return}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function T3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=a+32|0;Zq(c,b);x[a+44>>2]=0;b=x[a+48>>2];if(b&8){b=vc(c)+Eb(c)|0;x[a+44>>2]=b;d=vc(c);Fn(a,d,d,b);b=x[a+48>>2]}a:{if(!(b&16)){break a}b=Eb(c);e=a,f=b+vc(c)|0,x[e+44>>2]=f;jy(c,ad(c));d=vc(c);hx(a,d,Eb(c)+d|0);if(!(y[a+48|0]&3)){break a}while(1){if((b|0)<0){rs(a,2147483647);b=b-2147483647|0;continue}break}if(!b){break a}rs(a,b)}}function Lh(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ib-32|0;ib=c;a:{if(!y[b+4|0]){while(1){if((d|0)==4){d=0;x[c+28>>2]=0;e=dc(c+8|0,c+28|0,4);kc(c+16|0,x[a>>2],x[a+8>>2],x[e>>2],x[e+4>>2]);b:{if(x[c+20>>2]!=4){break b}if(Qb(c+28|0,b,4)){break b}Yb(a,4);d=1}ib=c+32|0;break a}e=b+d|0;d=d+1|0;if(y[e|0]){continue}break}aa(17442,9027,414,13118);p()}aa(17421,9027,412,13118);p()}return d|0}function y3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=ib-16|0;ib=f;while(1){a:{if((c|0)<=(g|0)){break a}d=x[a+24>>2];e=x[a+28>>2];if(d>>>0>=e>>>0){if((lb[x[x[a>>2]+52>>2]](a,x[b>>2])|0)==-1){break a}g=g+1|0;b=b+4|0}else{x[f+12>>2]=e-d>>2;x[f+8>>2]=c-g;e=d;d=x[rd(f+12|0,f+8|0)>>2];ui(e,b,d);e=d<<2;x[a+24>>2]=e+x[a+24>>2];g=g+d|0;b=b+e|0}continue}break}ib=f+16|0;return g|0}function vU(a,b){var c=0,d=0,e=0;c=ib-32|0;ib=c;a:{if(!y[b+5|0]){while(1){if((d|0)==5){d=0;v[c+28|0]=0;x[c+24>>2]=0;e=dc(c+8|0,c+24|0,5);kc(c+16|0,x[a>>2],x[a+8>>2],x[e>>2],x[e+4>>2]);b:{if(x[c+20>>2]!=5){break b}if(Qb(c+24|0,b,5)){break b}Yb(a,5);d=1}ib=c+32|0;break a}e=b+d|0;d=d+1|0;if(y[e|0]){continue}break}aa(17442,9027,414,13118);p()}aa(17421,9027,412,13118);p()}return d}function Yja(a){a=a|0;var b=0,c=0,d=0,e=0;e=ib-16|0;ib=e;b=mc(2500);c=ib-2496|0;ib=c;_S(a,c,c+2496|0);a=0;while(1){if((a|0)==624){x[b+2496>>2]=0;a:{if(x[b>>2]<0){break a}a=1;while(1){if((a|0)!=624){d=a<<2;a=a+1|0;if(!x[b+d>>2]){continue}break a}break}x[b>>2]=-2147483648}ib=c+2496|0}else{d=a<<2;x[d+b>>2]=x[c+d>>2];a=a+1|0;continue}break}a=x[uf(e+8|0,b)>>2];ib=e+16|0;return a|0}function bH(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=ib-16|0;ib=e;a:{b:{c:{if((a|0)!=(b|0)){g=x[12e4];x[12e4]=0;Fd();d=ib-16|0;ib=d;_w(d,a,e+12|0,1);f=mw(x[d>>2],x[d+4>>2],x[d+8>>2],x[d+12>>2]);ib=d+16|0;a=x[12e4];if(!a){break c}if(x[e+12>>2]!=(b|0)){break b}h=f;if((a|0)!=68){break a}break b}x[c>>2]=4;break a}x[12e4]=g;if(x[e+12>>2]==(b|0)){break a}}x[c>>2]=4;f=h}ib=e+16|0;return f}function n8(a,b){a=a|0;b=+b;var c=0;x[27524]=0;Y(958,a|0);c=x[27524];x[27524]=0;a:{b:{if((c|0)!=1){c=x[a+24>>2];x[27524]=0;b=+Wa(1050,c|0,+b);c=x[27524];x[27524]=0;if((c|0)!=1){break b}}_(V(0)|0)|0;x[27524]=0;X(945,7554,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)==1){break a}$();b=0}return+b}a=P()|0;x[27524]=0;Z(18);c=x[27524];x[27524]=0;if((c|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function OL(a){a=a|0;var b=0,c=0,d=0,e=0;c=ib-32|0;ib=c;a:{e=a+36|0;b=x[e>>2];d=x[a+40>>2];b:{if(Mb(b,d)){sc(c+24|0);break b}b=c+8|0;Nn(b,a);x[27524]=0;b=T(1018,b|0)|0;d=x[27524];x[27524]=0;if((d|0)==1){break a}x[c+24>>2]=b;nf(c+8|0);d=x[a+40>>2];b=x[a+36>>2]}if(!Mb(b,d)){e=x[c+24>>2];b=x[e>>2]}a=Xi(b,x[e+4>>2]);el(c+24|0);ib=c+32|0;return a|0}a=P()|0;nf(c+8|0);S(a|0);p()}function Ica(a,b){a=a|0;b=b|0;var c=E(0);a:{switch(b|0){case 0:return E(B[a+4220>>2]);case 1:return E(B[a+4224>>2]);case 2:return E(B[a+4228>>2]);case 3:return E(y[a+4240|0]?E(1):E(0));case 4:return E(E(E(x[a+4232>>2])*E(.03125)));case 5:return E(y[a+4241|0]?E(1):E(0));case 6:return E(y[a+4242|0]?E(1):E(0));case 7:c=y[a+4244|0]?E(1):E(0);break;default:break a}}return E(c)}function PH(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=ib-32|0;ib=d;e=Kc(d,c);x[27524]=0;U(1136,d+16|0,b|0,e|0);c=x[27524];x[27524]=0;a:{b:{if((c|0)!=1){x[27524]=0;a=Q(1137,a|0,d+16|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break b}wb(d+16|0);wb(e);x[a>>2]=107468;c=x[b+4>>2];x[a+8>>2]=x[b>>2];x[a+12>>2]=c;ib=d+32|0;return a|0}c=P()|0;break a}c=P()|0;wb(d+16|0)}wb(e);S(c|0);p()}function tW(a){var b=0,c=0;a:{if(Qb(a,15204,3)){break a}c=y[a+3|0];if(c>>>0>9){break a}if((Fb(y[a+202|0]|y[a+203|0]<<8)-1e4&65535)>>>0<57516){break a}b=1;b:{if(c>>>0>5){break b}if(!Fb(y[a+228|0]|y[a+229|0]<<8)){break a}if(!Fb(y[a+230|0]|y[a+231|0]<<8)){break a}b=0;if(Fb(y[a+232|0]|y[a+233|0]<<8)>>>0>4095){break b}b=Fb(y[a+234|0]|y[a+235|0]<<8)>>>0<100}return b}return 0}function XM(a){var b=E(0),c=0,d=E(0);b=B[a+4224>>2];B[a+4260>>2]=M(E(E(1)-E(b*b)));v[a+4264|0]=B[a+4236>>2]>E(.5);d=E(A[a+4256>>2]);b=E(E(E(E(B[a+4228>>2]*E(1999))+E(1))/E(1e3))*d);a:{if(b<E(4294967296)&b>=E(0)){c=~~b>>>0;break a}c=0}x[a+4248>>2]=c;c=a+4252|0;b=E(E(E(E(B[a+4232>>2]*E(1999))+E(1))/E(1e3))*d);b:{if(b<E(4294967296)&b>=E(0)){a=~~b>>>0;break b}a=0}x[c>>2]=a}function P8(a){a=a|0;var b=0,c=0;x[27524]=0;Y(958,a|0);b=x[27524];x[27524]=0;a:{b:{if((b|0)!=1){b=x[a+24>>2];x[27524]=0;b=T(1026,b|0)|0;c=x[27524];x[27524]=0;if((c|0)!=1){break b}}_(V(0)|0)|0;x[27524]=0;X(945,7226,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function Qma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);if(b){if(zh(2147483647)>>>0<b>>>0){_c();p()}e=b<<1;d=mc(e);x[a>>2]=d;x[a+4>>2]=d;g=Db(a),h=d+e|0,x[g>>2]=h;e=ib-16|0;ib=e;d=ei(e,a,b);b=x[d+4>>2];f=x[d+8>>2];while(1){if((b|0)==(f|0)){ic(d);ib=e+16|0}else{Rj(b,y[c|0]|y[c+1|0]<<8);b=b+2|0;x[d+4>>2]=b;continue}break}}return a|0}function IF(a,b,c,d,e){var f=0;f=ib-16|0;ib=f;a:{b:{c:{if(!d){a=ba(8)|0;x[27524]=0;c=Q(55,f|0,8148)|0;b=x[27524];x[27524]=0;if((b|0)==1){break c}lc(a,c);x[27524]=0;U(123,a|0,50060,962);a=x[27524];x[27524]=0;if((a|0)!=1){break a}b=P()|0;wb(c);break b}il(a,b,e);c=BF(a,c,e,d,75664,76436);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);ib=f+16|0;return c}b=P()|0;ca(a|0)}S(b|0)}p()}function HF(a,b,c,d,e){var f=0;f=ib-16|0;ib=f;a:{b:{c:{if(!d){a=ba(8)|0;x[27524]=0;c=Q(55,f|0,8148)|0;b=x[27524];x[27524]=0;if((b|0)==1){break c}lc(a,c);x[27524]=0;U(123,a|0,50060,962);a=x[27524];x[27524]=0;if((a|0)!=1){break a}b=P()|0;wb(c);break b}il(a,b,e);c=BF(a,c,e,d,74836,75608);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);ib=f+16|0;return c}b=P()|0;ca(a|0)}S(b|0)}p()}function CK(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0;c=ib-16|0;ib=c;a:{b:{c:{if(b<=0|b>4){a=ba(8)|0;x[27524]=0;c=Q(55,c|0,7802)|0;d=x[27524];x[27524]=0;if((d|0)==1){break c}lc(a,c);x[27524]=0;U(123,a|0,50060,962);a=x[27524];x[27524]=0;if((a|0)!=1){break a}d=P()|0;wb(c);break b}a=x[a+32>>2];e=a,f=Xe(65536/b),x[e+480244>>2]=f;Yp(a);ib=c+16|0;return}d=P()|0;ca(a|0)}S(d|0)}p()}function AK(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0;c=ib-16|0;ib=c;a:{b:{c:{if(b<=0|b>4){a=ba(8)|0;x[27524]=0;c=Q(55,c|0,7823)|0;d=x[27524];x[27524]=0;if((d|0)==1){break c}lc(a,c);x[27524]=0;U(123,a|0,50060,962);a=x[27524];x[27524]=0;if((a|0)!=1){break a}d=P()|0;wb(c);break b}a=x[a+32>>2];e=a,f=Xe(b*65536),x[e+480240>>2]=f;Yp(a);ib=c+16|0;return}d=P()|0;ca(a|0)}S(d|0)}p()}function vX(a,b){var c=0,d=0;b=!x[a+24>>2]|b;x[a+16>>2]=b;if(b&x[a+20>>2]){a=ib-16|0;ib=a;c=ba(16)|0;b=ib-16|0;ib=b;if(!y[480128]){v[480128]=1}dc(b+8|0,1,109284);d=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=d;ib=b+16|0;b=x[a+12>>2];a=x[a+8>>2];x[27524]=0;a=Ea(1138,c|0,8891,a|0,b|0)|0;b=x[27524];x[27524]=0;if((b|0)!=1){ha(a|0,93620,1139);p()}a=P()|0;ca(c|0);S(a|0);p()}}function my(a){var b=E(0),c=E(0),d=0,e=E(0),f=0;b=E(A[x[a+16>>2]+24620>>2]);c=E(E(E(lb[x[x[a>>2]+208>>2]](a))*b)/E(1e3));d=a,e=E(E(c*E(lb[x[x[a>>2]+200>>2]](a)))*E(2048)),B[d+4248>>2]=e;d=a,f=Yh(E(E(c+E(2))*E(4096))),x[d+4256>>2]=f;c=E(lb[x[x[a>>2]+212>>2]](a));B[a+4252>>2]=c;b=E(c/b);if(!(lb[x[x[a>>2]+196>>2]](a)|0)){b=eN(E(b*E(3.1415927410125732)))}B[a+4244>>2]=b+b}function _8(a){a=a|0;var b=0,c=0;x[27524]=0;Y(958,a|0);b=x[27524];x[27524]=0;a:{b:{if((b|0)!=1){b=x[a+24>>2];x[27524]=0;c=+la(1017,b|0);b=x[27524];x[27524]=0;if((b|0)!=1){break b}}_(V(0)|0)|0;x[27524]=0;X(945,7626,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function Rx(a,b,c){var d=0,e=0,f=0;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);if(c){Gk(a,c);d=ib-16|0;ib=d;e=Fh(d,a,c);c=x[e+4>>2];f=x[e+8>>2];while(1){if((c|0)==(f|0)){ic(e);ib=d+16|0}else{x[c>>2]=0;sc(c);c=c+4|0;x[e+4>>2]=c;continue}break}}c=0;e=0;d=ib-16|0;ib=d;f=d+8|0;while(1){if(c>>>0<32){c=c+48|0;e=XO(b);continue}break}x[f>>2]=e;Wn(f);ib=d+16|0;x[a+12>>2]=x[f>>2];return a}function pK(a,b){a=a|0;b=b|0;var c=0;c=ib-16|0;ib=c;a:{b:{c:{if(b>>>0>=256){b=ba(8)|0;x[27524]=0;c=Q(55,c|0,10644)|0;a=x[27524];x[27524]=0;if((a|0)==1){break c}lc(b,c);x[27524]=0;U(123,b|0,50060,962);a=x[27524];x[27524]=0;if((a|0)!=1){break a}a=P()|0;wb(c);break b}a=x[a+32>>2]+D(b,872)|0;x[a+1075008>>2]=0;x[a+1075068>>2]=0;ib=c+16|0;return}a=P()|0;ca(b|0)}S(a|0)}p()}function mm(a){if((a|0)>=0){if(a>>>0<=16383){if(a>>>0<=15){return v[a+87936|0]}if(a>>>0<=511){return v[(a>>>5|0)+87936|0]+5|0}return v[(a>>>10|0)+87936|0]+10|0}if(a>>>0<=16777215){if(a>>>0<=524287){return v[(a>>>15|0)+87936|0]+15|0}return v[(a>>>20|0)+87936|0]+20|0}if(a>>>0<=536870911){return v[(a>>>25|0)+87936|0]+25|0}a=v[(a>>>30|0)+87936|0]+30|0}else{a=0}return a}function aS(a,b){var c=0,d=0,e=0,f=0;c=ib-16|0;ib=c;a=Kb(a);d=Eb(b);x[27524]=0;R(46,a|0,d|0);d=x[27524];x[27524]=0;a:{if((d|0)!=1){e=c,f=Bt(b),x[e+8>>2]=f;e=c,f=yt(b),x[e>>2]=f;while(1){if(!Fi(c+8|0,c)){break a}b=y[x[c+8>>2]];x[27524]=0;R(47,a|0,((b|0)==13?10:b)<<24>>24);b=x[27524];x[27524]=0;if((b|0)!=1){Ie(c+8|0);continue}break}}b=P()|0;wb(a);S(b|0);p()}ib=c+16|0}function x5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ib-16|0;ib=c;a:{b:{if((ik(y[a+140|0])|0)!=1){break b}if((SJ(a)|0)!=(b|0)){break b}d=a+120|0;Ns(y[d+20|0]);b=ib-16|0;ib=b;x[b+8>>2]=c+8;a=ib-16|0;ib=a;e=x[18263];x[a+8>>2]=x[18262];x[a+12>>2]=e;e=x[18261];x[a>>2]=x[18260];x[a+4>>2]=e;lb[x[Dp(a,ik(y[d+20|0]))>>2]](b+8|0,d);ib=a+16|0;ib=b+16|0;break a}RJ(a,1,b)}ib=c+16|0}function v4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Tl(a);x[d>>2]=77412;a=kJ(zc(d),gJ(b));x[a>>2]=77744;x[27524]=0;Q(339,a+24|0,65536)|0;c=x[27524];x[27524]=0;a:{if((c|0)!=1){c=a+36|0;Rb(c,0,192);e=a+228|0;while(1){x[c>>2]=0;x[c+4>>2]=0;v[c+8|0]=0;c=c+12|0;if((e|0)!=(c|0)){continue}break}Rb(e,0,64);break a}b=P()|0;Gs(a);S(b|0);p()}x[a+292>>2]=b;x[a>>2]=77556;return d|0}function lK(a,b){a=a|0;b=b|0;var c=0;c=ib-16|0;ib=c;a:{b:{c:{if(b>>>0>=256){b=ba(8)|0;x[27524]=0;c=Q(55,c|0,10644)|0;a=x[27524];x[27524]=0;if((a|0)==1){break c}lc(b,c);x[27524]=0;U(123,b|0,50060,962);a=x[27524];x[27524]=0;if((a|0)!=1){break a}a=P()|0;wb(c);break b}ib=c+16|0;return+(+(x[(x[a+32>>2]+D(b,872)|0)+1075684>>2]-128|0)*.0078125)}a=P()|0;ca(b|0)}S(a|0)}p()}function tD(a){var b=0,c=0,d=0,e=0,f=0;a:{b:{if(Qb(a,11062,2)){if(Qb(a,13772,2)){break a}if(y[a+110|0]<=64){break b}break a}if(y[a+110|0]>64){break a}}if(v[a+112|0]<0|y[a+111|0]>128){break a}while(1){d=(b|0)==128;if(d){break a}c=a+b|0;e=v[c+113|0];if((e|0)<-2){break a}f=y[c+241|0];if(!f&(e|0)>=0|f>>>0>15){break a}b=b+1|0;if(y[c+369|0]<64){continue}break}}return d}function jK(a,b){a=a|0;b=b|0;var c=0;c=ib-16|0;ib=c;a:{b:{c:{if(b>>>0>=256){b=ba(8)|0;x[27524]=0;c=Q(55,c|0,10644)|0;a=x[27524];x[27524]=0;if((a|0)==1){break c}lc(b,c);x[27524]=0;U(123,b|0,50060,962);a=x[27524];x[27524]=0;if((a|0)!=1){break a}a=P()|0;wb(c);break b}ib=c+16|0;return+(+w[(x[a+32>>2]+D(b,872)|0)+1075766>>1]*30517578125e-15)}a=P()|0;ca(b|0)}S(a|0)}p()}function es(a,b,c){var d=0,e=0;if(c&2048){v[a|0]=43;a=a+1|0}if(c&1024){v[a|0]=35;a=a+1|0}d=c&260;if((d|0)!=260){v[a|0]=46;v[a+1|0]=42;a=a+2|0}c=c&16384;while(1){e=y[b|0];if(e){v[a|0]=e;a=a+1|0;b=b+1|0;continue}break}a:{b:{if((d|0)!=256){if((d|0)!=4){break b}b=c?70:102;break a}b=c?69:101;break a}b=c?65:97;if((d|0)==260){break a}b=c?71:103}v[a|0]=b;return(d|0)!=260}function bj(a,b,c,d,e){var f=0,g=0,h=0;f=ib-16|0;ib=f;x[f+8>>2]=b;b=0;g=6;a:{b:{if(gk(a,f+8|0)){break b}g=4;h=al(x[a>>2]);if(!$k(d,64,h)){break b}b=zn(d,h);while(1){c:{b=b-48|0;h=Gn(a);if(!ss(h,f+8|0)|(e|0)<2){break c}g=al(x[h>>2]);if(!$k(d,64,g)){break a}e=e-1|0;b=zn(d,g)+D(b,10)|0;continue}break}g=2;if(!gk(h,f+8|0)){break a}}x[c>>2]=x[c>>2]|g}ib=f+16|0;return b}function Kna(a,b){a=a|0;b=b|0;var c=0,d=0;d=ib-16|0;ib=d;c=d+8|0;$u(c,a,b);Xf(b,y[d+8|0],y[Lc(c)|0]);a=y[b+3|0];a:{if((a|0)!=9){if((a|0)!=19){break a}a=y[b+5|0];c=a&240;if((c|0)!=128){if((c|0)!=64){if((c|0)!=48){break a}v[b+3|0]=45;v[b+5|0]=a&15;break a}if((a|0)!=64){break a}v[b+3|0]=0;v[b|0]=254;break a}v[b+3|0]=20;v[b+5|0]=a&15|160;break a}v[b+3|0]=0}ib=d+16|0}function BY(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=ib-16|0;ib=d;c=-1;a:{if(!kg(a,7)){break a}c=0;if(!RC(a,11670)){break a}c=ib-16|0;ib=c;OC(c+8|0,d);e=x[c+12>>2];ld(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){gd(a,x[c+12>>2])}ib=c+16|0;e=(e|0)==(f|0);if(!e){NC(d)}c=-1;if(!e){break a}c=0;if(!QC(y[d+1|0])){break a}c=Ee(a,b,PC(d),kb)}ib=d+16|0;return c|0}function eda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=ib-16|0;ib=d;c=mc(64);x[27524]=0;e=T(841,c|0)|0;f=x[27524];x[27524]=0;a:{if((f|0)!=1){c=uf(d,e);e=x[c>>2];x[27524]=0;a=W(901,e|0,a|0,b|0)|0;b=x[27524];x[27524]=0;b:{c:{if((b|0)!=1){if((a|0)==1){break c}sc(d+8|0);break b}a=P()|0;yg(c);break a}ge(d+8|0,c)}yg(c);ib=d+16|0;return x[d+8>>2]}a=P()|0;Ib(c)}S(a|0);p()}function q4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);if(c){if(zh(357913941)>>>0<c>>>0){_c();p()}d=LE(c);x[a>>2]=d;x[a+4>>2]=d;f=Db(a),g=d+D(c,12)|0,x[f>>2]=g;e=Cd(b,c);d=ib-16|0;ib=d;c=hu(d,a,c);x[27524]=0;U(1111,b|0,e|0,c+4|0);b=x[27524];x[27524]=0;a:{if((b|0)!=1){ic(c);ib=d+16|0;break a}a=P()|0;ic(c);S(a|0);p()}}return a|0}function CO(a,b){var c=0,d=0,e=0,f=0;a:{if(z[a+480188>>1]<=b>>>0){break a}b:{c:{c=D(b,872)+a|0;d=y[c+1075783|0];switch(d-31|0){case 1:break b;case 0:break c;default:break a}}if(!(y[a+480209|0]&16)){break a}}e=a+1074376|0;f=(d|0)==32;c=v[c+1075785|0];d:{if((c|0)>=0){d=De(a+901692|0,y[(D(b,872)+a|0)+1075836|0]);break d}d=De(a+902204|0,c&127)}aQ(a,e,b,f,d,c&255)}}function $n(a,b,c,d){a:{if(x[a+480180>>2]==4){if(c){v[b+810|0]=y[b+810|0]&15|c<<4;break a}c=y[b+810|0]>>>4|0;break a}if(d){if(c){v[b+834|0]=c;break a}c=y[b+834|0];break a}if(c){v[b+810|0]=c;break a}c=y[b+810|0]}b:{if(!(v[b+851|0]&1)){break b}c=x[b+688>>2]+((c&255)<<2)|0;x[b+688>>2]=(c|0)>=256?256:c;if(!(v[a+480180|0]&1)){break b}x[b+88>>2]=x[b+88>>2]|2097152}}function Dw(a,b,c,d,e,f){var g=0,h=0,i=0;g=ib-16|0;ib=g;x[a+4>>2]=0;x[a>>2]=49220;h=mc(80);x[27524]=0;d=T(1060,d|0)|0;i=x[27524];x[27524]=0;a:{b:{if((i|0)!=1){x[g>>2]=d;d=x[ge(g+8|0,g)>>2];x[27524]=0;b=ja(f|0,h|0,b|0,c-b|0,d|0,e|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break b}x[a+4>>2]=b;Xc(g);ib=g+16|0;return a}a=P()|0;break a}a=P()|0;Xc(g)}Ib(h);S(a|0);p()}function Ela(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;f=ib-16|0;ib=f;c=Af(a,c);Pd(f,x[a+36>>2]);a:{if(!c){Pc(f,a+32|0,5);e=0;if(zb(x[x[f>>2]>>2],x[f+4>>2])){break a}}h=x[a+36>>2];g=ib-16|0;ib=g;e=Kb(g);x[27524]=0;fa(461,b|0,h|0,e|0,d|0)|0;b=x[27524];x[27524]=0;b:{if((b|0)!=1){xb(e);ib=g+16|0;break b}a=P()|0;xb(e);S(a|0);p()}e=c}af(a,e);ib=f+16|0}function Dba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=Ai(a,b,c,d);x[a>>2]=45428;b=a+4208|0;e=Bb(b,0),f=1060320051,x[e>>2]=f;e=Bb(b,1),f=1041865114,x[e>>2]=f;e=Bb(b,2),f=1065353216,x[e>>2]=f;e=Bb(b,3),f=1049951732,x[e>>2]=f;e=Bb(b,4),f=1049951732,x[e>>2]=f;x[27524]=0;R(903,a+44|0,2);b=x[27524];x[27524]=0;if((b|0)!=1){return a|0}b=P()|0;Rf(a);S(b|0);p()}function Qr(a,b,c,d,e,f){var g=0,h=0,i=0;g=ib-16|0;ib=g;x[a+4>>2]=0;x[a>>2]=49220;h=mc(80);x[27524]=0;d=T(1060,d|0)|0;i=x[27524];x[27524]=0;a:{b:{if((i|0)!=1){x[g>>2]=d;d=x[ge(g+8|0,g)>>2];x[27524]=0;b=ja(f|0,h|0,b|0,c|0,d|0,e|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break b}x[a+4>>2]=b;Xc(g);ib=g+16|0;return a}a=P()|0;break a}a=P()|0;Xc(g)}Ib(h);S(a|0);p()}function _t(a,b){var c=0,d=0;c=ib-32|0;ib=c;d=c+16|0;BS(d,a,a+1|0,a+2|0,a+3|0);BS(c,b,b+1|0,b+2|0,b+3|0);b=Zt(y[x[d>>2]],y[x[c>>2]]);a:{if(!Bj(b)){break a}b=y[x[d+4>>2]];a=y[x[c+4>>2]];b=(a|0)!=(b|0)?b<<24>>24<a<<24>>24?-1:1:0;if(!Bj(b)){break a}b=Zt(y[x[d+8>>2]],y[x[c+8>>2]]);if(!Bj(b)){break a}b=Zt(y[x[d+12>>2]],y[x[c+12>>2]])}a=Ue(b);ib=c+32|0;return a}function caa(a){a=a|0;var b=0;x[27524]=0;Y(958,a|0);b=x[27524];x[27524]=0;if((b|0)!=1){b=x[a+24>>2];if(b){Ib(Kp(b))}x[a+24>>2]=0;b=x[a+20>>2];if(b){Ib(b);x[a+20>>2]=0}Ib(a);return}_(V(0)|0)|0;x[27524]=0;X(945,5081,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)!=1){$();return}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function RW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=ib-32|0;ib=d;e=Nb(a);a=Cb(x[b>>2]);x[d+24>>2]=a;b=Cb(x[b+4>>2]);a:{while(1){if(Mb(a,b)){ci(d,x[a>>2],x[a+4>>2]);if((ac(x[d>>2])|0)==(c|0)){Eo(d,a);x[27524]=0;R(356,e|0,d|0);a=x[27524];x[27524]=0;if((a|0)==1){break a}yb(d)}a=x[Qm(d+24|0)>>2];continue}break}ib=d+32|0;return}a=P()|0;yb(d);Sc(e);S(a|0);p()}function BD(a,b,c){var d=0,e=0,f=0,g=0;a:{d=to(b,Ti(a));b=to(c,b);if(xd(x[a+4>>2],y[a+11|0])>>>0>=d>>>0){if((b|0)==-1){wB(a,nd(a),d);break a}e=ib-16|0;ib=e;x[e+12>>2]=b;if(b){f=xd(x[a+4>>2],y[a+11|0]);g=nd(a);c=f-d|0;x[e+8>>2]=c;b=x[Hb(e+12|0,e+8|0)>>2];b:{if((c|0)==(b|0)){b=c;break b}d=d+g|0;ai(d,b+d|0,c-b|0)}wB(a,g,f-b|0)}ib=e+16|0;break a}yk();p()}}function nz(a,b,c,d){a:{if(x[a+1074392>>2]!=(c|0)){break a}b:{if(d){c=D(b,872)+a|0;x[c+1075688>>2]=0;d=c+1075e3|0;x[d>>2]=0;x[d+4>>2]=0;c=x[c+1075080>>2]|4096;break b}c=D(b,872)+a|0;x[c+1075680>>2]=0;c=x[c+1075080>>2]}d=D(b,872)+a|0;x[d+1075080>>2]=c|2097152;wm(a,b,255,0);if(!(y[d+1075081|0]&2)){break a}a=x[a+1298300>>2];if(!Ed(a)){break a}vj(a,b,0)}}function Pr(a,b,c,d,e){var f=0,g=0,h=0;f=ib-16|0;ib=f;x[a+4>>2]=0;x[a>>2]=49220;g=mc(80);x[27524]=0;c=T(1060,c|0)|0;h=x[27524];x[27524]=0;a:{b:{if((h|0)!=1){x[f>>2]=c;c=x[ge(f+8|0,f)>>2];x[27524]=0;b=fa(e|0,g|0,b|0,c|0,d|0)|0;c=x[27524];x[27524]=0;if((c|0)==1){break b}x[a+4>>2]=b;Xc(f);ib=f+16|0;return a}a=P()|0;break a}a=P()|0;Xc(f)}Ib(g);S(a|0);p()}function DK(a,b){a=a|0;b=b|0;var c=0;c=ib-16|0;ib=c;a:{b:{c:{if(b-513>>>0<=4294966814){b=ba(8)|0;x[27524]=0;c=Q(55,c|0,9311)|0;a=x[27524];x[27524]=0;if((a|0)==1){break c}lc(b,c);x[27524]=0;U(123,b|0,50060,962);a=x[27524];x[27524]=0;if((a|0)!=1){break a}a=P()|0;wb(c);break b}x[x[a+32>>2]+1074420>>2]=D(b,1e4);ib=c+16|0;return}a=P()|0;ca(b|0)}S(a|0)}p()}function DF(a,b,c){var d=0;d=ib-16|0;ib=d;a:{b:{c:{if(b>>>0>=256){b=ba(8)|0;x[27524]=0;c=Q(55,d|0,10644)|0;a=x[27524];x[27524]=0;if((a|0)==1){break c}lc(b,c);x[27524]=0;U(123,b|0,50060,962);a=x[27524];x[27524]=0;if((a|0)!=1){break a}a=P()|0;wb(c);break b}a=(x[a+32>>2]+D(b,872)|0)+1075080|0;x[a>>2]=x[a>>2]|c;ib=d+16|0;return}a=P()|0;ca(b|0)}S(a|0)}p()}function qT(a,b){var c=0,d=0,e=0;c=ib-32|0;ib=c;a:{if(!y[b+4|0]){while(1){if((d|0)==4){d=0;x[c+28>>2]=0;e=dc(c+8|0,c+28|0,4);ld(c+16|0,a,x[e>>2],x[e+4>>2]);b:{if(x[c+20>>2]!=4){break b}if(Qb(c+28|0,b,4)){break b}gd(a,4);d=1}ib=c+32|0;break a}e=b+d|0;d=d+1|0;if(y[e|0]){continue}break}aa(17442,9027,414,13118);p()}aa(17421,9027,412,13118);p()}return d}function pba(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;b=pN(a,b,c,d,e^1);x[b>>2]=46040;a=b+4208|0;f=Bb(a,0),g=1056964608,x[f>>2]=g;f=Bb(a,1),g=1065353216,x[f>>2]=g;f=Bb(a,2),g=1020054733,x[f>>2]=g;f=Bb(a,3),g=1065353216,x[f>>2]=g;f=Bb(a,4),g=1056964608,x[f>>2]=g;f=Bb(a,5),g=1048406533,x[f>>2]=g;f=Bb(a,6),g=1056964608,x[f>>2]=g;return b|0}function iH(a,b,c,d){var e=0,f=0,g=0;e=ib-16|0;ib=e;a:{if((a|0)!=(b|0)){g=x[12e4];x[12e4]=0;Fd();d=jH(a,e+12|0,d);a=kb;f=x[12e4];b:{if(f){if(x[e+12>>2]!=(b|0)){break b}if((f|0)!=68){break a}x[c>>2]=4;a=!!d&(a|0)>=0|(a|0)>0;d=a?-1:0;a=a?2147483647:-2147483648;break a}x[12e4]=g;if(x[e+12>>2]==(b|0)){break a}}}x[c>>2]=4;d=0;a=0}ib=e+16|0;kb=a;return d}function cK(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;g=ib-16|0;ib=g;e=Eb(a);if(e>>>0>=b>>>0){f=ad(a);a:{if(f-e>>>0>=d>>>0){if(!d){break a}f=vc(a);i=f+b|0;if((b|0)!=(e|0)){h=b+f|0;ai(h+d|0,h,e-b|0);c=(c>>>0>=h>>>0?e+f>>>0>c>>>0?d:0:0)+c|0}ai(i,c,d);b=d+e|0;Wh(a,b);v[g+15|0]=0;oe(b+f|0,g+15|0);break a}qp(a,f,(d+e|0)-f|0,e,b,0,d,c)}ib=g+16|0;return a}yk();p()}function Z9(a,b){a=a|0;b=b|0;var c=0;x[27524]=0;Y(958,a|0);c=x[27524];x[27524]=0;a:{b:{if((c|0)!=1){x[a+16>>2]=b;b=x[a+20>>2];if(!b){break b}Ib(b);x[a+20>>2]=0;return}_(V(0)|0)|0;x[27524]=0;X(945,5663,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)==1){break a}$()}return}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function K2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=x[a+84>>2];f=x[e>>2];d=x[e+4>>2];h=x[a+28>>2];g=x[a+20>>2]-h|0;g=d>>>0<g>>>0?d:g;if(g){rc(f,h,g);f=g+x[e>>2]|0;x[e>>2]=f;d=x[e+4>>2]-g|0;x[e+4>>2]=d}d=c>>>0>d>>>0?d:c;if(d){rc(f,b,d);f=d+x[e>>2]|0;x[e>>2]=f;x[e+4>>2]=x[e+4>>2]-d}v[f|0]=0;b=x[a+44>>2];x[a+28>>2]=b;x[a+20>>2]=b;return c|0}function Tea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[a>>2]=b;c=ib-16|0;ib=c;d=mc(223888);x[27524]=0;b=Q(808,d|0,b+1074376|0)|0;e=x[27524];x[27524]=0;a:{if((e|0)!=1){b=x[uf(c+8|0,b)>>2];ib=c+16|0;break a}a=P()|0;Ib(d);S(a|0);p()}x[a+4>>2]=b;b=Nb(a+8|0);x[27524]=0;Y(591,a|0);c=x[27524];x[27524]=0;if((c|0)!=1){return a|0}c=P()|0;we(b);RP(a+4|0);S(c|0);p()}function ON(a,b){var c=0,d=0,e=0,f=0,g=0,h=E(0);c=ib-16|0;ib=c;d=0;a:{if(!fh(x[x[a>>2]-12>>2]+a|0)){break a}x[c+12>>2]=0;wk(a,c+12|0);e=x[c+12>>2];d=0;if(e>>>0>65535){break a}kk(b,e);while(1){if((f|0)==(e|0)){d=fh(x[x[a>>2]-12>>2]+a|0)}else{x[c+8>>2]=0;Pp(a,c+8|0);g=Bb(x[b>>2],f),h=B[c+8>>2],B[g>>2]=h;f=f+1|0;continue}break}}a=d;ib=c+16|0;return a}function ZV(a){var b=0,c=0,d=0;a:{if(Qb(a+60|0,15526,4)|(y[a+32|0]|y[a+33|0]<<8)>>>0>256|(y[a+49|0]<32|(y[a+36|0]|y[a+37|0]<<8)>>>0>255)){break a}if(v[a+51|0]<4|y[a+50|0]>64){break a}b=a+576|0;a=a- -64|0;while(1){if((a|0)==(b|0)){d=c;break a}b:{switch(y[a+15|0]){case 0:case 1:c=1;break;case 2:break b;default:break a}}a=a+16|0;continue}}return d&1}function Sea(a,b){a=a|0;b=b|0;var c=0,d=0;if(x[a+4>>2]!=x[Db(a)>>2]){c=ib-16|0;ib=c;x[c>>2]=a;a=x[a+4>>2];x[c+4>>2]=a;x[c+8>>2]=a+32;DP(x[c+4>>2],b);x[c+4>>2]=x[c+4>>2]+32;ic(c);ib=c+16|0;return}d=ib-32|0;ib=d;c=Db(a);c=Vt(d+8|0,oq(a,xg(x[a>>2],x[a+4>>2])+1|0),xg(x[a>>2],x[a+4>>2]),c);DP(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+32;Dd(a,c);uS(c);ib=d+32|0}function zW(a){var b=0,c=0;a:{if(Qb(a,13876,3)|(y[a+3|0]-1&255)>>>0>3){break a}if(Fb(y[a+196|0]|y[a+197|0]<<8)>>>0>255){break a}if((Fb(y[a+198|0]|y[a+199|0]<<8)-1&65535)>>>0>255){break a}if((Fb(y[a+200|0]|y[a+201|0]<<8)-1&65535)>>>0>31){break a}b=Fb(y[a+202|0]|y[a+203|0]<<8);if(b>>>0>256){break a}c=Fb(y[a+204|0]|y[a+205|0]<<8)>>>0<b>>>0}return c}function EK(a,b){a=a|0;b=b|0;var c=0;c=ib-16|0;ib=c;a:{b:{c:{if(b-65536>>>0<=4294901760){b=ba(8)|0;x[27524]=0;c=Q(55,c|0,5851)|0;a=x[27524];x[27524]=0;if((a|0)==1){break c}lc(b,c);x[27524]=0;U(123,b|0,50060,962);a=x[27524];x[27524]=0;if((a|0)!=1){break a}a=P()|0;wb(c);break b}x[x[a+32>>2]+1074416>>2]=b;ib=c+16|0;return}a=P()|0;ca(b|0)}S(a|0)}p()}function xt(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=ib-16|0;ib=e;a:{if(!b){break a}Ab(e+8|0,a+1074312|0,73);j=zb(x[x[e+8>>2]>>2],x[e+12>>2])?c- -64|0:c;c=120;h=sj(a);k=h^-1;f=1;while(1){if(!c){break a}l=c;c=c>>>1|0;i=f+c|0;g=nh(a,i,j,d);if(!(g>>>0>b>>>0&k)&(!(!g|h)|b>>>0<=g>>>0)){continue}f=i+1|0;c=(c^-1)+l|0;continue}}ib=e+16|0;return f}function _n(a,b,c,d){a:{if(x[a+480180>>2]==4){d=y[b+810|0];if(c){v[b+810|0]=d&240|c;break a}c=d&15;break a}if(d){if(c){v[b+834|0]=c;break a}c=y[b+834|0];break a}if(c){v[b+810|0]=c;break a}c=y[b+810|0]}b:{if(!(v[b+851|0]&1)){break b}c=x[b+688>>2]-((c&255)<<2)|0;x[b+688>>2]=(c|0)>0?c:0;if(!(v[a+480180|0]&1)){break b}x[b+88>>2]=x[b+88>>2]|2097152}}function I5(a,b){a=a|0;b=b|0;var c=0,d=0;if(A[a+4>>2]<A[Db(a)>>2]){c=ib-16|0;ib=c;x[c>>2]=a;a=x[a+4>>2];x[c+4>>2]=a;x[c+8>>2]=a+24;bK(x[c+4>>2],b);x[c+4>>2]=x[c+4>>2]+24;ic(c);ib=c+16|0;return}d=ib-32|0;ib=d;c=Db(a);c=UE(d+8|0,VE(a,Xi(x[a>>2],x[a+4>>2])+1|0),Xi(x[a>>2],x[a+4>>2]),c);bK(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+24;TE(a,c);SE(c);ib=d+32|0}function HA(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=ib-32|0;ib=d;e=Nb(a);a=Cb(x[b>>2]);x[d+24>>2]=a;b=Cb(x[b+4>>2]);a:{while(1){if(Mb(a,b)){ci(d,x[a>>2],x[a+4>>2]);if(x[d>>2]==(c|0)){Eo(d,a);x[27524]=0;R(356,e|0,d|0);a=x[27524];x[27524]=0;if((a|0)==1){break a}yb(d)}a=x[Qm(d+24|0)>>2];continue}break}ib=d+32|0;return}a=P()|0;yb(d);Sc(e);S(a|0);p()}function EF(a,b,c,d,e,f,g){var h=0,i=0,j=0;h=ib-16|0;ib=h;a:{b:{c:{if(b<g|b>f){a=ba(8)|0;x[27524]=0;d=Q(55,h|0,e|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break c}lc(a,d);x[27524]=0;U(123,a|0,50060,962);a=x[27524];x[27524]=0;if((a|0)!=1){break a}e=P()|0;wb(d);break b}i=x[a+32>>2]+d|0,j=Xe(b*c),x[i>>2]=j;ib=h+16|0;return}e=P()|0;ca(a|0)}S(e|0)}p()}function mv(a,b,c,d){var e=0,f=0;a:{e=y[a|0];f=y[c|0];b:{if(!(y[d|0]|((e|0)!=11|(f-5&255)>>>0>1))){v[a|0]=(f|0)==5?7:6;break b}if(!(y[b|0]|((f|0)!=11|(e-5&255)>>>0>1))){v[a|0]=(e|0)==5?7:6;v[b|0]=y[d|0];break b}if(!((e|0)!=10|(f|0)!=20|y[d|0]!=159)){v[a|0]=42;break b}if(y[b|0]!=159|(f|0)!=10|(e|0)!=20){break a}v[a|0]=42;v[b|0]=y[d|0]}v[c|0]=0}}function Jw(a,b,c,d){v[a+53|0]=1;a:{if(x[a+4>>2]!=(c|0)){break a}v[a+52|0]=1;c=x[a+16>>2];b:{if(!c){x[a+36>>2]=1;x[a+24>>2]=d;x[a+16>>2]=b;if((d|0)!=1){break a}if(x[a+48>>2]==1){break b}break a}if((b|0)==(c|0)){c=x[a+24>>2];if((c|0)==2){x[a+24>>2]=d;c=d}if(x[a+48>>2]!=1){break a}if((c|0)==1){break b}break a}x[a+36>>2]=x[a+36>>2]+1}v[a+54|0]=1}}function zY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=ib-32|0;ib=e;tv(e+8|0,c);c=y[d|0];x[27524]=0;R(247,e+20|0,c|0);c=x[27524];x[27524]=0;b:{c:{if((c|0)!=1){bk(e,e+8|0);x[27524]=0;X(118,a|0,b|0,x[e>>2],x[e+4>>2]);a=x[27524];x[27524]=0;if((a|0)==1){break c}dh(e+8|0);ib=e+32|0;break a}a=P()|0;xb(e+8|0);break b}a=P()|0;dh(e+8|0)}S(a|0);p()}}function up(a,b,c){var d=0,e=0,f=0;e=ib-16|0;ib=e;d=e+8|0;ed(d,b);x[27524]=0;b=T(1165,d|0)|0;d=x[27524];x[27524]=0;a:{if((d|0)==1){break a}x[27524]=0;d=T(1174,b|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break a}x[c>>2]=d;x[27524]=0;R(1175,a|0,b|0);a=x[27524];x[27524]=0;if((a|0)==1){break a}_b(e+8|0);ib=e+16|0;return}a=P()|0;_b(e+8|0);S(a|0);p()}function lJ(a){var b=0,c=0,d=0,e=0,f=0,g=0;a:{b=x[a>>2];b:{if(!b){break b}c=x[a+8>>2];if(!c){break b}a=x[a+12>>2];if(!a){break b}e=lb[a|0](b)|0;d=kb;if((d|0)<0){break b}if((lb[c|0](b,0,0,0)|0)<0){break a}if((lb[c|0](b,0,0,2)|0)<0){break a}f=lb[a|0](b)|0;a=kb;lb[c|0](b,e,d,0)|0;if((a|0)<0){break b}g=Ht(f,a)}return g}lb[c|0](b,e,d,0)|0;return 0}function wp(a,b,c){var d=0,e=0,f=0;e=ib-16|0;ib=e;d=e+8|0;ed(d,b);x[27524]=0;b=T(1147,d|0)|0;d=x[27524];x[27524]=0;a:{if((d|0)==1){break a}x[27524]=0;d=T(1160,b|0)|0;f=x[27524];x[27524]=0;if((f|0)==1){break a}v[c|0]=d;x[27524]=0;R(1161,a|0,b|0);a=x[27524];x[27524]=0;if((a|0)==1){break a}_b(e+8|0);ib=e+16|0;return}a=P()|0;_b(e+8|0);S(a|0);p()}function vD(a,b){var c=0,d=0,e=0,f=0;c=ib-16|0;ib=c;a:{if(b>>>0<3){if(!b){break a}if(!Ob(x[a>>2],x[a+8>>2],b)){break a}while(1)if((d|0)==2){Rj(c+8|0,z[c+14>>1]);d=z[c+8>>1];break a}else{v[c+13|0]=0;f=(c+14|0)+d|0;if(b>>>0>d>>>0){Hg(a,c+13|0);e=y[c+13|0]}else{e=0}v[f|0]=e;d=d+1|0;continue}}aa(11131,9027,137,14200);p()}ib=c+16|0;return d&65535}function qea(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=ib-16|0;ib=b;w[a>>1]=0;c=Nb(a+4|0);d=Nb(a+16|0);x[a+36>>2]=0;e=Kb(a+40|0);f=zg(a+52|0);Ic(c);w[a+28>>1]=65472;x[27524]=0;x[b+12>>2]=1065353216;R(845,c|0,b+12|0);g=x[27524];x[27524]=0;if((g|0)!=1){x[a+32>>2]=0;w[a+30>>1]=0;Ic(d);ib=b+16|0;return a|0}a=P()|0;HV(f);xb(e);uc(d);uc(c);S(a|0);p()}function baa(a){a=a|0;var b=0;x[27524]=0;Y(958,a|0);b=x[27524];x[27524]=0;a:{b:{if((b|0)!=1){x[a+16>>2]=0;b=x[a+20>>2];if(!b){break b}Ib(b);x[a+20>>2]=0;return}_(V(0)|0)|0;x[27524]=0;X(945,8864,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)==1){break a}$()}return}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function rma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;if(A[a+4>>2]<A[Db(a)>>2]){d=ib-16|0;ib=d;a=Fh(d,a,1);dW(x[a+4>>2],z[b>>1],y[c|0]);x[a+4>>2]=x[a+4>>2]+4;ic(a);ib=d+16|0;return}e=ib-32|0;ib=e;d=Db(a);d=cg(e+8|0,wg(a,tc(x[a>>2],x[a+4>>2])+1|0),tc(x[a>>2],x[a+4>>2]),d);dW(x[d+8>>2],z[b>>1],y[c|0]);x[d+8>>2]=x[d+8>>2]+4;Dd(a,d);bg(d);ib=e+32|0}function Sk(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;f=ib-16|0;ib=f;x[f+8>>2]=a;x[f+12>>2]=b;h=x[a+8>>2]+120|0;Ns(y[h+20|0]);g=ib-16|0;ib=g;x[g+8>>2]=f+8;e=ib-16|0;ib=e;i=x[d+4>>2];x[e+8>>2]=x[d>>2];x[e+12>>2]=i;d=x[c+4>>2];x[e>>2]=x[c>>2];x[e+4>>2]=d;lb[x[Dp(e,ik(y[h+20|0]))>>2]](g+8|0,h);ib=e+16|0;ib=g+16|0;x[a+4>>2]=x[a+4>>2]+x[b+8>>2];ib=f+16|0}function Lg(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;e=Jc(a);d=Eb(a);c=xf(b);a=0;a:{if(!c){break a}a=e;d=d+a|0;c=b+c|0;b:{if((c|0)==(b|0)){break b}c:{c=c-b|0;if((c|0)>(d-a|0)){break c}g=1-c|0;h=y[b|0];while(1){f=d-a|0;if((c|0)>(f|0)){break c}a=Np(a,g+f|0,h);if(!a){break c}if(!Rp(a,b,c)){break b}a=a+1|0;continue}}a=d}a=(a|0)==(d|0)?-1:a-e|0}return a}function $ma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=ib-112|0;ib=d;c=ib-16|0;ib=c;f=d+8|0;NW(c+8|0,f);e=x[c+12>>2];ld(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(e|0)){gd(a,x[c+12>>2])}ib=c+16|0;e=(e|0)==(g|0);if(!e){MW(f)}c=-1;a:{if(!e){break a}c=0;if(!PW(d+8|0)){break a}c=Ee(a,b,OW(y[d+55|0]|y[d+56|0]<<8),kb)}ib=d+112|0;return c|0}function a$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;e=ib+-64|0;ib=e;d=1;a:{if(gh(a,b,0)){break a}d=0;if(!b){break a}b=rz(b,107804,107852);d=0;if(!b){break a}d=e+8|0;Rb(d|4,0,52);x[e+56>>2]=1;x[e+20>>2]=-1;x[e+16>>2]=a;x[e+8>>2]=b;lb[x[x[b>>2]+28>>2]](b,d,x[c>>2],1);a=x[e+32>>2];if((a|0)==1){x[c>>2]=x[e+24>>2]}d=(a|0)==1}ib=e- -64|0;return d|0}function RY(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=ib-512|0;ib=d;c=ib-16|0;ib=c;f=d+8|0;rD(c+8|0,f);e=x[c+12>>2];ld(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(e|0)){gd(a,x[c+12>>2])}ib=c+16|0;e=(e|0)==(g|0);if(!e){qD(f)}c=-1;a:{if(!e){break a}c=0;if(!tD(d+8|0)){break a}c=Ee(a,b,sD(y[d+118|0],y[d+119|0]),kb)}ib=d+512|0;return c|0}function $9(a){a=a|0;var b=0;x[27524]=0;Y(958,a|0);b=x[27524];x[27524]=0;a:{b:{if((b|0)!=1){a=x[a+20>>2];if(!a){break b}return mg(a)|0}_(V(0)|0)|0;x[27524]=0;X(945,12139,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)==1){break a}$();return 0}return mg(21631)|0}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function rQ(a,b,c,d,e){var f=0,g=0,h=0,i=0;f=ib-16|0;ib=f;i=x[d+20>>2];h=x[d+52>>2];g=!h|e;v[f+15|0]=g;a:{if(!g|(b|0)!=2){break a}g=c&65535;c=0;while(1){if((c|0)==(g|0)){break a}x[(D(c,872)+d|0)+1380>>2]=0;c=c+1|0;continue}}x[d+24>>2]=0;x[d+16>>2]=0;x[d+20>>2]=0;x[d+48>>2]=h;w[d+72>>1]=z[d+74>>1];fe(a,i>>>0>1&e&(b|0)==1,f+15|0);ib=f+16|0}function $j(a,b){a:{if((b|0)>=1024){a=a*898846567431158e293;if(b>>>0<2047){b=b-1023|0;break a}a=a*898846567431158e293;b=((b|0)>=3069?3069:b)-2046|0;break a}if((b|0)>-1023){break a}a=a*2004168360008973e-307;if(b>>>0>4294965304){b=b+969|0;break a}a=a*2004168360008973e-307;b=((b|0)<=-2960?-2960:b)+1938|0}l(0,0);l(1,b+1023<<20);return a*+n()}function _y(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=ib-16|0;ib=d;e=Xh(b,c);a:{if(e>>>0<=sp(a)>>>0){f=c;g=x[a>>2];h=cd(g,x[a+4>>2]);i=h>>>0>=e>>>0;if(!i){x[d+12>>2]=b;x[d+12>>2]=x[d+12>>2]+h;f=x[d+12>>2]}b=ji(b,f,g);if(!i){Fu(a,f,c,e-cd(x[a>>2],x[a+4>>2])|0);break a}Od(a,b);break a}$B(a);Pl(a,Zl(a,e));Fu(a,b,c,e)}ib=d+16|0}function Xz(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+23|0]=0;v[a+24|0]=0;v[a+25|0]=0;v[a+26|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+20|0]=0;v[a+21|0]=0;v[a+22|0]=0;v[a+23|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function tZ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=ib-32|0;ib=e;f=x[b+16>>2];a:{if(f>>>0<=c>>>0){cc(a,x[d>>2],0);break a}g=x[b+12>>2];b=x[b+4>>2];x[e+20>>2]=x[d+4>>2];x[e+16>>2]=f-c;cc(e+24|0,x[d>>2],x[Hb(e+20|0,e+16|0)>>2]);d=x[x[b>>2]+28>>2];f=x[e+28>>2];x[e+8>>2]=x[e+24>>2];x[e+12>>2]=f;lb[d|0](a,b,c+g|0,e+8|0)}ib=e+32|0}function gja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=ib-16|0;ib=d;c=d+11|0;KT(a,c);if(Qb(c,13534,4)){a=1}else{KT(a,d+11|0);v[b|0]=1;a=0}c=ib-16|0;ib=c;a:{b:{a=(d+11|0)+a|0;c:{if(!a){a=0;break c}b=Kc(c,a);x[27524]=0;a=T(661,b|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break b}wb(b)}ib=c+16|0;break a}a=P()|0;wb(b);S(a|0);p()}ib=d+16|0;return a|0}function K8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;x[27524]=0;Y(958,a|0);f=x[27524];x[27524]=0;if((f|0)!=1){return Ws(x[x[a+24>>2]+24>>2],b,c,d,e)|0}_(V(0)|0)|0;x[27524]=0;X(945,12382,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)!=1){$();return 0}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function J$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;while(1){a:{if((c|0)==(d|0)|e>>>0<=h>>>0){break a}f=1;g=ib-16|0;ib=g;k=qi(g+8|0,x[a+8>>2]);i=ls(0,c,d-c|0,b?b:483372);pi(k);ib=g+16|0;b:{switch(i+2|0){default:f=i;break;case 0:case 1:break a;case 2:break b}}h=h+1|0;j=f+j|0;c=c+f|0;continue}break}return j|0}function IH(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=ib-16|0;ib=b;e=b+16|0;a:{while(1){d=x[a+36>>2];c=b+8|0;f=lb[x[x[d>>2]+20>>2]](d,x[a+40>>2],c,e,b+4|0)|0;d=-1;g=c;c=x[b+4>>2]-c|0;if((Dk(g,1,c,x[a+32>>2])|0)!=(c|0)){break a}b:{switch(f-1|0){case 1:break a;case 0:continue;default:break b}}break}d=Zs(x[a+32>>2])?-1:0}ib=b+16|0;return d|0}function wM(a){a=a|0;var b=0,c=0,d=0,e=0;b=ib-32|0;ib=b;a=Nb(a);x[27524]=0;Y(948,b+16|0);c=x[27524];x[27524]=0;a:{b:{if((c|0)!=1){c=Cb(x[b+16>>2]);d=Cb(x[b+20>>2]);e=x[Wb(b+8|0,a)>>2];x[27524]=0;U(949,c|0,d|0,e|0);c=x[27524];x[27524]=0;if((c|0)==1){break b}uc(b+16|0);ib=b+32|0;return}c=P()|0;break a}c=P()|0;uc(b+16|0)}ve(a);S(c|0);p()}function P4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=ib-16|0;ib=e;g=x[d+4>>2];Lx(b,c,g);f=x[b+16>>2];a:{if(f>>>0<=c>>>0){cc(a,x[d>>2],0);break a}x[e+12>>2]=f-c;x[e+8>>2]=g;d=x[d>>2];f=x[Hb(e+12|0,e+8|0)>>2];Nq(e,d,g,0,f);h=x[e>>2];i=x[e+4>>2];wh(Yf(Cb(x[b+4>>2]),c),Yf(Yf(Cb(x[b+4>>2]),c),i),h);Nq(a,d,g,0,f)}ib=e+16|0}function MP(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=x[a+16>>2];e=d?y[(D(b,872)+a|0)+1429|0]:e;f=x[a+40>>2];b=D(b,872)+a|0;a=b+1467|0;v[a|0]=y[a|0]|64;a=b+1468|0;h=a;i=x[a>>2];g=(+(d>>>0)+1)*+(c|0)/+(f>>>0);a:{if(F(g)<2147483648){a=~~g;break a}a=-2147483648}x[h>>2]=i+(a+((c|0)<0?e:0-e|0)|0);c=(d+1|0)==(f|0)?c:a;a=c>>31;v[b+1429|0]=(a^c)-a}function Fma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=ib-32|0;ib=e;$V(e+8|0,c);x[27524]=0;R(117,e+20|0,d|0);c=x[27524];x[27524]=0;b:{c:{if((c|0)!=1){bk(e,e+8|0);x[27524]=0;X(118,a|0,b|0,x[e>>2],x[e+4>>2]);a=x[27524];x[27524]=0;if((a|0)==1){break c}dh(e+8|0);ib=e+32|0;break a}a=P()|0;xb(e+8|0);break b}a=P()|0;dh(e+8|0)}S(a|0);p()}}function Cka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=ib-32|0;ib=e;Vq(e+8|0,c);x[27524]=0;R(581,e+20|0,d|0);c=x[27524];x[27524]=0;b:{c:{if((c|0)!=1){bk(e,e+8|0);x[27524]=0;X(300,a|0,b|0,x[e>>2],x[e+4>>2]);a=x[27524];x[27524]=0;if((a|0)==1){break c}EU(e+8|0);ib=e+32|0;break a}a=P()|0;wb(e+8|0);break b}a=P()|0;EU(e+8|0)}S(a|0);p()}}function r_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=ib-32|0;ib=e;qn(e+8|0,c);x[27524]=0;R(117,e+20|0,d|0);c=x[27524];x[27524]=0;b:{c:{if((c|0)!=1){bk(e,e+8|0);x[27524]=0;X(118,a|0,b|0,x[e>>2],x[e+4>>2]);a=x[27524];x[27524]=0;if((a|0)==1){break c}dh(e+8|0);ib=e+32|0;break a}a=P()|0;xb(e+8|0);break b}a=P()|0;dh(e+8|0)}S(a|0);p()}}function iv(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=ib-32|0;ib=e;dY(e+8|0,c);x[27524]=0;R(117,e+20|0,d|0);c=x[27524];x[27524]=0;b:{c:{if((c|0)!=1){bk(e,e+8|0);x[27524]=0;X(118,a|0,b|0,x[e>>2],x[e+4>>2]);a=x[27524];x[27524]=0;if((a|0)==1){break c}dh(e+8|0);ib=e+32|0;break a}a=P()|0;xb(e+8|0);break b}a=P()|0;dh(e+8|0)}S(a|0);p()}}function c3(a){a=a|0;a:{x[27524]=0;T(1141,482392)|0;a=x[27524];x[27524]=0;b:{if((a|0)==1){break b}x[27524]=0;T(1141,482728)|0;a=x[27524];x[27524]=0;if((a|0)==1){break b}x[27524]=0;T(1142,482476)|0;a=x[27524];x[27524]=0;if((a|0)==1){break b}x[27524]=0;T(1142,482812)|0;a=x[27524];x[27524]=0;if((a|0)==1){break b}break a}V(0)|0;Sb();p()}}function $t(a,b){var c=0,d=0;if(a-268435457>>>0>=4026531840){a=a+208|0;qoa(b,0,a,0);a=kb?0:D(a,b)}else{a=0}a:{if(!a){break a}x[27524]=0;b=T(757,a|0)|0;c=x[27524];x[27524]=0;b:{c:{if((c|0)==1){_(V(0)|0)|0;x[27524]=0;Z(18);c=x[27524];x[27524]=0;b=0;if((c|0)==1){break c}}break b}V(0)|0;Sb();p()}if(!b){break a}d=Rb(b,0,a)- -64|0}return d}function lfa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);if(zh(2147483647)>>>0<=2303){_c();p()}b=Mv(2304);x[a>>2]=b;x[a+4>>2]=b;f=Db(a),g=b+4608|0,x[f>>2]=g;d=ib-16|0;ib=d;c=ei(d,a,2304);b=x[c+4>>2];e=x[c+8>>2];while(1){if((b|0)==(e|0)){ic(c);ib=d+16|0}else{Nv(b);b=b+2|0;x[c+4>>2]=b;continue}break}return a|0}function eka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=ib+-64|0;ib=c;b=-1;a:{if(!(lb[x[x[a>>2]+32>>2]](a,0,1084)|0)){break a}yl(a,1080);d=c+60|0;DU(a,d);e=d;d=CU(c+40|0);b=0;if(!BU(e,d)){break a}yl(a,20);b=1;while(1){if((b&65535)>>>0>=32){b=A[d+4>>2]>=f>>>0}else{e=c+8|0;AU(a,e);b=b+1|0;f=XA(e)+f|0;continue}break}}ib=c- -64|0;return b|0}function PC(a){var b=0,c=0,d=0,e=0,f=0;d=y[a+9|0]|y[a+10|0]<<8;c=qoa(y[a+3|0],0,18,0);d=d+c|0;b=kb;b=c>>>0>d>>>0?b+1|0:b;c=d;d=b;f=c;c=y[a+6|0]|y[a+7|0]<<8;b=c>>>31|0;e=c<<1;c=f+e|0;b=b+d|0;b=c>>>0<e>>>0?b+1|0:b;d=b;a=y[a+4|0]|y[a+5|0]<<8;b=a>>>30|0;e=a<<2;c=e+c|0;a=b+d|0;a=c>>>0<e>>>0?a+1|0:a;b=c+3|0;a=b>>>0<3?a+1|0:a;kb=a;return b}function cea(a){a=a|0;var b=0,c=0;b=ib-32|0;ib=b;v[b+23|0]=0;v[b+24|0]=0;v[b+25|0]=0;v[b+26|0]=0;v[b+27|0]=0;v[b+28|0]=0;v[b+29|0]=0;v[b+30|0]=0;x[b+16>>2]=0;x[b+20>>2]=0;c=dc(b,b+16|0,15);kc(b+8|0,x[a>>2],x[a+8>>2],x[c>>2],x[c+4>>2]);c=0;a:{if(x[b+12>>2]!=15){break a}if(Qb(b+16|0,8473,15)){break a}Yb(a,15);c=1}ib=b+32|0;return c|0}function Xq(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=Cb(x[b>>2]);g=Cb(x[b+4>>2]);e=ib-16|0;ib=e;x[e+8>>2]=d;while(1){a:{if(!Mb(d,g)){break a}f=ib-16|0;ib=f;ci(f+8|0,x[d>>2],x[d+4>>2]);h=ac(x[f+8>>2]);ib=f+16|0;if((c|0)==(h|0)){break a}d=x[Qm(e+8|0)>>2];continue}break}ib=e+16|0;if(pc(d,Cb(x[b+4>>2]))){Oh(a);return}Eo(a,d)}function wD(a,b){var c=0,d=0,e=0,f=0;c=ib-16|0;ib=c;a:{if(b>>>0<5){if(!b){break a}if(!Ob(x[a>>2],x[a+8>>2],b)){break a}while(1)if((d|0)==4){cm(c,x[c+12>>2]);d=x[c>>2];break a}else{v[c+11|0]=0;f=(c+12|0)+d|0;if(b>>>0>d>>>0){Hg(a,c+11|0);e=y[c+11|0]}else{e=0}v[f|0]=e;d=d+1|0;continue}}aa(11131,9027,137,14200);p()}ib=c+16|0;return d}function aU(a){var b=0,c=0,d=0,e=0,f=0;e=y[a+28|0]|y[a+29|0]<<8;b=qoa(y[a+30|0],0,37,0);c=kb;d=b;b=qoa(y[a+24|0]|y[a+25|0]<<8,0,192,0);d=d+b|0;c=kb+c|0;c=b>>>0>d>>>0?c+1|0:c;b=c;f=e;a=y[a+26|0];c=a>>>26|0;e=d;d=a<<6;e=e+d|0;a=b+c|0;a=d>>>0>e>>>0?a+1|0:a;b=e;c=f+b|0;a=b>>>0>c>>>0?a+1|0:a;b=c+192|0;a=b>>>0<192?a+1|0:a;kb=a;return b}function sma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=ib-16|0;ib=c;x[c+12>>2]=1;a:{if(_h(a)){d=x[a>>2];e=tc(d,x[a+4>>2]);x[c+8>>2]=e;f=x[Hb(c+12|0,c+8|0)>>2];while(1){if(f){w[d>>1]=z[b>>1];v[d+2|0]=y[b+2|0];f=f-1|0;d=d+4|0;continue}break}if(!e){hW(a,1-e|0,b);break a}Od(a,x[a>>2]+4|0);break a}Ku(a);Gk(a,wg(a,1));hW(a,1,b)}ib=c+16|0}function hoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ib-16|0;ib=c;cc(c+8|0,b,10);d=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Yb(a,x[c+12>>2])}ib=c+16|0;a=(d|0)==(e|0);if(!a){v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+8|0]=0;v[b+9|0]=0}return a|0}function be(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=ib-16|0;ib=e;fn(b);f=uf(e+8|0,b);a:{d=a+8|0;b=x[d>>2];if(tc(b,x[a+12>>2])>>>0<=c>>>0){x[27524]=0;R(1238,d|0,c+1|0);a=x[27524];x[27524]=0;if((a|0)==1){break a}b=x[d>>2]}a=Bb(b,c);b=x[a>>2];if(b){ln(b);a=Bb(x[d>>2],c)}g=a,h=ce(f),x[g>>2]=h;AG(f);ib=e+16|0;return}a=P()|0;AG(f);S(a|0);p()}function aN(a){a=a|0;var b=0,c=0;c=ib-16|0;ib=c;b=x[x[a+16>>2]+24620>>2]/5|0;b=Dc(b,b>>31);x[a+4272>>2]=b;x[27524]=0;x[c+12>>2]=0;U(909,a+4256|0,b<<1,c+12|0);b=x[27524];x[27524]=0;a:{if((b|0)==1){b=V(108196)|0;if((jb|0)!=(da(108196)|0)){break a}_(b|0)|0;x[a+4272>>2]=0;$()}x[a+4276>>2]=0;x[a+4268>>2]=0;ib=c+16|0;return}S(b|0);p()}function Hfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=ib-32|0;ib=d;oB(d+8|0,c);x[27524]=0;R(466,d+20|0,43244);c=x[27524];x[27524]=0;b:{c:{if((c|0)!=1){bk(d,d+8|0);x[27524]=0;X(118,a|0,b|0,x[d>>2],x[d+4>>2]);a=x[27524];x[27524]=0;if((a|0)==1){break c}dh(d+8|0);ib=d+32|0;break a}a=P()|0;xb(d+8|0);break b}a=P()|0;dh(d+8|0)}S(a|0);p()}}function E4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=0;a:{if(!x[b+28>>2]){break a}e=0;if((lb[x[b+32>>2]](x[b+24>>2],c,0,0)|0)<0){break a}f=x[d+4>>2];c=x[d>>2];while(1){b:{if(!f){break b}e=lb[x[b+28>>2]](x[b+24>>2],c,f)|0;if(!e){break b}f=f-e|0;c=c+e|0;g=e+g|0;h=g>>>0<e>>>0?h+1|0:h;continue}break}e=g}cc(a,x[d>>2],e)}function iq(a){var b=0,c=0,d=0,e=0,f=0;c=ib-16|0;ib=c;d=Cb(x[a>>2]);e=a;f=Cb(x[a+4>>2]);a=ib-16|0;ib=a;x[a+8>>2]=d;while(1){if(Mb(d,f)){b=b+C[d>>3];d=x[Nt(a+8|0)>>2];continue}break}ib=a+16|0;a=Cb(x[e>>2]);x[c+8>>2]=a;b=-b;e=Cb(x[e+4>>2]);while(1){if(Mb(a,e)){b=b+C[a>>3];C[a>>3]=b;a=x[Nt(c+8|0)>>2];continue}else{ib=c+16|0}break}}function fca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Ai(a,b,c,d);x[a>>2]=44928;c=Nb(a+4208|0);x[a+4220>>2]=0;x[a+4224>>2]=1056964608;b=a+4228|0;v[b+4|0]=0;v[b+5|0]=4;v[b|0]=69;v[b+1|0]=99;v[b+2|0]=104;v[b+3|0]=111;v[b+6|0]=1;x[27524]=0;R(903,a+44|0,2);b=x[27524];x[27524]=0;if((b|0)!=1){bt(a);return a|0}b=P()|0;uc(c);Rf(a);S(b|0);p()}function md(a,b){a=a|0;b=b|0;var c=0,d=0;c=ib-16|0;ib=c;Jm(a);x[a+16>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[a>>2]=0;x[a+4>>2]=0;w[a+32>>1]=64;x[a+24>>2]=8363;x[a+28>>2]=16777344;x[a+36>>2]=0;v[a+39|0]=0;v[a+40|0]=0;v[a+41|0]=0;v[a+42|0]=0;d=z[a+34>>1]&-25151;w[a+34>>1]=(b|0)==4?d|32:d;b=Kc(c,21631);Fe(a+43|0,b);wb(b);FS(a);ib=c+16|0}function wO(a,b,c,d){var e=0,f=0,g=0,h=0;e=ib-16|0;ib=e;a:{b:{while(1){x[e+12>>2]=b;x[e+8>>2]=d;if(A[Hb(e+12|0,e+8|0)>>2]<=f>>>0){break b}g=Xp(v[Jb(a,f)|0]);h=Xp(v[Jb(c,f)|0]);if((g|0)!=(h|0)){a=g>>>0<h>>>0?-1:1;break a}f=f+1|0;if(g){continue}break}a=0;break a}a=0;if((b|0)==(d|0)){break a}a=b>>>0<d>>>0?-1:1}ib=e+16|0;return a}function sJ(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=x[a>>2];a:{if(!b){break a}c=x[a+8>>2];if(!c){break a}d=x[a+12>>2];if(!d){break a}e=lb[d|0](b)|0;a=kb;f=a;if((a|0)<0){break a}a=0;b:{if((lb[c|0](b,0,0,0)|0)<0){break b}a=0;if((lb[c|0](b,0,0,2)|0)<0){break b}lb[d|0](b)|0;a=kb;a=(a|0)>0|(a|0)>=0}g=a;lb[c|0](b,e,f,0)|0}return g|0}function KZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=ib-16|0;ib=d;x[d>>2]=b;x[d+4>>2]=c;x[d+8>>2]=b;x[d+12>>2]=c;e=ib-16|0;ib=e;c=ib-16|0;ib=c;x[c+4>>2]=1;g=c,h=mc(24),x[g+8>>2]=h;b=Tl(x[c+8>>2]);x[b>>2]=78072;tE(zc(b),x[d>>2],x[d+4>>2]);b=e+8|0;f=kn(c);jn(b,zc(f),f);Ul(c);ib=c+16|0;zf(a,b);Ud(b);ib=e+16|0;ib=d+16|0}function Gz(a,b,c){var d=0,e=0,f=0;d=Kb(a);a=Eb(b);x[27524]=0;R(48,d|0,a|0);a=x[27524];x[27524]=0;if((a|0)!=1){a:{while(1){if(Eb(b)>>>0>e>>>0){a=65533;f=v[ng(b,e)|0];if((f|0)>=-96){a=x[((f&255)<<2)+c>>2]}x[27524]=0;R(49,d|0,a|0);a=x[27524];x[27524]=0;if((a|0)==1){break a}e=e+1|0;continue}break}return}}a=P()|0;Gc(d);S(a|0);p()}function xx(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;g=ib-240|0;ib=g;x[g>>2]=a;h=1;a:{if((c|0)<2){break a}e=a;while(1){e=e-4|0;i=c-2|0;f=e-x[(i<<2)+d>>2]|0;if((lb[b|0](a,f)|0)>=0){if((lb[b|0](a,e)|0)>=0){break a}}j=f;f=(lb[b|0](f,e)|0)>=0;e=f?j:e;x[(h<<2)+g>>2]=e;h=h+1|0;c=f?c-1|0:i;if((c|0)>1){continue}break}}CI(g,h);ib=g+240|0}function tm(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0;h=ib-16|0;ib=h;i=-17;if(-17-b>>>0>=c>>>0){j=vc(a);if(b>>>0<=2147483622){x[h+8>>2]=b<<1;x[h+12>>2]=b+c;i=Wg(x[Yc(h+12|0,h+8|0)>>2])+1|0}c=mc(i);if(e){Ae(c,j,e)}k=e+f|0;if((k|0)!=(d|0)){Ae((c+e|0)+g|0,(e+j|0)+f|0,d-k|0)}if((b|0)!=10){Ib(j)}td(a,c);hf(a,i);ib=h+16|0;return}of();p()}function Xka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=ib+-64|0;ib=d;c=ib-16|0;ib=c;f=d+8|0;aV(c+8|0,f);e=x[c+12>>2];ld(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(e|0)){gd(a,x[c+12>>2])}ib=c+16|0;e=(e|0)==(g|0);if(!e){$U(f)}c=-1;a:{if(!e){break a}c=0;if(!cV(d+8|0)){break a}c=Ee(a,b,bV(d+8|0),kb)}ib=d- -64|0;return c|0}function OY(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=ib-48|0;ib=d;c=ib-16|0;ib=c;f=d+8|0;jD(c+8|0,f);e=x[c+12>>2];ld(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(e|0)){gd(a,x[c+12>>2])}ib=c+16|0;e=(e|0)==(g|0);if(!e){iD(f)}c=-1;a:{if(!e){break a}c=0;if(!lD(d+8|0)){break a}c=Ee(a,b,kD(y[d+43|0]),kb)}ib=d+48|0;return c|0}function MG(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=ib-16|0;ib=d;i=x[b>>2];h=x[a>>2];e=x[gc(a)>>2]==1186;f=x[c>>2]-h|0;g=f<<1;f=f>>>0>=2147483647?-1:g?g:4;g=Bu(e?0:h,f);if(g){if(!e){ce(a)}x[d+4>>2]=1151;e=xe(d+8|0,g,d+4|0);a=JG(a,e);Uc(e);x[b>>2]=x[a>>2]+(i-h|0);x[c>>2]=x[a>>2]+(f&-4);ib=d+16|0;return}Yw();p()}function Efa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=ib-32|0;ib=e;x[e+24>>2]=d;c=Af(a,c);Pd(e+8|0,x[a+36>>2]);f=a;a:{if(!c){Pc(e+8|0,a+32|0,5);d=0;if(zb(x[x[e+8>>2]>>2],x[e+12>>2])){break a}}d=x[a+36>>2];a=0;aD(b,x[e+24>>2]);while(1){if(A[e+24>>2]>a>>>0){xR(d,bc(x[b>>2],a));a=a+1|0;continue}break}d=c}af(f,d);ib=e+32|0}function pma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=ib-576|0;ib=d;c=ib-16|0;ib=c;XV(c+8|0,d);e=x[c+12>>2];ld(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){gd(a,x[c+12>>2])}ib=c+16|0;e=(e|0)==(f|0);if(!e){WV(d)}c=-1;a:{if(!e){break a}c=0;if(!ZV(d)){break a}c=Ee(a,b,YV(z[d+34>>1],z[d+36>>1]),kb)}ib=d+576|0;return c|0}function SU(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=ib-16|0;ib=d;e=$d(b,c);a:{if(e>>>0<=_h(a)>>>0){f=c;g=x[a>>2];h=tc(g,x[a+4>>2]);i=h>>>0>=e>>>0;if(!i){x[d+12>>2]=b;x[d+12>>2]=x[d+12>>2]+(h<<2);f=x[d+12>>2]}b=ji(b,f,g);if(!i){bB(a,f,c,e-tc(x[a>>2],x[a+4>>2])|0);break a}Od(a,b);break a}Ku(a);Gk(a,wg(a,e));bB(a,b,c,e)}ib=d+16|0}function Rla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=x[a>>2];d=cd(e,x[a+4>>2]);if(d>>>0<b>>>0){e=ib-32|0;ib=e;b=b-d|0;d=x[Db(a)>>2];f=x[a+4>>2];a:{if(b>>>0<=d-f>>>0){To(a,b,c);break a}d=Db(a);d=am(e+8|0,Zl(a,cd(x[a>>2],f)+b|0),cd(x[a>>2],x[a+4>>2]),d);wV(d,b,c);Dd(a,d);$l(d)}ib=e+32|0;return}if(b>>>0<d>>>0){Od(a,b+e|0)}}function tO(a,b){var c=0,d=0,e=0,f=0,g=0;d=ib-16|0;ib=d;dc(d+8|0,nd(b),xd(x[b+4>>2],y[b+11|0]));b=x[d+8>>2];e=x[d+12>>2];c=ib-16|0;ib=c;f=xd(x[a+4>>2],y[a+11|0]);x[c+12>>2]=f;x[c+8>>2]=e;g=Hb(c+12|0,c+8|0);a=jw(nd(a),b,x[g>>2]);a:{if(a){break a}a=-1;if(e>>>0>f>>>0){break a}a=e>>>0<f>>>0}ib=c+16|0;ib=d+16|0;return a>>>31|0}function s3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=x[a+44>>2];c=x[a+24>>2];if(e>>>0<c>>>0){x[a+44>>2]=c;e=c}f=x[a+8>>2];c=x[a+12>>2];d=-1;a:{if(f>>>0>=c>>>0){break a}if(pc(b,-1)){Fn(a,f,c-1|0,e);return gx(b)|0}g=zp(b);if(!(x[a+48>>2]&16)){d=-1;if(!pc(g,v[c-1|0])){break a}}Fn(a,f,c-1|0,e);v[x[a+12>>2]]=g;d=b}return d|0}function q8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;x[27524]=0;Y(958,a|0);d=x[27524];x[27524]=0;if((d|0)!=1){x[a+16>>2]=0;x[a+12>>2]=c;x[a+8>>2]=b;return}_(V(0)|0)|0;x[27524]=0;X(945,13003,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)!=1){$();return}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function fl(a,b,c){var d=0,e=0,f=0,g=0,h=0;f=ib-16|0;ib=f;x[f+8>>2]=c;while(1){a:{if((a|0)!=(b|0)){c=ib-32|0;ib=c;d=qc(c+24|0,x[a>>2]);e=x[f+8>>2];g=x[e+4>>2];e=x[e>>2];x[c+16>>2]=e;x[c+20>>2]=g;h=x[d+4>>2];d=x[d>>2];x[c+8>>2]=e;x[c+12>>2]=g;d=Nc(d,h,c+8|0);ib=c+32|0;if(!d){break a}b=a}ib=f+16|0;return b}a=a+8|0;continue}}function ema(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=ib-16|0;ib=d;x[d+12>>2]=c;a:{e=Ob(x[b>>2],x[b+8>>2],c<<2);if(!e){break a}wc(d+12|0,65535);Dg(a,z[d+12>>1]);c=Cb(x[a>>2]);x[d>>2]=c;a=Cb(x[a+4>>2]);while(1){if(!Mb(c,a)){break a}f=d+8|0;if(!Zo(b,f)){Ho(f)}w[c>>1]=x[d+8>>2];c=x[Ye(d)>>2];continue}}ib=d+16|0;return e|0}function cca(a){a=a|0;var b=0,c=0,d=0,e=0;c=ib-16|0;ib=c;x[x[a+20>>2]+148>>2]=-1;Lo(c+8|0,a+4228|0);d=x[a+20>>2];e=x[c+12>>2];b=x[c+8>>2];x[27524]=0;U(927,d+4|0,b|0,Jb(b,e)|0);b=x[27524];x[27524]=0;a:{if((b|0)==1){b=V(108196)|0;if((jb|0)!=(da(108196)|0)){break a}_(b|0)|0;Ic(x[a+20>>2]+4|0);$()}ib=c+16|0;return}S(b|0);p()}function yda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=ib-16|0;ib=d;x[d>>2]=x[a+8>>2];e=x[a+8>>2];x[d+8>>2]=a+8;x[d+4>>2]=D(b,52)+e;b=x[d>>2];a:{while(1){if(x[d+4>>2]==(b|0)){break a}x[27524]=0;R(883,b|0,c|0);a=x[27524];x[27524]=0;if((a|0)!=1){b=x[d>>2]+52|0;x[d>>2]=b;continue}break}a=P()|0;Vd(d);S(a|0);p()}Vd(d);ib=d+16|0}function y1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=ib-16|0;ib=d;i=x[b>>2];h=x[a>>2];e=x[gc(a)>>2]==1186;f=x[c>>2]-h|0;g=f<<1;f=f>>>0>=2147483647?-1:g?g:1;g=Bu(e?0:h,f);if(g){if(!e){ce(a)}x[d+4>>2]=1151;e=xe(d+8|0,g,d+4|0);a=JG(a,e);Uc(e);x[b>>2]=x[a>>2]+(i-h|0);x[c>>2]=f+x[a>>2];ib=d+16|0;return}Yw();p()}function noa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=ib-1968|0;ib=e;c=ib-16|0;ib=c;f=e+8|0;bY(c+8|0,f);d=x[c+12>>2];ld(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(d|0)){gd(a,x[c+12>>2])}ib=c+16|0;d=(d|0)==(g|0);if(!d){aY(f)}c=-1;a:{if(!d){break a}c=0;if(!cY(e+8|0)){break a}c=Ee(a,b,1024,0)}ib=e+1968|0;return c|0}function lda(a,b){a=a|0;b=b|0;var c=0,d=0;if(x[a+4>>2]!=x[Db(a)>>2]){c=ib-16|0;ib=c;a=Fh(c,a,1);lk(x[a+4>>2],B[b>>2]);x[a+4>>2]=x[a+4>>2]+4;ic(a);ib=c+16|0;return}d=ib-32|0;ib=d;c=Db(a);c=cg(d+8|0,wg(a,tc(x[a>>2],x[a+4>>2])+1|0),tc(x[a>>2],x[a+4>>2]),c);lk(x[c+8>>2],B[b>>2]);x[c+8>>2]=x[c+8>>2]+4;Dd(a,c);bg(c);ib=d+32|0}function GG(a,b,c,d,e){var f=0,g=0,h=0,i=0;f=ib-16|0;ib=f;g=1073741807;if(1073741807-b>>>0>=c>>>0){h=vc(a);if(b>>>0<=536870886){x[f+8>>2]=b<<1;x[f+12>>2]=b+c;g=fm(x[Yc(f+12|0,f+8|0)>>2])+1|0}c=Ii(g);if(e){ui(c,h,e)}if((d|0)!=(e|0)){i=e<<2;ui(c+i|0,h+i|0,d-e|0)}if((b|0)!=1){Ib(h)}td(a,c);hf(a,g);ib=f+16|0;return}of();p()}function uca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=ib-32|0;ib=d;x[d+28>>2]=c;x[d+8>>2]=33;e=x[a>>2];f=x[a+8>>2];c=x[Hb(d+28|0,d+8|0)>>2];if(!Ob(e,f,c)){c=jf(a)}e=d+8|0;jB(e,b);f=dc(d+16|0,x[d+8>>2],c);kc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);jB(e,b);Rb(x[d+8>>2]+c|0,0,33-c|0);Yb(a,x[d+28>>2]);ib=d+32|0;return c|0}function AC(a,b){a=a|0;b=b|0;var c=0,d=0;if(x[a+4>>2]!=x[Db(a)>>2]){c=ib-16|0;ib=c;a=ei(c,a,1);Pj(x[a+4>>2],z[b>>1]);x[a+4>>2]=x[a+4>>2]+2;ic(a);ib=c+16|0;return}d=ib-32|0;ib=d;c=Db(a);c=Uj(d+8|0,Vj(a,Oc(x[a>>2],x[a+4>>2])+1|0),Oc(x[a>>2],x[a+4>>2]),c);Pj(x[c+8>>2],z[b>>1]);x[c+8>>2]=x[c+8>>2]+2;Dd(a,c);Ui(c);ib=d+32|0}function xj(a){var b=0,c=0,d=0,e=0,f=0;b=x[a+4>>2];if(pc(x[a>>2],b)){a=0}else{b=Ni(b);e=Ni(x[a>>2]);c=ib-16|0;ib=c;x[c+8>>2]=b;while(1){a:{if(!Rg(b,e)){break a}d=ib-16|0;ib=d;x[d+8>>2]=b;f=IR(d+8|0);ib=d+16|0;if(z[x[f>>2]>>1]!=65535){break a}b=x[IR(c+8|0)>>2];continue}break}ib=c+16|0;a=nC(Cb(x[a>>2]),b)}return a&65535}function tea(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;c=ib-16|0;ib=c;if(!Ed(x[a+1298300>>2])){d=x[a+24620>>2];e=ib-16|0;ib=e;b=mc(536);x[27524]=0;d=Q(840,b|0,d|0)|0;f=x[27524];x[27524]=0;a:{if((f|0)!=1){b=x[uf(e+8|0,d)>>2];ib=e+16|0;break a}a=P()|0;Ib(b);S(a|0);p()}x[c+8>>2]=b;b=a+1298300|0;a=c+8|0;$O(b,ce(a));gz(a)}ib=c+16|0}function kk(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=x[a>>2];c=tc(d,x[a+4>>2]);if(c>>>0<b>>>0){d=ib-32|0;ib=d;b=b-c|0;c=x[Db(a)>>2];e=x[a+4>>2];a:{if(b>>>0<=c-e>>2>>>0){Tt(a,b);break a}c=Db(a);c=cg(d+8|0,wg(a,tc(x[a>>2],e)+b|0),tc(x[a>>2],x[a+4>>2]),c);WN(c,b);Dd(a,c);bg(c)}ib=d+32|0;return}if(b>>>0<c>>>0){Od(a,d+(b<<2)|0)}}function pR(a){a=a|0;var b=0,c=0,d=0;b=ib-16|0;ib=b;if(y[a+534|0]){while(1){d=c&65535;if(d>>>0>=256){v[a+534|0]=0}else{vj(a,d,1);c=c+1|0;continue}break}}v[b+15|0]=0;hi(a+8|0,18,b+15|0);tu(a+26|0,18,29210);v[b+14|0]=255;hi(a+62|0,256,b+14|0);ph(x[a>>2],x[a+4>>2],65535,261,1);ph(x[a>>2],x[a+4>>2],65535,260,0);ib=b+16|0}function oJ(a){var b=0,c=0,d=0,e=0;b=ib-32|0;ib=b;if(!y[a+20|0]){while(1){if(!(lb[x[x[a>>2]+40>>2]](a)|0)){mJ(a,65536);c=dc(b+16|0,Jb(x[a+4>>2],x[a+16>>2]),65536);d=x[x[a>>2]+44>>2];e=x[c+4>>2];x[b+8>>2]=x[c>>2];x[b+12>>2]=e;lb[d|0](b+24|0,a,b+8|0);x[a+16>>2]=x[a+16>>2]+x[b+28>>2];continue}break}v[a+20|0]=1}ib=b+32|0}function Zh(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=a;f=ib-16|0;ib=f;a:{e=Xh(b,c);if(e>>>0<4294967280){b:{if(Dl(e)){ee(d,e);break b}g=Wg(e)+1|0;h=mc(g);td(d,h);hf(d,g);vd(d,e);d=h}while(1){if((b|0)!=(c|0)){oe(d,b);d=d+1|0;b=b+1|0;continue}break}v[f+15|0]=0;oe(d,f+15|0);ib=f+16|0;break a}of();p()}return a|0}function V_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(gh(a,x[b+8>>2],e)){Iw(b,c,d);return}a:{if(!gh(a,x[b>>2],e)){break a}if(!(x[b+16>>2]!=(c|0)&x[b+20>>2]!=(c|0))){if((d|0)!=1){break a}x[b+32>>2]=1;return}x[b+20>>2]=c;x[b+32>>2]=d;x[b+40>>2]=x[b+40>>2]+1;if(!(x[b+36>>2]!=1|x[b+24>>2]!=2)){v[b+54|0]=1}x[b+44>>2]=4}}function Ur(a,b,c,d,e,f){var g=0;g=ib-16|0;ib=g;x[g+8>>2]=d;d=x[ge(g,g+8|0)>>2];x[27524]=0;ja(f|0,a+8|0,b|0,c|0,d|0,e|0)|0;b=x[27524];x[27524]=0;if((b|0)!=1){a=Xx(a);b=Wx(a+88|0);c=Vx(a+92|0);d=Ux(a+96|0);x[a>>2]=49340;x[b>>2]=49456;x[c>>2]=49536;x[d>>2]=49576;Xc(g+8|0);ib=g+16|0;return a}a=P()|0;Xc(g+8|0);S(a|0);p()}function Qaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=Ai(a,b,c,d);x[a+4272>>2]=1065353216;x[a>>2]=47072;b=a+4208|0;e=Bb(b,0),f=1056880300,x[e>>2]=f;e=Bb(b,1),f=1050733080,x[e>>2]=f;e=Bb(b,2),f=1056964608,x[e>>2]=f;x[27524]=0;R(903,a+44|0,2);b=x[27524];x[27524]=0;if((b|0)!=1){return a|0}b=P()|0;Rf(a);S(b|0);p()}function Jaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=Ai(a,b,c,d);x[a>>2]=47308;b=a+4208|0;e=Bb(b,0),f=1065353216,x[e>>2]=f;e=Bb(b,1),f=1065353216,x[e>>2]=f;e=Bb(b,2),f=1051372203,x[e>>2]=f;e=Bb(b,3),f=0,x[e>>2]=f;x[27524]=0;R(903,a+44|0,2);b=x[27524];x[27524]=0;if((b|0)!=1){return a|0}b=P()|0;Rf(a);S(b|0);p()}function LN(a){var b=0,c=0,d=0;c=ib-32|0;ib=c;a:{d=vy(a);b=Wj(x[a>>2],x[a+4>>2]);b:{if(d>>>0<=b>>>0){break b}x[27524]=0;b=fa(907,c+8|0,b|0,b|0,Db(a)|0)|0;d=x[27524];x[27524]=0;if((d|0)!=1){Dd(a,b);IN(b);break b}_(V(0)|0)|0;x[27524]=0;Z(18);a=x[27524];x[27524]=0;if((a|0)==1){break a}}ib=c+32|0;return}V(0)|0;Sb();p()}function KN(a){var b=0,c=0,d=0;c=ib-32|0;ib=c;a:{d=_h(a);b=tc(x[a>>2],x[a+4>>2]);b:{if(d>>>0<=b>>>0){break b}x[27524]=0;b=fa(908,c+8|0,b|0,b|0,Db(a)|0)|0;d=x[27524];x[27524]=0;if((d|0)!=1){Dd(a,b);bg(b);break b}_(V(0)|0)|0;x[27524]=0;Z(18);a=x[27524];x[27524]=0;if((a|0)==1){break a}}ib=c+32|0;return}V(0)|0;Sb();p()}function wna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=ib-32|0;ib=e;c=ib-16|0;ib=c;f=e+8|0;GC(c+8|0,f);d=x[c+12>>2];ld(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(d|0)){gd(a,x[c+12>>2])}ib=c+16|0;d=(d|0)==(g|0);if(!d){kv(f)}c=-1;a:{if(!d){break a}c=0;if(!_W(e+8|0)){break a}c=Ee(a,b,72,0)}ib=e+32|0;return c|0}function XP(a,b,c,d){var e=0,f=0;e=ib-16|0;ib=e;f=-2147483648;f=!c|!(v[c+15|0]&1)?f:x[c+8>>2];a:{b:{if(!(!d|!(y[d+34|0]&32))){f=z[d+28>>1];break b}if((f|0)==-2147483648){break a}}lq(b,f,a);Ab(e+8|0,a+1074312|0,10);if(!zb(x[x[e+8>>2]>>2],x[e+12>>2])|x[a+480208>>2]&16384){break a}x[b+88>>2]=x[b+88>>2]&-257}ib=e+16|0}function Yia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=ib-608|0;ib=d;c=ib-16|0;ib=c;zT(c+8|0,d);e=x[c+12>>2];ld(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){gd(a,x[c+12>>2])}ib=c+16|0;e=(e|0)==(f|0);if(!e){yT(d)}c=-1;a:{if(!e){break a}c=0;if(!BT(d)){break a}c=Ee(a,b,AT(z[d+34>>1]),kb)}ib=d+608|0;return c|0}function Ky(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=H(c,.999);h=c*3.141592653589793;i=Ot(b);while(1){if((e|0)!=32768){f=((e^-1)<<12&28672)+(e>>>3|0)|0;if((f|0)!=16384){d=+(f-16384|0)*.000244140625;g=h*d;d=Ki(g)*Ot(M(d*d*-.0625+1)*b)/(i*g)}else{d=1}j=a,k=wA(c*d*32768),w[j>>1]=k;e=e+1|0;a=a+2|0;continue}break}}function ET(a){var b=0,c=0;a:{if(Qb(a,3868,4)|y[a+63|0]!=26){break a}b=y[a+65|0];if(y[a+66|0]|(b|0)!=16&(b|0)!=1|(y[a+64|0]&3|(y[a+78|0]|y[a+79|0]<<8)>>>0>127)){break a}if((y[a+80|0]|y[a+81|0]<<8)>>>0>127){break a}b=a+80|0;a=a+78|0;a=Lk(y[a|0]|y[a+1|0]<<8,y[b|0]|y[b+1|0]<<8)?b:a;c=(y[a|0]|y[a+1|0]<<8)!=0}return c}function p8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;x[27524]=0;Y(958,a|0);d=x[27524];x[27524]=0;if((d|0)!=1){x[a+4>>2]=c;x[a>>2]=b?b:939;return}_(V(0)|0)|0;x[27524]=0;X(945,13033,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)!=1){$();return}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function nF(a,b,c,d,e){var f=0;a:{f=ib-32|0;ib=f;dp(f+8|0,c);x[27524]=0;R(e|0,f+20|0,d|0);c=x[27524];x[27524]=0;b:{c:{if((c|0)!=1){bk(f,f+8|0);x[27524]=0;X(118,a|0,b|0,x[f>>2],x[f+4>>2]);a=x[27524];x[27524]=0;if((a|0)==1){break c}dh(f+8|0);ib=f+32|0;break a}a=P()|0;xb(f+8|0);break b}a=P()|0;dh(f+8|0)}S(a|0);p()}}function l9(a,b){a=a|0;b=b|0;var c=0;x[27524]=0;Y(958,a|0);c=x[27524];x[27524]=0;if((c|0)!=1){return E(eM(x[x[a+24>>2]+24>>2],b))}_(V(0)|0)|0;x[27524]=0;X(945,6232,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)!=1){$();return E(E(0))}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function kF(a,b,c,d,e){var f=0;a:{f=ib-32|0;ib=f;QW(f+8|0,c);x[27524]=0;R(e|0,f+20|0,d|0);c=x[27524];x[27524]=0;b:{c:{if((c|0)!=1){bk(f,f+8|0);x[27524]=0;X(118,a|0,b|0,x[f>>2],x[f+4>>2]);a=x[27524];x[27524]=0;if((a|0)==1){break c}dh(f+8|0);ib=f+32|0;break a}a=P()|0;xb(f+8|0);break b}a=P()|0;dh(f+8|0)}S(a|0);p()}}function k9(a,b){a=a|0;b=b|0;var c=0;x[27524]=0;Y(958,a|0);c=x[27524];x[27524]=0;if((c|0)!=1){return E(dM(x[x[a+24>>2]+24>>2],b))}_(V(0)|0)|0;x[27524]=0;X(945,9325,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)!=1){$();return E(E(0))}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function j9(a,b){a=a|0;b=b|0;var c=0;x[27524]=0;Y(958,a|0);c=x[27524];x[27524]=0;if((c|0)!=1){return E(cM(x[x[a+24>>2]+24>>2],b))}_(V(0)|0)|0;x[27524]=0;X(945,6275,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)!=1){$();return E(E(0))}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function i9(a,b){a=a|0;b=b|0;var c=0;x[27524]=0;Y(958,a|0);c=x[27524];x[27524]=0;if((c|0)!=1){return E(bM(x[x[a+24>>2]+24>>2],b))}_(V(0)|0)|0;x[27524]=0;X(945,6177,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)!=1){$();return E(E(0))}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function h9(a,b){a=a|0;b=b|0;var c=0;x[27524]=0;Y(958,a|0);c=x[27524];x[27524]=0;if((c|0)!=1){return E(aM(x[x[a+24>>2]+24>>2],b))}_(V(0)|0)|0;x[27524]=0;X(945,6133,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)!=1){$();return E(E(0))}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function Nma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=ib-240|0;ib=d;c=ib-16|0;ib=c;rW(c+8|0,d);e=x[c+12>>2];ld(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){gd(a,x[c+12>>2])}ib=c+16|0;e=(e|0)==(f|0);if(!e){qW(d)}c=-1;a:{if(!e){break a}c=0;if(!tW(d)){break a}c=Ee(a,b,sW(x[d+4>>2]),kb)}ib=d+240|0;return c|0}function Jha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=ib-32|0;ib=d;x[d+28>>2]=c;x[d+8>>2]=4896;e=x[a>>2];f=x[a+8>>2];c=x[Hb(d+28|0,d+8|0)>>2];if(!Ob(e,f,c)){c=jf(a)}e=d+8|0;mB(e,b);f=dc(d+16|0,x[d+8>>2],c);kc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);mB(e,b);Rb(x[d+8>>2]+c|0,0,4896-c|0);Yb(a,x[d+28>>2]);ib=d+32|0}function BT(a){var b=0;a:{if(Qb(a+44|0,14157,4)|y[a+28|0]!=26|(y[a+40|0]|y[a+41|0]<<8|y[a+30|0]>2)){break a}if(((y[a+38|0]|y[a+39|0]<<8)-33&65535)>>>0<65504|((y[a+32|0]|y[a+33|0]<<8)-257&65535)>>>0<65280|((y[a+34|0]|y[a+35|0]<<8)-256&65535)>>>0<65281){break a}b=((y[a+36|0]|y[a+37|0]<<8)-1&65535)>>>0<128}return b}function Rr(a,b,c,d,e){var f=0;f=ib-16|0;ib=f;x[f+8>>2]=c;c=x[ge(f,f+8|0)>>2];x[27524]=0;fa(e|0,a+8|0,b|0,c|0,d|0)|0;b=x[27524];x[27524]=0;if((b|0)!=1){a=Xx(a);b=Wx(a+88|0);c=Vx(a+92|0);d=Ux(a+96|0);x[a>>2]=49340;x[b>>2]=49456;x[c>>2]=49536;x[d>>2]=49576;Xc(f+8|0);ib=f+16|0;return a}a=P()|0;Xc(f+8|0);S(a|0);p()}function zma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=ib-32|0;ib=d;x[d+28>>2]=c;x[d+8>>2]=102;e=x[a>>2];f=x[a+8>>2];c=x[Hb(d+28|0,d+8|0)>>2];if(!Ob(e,f,c)){c=jf(a)}e=d+8|0;iW(e,b);f=dc(d+16|0,x[d+8>>2],c);kc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);iW(e,b);Rb(x[d+8>>2]+c|0,0,102-c|0);Yb(a,x[d+28>>2]);ib=d+32|0}function uja(a,b){a=a|0;b=b|0;var c=0,d=0;if(x[a+4>>2]!=x[Db(a)>>2]){c=ib-16|0;ib=c;a=wv(c,a,1);UT(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+20;ic(a);ib=c+16|0;return}d=ib-32|0;ib=d;c=Db(a);c=UB(d+8|0,VB(a,Kf(x[a>>2],x[a+4>>2])+1|0),Kf(x[a>>2],x[a+4>>2]),c);UT(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+20;TB(a,c);Ru(c);ib=d+32|0}function Rha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=ib-32|0;ib=d;x[d+28>>2]=c;x[d+8>>2]=263;e=x[a>>2];f=x[a+8>>2];c=x[Hb(d+28|0,d+8|0)>>2];if(!Ob(e,f,c)){c=jf(a)}e=d+8|0;dS(e,b);f=dc(d+16|0,x[d+8>>2],c);kc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);dS(e,b);Rb(x[d+8>>2]+c|0,0,263-c|0);Yb(a,x[d+28>>2]);ib=d+32|0}function Ay(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=ib-16|0;ib=d;h=z[b>>1];c=Td(a);e=gc(a);f=ib-16|0;ib=f;while(1){if(c){g=lt(z[c+16>>1],h);e=g?e:c;c=x[(g?c+4|0:c)>>2];continue}break}c=x[Wb(f+8|0,e)>>2];ib=f+16|0;a:{if(Mb(c,eg(a))){if(!lt(z[b>>1],z[ud(c)>>1])){break a}}c=eg(a)}a=x[Wb(d+8|0,c)>>2];ib=d+16|0;return a}function kC(a,b){a=a|0;b=b|0;var c=0,d=0;if(x[a+4>>2]!=x[Db(a)>>2]){c=ib-16|0;ib=c;a=nX(c,a,1);mX(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+40;ic(a);ib=c+16|0;return}d=ib-32|0;ib=d;c=Db(a);c=kX(d+8|0,lX(a,Qq(x[a>>2],x[a+4>>2])+1|0),Qq(x[a>>2],x[a+4>>2]),c);mX(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+40;jX(a,c);iX(c);ib=d+32|0}function f1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;a:{if(!kf(f)){b=x[f+4>>2];x[a>>2]=x[f>>2];x[a+4>>2]=b;x[a+8>>2]=x[f+8>>2];break a}d=x[f>>2];b:{c:{c=x[f+4>>2];d:{if(js(c)){ee(a,c);break d}if(c>>>0>=1073741808){break c}e=fm(c)+1|0;b=Ii(e);td(a,b);hf(a,e);vd(a,c);a=b}ui(a,d,c+1|0);break b}of();p()}}}function cna(a,b){a=a|0;b=b|0;var c=0,d=0;if(A[a+4>>2]<A[Db(a)>>2]){c=ib-16|0;ib=c;a=wv(c,a,1);WB(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+20;ic(a);ib=c+16|0;return}d=ib-32|0;ib=d;c=Db(a);c=UB(d+8|0,VB(a,Kf(x[a>>2],x[a+4>>2])+1|0),Kf(x[a>>2],x[a+4>>2]),c);WB(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+20;TB(a,c);Ru(c);ib=d+32|0}function Sy(a,b,c){var d=0,e=0,f=0;d=ib-16|0;ib=d;f=x[b+656>>2];e=0;a:{if(!f){break a}f=Cv(f,c);e=a+1074312|0;Ab(d+8|0,e,31);a=0;if(!zb(x[x[d+8>>2]>>2],x[d+12>>2])){Ab(d,e,93);a=zb(x[x[d>>2]>>2],x[d+4>>2])^1}if(!(v[yO(b,c)+6|0]&1)){e=0;if(!(v[f+12|0]&1)|a){break a}}e=pc(x[f>>2],x[f+4>>2])^1}ib=d+16|0;return e}function Ifa(a,b){a=a|0;b=b|0;var c=0,d=0;if(A[a+4>>2]<A[Db(a)>>2]){c=ib-16|0;ib=c;a=rA(c,a,1);dA(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+32;ic(a);ib=c+16|0;return}d=ib-32|0;ib=d;c=Db(a);c=Vt(d+8|0,oq(a,xg(x[a>>2],x[a+4>>2])+1|0),xg(x[a>>2],x[a+4>>2]),c);dA(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+32;zR(a,c);cA(c);ib=d+32|0}function wQ(a,b){a=a|0;b=b|0;var c=0,d=0;if(A[a+4>>2]<A[Db(a)>>2]){c=ib-16|0;ib=c;a=hu(c,a,1);fp(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+12;ic(a);ib=c+16|0;return}d=ib-32|0;ib=d;c=Db(a);c=Pk(d+8|0,on(a,wd(x[a>>2],x[a+4>>2])+1|0),wd(x[a>>2],x[a+4>>2]),c);fp(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+12;Hr(a,c);vQ(c);ib=d+32|0}function _ka(a,b){a=a|0;b=b|0;var c=0,d=0;c=ib-16|0;ib=c;x[c>>2]=x[a+8>>2];d=x[a+8>>2];x[c+8>>2]=a+8;x[c+4>>2]=D(b,20)+d;b=x[c>>2];a:{while(1){if(x[c+4>>2]==(b|0)){break a}x[27524]=0;Y(232,b|0);a=x[27524];x[27524]=0;if((a|0)!=1){b=x[c>>2]+20|0;x[c>>2]=b;continue}break}a=P()|0;Vd(c);S(a|0);p()}Vd(c);ib=c+16|0}function Zea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=ib-32|0;ib=d;b=Pg(d,b);x[27524]=0;U(805,d+16|0,b|0,c|0);e=x[27524];x[27524]=0;a:{b:{if((e|0)!=1){x[27524]=0;U(56,a|0,d+16|0,c|0);a=x[27524];x[27524]=0;if((a|0)==1){break b}wb(d+16|0);wb(b);ib=d+32|0;return}c=P()|0;break a}c=P()|0;wb(d+16|0)}wb(b);S(c|0);p()}function Ska(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=ib-32|0;ib=d;x[d+28>>2]=c;x[d+8>>2]=22;e=x[a>>2];f=x[a+8>>2];c=x[Hb(d+28|0,d+8|0)>>2];if(!Ob(e,f,c)){c=jf(a)}e=d+8|0;Tu(e,b);f=dc(d+16|0,x[d+8>>2],c);kc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);Tu(e,b);Rb(x[d+8>>2]+c|0,0,22-c|0);Yb(a,x[d+28>>2]);ib=d+32|0}function Qka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=ib-32|0;ib=d;x[d+28>>2]=c;x[d+8>>2]=40;e=x[a>>2];f=x[a+8>>2];c=x[Hb(d+28|0,d+8|0)>>2];if(!Ob(e,f,c)){c=jf(a)}e=d+8|0;cB(e,b);f=dc(d+16|0,x[d+8>>2],c);kc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);cB(e,b);Rb(x[d+8>>2]+c|0,0,40-c|0);Yb(a,x[d+28>>2]);ib=d+32|0}function K1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=ib-32|0;ib=g;h=x[24615];x[g+24>>2]=x[24614];x[g+28>>2]=h;h=x[24613];x[g+16>>2]=x[24612];x[g+20>>2]=h;h=x[24611];x[g+8>>2]=x[24610];x[g+12>>2]=h;h=x[24609];x[g>>2]=x[24608];x[g+4>>2]=h;h=a;a=g+32|0;b=ek(h,b,c,d,e,f,g,a);ib=a;return b|0}function Dia(a,b){a=a|0;b=b|0;var c=0,d=0;if(x[a+4>>2]!=x[Db(a)>>2]){c=ib-16|0;ib=c;a=lw(c,a);zA(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+12;ic(a);ib=c+16|0;return}d=ib-32|0;ib=d;c=Db(a);c=Pk(d+8|0,on(a,wd(x[a>>2],x[a+4>>2])+1|0),wd(x[a>>2],x[a+4>>2]),c);zA(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+12;YS(a,c);XS(c);ib=d+32|0}function dq(a,b){a=a|0;b=b|0;var c=0,d=0;d=ib-16|0;ib=d;v[d+15|0]=b;a:{b:{c:{if(!kf(a)){c=10;b=y[a+11|0];if((b|0)==10){break c}ee(a,b+1|0);c=a;break a}c=Kl(a);b=x[a+4>>2];c=c-1|0;if((b|0)!=(c|0)){break b}}tm(a,c,1,c,c,0,0);b=c}c=x[a>>2];vd(a,b+1|0)}a=b+c|0;oe(a,d+15|0);v[d+14|0]=0;oe(a+1|0,d+14|0);ib=d+16|0}function UM(a){var b=0,c=E(0),d=0,e=0;e=x[x[a+16>>2]+24620>>2];b=ib-16|0;ib=b;x[b+12>>2]=0;x[b+8>>2]=1065353216;c=$h(E(B[xq(a+4208|0,b+12|0,b+8|0)>>2]*E(999)));a:{if(c<E(4294967296)&c>=E(0)){d=~~c>>>0;break a}d=0}ib=b+16|0;b=(e>>>0)/(d+1>>>0)|0;b=b>>>0<=2?2:b;x[a+4216>>2]=b;x[a+4220>>2]=b>>>1;wc(a+4224|0,b)}function Of(a,b,c,d){var e=0,f=0,g=0;a:{if(!Eb(a)|(c-b|0)<5){break a}hs(b,c);e=c-4|0;c=Jc(a);g=c+Eb(a)|0;b:{while(1){c:{a=v[c|0];f=a-127|0;if(b>>>0>=e>>>0){break c}if((a|0)!=x[b>>2]&(f&255)>>>0>=130){break b}b=b+4|0;c=((g-c|0)>1)+c|0;continue}break}if((f&255)>>>0<130|a>>>0>x[e>>2]-1>>>0){break a}}x[d>>2]=4}}function FY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=ib-32|0;ib=d;x[d+28>>2]=c;x[d+8>>2]=65;e=x[a>>2];f=x[a+8>>2];c=x[Hb(d+28|0,d+8|0)>>2];if(!Ob(e,f,c)){c=jf(a)}e=d+8|0;vv(e,b);f=dc(d+16|0,x[d+8>>2],c);kc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);vv(e,b);Rb(x[d+8>>2]+c|0,0,65-c|0);Yb(a,x[d+28>>2]);ib=d+32|0}function Eja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=ib-1120|0;ib=d;c=ib-16|0;ib=c;ZT(c+8|0,d+8|0);e=x[c+12>>2];ld(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){gd(a,x[c+12>>2])}ib=c+16|0;c=-1;a:{if((e|0)!=(f|0)){break a}c=0;if(!$T(d+8|0)){break a}c=Ee(a,b,_T(x[d+1112>>2]),kb)}ib=d+1120|0;return c|0}function h_(a,b){a=a|0;b=b|0;var c=0,d=0;if(A[a+4>>2]<A[Db(a)>>2]){c=ib-16|0;ib=c;a=lw(c,a);fp(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+12;ic(a);ib=c+16|0;return}d=ib-32|0;ib=d;c=Db(a);c=Pk(d+8|0,on(a,wd(x[a>>2],x[a+4>>2])+1|0),wd(x[a>>2],x[a+4>>2]),c);fp(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+12;Hr(a,c);kw(c);ib=d+32|0}function dZ(a,b){a=a|0;b=b|0;var c=0,d=0;if(A[a+4>>2]<A[Db(a)>>2]){c=ib-16|0;ib=c;a=gE(c,a);Uv(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+36;ic(a);ib=c+16|0;return}d=ib-32|0;ib=d;c=Db(a);c=eE(d+8|0,fE(a,tr(x[a>>2],x[a+4>>2])+1|0),tr(x[a>>2],x[a+4>>2]),c);Uv(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+36;dE(a,c);Wv(c);ib=d+32|0}function Zma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=ib-224|0;ib=d;c=ib-16|0;ib=c;FW(c+8|0,d);e=x[c+12>>2];ld(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){gd(a,x[c+12>>2])}ib=c+16|0;c=-1;a:{if((e|0)!=(f|0)){break a}c=0;if(!HW(d)){break a}c=Ee(a,b,GW(y[d+216|0],y[d+217|0]),kb)}ib=d+224|0;return c|0}function TZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=ib-32|0;ib=d;b=Nk(d,b);x[27524]=0;U(158,d+16|0,b|0,c|0);e=x[27524];x[27524]=0;a:{b:{if((e|0)!=1){x[27524]=0;U(4,a|0,d+16|0,c|0);a=x[27524];x[27524]=0;if((a|0)==1){break b}xb(d+16|0);xb(b);ib=d+32|0;return}c=P()|0;break a}c=P()|0;xb(d+16|0)}xb(b);S(c|0);p()}function Pma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=ib-32|0;ib=d;x[d+28>>2]=c;x[d+8>>2]=5;e=x[a>>2];f=x[a+8>>2];c=x[Hb(d+28|0,d+8|0)>>2];if(!Ob(e,f,c)){c=jf(a)}e=d+8|0;Ko(e,b);f=dc(d+16|0,x[d+8>>2],c);kc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);Ko(e,b);Rb(x[d+8>>2]+c|0,0,5-c|0);Yb(a,x[d+28>>2]);ib=d+32|0}function DN(a){a=a|0;var b=0,c=0;c=ib-16|0;ib=c;b=x[a+4232>>2];b=(b>>>1)+(b>>>6)|0;x[a+4220>>2]=b;x[27524]=0;x[c+12>>2]=0;U(909,a+4208|0,b<<1,c+12|0);b=x[27524];x[27524]=0;a:{if((b|0)==1){b=V(108196)|0;if((jb|0)!=(da(108196)|0)){break a}_(b|0)|0;x[a+4220>>2]=0;$()}x[a+4224>>2]=0;ib=c+16|0;return}S(b|0);p()}function C7(a,b){a=a|0;b=b|0;var c=0,d=0;a=Kb(a);c=Eb(b);x[27524]=0;R(73,a|0,c|0);c=x[27524];x[27524]=0;if((c|0)!=1){a:{b:{while(1){if(Eb(b)>>>0<=d>>>0){break b}c=v[ng(b,d)|0];x[27524]=0;R(51,a|0,Ke(Ke(c))|0);c=x[27524];x[27524]=0;if((c|0)!=1){d=d+1|0;continue}break}break a}return}}b=P()|0;xb(a);S(b|0);p()}function l8(a,b){a=a|0;b=b|0;var c=0;x[27524]=0;Y(958,a|0);c=x[27524];x[27524]=0;if((c|0)!=1){pL(x[x[a+24>>2]+24>>2],b);return 1}_(V(0)|0)|0;x[27524]=0;X(945,5787,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)!=1){$();return 0}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function cz(a,b,c,d,e,f){var g=0,h=0,i=0;g=ib-16|0;ib=g;h=-17;if(-17-b>>>0>=c>>>0){i=nd(a);if(b>>>0<=2147483622){x[g+8>>2]=b<<1;x[g+12>>2]=b+c;h=Wg(x[Yc(g+12|0,g+8|0)>>2])+1|0}c=mc(h);if(e){Ae(c,i,e)}if((d|0)!=(e|0)){Ae((c+e|0)+f|0,e+i|0,d-e|0)}if((b|0)!=10){Ib(i)}td(a,c);hf(a,h);ib=g+16|0;return}of();p()}function Lia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=ib+-64|0;ib=d;c=ib-16|0;ib=c;_u(c+8|0,d);e=x[c+12>>2];ld(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){gd(a,x[c+12>>2])}ib=c+16|0;e=(e|0)==(f|0);if(!e){Vu(d)}c=-1;a:{if(!e){break a}c=0;if(!eT(d)){break a}c=Ee(a,b,dT(d),kb)}ib=d- -64|0;return c|0}function L8(a,b){a=a|0;b=b|0;var c=0;x[27524]=0;Y(958,a|0);c=x[27524];x[27524]=0;if((c|0)!=1){return KL(x[x[a+24>>2]+24>>2],b)|0}_(V(0)|0)|0;x[27524]=0;X(945,6627,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)!=1){$();return 0}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function L4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;a:{if(y[b+40|0]){break a}if(!x[b+28>>2]){v[b+40|0]=1;break a}d=x[c+4>>2];f=x[c>>2];while(1){b:{if(d){e=lb[x[b+28>>2]](x[b+24>>2],f,d)|0;if(e){break b}v[b+40|0]=1}d=g;break a}d=d-e|0;f=e+f|0;g=e+g|0;h=g>>>0<e>>>0?h+1|0:h;continue}}cc(a,x[c>>2],d)}function ima(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=ib-192|0;ib=d;c=ib-16|0;ib=c;ev(c+8|0,d);e=x[c+12>>2];ld(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){gd(a,x[c+12>>2])}ib=c+16|0;e=(e|0)==(f|0);if(!e){RV(d)}c=-1;a:{if(!e){break a}c=0;if(!TV(d)){break a}c=Ee(a,b,SV(d),kb)}ib=d+192|0;return c|0}function et(a){var b=0,c=0,d=0;b=ki(+B[a+4228>>2]*8)*.25+-.25;C[a+4248>>3]=b;if(y[a+4240|0]){if(b>45e-5){c=xp(b)/.6931471805599453;b=c-J(c);d=c-b;c=0;a:{if(b<.2075187496394219){break a}c=.4150374992788438;if(b<.5){break a}c=b<.792481250360578?.5849625007211562:1}b=ki(d+c)*.5}else{b=0}C[a+4248>>3]=b}dt(a)}function Tma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=ib-208|0;ib=d;c=ib-16|0;ib=c;xW(c+8|0,d);e=x[c+12>>2];ld(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){gd(a,x[c+12>>2])}ib=c+16|0;e=(e|0)==(f|0);if(!e){wW(d)}c=-1;a:{if(!e){break a}c=0;if(!zW(d)){break a}c=Ee(a,b,yW(d),kb)}ib=d+208|0;return c|0}function Ql(a,b,c,d,e){var f=0;a:{if(c>>>0>255){break a}b:{switch(d-2|0){case 0:d=D(c,872)+b|0;f=HP(x[d+720>>2],x[d+1272>>2],e);if((f+5&255)>>>0>5){break a}return GP(a,b,c,e);case 1:break b;default:break a}}f=GP(a,b,c,e);if((f+5&255)>>>0>5){break a}a=D(c,872)+b|0;f=HP(x[a+720>>2],x[a+1272>>2],e)}return f}function coa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=ib-16|0;ib=d;x[d+12>>2]=c;a:{if(!Ob(x[b>>2],x[b+8>>2],c<<1)){break a}wc(d+12|0,65535);Dg(a,z[d+12>>1]);c=Cb(x[a>>2]);x[d>>2]=c;a=Cb(x[a+4>>2]);while(1){if(!Mb(c,a)){break a}ov(b,d+8|0);e=c,f=Fb(z[d+8>>1]),w[e>>1]=f;c=x[Ye(d)>>2];continue}}ib=d+16|0}function bn(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;a:{if(x[c>>2]|x[d>>2]){while(1){if((b|0)==(f|0)){break a}e=x[d>>2];g=x[c>>2];h=c,i=g-kd((kd(0-g|0,31)&255)+g|0,8)|0,x[h>>2]=i;h=d,i=x[d>>2]-kd(e+(kd(0-e|0,31)&255)|0,8)|0,x[h>>2]=i;e=(f<<3)+a|0;x[e>>2]=x[c>>2];x[e+4>>2]=x[d>>2];f=f+1|0;continue}}Rb(a,0,b<<3)}}function fs(a,b,c,d){var e=0;a:{if(!(d&2048)){break a}e=d&74;if(!c|((e|0)==8|(e|0)==64)){break a}v[a|0]=43;a=a+1|0}if(d&512){v[a|0]=35;a=a+1|0}while(1){e=y[b|0];if(e){v[a|0]=e;a=a+1|0;b=b+1|0;continue}break}e=d&74;b=111;b:{if((e|0)==64){break b}b=d&16384?88:120;if((e|0)==8){break b}b=c?100:117}v[a|0]=b}function Vha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=ib-80|0;ib=d;c=ib-16|0;ib=c;tV(c+8|0,d);e=x[c+12>>2];ld(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){gd(a,x[c+12>>2])}ib=c+16|0;e=(e|0)==(f|0);if(!e){nB(d)}c=-1;a:{if(!e){break a}c=0;if(!iS(d)){break a}c=Ee(a,b,hS(d),kb)}ib=d+80|0;return c|0}function L$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=ib-16|0;ib=f;x[e>>2]=c;a=Lw(f+12|0,0,x[a+8>>2]);b=2;a:{if(a+1>>>0<2){break a}c=a-1|0;b=1;if(c>>>0>d-x[e>>2]>>>0){break a}b=f+12|0;while(1){if(c){a=y[b|0];d=x[e>>2];x[e>>2]=d+1;v[d|0]=a;c=c-1|0;b=b+1|0;continue}break}b=0}ib=f+16|0;return b|0}function cu(a){var b=0,c=0;b=x[a+76>>2];a:{if(!((b|0)>=0&(!b|x[120008]!=(b&-1073741825)))){b=x[a+4>>2];if((b|0)!=x[a+8>>2]){x[a+4>>2]=b+1;a=y[b|0];break a}a=ex(a);break a}b=a+76|0;c=x[b>>2];x[b>>2]=c?c:1073741823;c=x[a+4>>2];b:{if((c|0)!=x[a+8>>2]){x[a+4>>2]=c+1;a=y[c|0];break b}a=ex(a)}ce(b)}return a}function Uja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=ib-128|0;ib=d;c=ib-16|0;ib=c;iU(c+8|0,d);e=x[c+12>>2];ld(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){gd(a,x[c+12>>2])}ib=c+16|0;e=(e|0)==(f|0);if(!e){hU(d)}c=-1;a:{if(!e){break a}c=0;if(!jU(d)){break a}c=Ee(a,b,256,0)}ib=d+128|0;return c|0}function Dfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=ib-16|0;ib=d;c=Af(a,c);Pd(d,x[a+36>>2]);a:{b:{if(!c){Pc(d,a+32|0,5);e=-1;if(!zb(x[x[d>>2]>>2],x[d+4>>2])){break b}break a}e=x[c+16>>2]}f=x[a+36>>2];c:{d:{switch(e+1|0){case 0:case 2:si(f,b);break c;default:break d}}EV(f,b,e)}f=c}af(a,f);ib=d+16|0}function iO(a){var b=0,c=0;a:{if(Qb(a,14191,4)){break a}b=y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24);if((b|0)!=-1095062050&(b|0)!=-1346458146){break a}b=y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24);if(!b){break a}c=(b+24|0)==(y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24))}return c}function b3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a=Kb(a);d=xd(x[b+4>>2],y[b+11|0]);e=xd(x[c+4>>2],y[c+11|0]);b=nd(b);x[27524]=0;X(105,a|0,b|0,d|0,d+e|0);b=x[27524];x[27524]=0;a:{if((b|0)!=1){b=nd(c);x[27524]=0;W(106,a|0,b|0,e|0)|0;b=x[27524];x[27524]=0;if((b|0)!=1){break a}}b=P()|0;xb(a);S(b|0);p()}}function ww(a,b,c,d,e){var f=0,g=0;g=c-b|0;a:{if((e|0)>=(g|0)){e=D(32-G(d|1)|0,1233)>>12;f=61;if((g|0)<(e+(A[(e<<2)+25760>>2]<=d>>>0)|0)){break a}}b:{if(d>>>0<=99999999){c=sx(b,d);break b}c=d;d=(d>>>0)/1e8|0;e=c+D(d,-1e8)|0;c=(e>>>0)/1e4|0;c=kj(kj(sI(b,d),c),e+D(c,-1e4)|0)}f=0}x[a+4>>2]=f;x[a>>2]=c}function w6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=ib-16|0;ib=e;a:{if(!(c&1024)){break a}f=e,g=ke(b),x[f+8>>2]=g;b:{if(!Eb(b)){break b}if(y[Qc(b,0)|0]!=43){if(y[Qc(b,0)|0]!=45){break b}}d=d+1|0;gK(e+8|0)}c=Eb(b);if(c>>>0>=d>>>0){break a}fK(b,x[pj(e,e+8|0)>>2],d-c|0,48)}$c(a,b);ib=e+16|0}function nba(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=E(0);if(b>>>0<=6){c=Ld(c,E(0));a:{b:{switch(b-1|0){case 0:c=$h(c);if(c==B[Bb(a+4208|0,1)>>2]){break a}x[a+4236>>2]=0;B[a+4240>>2]=E(c*E(.5))+E(.5);break a;case 3:break b;default:break a}}c=E($h(E(c*E(4)))*E(.25))}d=Bb(a+4208|0,b),e=c,B[d>>2]=e;my(a)}}function iC(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=ib-32|0;ib=f;x[f+8>>2]=c;g=f,h=jf(b),x[g+28>>2]=h;c=f+8|0;Wf(c,b,x[Hb(c,f+28|0)>>2]);b=Le(c);x[27524]=0;ea(240,a|0,b|0,x[f+8>>2],d|0,e|0);a=x[27524];x[27524]=0;if((a|0)!=1){Rc(f+8|0);ib=f+32|0;return}a=P()|0;Rc(f+8|0);S(a|0);p()}function eoa(a){a=a|0;var b=0,c=0,d=0;c=ib-32|0;ib=c;b=255;a:{if(wj(x[a>>2],x[a+4>>2])>>>0<=49){b=hA(c,x[a+12>>2]);x[27524]=0;R(293,a|0,b|0);d=x[27524];x[27524]=0;if((d|0)==1){break a}tl(b);Lj(a,wj(x[a>>2],x[a+4>>2])-1&255);b=wj(x[a>>2],x[a+4>>2])-1|0}ib=c+32|0;return b&255}a=P()|0;tl(b);S(a|0);p()}function Wba(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=E(0);if(b>>>0<=6){c=Ld(c,E(0));a:{b:{switch(b-3|0){case 0:c=$h(c);if(c==B[Bb(a+4208|0,3)>>2]){break a}x[a+4236>>2]=0;B[a+4240>>2]=E(c*E(.5))+E(.5);break a;case 1:break b;default:break a}}c=E($h(E(c*E(4)))*E(.25))}d=Bb(a+4208|0,b),e=c,B[d>>2]=e;my(a)}}function Dq(a){var b=0,c=0;b=ib-32|0;ib=b;x[b+24>>2]=0;x[b+28>>2]=0;x[b+16>>2]=0;x[b+20>>2]=0;x[b+8>>2]=0;x[b+12>>2]=0;x[b>>2]=0;x[b+4>>2]=0;c=a+288|0;nA(c,c+512|0,b);x[b+24>>2]=0;x[b+28>>2]=0;x[b+16>>2]=0;x[b+20>>2]=0;x[b+8>>2]=0;x[b+12>>2]=0;x[b>>2]=0;x[b+4>>2]=0;a=a+800|0;nA(a,MS(a),b);ib=b+32|0}function Dy(a,b,c){var d=0,e=0;d=ib-16|0;ib=d;x[d>>2]=a;a=x[a+4>>2];x[d+4>>2]=a;x[d+8>>2]=a+D(b,52);b=x[d+4>>2];a=x[d+8>>2];a:{while(1){if((a|0)==(b|0)){break a}x[27524]=0;R(883,b|0,c|0);e=x[27524];x[27524]=0;if((e|0)!=1){b=b+52|0;x[d+4>>2]=b;continue}break}a=P()|0;ic(d);S(a|0);p()}ic(d);ib=d+16|0}function qQ(a,b,c){var d=0,e=0;d=ib-16|0;ib=d;e=x[b+48>>2]+1|0;x[b+52>>2]=e;a:{if(A[Xb(x[a+484344>>2],z[b+70>>1])+12>>2]>e>>>0){break a}if(!c){w[b+74>>1]=z[b+72>>1]+1}x[b+52>>2]=0;Ab(d+8|0,a+1074312|0,63);if(!zb(x[x[d+8>>2]>>2],x[d+12>>2])){break a}a=x[b+56>>2];x[b+56>>2]=0;x[b+52>>2]=a}ib=d+16|0}function b9(a){a=a|0;var b=0;x[27524]=0;Y(958,a|0);b=x[27524];x[27524]=0;if((b|0)!=1){return XL(x[x[a+24>>2]+24>>2])|0}_(V(0)|0)|0;x[27524]=0;X(945,12761,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)!=1){$();return 0}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function N8(a,b){a=a|0;b=b|0;var c=0;x[27524]=0;Y(958,a|0);c=x[27524];x[27524]=0;if((c|0)!=1){return ML(x[a+24>>2],b)|0}_(V(0)|0)|0;x[27524]=0;X(945,9739,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)!=1){$();return 0}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function F9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=ib-16|0;ib=d;ed(a,b);x[27524]=0;U(66,d+8|0,b|0,c|0);e=x[27524];x[27524]=0;a:{if((e|0)==1){break a}_b(d+8|0);b=x[b+24>>2];if(b){x[27524]=0;U(67,d|0,b|0,c|0);b=x[27524];x[27524]=0;if((b|0)==1){break a}_b(d)}ib=d+16|0;return}b=P()|0;_b(a);S(b|0);p()}function xN(a){a=a|0;var b=0,c=0,d=0;b=C[a+4264>>3]*+A[x[a+16>>2]+1074376>>2];a:{if(F(b)<0x8000000000000000){d=~~b>>>0;c=F(b)>=1?~~(b>0?H(J(b*2.3283064365386963e-10),4294967295):K((b-+(~~b>>>0>>>0))*2.3283064365386963e-10))>>>0:0;break a}c=-2147483648}C[a+4256>>3]=b-(+(d>>>0)+ +(c|0)*4294967296)}function f9(a){a=a|0;var b=0;x[27524]=0;Y(958,a|0);b=x[27524];x[27524]=0;if((b|0)!=1){return $L(x[x[a+24>>2]+24>>2])|0}_(V(0)|0)|0;x[27524]=0;X(945,8744,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)!=1){$();return 0}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function d9(a){a=a|0;var b=0;x[27524]=0;Y(958,a|0);b=x[27524];x[27524]=0;if((b|0)!=1){return ZL(x[x[a+24>>2]+24>>2])|0}_(V(0)|0)|0;x[27524]=0;X(945,7113,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)!=1){$();return 0}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function c9(a){a=a|0;var b=0;x[27524]=0;Y(958,a|0);b=x[27524];x[27524]=0;if((b|0)!=1){return YL(x[x[a+24>>2]+24>>2])|0}_(V(0)|0)|0;x[27524]=0;X(945,5322,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)!=1){$();return 0}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function a9(a){a=a|0;var b=0;x[27524]=0;Y(958,a|0);b=x[27524];x[27524]=0;if((b|0)!=1){return WL(x[x[a+24>>2]+24>>2])|0}_(V(0)|0)|0;x[27524]=0;X(945,9278,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)!=1){$();return 0}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function X_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;if(gh(a,x[b+8>>2],0)){Hw(b,c,d);return}e=x[a+12>>2];f=a+16|0;cG(x[f>>2],x[a+20>>2],b,c,d);a=a+24|0;e=(e<<3)+f|0;a:{if(a>>>0>=e>>>0){break a}while(1){cG(x[a>>2],x[a+4>>2],b,c,d);if(y[b+54|0]){break a}a=a+8|0;if(e>>>0>a>>>0){continue}break}}}function V8(a){a=a|0;var b=0;x[27524]=0;Y(958,a|0);b=x[27524];x[27524]=0;if((b|0)!=1){return Cg(x[x[a+24>>2]+24>>2])|0}_(V(0)|0)|0;x[27524]=0;X(945,7081,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)!=1){$();return 0}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function U8(a){a=a|0;var b=0;x[27524]=0;Y(958,a|0);b=x[27524];x[27524]=0;if((b|0)!=1){return Ip(x[x[a+24>>2]+24>>2])|0}_(V(0)|0)|0;x[27524]=0;X(945,6790,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)!=1){$();return 0}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function T8(a){a=a|0;var b=0;x[27524]=0;Y(958,a|0);b=x[27524];x[27524]=0;if((b|0)!=1){return QL(x[x[a+24>>2]+24>>2])|0}_(V(0)|0)|0;x[27524]=0;X(945,6888,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)!=1){$();return 0}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function S8(a){a=a|0;var b=0;x[27524]=0;Y(958,a|0);b=x[27524];x[27524]=0;if((b|0)!=1){return PL(x[x[a+24>>2]+24>>2])|0}_(V(0)|0)|0;x[27524]=0;X(945,6956,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)!=1){$();return 0}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function Q8(a){a=a|0;var b=0;x[27524]=0;Y(958,a|0);b=x[27524];x[27524]=0;if((b|0)!=1){return Hp(x[x[a+24>>2]+24>>2])|0}_(V(0)|0)|0;x[27524]=0;X(945,7428,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)!=1){$();return 0}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function Mea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=rc(a,b,614);e=c+616|0;a=0;while(1){d=D(a,872);aq(d+e|0,(b+d|0)+616|0);a=a+1|0;if((a|0)!=256){continue}break}a=DA(c+223848|0,b+223848|0);x[27524]=0;Q(809,c+223860|0,b+223860|0)|0;b=x[27524];x[27524]=0;if((b|0)!=1){return c|0}b=P()|0;ec(a);S(b|0);p()}function H8(a){a=a|0;var b=0;x[27524]=0;Y(958,a|0);b=x[27524];x[27524]=0;if((b|0)!=1){return IL(x[x[a+24>>2]+24>>2])|0}_(V(0)|0)|0;x[27524]=0;X(945,5819,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)!=1){$();return 0}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function nca(a,b){a=a|0;b=b|0;var c=0;a:{c=ib-32|0;ib=c;Rs(c,b);x[27524]=0;R(919,c+16|0,c|0);b=x[27524];x[27524]=0;b:{c:{if((b|0)!=1){x[27524]=0;U(920,a|0,0,c+16|0);a=x[27524];x[27524]=0;if((a|0)==1){break c}Gc(c+16|0);xb(c);ib=c+32|0;break a}a=P()|0;break b}a=P()|0;Gc(c+16|0)}xb(c);S(a|0);p()}}function g9(a){a=a|0;var b=0;x[27524]=0;Y(958,a|0);b=x[27524];x[27524]=0;if((b|0)!=1){return+Zy(x[x[a+24>>2]+24>>2])}_(V(0)|0)|0;x[27524]=0;X(945,10087,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)!=1){$();return 0}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function $8(a){a=a|0;var b=0;x[27524]=0;Y(958,a|0);b=x[27524];x[27524]=0;if((b|0)!=1){return+VL(x[x[a+24>>2]+24>>2])}_(V(0)|0)|0;x[27524]=0;X(945,15147,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)!=1){$();return 0}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function ch(a,b){var c=0,d=0,e=0,f=0;d=ib-16|0;ib=d;a:{if(!b){b=0;break a}c=b>>31;e=(c^b)-c|0;c=G(e);Sf(d,e,0,0,0,c+81|0);e=0+x[d+8>>2]|0;c=(x[d+12>>2]^65536)+(16414-c<<16)|0;c=e>>>0<f>>>0?c+1|0:c;f=b&-2147483648|c;c=x[d+4>>2];b=x[d>>2]}x[a>>2]=b;x[a+4>>2]=c;x[a+8>>2]=e;x[a+12>>2]=f;ib=d+16|0}function aR(a,b,c){var d=0,e=0,f=0,g=0;if(c==0){e=a;b=_r(b);o(0);a=j(1)|0;f=j(0)|0;o(+c);d=j(1)|0;j(0)|0;l(0,f|0);l(1,a&2147483647|d&-2147483648);rl(e,b,+n());return}a:{if(!tf(b)){break a}d=F(c)<O;if(b<0){c=d?c:1;break a}if(d){break a}rl(a,b,tf(c)?N:c);return}b=_r(b);g=Ki(c);rl(a,b*gf(c),g*b)}function Uma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=ib-16|0;ib=d;x[d+8>>2]=c;x[d+12>>2]=-1;if((c|0)!=-1){f=d,g=Eb(a),x[f>>2]=g;e=x[Hb(d+12|0,d)>>2];x[d+4>>2]=e;a=Rp(Jc(a),b,x[Hb(d+4|0,d+8|0)>>2]);a:{if(a){break a}a=-1;if(c>>>0>e>>>0){break a}a=c>>>0<e>>>0}ib=d+16|0;return a|0}yk();p()}function yC(a,b,c){var d=0,e=0,f=0;d=ib-32|0;ib=d;x[d+28>>2]=c;x[d+8>>2]=192;e=x[a>>2];f=x[a+8>>2];c=x[Hb(d+28|0,d+8|0)>>2];if(!Ob(e,f,c)){c=jf(a)}e=d+8|0;ev(e,b);f=dc(d+16|0,x[d+8>>2],c);kc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);ev(e,b);Rb(x[d+8>>2]+c|0,0,192-c|0);Yb(a,x[d+28>>2]);ib=d+32|0}function bda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Ai(a,b,c,d);x[a>>2]=43868;b=Nb(a+4208|0);x[a+4228>>2]=0;x[a+4220>>2]=0;x[a+4224>>2]=0;x[a+4232>>2]=x[c+24620>>2];RX(a+4260|0,80,150,80,255);x[27524]=0;R(903,a+44|0,2);c=x[27524];x[27524]=0;if((c|0)!=1){return a|0}c=P()|0;uc(b);Rf(a);S(c|0);p()}function aL(a,b){a=a|0;b=b|0;var c=0;b=ib-16|0;ib=b;x[a+4>>2]=0;x[a>>2]=49220;a=ba(8)|0;x[27524]=0;b=Q(55,b|0,12029)|0;c=x[27524];x[27524]=0;a:{b:{if((c|0)!=1){lc(a,b);x[27524]=0;U(123,a|0,50060,962);a=x[27524];x[27524]=0;if((a|0)!=1){break a}c=P()|0;wb(b);break b}c=P()|0;ca(a|0)}S(c|0)}p()}function NN(a,b){var c=0,d=0,e=0,f=0,g=E(0);c=ib-16|0;ib=c;if(fh(x[x[a>>2]-12>>2]+a|0)){w[c+14>>1]=0;dg(a,c+14|0);e=z[c+14>>1];kk(b,e);while(1){if((d|0)!=(e|0)){x[c+8>>2]=0;Pp(a,c+8|0);f=Bb(x[b>>2],d),g=B[c+8>>2],B[f>>2]=g;d=d+1|0;continue}break}d=fh(x[x[a>>2]-12>>2]+a|0)}ib=c+16|0;return d}function HS(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=ib-16|0;ib=e;x[e+12>>2]=6553600;i=e,j=ac(b),x[i+8>>2]=j;f=+(d>>>0)/6553600;g=e+12|0;b=e+8|0;h=Lq(f*+A[Hb(g,b)>>2]);x[e+8>>2]=6553600;i=e,j=ac(c),x[i+4>>2]=j;i=e,j=Lq(f*+A[Hb(b,e+4|0)>>2]),x[i+12>>2]=j;x[e+8>>2]=d-h;lo(a,h,Hb(b,g));ib=e+16|0}function jl(a,b){a=a|0;b=b|0;var c=0;c=ib-32|0;ib=c;Rs(c,b);x[27524]=0;R(1081,c+16|0,c|0);b=x[27524];x[27524]=0;a:{b:{if((b|0)!=1){x[27524]=0;U(920,a|0,0,c+16|0);a=x[27524];x[27524]=0;if((a|0)==1){break b}Gc(c+16|0);xb(c);ib=c+32|0;return}b=P()|0;break a}b=P()|0;Gc(c+16|0)}xb(c);S(b|0);p()}function fw(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+20|0]=0;v[a+21|0]=0;v[a+22|0]=0;v[a+23|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function ef(a,b,c){var d=0,e=0;a=Kb(a);d=Eb(b);x[27524]=0;R(48,a|0,d|0);d=x[27524];x[27524]=0;if((d|0)!=1){a:{while(1){if(Eb(b)>>>0>e>>>0){d=x[(y[ng(b,e)|0]<<2)+c>>2];x[27524]=0;R(49,a|0,d|0);d=x[27524];x[27524]=0;if((d|0)==1){break a}e=e+1|0;continue}break}return}}b=P()|0;Gc(a);S(b|0);p()}function _w(a,b,c,d){var e=0,f=0,g=0,h=0;e=ib-160|0;ib=e;x[e+60>>2]=b;x[e+20>>2]=b;x[e+24>>2]=-1;f=e+16|0;ti(f,0,0);CH(e,f,d,1);d=x[e+8>>2];f=x[e+12>>2];g=x[e>>2];h=x[e+4>>2];if(c){x[c>>2]=((x[e+20>>2]+x[e+136>>2]|0)-x[e+60>>2]|0)+b}x[a+8>>2]=d;x[a+12>>2]=f;x[a>>2]=g;x[a+4>>2]=h;ib=e+160|0}function WM(a){a=a|0;var b=0,c=0;c=ib-16|0;ib=c;b=x[a+4256>>2];x[a+4240>>2]=b<<1;x[27524]=0;x[c+12>>2]=0;U(909,a+4208|0,b<<2,c+12|0);b=x[27524];x[27524]=0;a:{if((b|0)==1){b=V(108196)|0;if((jb|0)!=(da(108196)|0)){break a}_(b|0)|0;x[a+4240>>2]=0;$()}x[a+4244>>2]=0;ib=c+16|0;return}S(b|0);p()}function SW(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+14|0]=0;v[a+15|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+20|0]=0;v[a+21|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function J8(a){a=a|0;var b=0;x[27524]=0;Y(958,a|0);b=x[27524];x[27524]=0;if((b|0)!=1){return+C[x[a+24>>2]+16>>3]}_(V(0)|0)|0;x[27524]=0;X(945,7590,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)!=1){$();return 0}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function F8(a){a=a|0;var b=0;x[27524]=0;Y(958,a|0);b=x[27524];x[27524]=0;if((b|0)!=1){return x[x[a+24>>2]+8>>2]}_(V(0)|0)|0;x[27524]=0;X(945,10839,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)!=1){$();return-1}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function xz(a,b,c){var d=0;d=x[a+480180>>2];a:{if((d|0)!=1048576){if((d|0)!=4){break a}d=y[b+813|0];if(c){v[b+813|0]=d&15|c<<4;break a}c=(d&240)>>>4|0;break a}if(c){v[b+813|0]=c;break a}c=y[b+813|0]}b:{if(!(v[b+851|0]&1)|!x[b+700>>2]){break b}c=c&255;if(!c){break b}mk(a,b,b+700|0,c<<2,0)}}function P5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);c=tk(x[b+4>>2],x[b+8>>2]);if(c){ZQ(a,c);d=x[b+4>>2];e=x[b+8>>2];b=ib-16|0;ib=b;a=Wt(b,a,c);x[27524]=0;U(1082,d|0,e|0,a+4|0);c=x[27524];x[27524]=0;a:{if((c|0)!=1){ic(a);ib=b+16|0;break a}b=P()|0;ic(a);S(b|0);p()}}}function OD(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=x[a+92>>2];e=x[a+96>>2];if(d|e){while(1){if((c|0)==(g|0)){x[a+96>>2]=e;x[a+92>>2]=d}else{f=(g<<3)+b|0;h=x[f>>2];d=d-kd((kd(0-d|0,31)&255)+d|0,8)|0;x[f>>2]=h+d;h=x[f+4>>2];e=e-kd((kd(0-e|0,31)&255)+e|0,8)|0;x[f+4>>2]=h+e;g=g+1|0;continue}break}}}function rla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=ib-16|0;ib=d;Vf(b);x[d+12>>2]=0;a:{if(!wk(a,d+12|0)){break a}f=c;c=x[d+12>>2];if(f>>>0<c>>>0){break a}while(1){if((c|0)==(e|0)){e=1;break a}v[d+11|0]=0;if(Sh(a,d+11|0)){dq(b,v[d+11|0]);e=e+1|0;continue}break}e=0}ib=d+16|0;return e|0}function e9(a){a=a|0;var b=0;x[27524]=0;Y(958,a|0);b=x[27524];x[27524]=0;if((b|0)!=1){return _L(x[a+24>>2])|0}_(V(0)|0)|0;x[27524]=0;X(945,9704,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)!=1){$();return 0}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function Fz(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;f=ib-16|0;ib=f;g=x[b+480180>>2];a:{if(g&64671904){b=y[(d&15)+43776|0];v[a+2|0]=0;w[a>>1]=b;break a}Ab(f+8|0,b+1074312|0,66);h=a;a=(c&255)==4&(g|0)==4;b=(d&255)<<a<<4;Bl(h,(i=zb(x[x[f+8>>2]>>2],x[f+12>>2])?0:b,j=b,k=e,k?i:j),a)}ib=f+16|0}function E1(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;c=ib-128|0;ib=c;x[c+12>>2]=c+116;d=x[a+8>>2];a=c+16|0;PG(d,a,c+12|0,e,f,g);e=x[c+12>>2];d=ib-16|0;ib=d;x[d+8>>2]=b;while(1){if((a|0)!=(e|0)){bI(d+8|0,v[a|0]);a=a+1|0;continue}break}ib=d+16|0;ib=c+128|0;return x[d+8>>2]}function yz(a,b,c){var d=0;d=x[a+480180>>2];a:{if((d|0)!=1048576){if((d|0)!=4){break a}d=y[b+814|0];if(c){v[b+814|0]=d&15|c<<4;break a}c=(d&240)>>>4|0;break a}if(c){v[b+813|0]=c;break a}c=y[b+813|0]}b:{if(!(v[b+851|0]&1)|!x[b+700>>2]){break b}c=c&255;if(!c){break b}mk(a,b,b+700|0,c,0)}}function d$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=ib-16|0;ib=d;a:{e=x[b>>2];if(Ed(e)){if(!Qe(c)){vM(c,17746);e=x[b>>2]}b=x[b+4>>2];lb[x[x[b>>2]+24>>2]](d,b,e);x[27524]=0;Q(806,c|0,d|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break a}wb(d)}$c(a,c);ib=d+16|0;return}a=P()|0;wb(d);S(a|0);p()}function cC(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=ib-32|0;ib=e;x[e+8>>2]=c;f=e,g=jf(b),x[f+28>>2]=g;c=e+8|0;Wf(c,b,x[Hb(c,e+28|0)>>2]);b=Le(c);x[27524]=0;X(341,a|0,b|0,x[e+8>>2],d|0);a=x[27524];x[27524]=0;if((a|0)!=1){Rc(e+8|0);ib=e+32|0;return}a=P()|0;Rc(e+8|0);S(a|0);p()}function Kea(a,b){a=a|0;b=b|0;var c=0,d=0;a:{if(Qd(y[b+24|0])){a=zg(a);c=Ni(x[b>>2]);d=Gf(b);x[27524]=0;U(812,a|0,c|0,d|0);c=x[27524];x[27524]=0;if((c|0)==1){break a}x[27524]=0;Q(811,a+12|0,b+12|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break a}v[a+24|0]=1}return}b=P()|0;PP(a);S(b|0);p()}function mW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ib-16|0;ib=c;a=zg(a);b=b+236|0;e=Kq(b);a:{while(1){if((b|0)!=(e|0)){d=z[b>>1];w[c+14>>1]=d;if(d){x[27524]=0;U(396,c|0,a|0,c+14|0);d=x[27524];x[27524]=0;if((d|0)==1){break a}}b=b+2|0;continue}break}ib=c+16|0;return}b=P()|0;Nu(a);S(b|0);p()}function BA(a,b,c,d,e){var f=0;a:{f=x[a>>2];if(!_d(f,x[a+20>>2])|c>>>0>=f>>>0|f-c>>>0<d>>>0){break a}Jm(b);b=no(b,a);x[b+20>>2]=0;x[b>>2]=d;if(!Xg(b)){break a}if(x[a>>2]!=(d|0)){qr(b+68|0)}rc(x[b+20>>2],x[a+20>>2]+c|0,d);x[b+8>>2]=e?d:0;x[b+4>>2]=0;w[b+34>>1]=z[b+34>>1]&65533|(e?2:0)}}function SN(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=ib-16|0;ib=d;x[d+12>>2]=b;a:{if(_h(a)>>>0>=b>>>0){f=x[a>>2];e=tc(f,x[a+4>>2]);x[d+8>>2]=e;RN(f,x[Hb(d+12|0,d+8|0)>>2],c);if(b>>>0>e>>>0){Cy(a,b-e|0,c);break a}Od(a,x[a>>2]+(b<<2)|0);break a}Ku(a);Gk(a,wg(a,b));Cy(a,b,c)}ib=d+16|0}function vp(a,b){var c=0,d=0;c=ib-16|0;ib=c;d=c+8|0;ed(d,a);x[27524]=0;a=T(1164,d|0)|0;d=x[27524];x[27524]=0;a:{b:{if((d|0)==1){break b}x[27524]=0;X(1176,a|0,98224,98250,b|0);a=x[27524];x[27524]=0;if((a|0)==1){break b}_b(c+8|0);ib=c+16|0;break a}a=P()|0;_b(c+8|0);S(a|0);p()}return b}function vY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ib-16|0;ib=d;x[d+12>>2]=c;a:{if(!Ob(x[b>>2],x[b+8>>2],c<<1)){break a}wc(d+12|0,65535);Dg(a,z[d+12>>1]);c=Cb(x[a>>2]);x[d>>2]=c;a=Cb(x[a+4>>2]);while(1){if(!Mb(c,a)){break a}ov(b,d+8|0);w[c>>1]=z[d+8>>1];c=x[Ye(d)>>2];continue}}ib=d+16|0}function wm(a,b,c,d){var e=0,f=0;a:{f=x[(D(b,872)+a|0)+1075648>>2];if(!f){break a}if(!zj(y[f+31|0])){break a}e=y[f+34|0]-1|0;if((e&255)>>>0>249){break a}e=x[Nd(a+906300|0,e)>>2];if(!e){break a}lb[x[x[e>>2]+96>>2]](e,f,c,d,b);if(c>>>0>250){break a}w[(D(b,872)+a|0)+1075834>>1]=65535}}function aaa(a){a=a|0;var b=0;x[27524]=0;Y(958,a|0);b=x[27524];x[27524]=0;if((b|0)!=1){return x[a+16>>2]}_(V(0)|0)|0;x[27524]=0;X(945,5693,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)!=1){$();return-1}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function SJ(a){var b=0,c=0,d=0,e=0;d=ib-16|0;ib=d;b=a+120|0;Ns(y[b+20|0]);c=ib-16|0;ib=c;x[c+8>>2]=d+8;a=ib-16|0;ib=a;e=x[18259];x[a+8>>2]=x[18258];x[a+12>>2]=e;e=x[18257];x[a>>2]=x[18256];x[a+4>>2]=e;b=lb[x[Dp(a,ik(y[b+20|0]))>>2]](c+8|0,b)|0;ib=a+16|0;ib=c+16|0;ib=d+16|0;return b}function r9(a){a=a|0;var b=0;x[27524]=0;Y(983,a|0);b=x[27524];x[27524]=0;a:{if((b|0)==1){_(V(0)|0)|0;x[27524]=0;X(945,11870,a|0,0,0);a=x[27524];x[27524]=0;if((a|0)==1){break a}$();a=0}return a|0}a=P()|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Sb();p()}function Jfa(a,b){a=a|0;b=b|0;var c=0;a:{x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);c=Oc(x[b>>2],x[b+4>>2]);if(c){sq(a,c);AR(a,x[b>>2],x[b+4>>2],c)}x[27524]=0;Q(3,a+12|0,b+12|0)|0;c=x[27524];x[27524]=0;if((c|0)!=1){x[a+24>>2]=x[b+24>>2];w[a+28>>1]=z[b+28>>1];break a}b=P()|0;jd(a);S(b|0);p()}}function IM(a,b,c){v[a+12|0]=0;x[c>>2]=0;x[b>>2]=0;x[a+28>>2]=0;x[a+32>>2]=0;w[a+24>>1]=0;x[a+36>>2]=0;x[a+40>>2]=0;x[a+44>>2]=0;x[a+48>>2]=0;HM(a+60|0);HM(a+52|0);Zp(a+49956|0);Zp(a+58148|0);Zp(a+66340|0);Zp(a+74532|0);Rb(a+228|0,0,32768);Rb(a+32996|0,0,512);Rb(a+33508|0,0,16384)}function nfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=ib-16|0;ib=d;x[d+12>>2]=b;a:{if(sp(a)>>>0>=b>>>0){f=x[a>>2];e=cd(f,x[a+4>>2]);x[d+8>>2]=e;hi(f,x[Hb(d+12|0,d+8|0)>>2],c);if(b>>>0>e>>>0){To(a,b-e|0,c);break a}Od(a,x[a>>2]+b|0);break a}$B(a);Pl(a,Zl(a,b));To(a,b,c)}ib=d+16|0}function ks(a,b,c,d){var e=0,f=0;e=ib-160|0;ib=e;f=-1;x[e+148>>2]=b?b-1|0:0;a=b?a:e+158|0;x[e+144>>2]=a;e=Rb(e,0,144);x[e+76>>2]=-1;x[e+36>>2]=1146;x[e+80>>2]=-1;x[e+44>>2]=e+159;x[e+84>>2]=e+144;a:{if((b|0)<0){x[12e4]=61;break a}v[a|0]=0;f=xI(e,c,d,1120,1121)}ib=e+160|0;return f}function dj(a,b,c,d){var e=0,f=0,g=0,h=0;e=ib-16|0;ib=e;x[e+12>>2]=d;g=qi(e+8|0,b);b=ib-16|0;ib=b;d=x[e+12>>2];x[b+12>>2]=d;x[b+8>>2]=d;f=-1;d=ks(0,0,c,d);a:{if((d|0)<0){break a}h=a;d=d+1|0;a=Gd(d);x[h>>2]=a;if(!a){break a}f=ks(a,d,c,x[b+12>>2])}ib=b+16|0;pi(g);ib=e+16|0;return f}function Gda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=ib-16|0;ib=d;c=Af(a,c);Pd(d,x[a+36>>2]);a:{b:{if(!c){Pc(d,a+32|0,5);e=-1;if(!zb(x[x[d>>2]>>2],x[d+4>>2])){break b}break a}e=x[c+16>>2]}f=x[a+36>>2];c:{if(!((e|0)!=4&(e|0)!=-1)){wk(f,b);break c}nH(f,b,e)}f=c}af(a,f);ib=d+16|0}function xs(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ib-16|0;ib=c;d=ba(16)|0;if(!y[485361]){v[485361]=1}a=dc(c+8|0,a,109584);x[27524]=0;e=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=e;a=W(1122,d|0,c|0,b|0)|0;b=x[27524];x[27524]=0;if((b|0)!=1){ha(a|0,107504,1123);p()}a=P()|0;ca(d|0);S(a|0);p()}function dea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=ib+-64|0;ib=d;Vf(b);e=d+40|0;Wf(e,a,c);a=x[d+40>>2];c=d+8|0;ig(c,1,Le(e),a);x[27524]=0;R(226,d+24|0,c|0);a=x[27524];x[27524]=0;if((a|0)!=1){a=d+24|0;Ac(b,a);wb(a);Rc(d+40|0);ib=d- -64|0;break a}a=P()|0;Rc(d+40|0);S(a|0);p()}}function $h(a){var b=E(0),c=0,d=0;c=(q(a),j(2));d=c>>>23&255;if(d>>>0<=149){if(d>>>0<=125){return E(a*E(0))}a=(c|0)>=0?a:E(-a);b=E(E(E(a+E(8388608))+E(-8388608))-a);a:{if(b>E(.5)){a=E(E(a+b)+E(-1));break a}a=E(a+b);if(!(b<=E(-.5))){break a}a=E(a+E(1))}a=(c|0)>=0?a:E(-a)}return a}function er(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0;f=ib-16|0;ib=f;x[f+12>>2]=c;c=f+12|0;wc(c,256);wc(c,65535);h=z[f+12>>1];Dg(a,h);c=0;while(1){if((c|0)==(h|0)){ib=f+16|0}else{g=y[b+c|0];i=Ml(x[a>>2],x[a+4>>2],c),j=(d|0)==(g|0)?-1:(e|0)==(g|0)?-2:g,w[i>>1]=j;c=c+1|0;continue}break}}function dK(a,b){var c=0;c=ib-32|0;ib=c;wi(c,b);x[27524]=0;U(923,c+16|0,0,c|0);b=x[27524];x[27524]=0;a:{b:{if((b|0)!=1){x[27524]=0;R(1084,a|0,c+16|0);a=x[27524];x[27524]=0;if((a|0)==1){break b}Gc(c+16|0);wb(c);ib=c+32|0;return}b=P()|0;break a}b=P()|0;Gc(c+16|0)}wb(c);S(b|0);p()}function c4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=a+60|0;d=Xs(c);x[a>>2]=93368;x[d>>2]=93388;x[a+60>>2]=93428;x[a>>2]=93408;x[a+4>>2]=0;e=c;c=a+8|0;On(e,c);x[a>>2]=93368;x[d>>2]=93388;x[27524]=0;Q(92,c|0,b|0)|0;b=x[27524];x[27524]=0;if((b|0)!=1){return a|0}a=P()|0;cl(d);S(a|0);p()}function RR(a,b){var c=0,d=0,e=0,f=0;c=ib-96|0;ib=c;_S(b,c,c+96|0);b=0;while(1){if((b|0)==12){x[a+104>>2]=0;x[a+96>>2]=!(x[a+88>>2]|x[a+92>>2]);x[a+100>>2]=0;ib=c+96|0}else{d=b<<3;e=d+a|0;f=c+d|0;d=x[f+4>>2];x[e>>2]=x[f>>2];x[e+4>>2]=d&65535;b=b+1|0;continue}break}x[a+112>>2]=0}function NH(a,b,c){var d=0,e=0,f=0,g=0;d=ib-16|0;ib=d;a=Ts(a);x[a+32>>2]=b;x[a>>2]=93908;b=d+8|0;qs(b,a);x[27524]=0;b=T(1143,b|0)|0;e=x[27524];x[27524]=0;if((e|0)!=1){_b(d+8|0);x[a+40>>2]=c;x[a+36>>2]=b;f=a,g=En(b),v[f+44|0]=g;ib=d+16|0;return}b=P()|0;_b(d+8|0);Pn(a);S(b|0);p()}function LH(a,b,c){var d=0,e=0,f=0,g=0;d=ib-16|0;ib=d;a=aI(a);x[a+32>>2]=b;x[a>>2]=94276;b=d+8|0;qs(b,a);x[27524]=0;b=T(1144,b|0)|0;e=x[27524];x[27524]=0;if((e|0)!=1){_b(d+8|0);x[a+40>>2]=c;x[a+36>>2]=b;f=a,g=En(b),v[f+44|0]=g;ib=d+16|0;return}b=P()|0;_b(d+8|0);ts(a);S(b|0);p()}function HD(a,b,c,d){var e=0,f=0,g=0;b=x[a+1076>>2]+(b-(b&c?c<<1:0)|0)|0;x[a+1076>>2]=b;c=b+x[a+1080>>2]|0;x[a+1080>>2]=c;e=d;d=x[a+1068>>2];w[e+(d<<1)>>1]=y[a+1084|0]?c:b;x[a+1064>>2]=x[a+1064>>2]+1;f=a,g=Md(z[x[a+1060>>2]+34>>1])+d|0,x[f+1068>>2]=g;x[a+1072>>2]=x[a+1072>>2]-1}function BZ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=ib-32|0;ib=e;x[e+24>>2]=d;x[e+28>>2]=c;x[27524]=0;X(177,e+8|0,b|0,e+28|0,e+24|0);c=x[27524];x[27524]=0;if((c|0)!=1){c=e+16|0;_o(c,x[e+8>>2],x[e+12>>2]);zf(a,c);Ud(c);Ud(e+8|0);Ud(b);ib=e+32|0;return}a=P()|0;Ud(b);S(a|0);p()}function VU(a,b,c,d){var e=0,f=0;e=ib-16|0;ib=e;x[e+12>>2]=a;a:{if(!(!c|b)){a=Xe(+(D(a,d)>>>0)*.25*1e4);break a}if(!(!a|!b)){wc(e+12|0,10);a=D(y[x[e+12>>2]+26816|0],1e4);break a}f=+(a>>>0);if(a-1>>>0<=9){a=Xe(733.8401379310345/f*1e4);break a}a=Xe(f/.264*1e4)}ib=e+16|0;return a}function NV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=ib+-64|0;ib=c;d=c+40|0;Wf(d,a,32);a=x[c+40>>2];e=c+8|0;ig(e,2,Le(d),a);x[27524]=0;R(226,c+24|0,e|0);a=x[27524];x[27524]=0;if((a|0)!=1){Xm(c,b);a=c+24|0;Ol(c,a);wb(a);Rc(c+40|0);ib=c- -64|0;break a}a=P()|0;Rc(c+40|0);S(a|0);p()}}function Jt(a,b){var c=0,d=0,e=0,f=0,g=0;d=ib-16|0;ib=d;ye(d+8|0,b);b=x[d+8>>2];e=x[d+12>>2];c=ib-16|0;ib=c;f=Eb(a);x[c+12>>2]=f;x[c+8>>2]=e;g=Hb(c+12|0,c+8|0);a=Rp(Jc(a),b,x[g>>2]);a:{if(a){break a}a=-1;if(e>>>0>f>>>0){break a}a=e>>>0<f>>>0}ib=c+16|0;ib=d+16|0;return a>>>31|0}function lf(a){var b=0,c=0;b=ib-32|0;ib=b;v[b+8|0]=0;x[b>>2]=0;x[b+4>>2]=4194432;nD(b+9|0);x[a>>2]=x[b>>2];c=x[b+8>>2];x[a+4>>2]=x[b+4>>2];x[a+8>>2]=c;c=x[b+16>>2];x[a+12>>2]=x[b+12>>2];x[a+16>>2]=c;c=x[b+24>>2];x[a+20>>2]=x[b+20>>2];x[a+24>>2]=c;v[a+28|0]=y[b+28|0];ib=b+32|0}function Wca(a,b){a=a|0;b=b|0;var c=0;a:{b:{c=x[a+20>>2];b=x[c+4>>2];if((cd(b,x[c+8>>2])|0)!=8){break b}if(Qb(b,9504,4)){break b}c=y[b+4|0]|y[b+5|0]<<8|(y[b+6|0]<<16|y[b+7|0]<<24);x[a+4260>>2]=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);x[a+4264>>2]=c;break a}ty(a,a)}ft(a)}function qN(a){a=a|0;var b=0,c=0;c=ib-16|0;ib=c;b=x[x[a+16>>2]+1074404>>2];x[27524]=0;x[c+12>>2]=0;U(909,a+4208|0,D(b,254)|0,c+12|0);b=x[27524];x[27524]=0;a:{if((b|0)==1){b=V(108196)|0;if((jb|0)!=(da(108196)|0)){break a}_(b|0)|0;$()}x[a+4220>>2]=0;ib=c+16|0;return}S(b|0);p()}function Ona(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=ib-624|0;ib=b;d=-1;c=ib-16|0;ib=c;e=b+8|0;FX(c+8|0,e);f=x[c+12>>2];ld(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(f|0)){gd(a,x[c+12>>2])}ib=c+16|0;a=(f|0)==(g|0);if(!a){EX(e)}if(a){d=GX(b+8|0)}ib=b+624|0;return d|0}function $ia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=ib-160|0;ib=b;d=-1;c=ib-16|0;ib=c;e=b+8|0;DT(c+8|0,e);f=x[c+12>>2];ld(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(f|0)){gd(a,x[c+12>>2])}ib=c+16|0;a=(f|0)==(g|0);if(!a){CT(e)}if(a){d=ET(b+8|0)}ib=b+160|0;return d|0}function jU(a){var b=0;a:{if(Qb(a,15496,4)|((y[a+8|0]|y[a+9|0]<<8)-768&65535)>>>0<65280|(((y[a+112|0]|y[a+113|0]<<8)-65&65535)>>>0<65472|(y[a+106|0]|y[a+107|0]<<8)>>>0>256)){break a}if((y[a+122|0]|y[a+123|0]<<8)>>>0>255){break a}b=(y[a+124|0]|y[a+125|0]<<8)>>>0<4e3}return b}function FC(a,b,c){var d=0,e=0,f=0;d=ib+-64|0;ib=d;Vf(b);e=d+40|0;Wf(e,a,c);a=x[d+40>>2];f=d+8|0;ig(f,3,Le(e),a);x[27524]=0;R(226,d+24|0,f|0);e=x[27524];x[27524]=0;if((e|0)!=1){e=b;b=d+24|0;Ac(e,b);wb(b);Rc(d+40|0);ib=d- -64|0;return!c|(a|0)!=0}a=P()|0;Rc(d+40|0);S(a|0);p()}function nna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=ib-32|0;ib=b;d=-1;c=ib-16|0;ib=c;e=b+8|0;Tu(c+8|0,e);f=x[c+12>>2];ld(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(f|0)){gd(a,x[c+12>>2])}ib=c+16|0;a=(f|0)==(g|0);if(!a){SW(e)}if(a){d=TW(b+8|0)}ib=b+32|0;return d|0}function lla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=ib-16|0;ib=b;d=-1;c=ib-16|0;ib=c;e=b+8|0;Ko(c+8|0,e);f=x[c+12>>2];ld(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(f|0)){gd(a,x[c+12>>2])}ib=c+16|0;a=(f|0)==(g|0);if(!a){mV(e)}if(a){d=nV(b+8|0)}ib=b+16|0;return d|0}function lX(a,b){var c=0,d=0,e=0;d=ib-16|0;ib=d;x[d+12>>2]=b;c=ib-16|0;ib=c;x[c+12>>2]=107374182;x[c+8>>2]=2147483647;e=Hb(c+12|0,c+8|0);ib=c+16|0;c=b;b=x[e>>2];if(c>>>0<=b>>>0){a=hX(a);if(a>>>0<b>>>1>>>0){x[d+8>>2]=a<<1;b=x[Yc(d+8|0,d+12|0)>>2]}ib=d+16|0;return b}_c();p()}function ama(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=ib+-64|0;ib=d;e=d+40|0;Wf(e,a,c);a=x[d+40>>2];c=d+8|0;ig(c,2,Le(e),a);x[27524]=0;R(226,d+24|0,c|0);a=x[27524];x[27524]=0;if((a|0)!=1){a=d+24|0;Il(b,a);wb(a);Rc(d+40|0);ib=d- -64|0;break a}a=P()|0;Rc(d+40|0);S(a|0);p()}}function aea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=ib+-64|0;ib=d;e=d+40|0;Wf(e,a,c);a=x[d+40>>2];c=d+8|0;ig(c,1,Le(e),a);x[27524]=0;R(226,d+24|0,c|0);a=x[27524];x[27524]=0;if((a|0)!=1){a=d+24|0;Fe(b,a);wb(a);Rc(d+40|0);ib=d- -64|0;break a}a=P()|0;Rc(d+40|0);S(a|0);p()}}function JX(a,b){var c=0,d=0,e=0;d=ib-16|0;ib=d;x[d+12>>2]=b;c=ib-16|0;ib=c;x[c+12>>2]=153391689;x[c+8>>2]=2147483647;e=Hb(c+12|0,c+8|0);ib=c+16|0;c=b;b=x[e>>2];if(c>>>0<=b>>>0){a=oC(a);if(a>>>0<b>>>1>>>0){x[d+8>>2]=a<<1;b=x[Yc(d+8|0,d+12|0)>>2]}ib=d+16|0;return b}_c();p()}function zE(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=ib-32|0;ib=e;g=x[b+8>>2];f=x[b>>2];lg(e+16|0,c,d);c=x[x[f>>2]+28>>2];d=x[e+20>>2];x[e+8>>2]=x[e+16>>2];x[e+12>>2]=d;lb[c|0](e+24|0,f,g,e+8|0);lg(a,x[e+24>>2],x[e+28>>2]);x[b+8>>2]=x[b+8>>2]+x[a+4>>2];ib=e+32|0}function eJ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=ib-32|0;ib=e;lg(e+24|0,b,c);b=zf(e+16|0,d);x[27524]=0;c=x[b+4>>2];x[e+8>>2]=x[b>>2];x[e+12>>2]=c;Mg(173,a,x[e+24>>2],x[e+28>>2],e+8|0);a=x[27524];x[27524]=0;if((a|0)!=1){Ud(d);ib=e+32|0;return}a=P()|0;Ud(d);S(a|0);p()}function VX(a,b){var c=0,d=0;a:{b:{a=a-12|0;c:{if(a>>>0>31){break c}d=1<<a;c=1;if(d&-2145904587){break a}if(d&65792){break b}if((a|0)!=7){break c}b=b&240;c=1;if(!b|(b|0)==96|(b|0)==224){break a}}return 0}b=(b&240)-96|0;c=0;if(b>>>0>=144){break a}c=297>>>(b>>>4)&1}return c}function QU(a,b){var c=0,d=0;a:{c=x[b>>2];d=x[b+20>>2];if(!_d(c,d)){break a}if(x[a+20>>2]==(d|0)){x[a+20>>2]=0;c=x[b>>2]}wc(a,c);c=z[a+34>>1]&-2|w[b+34>>1]&1;w[a+34>>1]=c;w[a+34>>1]=c&65471|z[b+34>>1]&64;if(!Xg(a)){break a}rc(x[a+20>>2],x[b+20>>2],Nj(x[a>>2],z[a+34>>1]))}}function DX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=ib+-64|0;ib=d;e=d+40|0;Wf(e,a,c);a=x[d+40>>2];c=d+8|0;ig(c,2,Le(e),a);x[27524]=0;R(226,d+24|0,c|0);a=x[27524];x[27524]=0;if((a|0)!=1){a=d+24|0;Cc(b,a);wb(a);Rc(d+40|0);ib=d- -64|0;break a}a=P()|0;Rc(d+40|0);S(a|0);p()}}function VJ(a,b,c){var d=0,e=0;while(1){a:{if((a|0)!=(b|0)){e=x[a>>2];d=xf(e);b:{c:{if((Eb(c)|0)==(d|0)){x[27524]=0;d=W(365,c|0,e|0,d|0)|0;e=x[27524];x[27524]=0;if((e|0)==1){break c}d=!d}else{d=0}break b}V(0)|0;Sb();p()}if(!d){break a}}else{a=b}return a}a=a+8|0;continue}}function Oh(a){var b=0,c=0,d=0,e=0,f=0,g=0;d=ib-16|0;ib=d;b=ib-16|0;ib=b;x[b+4>>2]=1;f=b,g=mc(16),x[f+8>>2]=g;c=Tl(x[b+8>>2]);x[c>>2]=42760;f=hn(zc(c)),g=42892,x[f>>2]=g;c=d+8|0;e=kn(b);jn(c,zc(e),e);Ul(b);ib=b+16|0;zf(a,c);Ud(c);ib=d+16|0;x[a+8>>2]=0;Id(a+12|0);return a}function In(a,b,c){var d=0,e=0,f=0;a:{if(!b){d=a;break a}while(1){d=soa(a,b,10,0);f=kb;e=qoa(d,f,246,0)+a|0;c=c-1|0;v[c|0]=e|48;e=b>>>0>9;a=d;b=f;if(e){continue}break}}if(d){while(1){c=c-1|0;a=(d>>>0)/10|0;v[c|0]=D(a,246)+d|48;b=d>>>0>9;d=a;if(b){continue}break}}return c}function I2(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;h=(e-d|0)+b|0;a:{while(1){if((d|0)!=(e|0)){a=-1;if((b|0)==(c|0)){break a}f=v[b|0];g=v[d|0];if((f|0)<(g|0)){break a}if((f|0)>(g|0)){return 1}else{d=d+1|0;b=b+1|0;continue}}break}a=(c|0)!=(h|0)}return a|0}function H5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ib-16|0;ib=c;Nn(c,a);if(x[b>>2]){Ic(b);a=x[b>>2];Jr(b);Ib(a);d=Db(b),e=0,x[d>>2]=e;x[b>>2]=0;x[b+4>>2]=0}x[b>>2]=x[c>>2];x[b+4>>2]=x[c+4>>2];a=Db(c);d=Db(b),e=x[a>>2],x[d>>2]=e;x[a>>2]=0;x[c>>2]=0;x[c+4>>2]=0;nf(c);ib=c+16|0}function GD(a,b,c,d){var e=0,f=0;b=x[a+1076>>2]+(b-(b&c?c<<1:0)|0)|0;x[a+1076>>2]=b;c=b+x[a+1080>>2]|0;x[a+1080>>2]=c;v[x[a+1068>>2]+d|0]=y[a+1084|0]?c:b;x[a+1064>>2]=x[a+1064>>2]+1;e=a,f=x[a+1068>>2]+Md(z[x[a+1060>>2]+34>>1])|0,x[e+1068>>2]=f;x[a+1072>>2]=x[a+1072>>2]-1}function tca(a){a=a|0;var b=0,c=0,d=0,e=0;b=ib-16|0;ib=b;x[b+12>>2]=a;x[b+8>>2]=4104;a=0;d=x[b+8>>2];a:{if(d>>>0<4096){break a}c=x[b+12>>2];e=c+7&-8;c=e-c|0;if(c>>>0>d-4096>>>0){break a}x[b+12>>2]=e;x[b+8>>2]=d-c;a=e}if(!a){aa(6056,8962,88,7348);p()}ib=b+16|0;return a|0}function _ea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=ib+-64|0;ib=c;d=c+40|0;Wf(d,a,32);a=x[c+40>>2];e=c+8|0;ig(e,1,Le(d),a);x[27524]=0;R(226,c+24|0,e|0);a=x[27524];x[27524]=0;if((a|0)!=1){a=c+24|0;Cc(b,a);wb(a);Rc(c+40|0);ib=c- -64|0;break a}a=P()|0;Rc(c+40|0);S(a|0);p()}}function Be(a){var b=0,c=0,d=0;o(+a);b=j(1)|0;j(0)|0;d=b>>>20&2047;if(d>>>0<=1074){if(d>>>0<=1021){return a*0}a=(b|0)>0|(b|0)>=0?a:-a;c=a+4503599627370496+-4503599627370496-a;a:{if(c>.5){a=a+c+-1;break a}a=a+c;if(!(c<=-.5)){break a}a=a+1}a=(b|0)>0|(b|0)>=0?a:-a}return a}function yfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ib-16|0;ib=d;a=tS(d,a+8|0,b);b=x[a>>2];a:{while(1){if(x[a+4>>2]==(b|0)){break a}x[27524]=0;R(760,b|0,c|0);b=x[27524];x[27524]=0;if((b|0)!=1){b=x[a>>2]+32|0;x[a>>2]=b;continue}break}b=P()|0;Vd(a);S(b|0);p()}Vd(a);ib=d+16|0}function nn(a,b){var c=0,d=0,e=0,f=0;c=ib-16|0;ib=c;a:{if(!b){b=0;break a}d=b;b=G(b);Sf(c,d,0,0,0,b+81|0);e=16414-b<<16;b=0;d=b+x[c+8>>2]|0;e=e+(x[c+12>>2]^65536)|0;e=b>>>0>d>>>0?e+1|0:e;f=d;d=x[c>>2];b=x[c+4>>2]}x[a>>2]=d;x[a+4>>2]=b;x[a+8>>2]=f;x[a+12>>2]=e;ib=c+16|0}function xw(a,b,c,d,e){var f=0,g=0;a:{f=ib+-64|0;ib=f;g=f+40|0;Wf(g,a,e);a=x[f+40>>2];e=f+8|0;ig(e,d,Le(g),a);x[27524]=0;R(226,f+24|0,e|0);a=x[27524];x[27524]=0;if((a|0)!=1){dc(f,b,c);a=f+24|0;Ol(f,a);wb(a);Rc(f+40|0);ib=f- -64|0;break a}a=P()|0;Rc(f+40|0);S(a|0);p()}}function bt(a){var b=0,c=0,d=E(0);b=a+4232|0;c=y[b|0];if(c>>>0>=5){v[b|0]=0;c=0}if(v[a+4233|0]<0){v[a+4233|0]=127}b=v[a+4234|0];if((b|0)<0){v[a+4234|0]=127;b=127}a:{if((c|0)==3){d=E(E(1)-ze(E(2),E(-E((b&255)+1|0))));break a}d=ze(E(2),E(-E((b&255)>>>0)))}B[a+4224>>2]=d}function PX(a){var b=0,c=0,d=0,e=0,f=0,g=0;b=ib-16|0;ib=b;f=Jb(a,31),g=0,v[f|0]=g;v[b+15|0]=0;c=Bi(a,jo(a),b+15|0);v[b+14|0]=0;c=Xh(a,c);sm(c+a|0,jo(a),b+14|0);while(1){if((c|0)!=(d|0)){e=Jb(a,d);if((y[e|0]-127&255)>>>0<=160){v[e|0]=32}d=d+1|0;continue}break}ib=b+16|0}function IC(a,b,c){var d=0,e=0,f=0;d=ib+-64|0;ib=d;e=d+40|0;Wf(e,a,c);a=x[d+40>>2];f=d+8|0;ig(f,3,Le(e),a);x[27524]=0;R(226,d+24|0,f|0);e=x[27524];x[27524]=0;if((e|0)!=1){e=b;b=d+24|0;Cc(e,b);wb(b);Rc(d+40|0);ib=d- -64|0;return!c|(a|0)!=0}a=P()|0;Rc(d+40|0);S(a|0);p()}function tla(a,b){a=a|0;b=b|0;var c=0,d=0;c=ib-16|0;ib=c;x[c+8>>2]=b;a:{if(tc(x[a>>2],x[a+4>>2])>>>0>511){break a}if(!Ed(b)){break a}x[27524]=0;R(491,a|0,c+8|0);a=x[27524];x[27524]=0;d=b;if((a|0)!=1){break a}a=P()|0;yg(c+8|0);S(a|0);p()}yg(c+8|0);ib=c+16|0;return d|0}function gT(a){var b=0,c=0,d=0,e=0;c=ib-16|0;ib=c;b=Cb(x[a>>2]);x[c+8>>2]=b;e=Cb(x[a+4>>2]);while(1){a:{d=Mb(b,e);if(!d){break a}a=z[b>>1];b:{if(!((a|0)!=255&(a|0)!=99)){w[b>>1]=65535;break b}if(a>>>0>63){break a}}b=x[Ye(c+8|0)>>2];continue}break}ib=c+16|0;return d^1}function DD(a,b,c){var d=0,e=0,f=0,g=0;d=ib-16|0;ib=d;e=x[a+4>>2];f=e+b|0;x[a+4>>2]=f;a:{b:{if(!e){g=f-1|0;break b}g=f-1|0;if((g^e-1)>>>0>31){break b}a=x[a>>2];break a}a=x[a>>2];x[a+((f>>>0>=33?g>>>5|0:0)<<2)>>2]=0}So(d+8|0,a,e);Jv(x[d+8>>2],x[d+12>>2],b,c);ib=d+16|0}function sX(a,b,c){var d=0,e=0;d=ib-16|0;ib=d;v[d+15|0]=1;v[d+14|0]=a>>>2;a=y[mf(d+15|0,d+14|0)|0];e=b>>>0<2|a>>>0<15;if(!e){v[d+13|0]=1;v[d+12|0]=(((a+b|0)-2&65535)>>>0)/((b-1&65535)>>>0);a=y[mf(d+13|0,d+12|0)|0]}ib=d+16|0;return(c?a<<4|(e?15:0):a&15|(e?-16:0))&255}function rF(a,b,c,d){var e=0,f=0,g=0,h=0;e=ib-16|0;ib=e;x[e+12>>2]=c;c=e+12|0;wc(c,d);wc(c,65535);f=z[e+12>>1];Dg(a,f);c=0;while(1){if((c|0)==(f|0)){ib=e+16|0}else{d=y[b+c|0];g=Ml(x[a>>2],x[a+4>>2],c),h=(d|0)==255?-1:(d|0)==254?-2:d,w[g>>1]=h;c=c+1|0;continue}break}}function op(a,b,c){var d=0,e=0,f=0;d=a*a;f=d*(d*d)*(d*1.58969099521155e-10+-2.5050760253406863e-8)+(d*(d*27557313707070068e-22+-.0001984126982985795)+.00833333333332249);e=d*a;if(!c){return e*(d*f+-.16666666666666632)+a}return a-(d*(b*.5-f*e)-b+e*.16666666666666632)}function T2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;a:{if(!y[a+44|0]){c=(c|0)>0?c:0;while(1){if((c|0)==(d|0)){break a}if(((f=a,g=Ke(v[b|0]),e=x[x[a>>2]+52>>2],lb[e](f|0,g|0)|0)|0)==-1){return d|0}else{b=b+1|0;d=d+1|0;continue}}}c=Dk(b,1,c,x[a+32>>2])}return c|0}function Gj(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Cb(x[b>>2]);f=Cb(x[b+4>>2]);e=ib-16|0;ib=e;x[e+8>>2]=d;while(1){a:{if(!Mb(d,f)){break a}if(oX(c,x[d>>2],x[d+4>>2])){break a}d=x[Qm(e+8|0)>>2];continue}break}ib=e+16|0;if(pc(d,Cb(x[b+4>>2]))){Oh(a);return}Eo(a,d)}function uh(a,b){var c=0,d=0,e=0;a:{if(!(v[a+480180|0]&1|b)){break a}e=x[a+24616>>2]&524288;b=0;while(1){if((b|0)==127){break a}c=(b<<5)+a|0;w[c+480286>>1]=64;d=c+480280|0;x[d>>2]=x[d>>2]&-257;d=c+480284|0;c=(b&3)-1>>>0<2;w[d>>1]=e?c<<8:c?192:64;b=b+1|0;continue}}}function Z4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=ib-32|0;ib=d;x[d+24>>2]=c;a:{while(1){if((a|0)==(b|0)){break a}c=Kc(d+8|0,x[a>>2]);x[27524]=0;Q(1099,d+24|0,c|0)|0;e=x[27524];x[27524]=0;if((e|0)!=1){wb(c);a=a+4|0;continue}break}a=P()|0;wb(c);S(a|0);p()}ib=d+32|0}function t3(a){a=a|0;var b=0,c=0,d=0;c=x[a+44>>2];b=x[a+24>>2];if(c>>>0<b>>>0){x[a+44>>2]=b;c=b}d=-1;a:{if(!(y[a+48|0]&8)){break a}b=x[a+16>>2];if(b>>>0<c>>>0){Fn(a,x[a+8>>2],x[a+12>>2],c);b=x[a+16>>2]}a=x[a+12>>2];if(a>>>0>=b>>>0){break a}d=Ke(v[a|0])}return d|0}function rR(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=ib-16|0;ib=e;b:{c:{if((b|0)==(c|0)){b=a;a=Jc(d);Zh(b,a,Eb(d)+a|0);break c}jR(e,c,d);x[27524]=0;U(44,a|0,b|0,e|0);a=x[27524];x[27524]=0;if((a|0)==1){break b}Gc(e)}ib=e+16|0;break a}a=P()|0;Gc(e);S(a|0);p()}}function ns(a,b){var c=0,d=0,e=0;d=-1;a:{if((a|0)==-1){break a}e=x[b+76>>2]>=0;b:{c=x[b+4>>2];c:{if(!c){qx(b);c=x[b+4>>2];if(!c){break c}}if(x[b+44>>2]-8>>>0<c>>>0){break b}}if(!e){break a}return-1}c=c-1|0;x[b+4>>2]=c;v[c|0]=a;x[b>>2]=x[b>>2]&-17;d=a&255}return d}function tt(a,b){var c=0,d=0,e=0,f=0,g=0;c=ib-16|0;ib=c;d=ib-16|0;ib=d;f=d,g=qoa(x[b>>2],x[b+4>>2],1e6,0),x[f>>2]=g;x[d+4>>2]=kb;b=Oe(d+8|0,d);e=x[b+4>>2];b=x[b>>2];ib=d+16|0;x[c+8>>2]=b;x[c+12>>2]=e;b=x[c+12>>2];x[a>>2]=x[c+8>>2];x[a+4>>2]=b;ib=c+16|0;return a}function cE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=ib-16|0;ib=d;b:{c:{if(!b){b=a;a=nd(c);Zh(b,a,xd(x[c+4>>2],y[c+11|0])+a|0);break c}TO(d,c);x[27524]=0;U(44,a|0,b|0,d|0);a=x[27524];x[27524]=0;if((a|0)==1){break b}Gc(d)}ib=d+16|0;break a}a=P()|0;Gc(d);S(a|0);p()}}function SV(a){var b=0,c=0,d=0,e=0;d=y[a+32|0]|y[a+33|0]<<8;e=y[a+38|0]|y[a+39|0]<<8;c=y[a+34|0]|y[a+35|0]<<8;b=c+(y[a+36|0]|y[a+37|0]<<8)|0;a=0;a=b>>>0<c>>>0?1:a;c=b;b=e+b|0;a=b>>>0<c>>>0?a+1|0:a;a=a<<2|b>>>30;c=b<<2;b=d+c|0;a=b>>>0<c>>>0?a+1|0:a;kb=a;return b}function Ol(a,b){var c=0,d=0,e=0,f=0;c=ib-16|0;ib=c;d=Jc(b);e=c,f=Eb(b),x[e+12>>2]=f;x[c+8>>2]=x[a+4>>2]-1;wh(d,d+x[Hb(c+12|0,c+8|0)>>2]|0,x[a>>2]);d=x[a>>2];e=c,f=Eb(b),x[e+12>>2]=f;a=x[a+4>>2];x[c+8>>2]=a-1;sm(d+x[Hb(c+12|0,c+8|0)>>2]|0,a+d|0,78304);ib=c+16|0}function DR(a,b){var c=0,d=0;x[a+4>>2]=b;x[a>>2]=110104;x[a+20>>2]=0;x[a+24>>2]=0;c=(b>>>5|0)+((b&31)!=0)|0;x[a+12>>2]=c;d=(b>>>0)/(c>>>0)|0;x[a+8>>2]=d;x[a+32>>2]=d>>>0>=31?-1:-1>>>31-d|0;x[a+28>>2]=b>>>0>=c>>>0?-1>>>32-d|0:0;x[a+16>>2]=(D(c,d)-b|0)+c;return a}function jca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;x[a+4>>2]=b;x[a>>2]=0;b=Gu(a+8|0,d);x[27524]=0;Q(922,a+20|0,c|0)|0;c=x[27524];x[27524]=0;if((c|0)!=1){x[a+32>>2]=0;x[a+36>>2]=0;v[a+42|0]=0;v[a+40|0]=0;v[a+41|0]=y[a+41|0]&224|25;return a|0}a=P()|0;$b(b);S(a|0);p()}function hD(a,b){var c=0,d=0;c=ib-16|0;ib=c;d=c+8|0;ed(d,a);x[27524]=0;a=T(19,d|0)|0;d=x[27524];x[27524]=0;a:{if((d|0)==1){break a}x[27524]=0;a=Q(20,a|0,b|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break a}_b(c+8|0);ib=c+16|0;return a}a=P()|0;_b(c+8|0);S(a|0);p()}function eA(a,b,c){var d=0,e=0,f=0;d=ib-16|0;ib=d;a=rA(d,a,b);b=x[a+4>>2];e=x[a+8>>2];a:{while(1){if((b|0)==(e|0)){break a}x[27524]=0;R(760,b|0,c|0);f=x[27524];x[27524]=0;if((f|0)!=1){b=b+32|0;x[a+4>>2]=b;continue}break}b=P()|0;ic(a);S(b|0);p()}ic(a);ib=d+16|0}function dl(a){var b=0,c=0;a:{b=x[a+1396>>2];if((b|0)>24){break a}if(!b){x[a+1392>>2]=0}while(1){if(y[a+1376|0]?0:x[a+1384>>2]){break a}c=Ds(a);if((c|0)==-1){break a}b=x[a+1396>>2];x[a+1396>>2]=b+8;x[a+1392>>2]=x[a+1392>>2]+(c<<b);if((b|0)<17){continue}break}}}function Yj(a,b){var c=0,d=0,e=0,f=0,g=0;g=x[a+8>>2];while(1){if((b|0)!=(e|0)){d=x[a>>2];if(d){c=x[a+4>>2]}else{x[a>>2]=8;c=g;d=x[a+12>>2];if((c|0)!=(d|0)){c=d-1|0;x[a+12>>2]=c}d=8;c=y[c|0]}x[a>>2]=d-1;x[a+4>>2]=c>>>1;f=c&1|f<<1;e=e+1|0;continue}break}return f}function Dea(a,b){a=a|0;b=b|0;var c=0,d=0;c=y[a+11|0];a:{b:{c:{if(!Ue(c)){d=10;c=Ke(c);if((c|0)==10){break c}ee(a,c+1|0);d=a;break a}c=x[a+4>>2];d=Ju(x[a+8>>2])-1|0;if((c|0)!=(d|0)){break b}}cz(a,d,1,d,d,0);c=d}d=x[a>>2];vd(a,c+1|0)}a=c+d|0;ne(a,b);ne(a+1|0,0)}function gJ(a){var b=0,c=0,d=0;b=ib-48|0;ib=b;$f(x[x[a>>2]-12>>2]+a|0,0);Pd(b+32|0,a);c=b+16|0;a=kt(a,0,2);Pd(c,a);d=x[b+44>>2];x[b+8>>2]=x[b+40>>2];x[b+12>>2]=d;d=x[b+36>>2];x[b>>2]=x[b+32>>2];x[b+4>>2]=d;eh(a,b);a=Ht(x[c+8>>2],x[c+12>>2]);ib=b+48|0;return a}function Wma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;b=ib-160|0;ib=b;d=-1;c=ib-16|0;ib=c;CW(c+8|0,b);e=x[c+12>>2];ld(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){gd(a,x[c+12>>2])}ib=c+16|0;a=(e|0)==(f|0);if(!a){BW(b)}if(a){d=DW(b)}ib=b+160|0;return d|0}function Uca(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=E(0),f=0,g=E(0);d=ib-16|0;ib=d;f=d,g=E(E(lb[x[x[a>>2]+48>>2]](a,b))+c),B[f+12>>2]=g;c=E(0);e=B[d+12>>2];a:{if(!(e<E(0))){c=E(1);if(!(e>E(1))){break a}}B[d+12>>2]=c}lb[x[x[a>>2]+44>>2]](a,b,B[d+12>>2]);ib=d+16|0}function TA(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=ib-1024|0;ib=e;d=ib-16|0;ib=d;QA(d+8|0,e);f=x[d+12>>2];kc(d,x[a>>2],x[a+8>>2],x[d+8>>2],x[d+12>>2]);g=x[d+4>>2];if((g|0)==(f|0)){Yb(a,x[d+12>>2])}ib=d+16|0;if((f|0)==(g|0)){h=RA(e,c)>>>0<=b>>>0}ib=e+1024|0;return h}function Jia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;b=ib-208|0;ib=b;d=-1;c=ib-16|0;ib=c;bT(c+8|0,b);e=x[c+12>>2];ld(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){gd(a,x[c+12>>2])}ib=c+16|0;a=(e|0)==(f|0);if(!a){aT(b)}if(a){d=cT(b)}ib=b+208|0;return d|0}function pH(a,b,c){var d=0,e=0,f=0,g=0;d=a;a:{e=$d(b,c);if(e>>>0<1073741808){b:{if(js(e)){ee(d,e);break b}f=fm(e)+1|0;g=Ii(f);td(d,g);hf(d,f);vd(d,e);d=g}while(1){if((b|0)!=(c|0)){td(d,x[b>>2]);d=d+4|0;b=b+4|0;continue}break}td(d,0);break a}of();p()}return a}function mP(a,b){var c=0,d=0,e=0,f=0,g=0;c=ib-16|0;ib=c;d=ib-16|0;ib=d;f=d,g=qoa(b,b>>31,500654080,20),x[f>>2]=g;x[d+4>>2]=kb;b=Oe(d+8|0,d);e=x[b+4>>2];b=x[b>>2];ib=d+16|0;x[c+8>>2]=b;x[c+12>>2]=e;b=x[c+12>>2];x[a>>2]=x[c+8>>2];x[a+4>>2]=b;ib=c+16|0;return a}function UJ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a=Kb(a);d=xf(b);e=Eb(c);x[27524]=0;X(1088,a|0,b|0,d|0,d+e|0);b=x[27524];x[27524]=0;a:{if((b|0)!=1){b=Jc(c);x[27524]=0;W(1089,a|0,b|0,e|0)|0;b=x[27524];x[27524]=0;if((b|0)!=1){break a}}b=P()|0;wb(a);S(b|0);p()}}function Sz(a,b,c,d){var e=0,f=0,g=0;e=Td(a);a:{if(e){f=gc(a);while(1){a=e;e=z[a+16>>1];g=x[a+20>>2];if(ql(c,d,e,g)){f=a;e=x[a>>2];if(e){continue}break a}if(!ql(e,g,c,d)){break a}f=a+4|0;e=x[a+4>>2];if(e){continue}break}break a}a=gc(a);f=a}x[b>>2]=a;return f}function pz(a,b,c,d){var e=0,f=0,g=0;e=Td(a);a:{if(e){f=gc(a);while(1){a=e;e=y[a+16|0];g=x[a+20>>2];if(Un(c,d,e,g)){f=a;e=x[a>>2];if(e){continue}break a}if(!Un(e,g,c,d)){break a}f=a+4|0;e=x[a+4>>2];if(e){continue}break}break a}a=gc(a);f=a}x[b>>2]=a;return f}function jq(a,b,c,d){var e=0,f=0,g=0;a:{e=sl(a,b);if((e|0)==255){break a}g=x[a>>2];if(qk(g)){break a}f=Cd(a+318|0,e);e=oR(e);if(v[Jb(f,10)|0]&1|d){ph(g,x[a+4>>2],b,e- -64|0,nR(c,y[Jb(f,2)|0]))}if(d){break a}ph(x[a>>2],x[a+4>>2],b,e+67|0,nR(c,y[Jb(f,3)|0]))}}function IZ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=ib-16|0;ib=e;f=x[b+8>>2];a:{if(f>>>0<=c>>>0){c=x[d>>2];b=0;break a}x[e+12>>2]=f-c;x[e+8>>2]=x[d+4>>2];c=x[b+4>>2]+c|0;f=c;b=x[Hb(e+12|0,e+8|0)>>2];g=c+b|0;c=x[d>>2];ji(f,g,c)}cc(a,c,b);ib=e+16|0}function pla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=ib-16|0;ib=c;Vf(b);v[c+15|0]=0;a:{if(!Sh(a,c+15|0)){break a}f=y[c+15|0];d=1;while(1){if((e&255)==(f|0)){break a}v[c+14|0]=0;if(Sh(a,c+14|0)){dq(b,v[c+14|0]);e=e+1|0;continue}break}d=0}ib=c+16|0;return d|0}function lF(a,b,c,d){var e=0,f=0;a:{e=ib+-64|0;ib=e;f=e+40|0;Wf(f,a,d);a=x[e+40>>2];d=e+8|0;ig(d,c,Le(f),a);x[27524]=0;R(226,e+24|0,d|0);a=x[27524];x[27524]=0;if((a|0)!=1){a=e+24|0;Fe(b,a);wb(a);Rc(e+40|0);ib=e- -64|0;break a}a=P()|0;Rc(e+40|0);S(a|0);p()}}function MY(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;b=ib-48|0;ib=b;d=-1;c=ib-16|0;ib=c;eD(c+8|0,b);e=x[c+12>>2];ld(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){gd(a,x[c+12>>2])}ib=c+16|0;a=(e|0)==(f|0);if(!a){dD(b)}if(a){d=fD(b)}ib=b+48|0;return d|0}function wf(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=a;e=ib-16|0;ib=e;a:{if(b>>>0<4294967280){b:{if(Dl(b)){ee(d,b);break b}f=Wg(b)+1|0;g=mc(f);td(d,g);hf(d,f);vd(d,b);d=g}c=SB(d,b,c);v[e+15|0]=0;oe(b+c|0,e+15|0);ib=e+16|0;break a}of();p()}return a|0}function _L(a){var b=0,c=0;b=x[a+24>>2];c=z[b+1074448>>1];if(c>>>0>=xj(Tb(x[b+484360>>2],y[b+484376|0]))>>>0){return z[x[a+24>>2]+1074446>>1]}a=x[a+24>>2];b=z[bc(x[Tb(x[a+484360>>2],y[a+484376|0])>>2],c)>>1];return Sm(x[a+484344>>2],x[a+484348>>2],b)?b:-1}function QX(a,b,c){var d=0,e=0;d=ib+-64|0;ib=d;Vf(b);e=d+40|0;Wf(e,a,c);a=x[d+40>>2];c=d+8|0;ig(c,2,Le(e),a);x[27524]=0;R(226,d+24|0,c|0);a=x[27524];x[27524]=0;if((a|0)!=1){a=d+24|0;Ac(b,a);wb(a);Rc(d+40|0);ib=d- -64|0;return}a=P()|0;Rc(d+40|0);S(a|0);p()}function F2(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;a:{while(1){if((d|0)!=(e|0)){a=-1;if((b|0)==(c|0)){break a}f=x[b>>2];g=x[d>>2];if((f|0)<(g|0)){break a}if((f|0)>(g|0)){return 1}else{d=d+4|0;b=b+4|0;continue}}break}a=(b|0)!=(c|0)}return a|0}function YC(a,b){var c=0,d=0,e=0;c=ib-16|0;ib=c;a=wv(c,a,b);b=x[a+4>>2];d=x[a+8>>2];a:{while(1){if((b|0)==(d|0)){break a}x[27524]=0;Y(232,b|0);e=x[27524];x[27524]=0;if((e|0)!=1){b=b+20|0;x[a+4>>2]=b;continue}break}b=P()|0;ic(a);S(b|0);p()}ic(a);ib=c+16|0}function Ffa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=b;d=ib-16|0;ib=d;b=Af(a,c);Pd(d,x[a+36>>2]);a:{b:{if(!b){Pc(d,a+32|0,5);c=-1;if(!zb(x[x[d>>2]>>2],x[d+4>>2])){break b}break a}c=x[b+16>>2]}bA(x[a+36>>2],e,c);f=1;g=b}af(a,g);ib=d+16|0;return f|0}function qx(a){var b=0,c=0;b=x[a+72>>2];x[a+72>>2]=b-1|b;if(x[a+20>>2]!=x[a+28>>2]){lb[x[a+36>>2]](a,0,0)|0}x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;b=x[a>>2];if(b&4){x[a>>2]=b|32;return-1}c=x[a+44>>2]+x[a+48>>2]|0;x[a+8>>2]=c;x[a+4>>2]=c;return b<<27>>31}function uX(a,b,c){var d=0,e=0;d=ib-16|0;ib=d;e=0;a:{if(!a){break a}b:{c:{if(a>>>0<=15){if(b>>>0<2|c){break c}break b}if(b>>>0>1){break b}}e=a|-16;break a}v[d+15|0]=1;v[d+14|0]=(a>>>0)/((b-1&255)>>>0);e=y[mf(d+15|0,d+14|0)|0]}a=e;ib=d+16|0;return a&255}function tda(a,b){a=a|0;b=b|0;var c=0;c=ib-32|0;ib=c;x[c+8>>2]=-1;x[c+12>>2]=0;x[c>>2]=0;Kb(c+16|0);x[27524]=0;x[c>>2]=x[c>>2]&-1332|1058;x[c+4>>2]=1;U(104,a|0,b|0,c|0);a=x[27524];x[27524]=0;if((a|0)!=1){Qj(c);ib=c+32|0;return}a=P()|0;Qj(c);S(a|0);p()}function hba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=Ai(a,b,c,d);x[a>>2]=46544;b=a+4208|0;e=Bb(b,0),f=1017370378,x[e>>2]=f;e=Bb(b,1),f=0,x[e>>2]=f;x[27524]=0;R(903,a+44|0,2);b=x[27524];x[27524]=0;if((b|0)!=1){return a|0}b=P()|0;Rf(a);S(b|0);p()}function fB(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;_U(a,b);bd(a,ac(y[b+8|0]|y[b+9|0]<<8|(y[b+10|0]<<16|y[b+11|0]<<24))+504|0);ZU(a,d);a:{b=ac(y[b+32|0]|y[b+33|0]<<8|(y[b+34|0]<<16|y[b+35|0]<<24));if(!b){break a}if(!bd(a,b)){break a}hB(a,c);return}Rb(c,0,80)}function xf(a){var b=0,c=0,d=0;b=a;a:{if(b&3){while(1){if(!y[b|0]){break a}b=b+1|0;if(b&3){continue}break}}while(1){c=b;b=b+4|0;d=x[c>>2];if(!((d^-1)&d-16843009&-2139062144)){continue}break}while(1){b=c;c=b+1|0;if(y[b|0]){continue}break}}return b-a|0}function s5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=x[b>>2];e=x[b+8>>2];f=x[b+4>>2];a=0;a:while(1){if((a|0)!=(f|0)){g=(a<<2)+d|0;b=0;while(1)if((b|0)==(e|0)){a=a+1|0;continue a}else{c=x[g>>2]+(b<<3)|0;x[c>>2]=0;x[c+4>>2]=0;b=b+1|0;continue}}break}}function G4(a){a=a|0;var b=0,c=0,d=0;b=ib-32|0;ib=b;if(!y[a+8|0]){Yi(a+12|0,x[a+4>>2]);he(b+24|0,x[a+12>>2],x[a+16>>2]);c=x[x[a>>2]+40>>2];d=x[b+28>>2];x[b+8>>2]=x[b+24>>2];x[b+12>>2]=d;lb[c|0](b+16|0,a,0,b+8|0);v[a+8|0]=1}ib=b+32|0;return x[a+12>>2]}function bca(a,b){a=a|0;b=b|0;var c=0,d=0;b=ib-16|0;ib=b;a:{b:{d=x[a+20>>2];c=x[d+4>>2];if((cd(c,x[d+8>>2])|0)!=7){break b}if(Qb(c,9504,4)){break b}c=Cb(c);d=Cb(x[x[a+20>>2]+8>>2]);Lo(b+8|0,a+4228|0);wh(c,d,x[b+8>>2]);break a}ty(a,a)}bt(a);ib=b+16|0}function KC(a,b,c){var d=0,e=0;d=ib+-64|0;ib=d;e=d+40|0;Wf(e,a,c);a=x[d+40>>2];c=d+8|0;ig(c,3,Le(e),a);x[27524]=0;R(226,d+24|0,c|0);a=x[27524];x[27524]=0;if((a|0)!=1){a=d+24|0;Il(b,a);wb(a);Rc(d+40|0);ib=d- -64|0;return}a=P()|0;Rc(d+40|0);S(a|0);p()}function _E(a,b){var c=0,d=0,e=0,f=0;c=ib-16|0;ib=c;x[b>>2]=0;v[c+15|0]=0;Sh(a,c+15|0);d=y[c+15|0];e=d>>>2|0;f=d&3;d=0;while(1){x[b>>2]=e;if((d|0)==(f|0)){ib=c+16|0}else{v[c+15|0]=0;Sh(a,c+15|0);d=d+1|0;e=x[b>>2]|y[c+15|0]<<(d<<3)-2;continue}break}}function I1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=ib-16|0;ib=g;x[g+8>>2]=b;ed(g,d);x[27524]=0;b=T(1164,g|0)|0;d=x[27524];x[27524]=0;if((d|0)!=1){_b(g);SG(a,f+24|0,g+8|0,c,e,b);ib=g+16|0;return x[g+8>>2]}a=P()|0;_b(g);S(a|0);p()}function H1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=ib-16|0;ib=g;x[g+8>>2]=b;ed(g,d);x[27524]=0;b=T(1164,g|0)|0;d=x[27524];x[27524]=0;if((d|0)!=1){_b(g);RG(a,f+16|0,g+8|0,c,e,b);ib=g+16|0;return x[g+8>>2]}a=P()|0;_b(g);S(a|0);p()}function cT(a){var b=0;a:{if(Qb(a,14989,4)){break a}if(Fb(y[a+4|0]|y[a+5|0]<<8)>>>0>2|y[a+6|0]>128){break a}if(Fb(y[a+200|0]|y[a+201|0]<<8)>>>0>3999){break a}if(!Fb(y[a+140|0]|y[a+141|0]<<8)){break a}b=(Fb(y[a+148|0]|y[a+149|0]<<8)|0)==50}return b}function yI(a,b){var c=0,d=0,e=0;o(+a);d=j(1)|0;e=j(0)|0;c=d>>>20&2047;if((c|0)!=2047){if(!c){if(a==0){c=0}else{a=yI(a*0x10000000000000000,b);c=x[b>>2]+-64|0}x[b>>2]=c;return a}x[b>>2]=c-1022;l(0,e|0);l(1,d&-2146435073|1071644672);a=+n()}return a}function Xr(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=ib-16|0;ib=f;d=ad(a);e=Eb(a);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=vc(a);Ae(d+e|0,b,c);b=c+e|0;Wh(a,b);v[f+15|0]=0;oe(b+d|0,f+15|0);break a}qp(a,d,(c+e|0)-d|0,e,e,0,c,b)}ib=f+16|0;return a|0}function XG(a,b,c){var d=0,e=0,f=0;d=a;a:{if(b>>>0<1073741808){b:{if(js(b)){ee(d,b);break b}e=fm(b)+1|0;f=Ii(e);td(d,f);hf(d,e);vd(d,b);d=f}e=b;f=d;while(1){x[f>>2]=c;f=f+4|0;e=e-1|0;if(e){continue}break}td((b<<2)+d|0,0);break a}of();p()}return a}function O1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=ib-16|0;ib=g;x[g+8>>2]=b;ed(g,d);x[27524]=0;b=T(19,g|0)|0;d=x[27524];x[27524]=0;if((d|0)!=1){_b(g);VG(a,f+24|0,g+8|0,c,e,b);ib=g+16|0;return x[g+8>>2]}a=P()|0;_b(g);S(a|0);p()}function N1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=ib-16|0;ib=g;x[g+8>>2]=b;ed(g,d);x[27524]=0;b=T(19,g|0)|0;d=x[27524];x[27524]=0;if((d|0)!=1){_b(g);UG(a,f+16|0,g+8|0,c,e,b);ib=g+16|0;return x[g+8>>2]}a=P()|0;_b(g);S(a|0);p()}function Nea(a,b){a=a|0;b=b|0;var c=0,d=0;a:{b:{c:{if(!kf(a)){c=1;d=y[a+11|0];if((d|0)==1){break c}ee(a,d+1|0);c=a;break a}c=Kl(a)-1|0;d=x[a+4>>2];if((c|0)!=(d|0)){break b}}GG(a,c,1,c,c);d=c}c=x[a>>2];vd(a,d+1|0)}a=(d<<2)+c|0;td(a,b);td(a+4|0,0)}function Ida(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=ib-16|0;ib=e;c=Af(a,c);Pd(e,x[a+36>>2]);a:{b:{if(!c){Pc(e,a+32|0,5);f=-1;if(!zb(x[x[e>>2]>>2],x[e+4>>2])){break b}break a}f=x[c+16>>2]}lb[d|0](x[a+36>>2],b,f);g=c}af(a,g);ib=e+16|0}function GR(a,b,c){var d=0,e=0,f=0,g=0;f=x[b+4>>2];e=b+4|0;nq(x[a>>2],c,e);g=x[a+4>>2];d=b+8|0;while(1){if((c|0)!=(g|0)){Pj(x[d>>2],z[c>>1]);x[d>>2]=x[d>>2]+2;c=c+2|0;continue}break}oc(a,e);oc(a+4|0,d);oc(Db(a),zc(b));x[b>>2]=x[b+4>>2];return f}function VW(a,b,c){var d=0,e=0,f=0,g=0;f=x[b+4>>2];e=b+4|0;nq(x[a>>2],c,e);g=x[a+4>>2];d=b+8|0;while(1){if((c|0)!=(g|0)){Uk(x[d>>2],y[c|0]);x[d>>2]=x[d>>2]+1;c=c+1|0;continue}break}oc(a,e);oc(a+4|0,d);oc(Db(a),zc(b));x[b>>2]=x[b+4>>2];return f}function hE(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function bR(a){var b=0,c=0,d=0,e=0,f=0;b=ib-16|0;ib=b;c=a;d=x[a>>2];f=tk(d,x[a+4>>2]);a=Cb(d);x[b+8>>2]=a;e=+(f>>>0);c=Cb(x[c+4>>2]);while(1){if(Mb(a,c)){C[a>>3]=C[a>>3]/e;C[a+8>>3]=C[a+8>>3]/e;a=x[qq(b+8|0)>>2];continue}else{ib=b+16|0}break}}function Nr(a,b,c,d){var e=0;e=ib-32|0;ib=e;x[e+8>>2]=-1;x[e+12>>2]=0;x[e>>2]=0;Kb(e+16|0);x[e+4>>2]=d;x[27524]=0;x[e>>2]=x[e>>2]&-1332|1058;U(c|0,a|0,b|0,e|0);a=x[27524];x[27524]=0;if((a|0)!=1){nm(e);ib=e+32|0;return}a=P()|0;nm(e);S(a|0);p()}function DC(a){var b=0,c=0,d=0,e=0;b=y[a+2|0];c=b+(y[a+5|0]|y[a+6|0]<<8)|0;d=b>>>0>c>>>0?1:d;b=c;c=b<<1;b=d<<1|b>>>31;a=y[a+3|0]|y[a+4|0]<<8;d=a>>>30|0;e=c;c=a<<2;e=e+c|0;a=b+d|0;a=c>>>0>e>>>0?a+1|0:a;b=e+47|0;a=b>>>0<47?a+1|0:a;kb=a;return b}function Ci(a){var b=0,c=0,d=0,e=0;b=Re(a);c=b&63;e=b<<24>>24;a:{if(!(b&64)){break a}b=6;while(1){d=Re(a);c=(d&127)<<b|c;if(d<<24>>24>=0){break a}d=b>>>0<25;b=b+7|0;if(d){continue}break}}a=(e|0)<0;b=a?-2147483648:c;return a?(c|0)>=0?0-c|0:b:b}function q7(a,b){a=a|0;b=b|0;var c=0;a:{if((a|0)==(b|0)){break a}c=x[a+4>>2];if(c){Ib(c);x[a+4>>2]=0}if(lb[x[x[b>>2]+8>>2]](b)|0){b=lb[x[x[b>>2]+8>>2]](b)|0}else{b=21631}c=Gd(xf(b)+1|0);x[a+4>>2]=c;if(!c){break a}rc(c,b,xf(b)+1|0)}return a|0}function np(a,b){var c=0,d=0,e=0,f=0;c=a*a;d=c*.5;e=1-d;f=1-e-d;d=c*c;return e+(f+(c*(c*(c*(c*2480158728947673e-20+-.001388888888887411)+.0416666666666666)+d*d*(c*(c*-11359647557788195e-27+2.087572321298175e-9)+-2.7557314351390663e-7))-a*b))}function Sb(){var a=0;a=x[27397];x[27524]=0;Z(a|0);a=x[27524];x[27524]=0;a:{if((a|0)!=1){x[27524]=0;Z(1255);a=x[27524];x[27524]=0;if((a|0)!=1){break a}}_(V(0)|0)|0;x[27524]=0;Z(1255);a=x[27524];x[27524]=0;if((a|0)!=1){break a}V(0)|0;Sb()}p()}function SA(a,b,c){var d=0;d=ib-16|0;ib=d;w[d+12>>1]=c;w[d+14>>1]=b;b=Cb(x[a>>2]);c=Cb(x[a+4>>2]);a=ib-16|0;ib=a;x[a+8>>2]=b;while(1){if(Mb(b,c)){if(z[b>>1]==z[d+14>>1]){w[b>>1]=z[d+12>>1]}b=x[Ye(a+8|0)>>2];continue}break}ib=a+16|0;ib=d+16|0}function AF(a,b,c,d){var e=0,f=0,g=0;a:{e=ib-16|0;ib=e;x[e+4>>2]=1;f=e,g=mc(d),x[f+8>>2]=g;d=x[e+8>>2];x[27524]=0;Q(c|0,d|0,b|0)|0;b=x[27524];x[27524]=0;if((b|0)!=1){b=a;a=kn(e);jn(b,zc(a),a);Ul(e);ib=e+16|0;break a}a=P()|0;Ul(e);S(a|0);p()}}function jQ(a,b){var c=0,d=0;d=ib-16|0;ib=d;c=x[a+104>>2];a:{if(!c){break a}c=x[c>>2];if(!c){break a}x[a+76>>2]=c;x[a+88>>2]=x[a+88>>2]&-131|128;x[d+12>>2]=b<<8;x[d+8>>2]=c-1;b=c+(x[Hb(d+12|0,d+8|0)>>2]^-1)|0;x[a>>2]=0;x[a+4>>2]=b}ib=d+16|0}function jP(a,b){a=fP(a);fP(a+368680|0);if(b){eP(a,1);return}if(!y[478968]){jP(110264,1);v[478968]=1}co(241376,306912,a+131112|0);co(306912,372448,a+196648|0);co(372448,437984,a+262184|0);co(110288,241376,a+24|0);rc(a+327720|0,437984,40960)}function dk(a,b,c,d,e,f){var g=0;g=ib-32|0;ib=g;x[g+8>>2]=-1;x[g+12>>2]=0;x[g>>2]=0;Kb(g+16|0);x[g+4>>2]=f;x[27524]=0;x[g>>2]=x[g>>2]&e|d;U(c|0,a|0,b|0,g|0);a=x[27524];x[27524]=0;if((a|0)!=1){Qj(g);ib=g+32|0;return}a=P()|0;Qj(g);S(a|0);p()}function bN(a,b,c){var d=0,e=0;if(E(F(a))<E(0x8000000000000000)){d=~~a>>>0}else{d=0}e=d&-2147483648;d=e?0-d|0:d;while(1){if(!((d|0)<0|(b|0)<=0)){b=b-1|0;d=d<<1;continue}break}b=(d>>>31|0)+b<<31-c|(d&2147483647)>>>c;return E((e?b^-1|e:b)|0)}function RD(a){var b=0,c=0;a:{if(Qb(a,14176,4)){break a}if(Qb(a+8|0,14097,4)){break a}b=ac(y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24));if(!b){break a}c=(ac(y[a+12|0]|y[a+13|0]<<8|(y[a+14|0]<<16|y[a+15|0]<<24))|0)!=0&b>>>0>27}return c}function Hia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=ib-32|0;ib=d;e=d+16|0;$V(e,c);fj(d+8|0,e);x[27524]=0;X(118,a|0,b|0,x[d+8>>2],x[d+12>>2]);a=x[27524];x[27524]=0;if((a|0)!=1){$b(d+16|0);ib=d+32|0;break a}a=P()|0;$b(d+16|0);S(a|0);p()}}
function zQ(a,b){var c=0;c=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);v[a|0]=c;v[a+1|0]=c>>>8;v[a+2|0]=c>>>16;v[a+3|0]=c>>>24;b=y[b+3|0]|y[b+4|0]<<8|(y[b+5|0]<<16|y[b+6|0]<<24);v[a+3|0]=b;v[a+4|0]=b>>>8;v[a+5|0]=b>>>16;v[a+6|0]=b>>>24}function tB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=Nb(a+8|0);x[27524]=0;d=T(206,b|0)|0;e=x[27524];x[27524]=0;b:{if((e|0)==1){break b}x[27524]=0;U(248,a|0,b|0,d|0);a=x[27524];x[27524]=0;if((a|0)==1){break b}break a}a=P()|0;ec(c);S(a|0);p()}}function mF(a,b,c,d){var e=0,f=0,g=0,h=0;e=ib-16|0;ib=e;x[e+12>>2]=c;c=e+12|0;wc(c,d);wc(c,65535);d=z[e+12>>1];Dg(a,d);c=0;while(1){if((c|0)==(d|0)){ib=e+16|0}else{f=y[b+c|0];g=Ml(x[a>>2],x[a+4>>2],c),h=f,w[g>>1]=h;c=c+1|0;continue}break}}function je(a,b){var c=0,d=0;c=x[a+4>>2];d=c+b|0;x[a+4>>2]=d;if(x[a+8>>2]>=(d|0)){d=x[a>>2]+(c>>3)|0;a=c&7;c=y[d|0]&255>>>a;a=a+b|0;b=0;while(1){if((a|0)>=9){a=a-8|0;b=c<<a|b;c=y[d+1|0];d=d+1|0;continue}break}a=c>>>8-a|b}else{a=0}return a}function jT(a){var b=0,c=0;a:{if(y[a+29|0]!=2){break a}b=y[a+28|0];if((b|0)!=26&(b|0)!=2|y[a+30|0]!=2){break a}b=y[a+31|0];if(b>>>0>21|!(1<<b&3146753)|y[a+33|0]>64){break a}b=y[a+34|0];if(b>>>0>=65&(b|0)!=88){break a}c=hT(a+20|0)}return c}function fma(a){a=a|0;var b=0,c=0,d=0;b=ib-32|0;ib=b;v[b+30|0]=0;w[b+28>>1]=0;c=dc(b+8|0,b+28|0,3);kc(b+16|0,x[a>>2],x[a+8>>2],x[c>>2],x[c+4>>2]);a:{if(x[b+20>>2]!=3){break a}if(Qb(b+28|0,14748,3)){break a}Yb(a,3);d=1}ib=b+32|0;return d|0}function eia(a){a=a|0;var b=0,c=0,d=0;b=ib-32|0;ib=b;w[b+28>>1]=0;x[b+24>>2]=0;c=dc(b+8|0,b+24|0,6);kc(b+16|0,x[a>>2],x[a+8>>2],x[c>>2],x[c+4>>2]);a:{if(x[b+20>>2]!=6){break a}if(Qb(b+24|0,3856,6)){break a}Yb(a,6);d=1}ib=b+32|0;return d|0}function Yna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=ib-32|0;ib=d;e=d+16|0;Vq(e,c);fj(d+8|0,e);x[27524]=0;X(300,a|0,b|0,x[d+8>>2],x[d+12>>2]);a=x[27524];x[27524]=0;if((a|0)!=1){Zb(d+16|0);ib=d+32|0;break a}a=P()|0;Zb(d+16|0);S(a|0);p()}}function Tla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=ib-32|0;ib=d;e=d+16|0;oB(e,c);fj(d+8|0,e);x[27524]=0;X(118,a|0,b|0,x[d+8>>2],x[d+12>>2]);a=x[27524];x[27524]=0;if((a|0)!=1){$b(d+16|0);ib=d+32|0;break a}a=P()|0;$b(d+16|0);S(a|0);p()}}function Pla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=ib-32|0;ib=d;e=d+16|0;dp(e,c);fj(d+8|0,e);x[27524]=0;X(118,a|0,b|0,x[d+8>>2],x[d+12>>2]);a=x[27524];x[27524]=0;if((a|0)!=1){$b(d+16|0);ib=d+32|0;break a}a=P()|0;$b(d+16|0);S(a|0);p()}}function Pja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=ib-32|0;ib=d;e=d+16|0;Lp(e,c);fj(d+8|0,e);x[27524]=0;X(300,a|0,b|0,x[d+8>>2],x[d+12>>2]);a=x[27524];x[27524]=0;if((a|0)!=1){Zb(d+16|0);ib=d+32|0;break a}a=P()|0;Zb(d+16|0);S(a|0);p()}}function G1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;a=ib-16|0;ib=a;x[a+8>>2]=b;ed(a,d);x[27524]=0;b=T(1164,a|0)|0;d=x[27524];x[27524]=0;if((d|0)!=1){_b(a);QG(f+20|0,a+8|0,c,e,b);ib=a+16|0;return x[a+8>>2]}b=P()|0;_b(a);S(b|0);p()}function zna(a,b){a=a|0;b=b|0;var c=0;b=ib-32|0;ib=b;c=-1;a:{if(!dC(a,b+16|0)){break a}c=0;if(!eX(b+16|0)){break a}if(!Qb(b+16|0,14162,4)){c=-1;if(!gd(a,4)){break a}}c=-1;if(!Xj(a,b+8|0)){break a}c=!Qb(b+8|0,14138,4)}ib=b+32|0;return c|0}function zX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=ib-32|0;ib=d;e=d+16|0;dY(e,c);fj(d+8|0,e);x[27524]=0;X(118,a|0,b|0,x[d+8>>2],x[d+12>>2]);a=x[27524];x[27524]=0;if((a|0)!=1){$b(d+16|0);ib=d+32|0;break a}a=P()|0;$b(d+16|0);S(a|0);p()}}function vw(a,b,c,d,e){var f=0;f=ib-32|0;ib=f;x[f+8>>2]=-1;x[f+12>>2]=0;x[f>>2]=0;x[f+4>>2]=0;Kb(f+16|0);x[27524]=0;x[f>>2]=x[f>>2]&e|d;U(c|0,a|0,b|0,f|0);a=x[27524];x[27524]=0;if((a|0)!=1){Qj(f);ib=f+32|0;return}a=P()|0;Qj(f);S(a|0);p()}function tw(a,b){var c=0,d=0,e=0,f=0;c=ib-16|0;ib=c;w[b>>1]=0;v[c+15|0]=0;Sh(a,c+15|0);d=y[c+15|0];e=d>>>1|0;f=d&1;d=0;while(1){w[b>>1]=e;if(d>>>0>=f>>>0){ib=c+16|0}else{v[c+15|0]=0;Sh(a,c+15|0);e=z[b>>1]|y[c+15|0]<<7;d=1;continue}break}}function bD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=ib-32|0;ib=d;e=d+16|0;tv(e,c);fj(d+8|0,e);x[27524]=0;X(118,a|0,b|0,x[d+8>>2],x[d+12>>2]);a=x[27524];x[27524]=0;if((a|0)!=1){$b(d+16|0);ib=d+32|0;break a}a=P()|0;$b(d+16|0);S(a|0);p()}}function Zv(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=ib-16|0;ib=e;lg(e+8|0,b,c);x[27524]=0;Oa(175,a|0,x[e+8>>2],x[e+12>>2]);b=x[27524];x[27524]=0;if((b|0)!=1){x[a+8>>2]=0;zf(a+12|0,d);Ud(d);ib=e+16|0;return a|0}a=P()|0;Ud(d);S(a|0);p()}function FE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=ib-32|0;ib=d;e=d+16|0;qn(e,c);fj(d+8|0,e);x[27524]=0;X(118,a|0,b|0,x[d+8>>2],x[d+12>>2]);a=x[27524];x[27524]=0;if((a|0)!=1){$b(d+16|0);ib=d+32|0;break a}a=P()|0;$b(d+16|0);S(a|0);p()}}function k$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=ib-16|0;ib=e;if(d>>>0<4294967280){a:{if(Dl(d)){ee(a,c);break a}f=Wg(d)+1|0;d=mc(f);td(a,d);hf(a,f);vd(a,c);a=d}a=Ae(a,b,c);v[e+15|0]=0;oe(a+c|0,e+15|0);ib=e+16|0;return}of();p()}function TP(a,b){var c=0,d=0;a:{if(!(y[a+89|0]&16)){break a}c=x[a+656>>2];if(!c){break a}c=x[c>>2];b:{if(c){d=a;a=x[a+696>>2]-(c<<1)|0;a=(a|0)>0?a:0;x[d+696>>2]=a;a=(D(a,x[b>>2])|0)/65536|0;break b}if(x[a+696>>2]){break a}a=0}x[b>>2]=a}}function M1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;a=ib-16|0;ib=a;x[a+8>>2]=b;ed(a,d);x[27524]=0;b=T(19,a|0)|0;d=x[27524];x[27524]=0;if((d|0)!=1){_b(a);TG(f+20|0,a+8|0,c,e,b);ib=a+16|0;return x[a+8>>2]}b=P()|0;_b(a);S(b|0);p()}function yW(a){var b=0,c=0,d=0,e=0;b=y[a+3|0];c=qoa(b>>>0<3?48:64,0,Fb(y[a+196|0]|y[a+197|0]<<8),0);d=kb;e=c;c=qoa(qoa(Fb(y[a+198|0]|y[a+199|0]<<8),0,b>>>0<4?4:5,0),kb,Fb(y[a+200|0]|y[a+201|0]<<8),0);b=e+c|0;b=b+512|0;a=b;kb=0;return a}function ti(a,b,c){var d=0,e=0,f=0,g=0;x[a+112>>2]=b;x[a+116>>2]=c;e=x[a+4>>2];d=x[a+44>>2]-e|0;x[a+120>>2]=d;x[a+124>>2]=d>>31;d=a;a=x[a+8>>2];f=a-e|0;g=f>>31;if(!(!(b|c)|((c|0)>=(g|0)&b>>>0>=f>>>0|(c|0)>(g|0)))){a=b+e|0}x[d+104>>2]=a}function oda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=b;d=ib-16|0;ib=d;b=Af(a,c);Pd(d,x[a+36>>2]);a:{b:{if(!b){Pc(d,a+32|0,5);c=-1;if(!zb(x[x[d>>2]>>2],x[d+4>>2])){break b}break a}c=x[b+16>>2]}bA(x[a+36>>2],e,c);f=b}af(a,f);ib=d+16|0}function iQ(a,b){var c=0,d=0;a:{if(!(v[a+851|0]&1)){break a}c=x[a+104>>2];if(!c){break a}d=x[c>>2];if(!d){break a}x[a+76>>2]=d;x[a>>2]=0;x[a+4>>2]=d-1;c=x[a+88>>2];x[a+88>>2]=b?c|134:c&-135|128;if(!b){break a}x[a+84>>2]=d;x[a+80>>2]=0}}function Gna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ib-16|0;ib=c;Sv(c+8|0,b);d=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Yb(a,x[c+12>>2])}ib=c+16|0;if((d|0)!=(e|0)){v[b+2|0]=0;v[b|0]=0;v[b+1|0]=0}}function vla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=ib-16|0;ib=c;while(1){a:{d=x[a>>2];if(tc(d,x[a+4>>2])>>>0>e>>>0){Nk(c,x[Bb(d,e)>>2]+40|0);d=Aq(c,b);xb(c);if(!d){break a}f=x[Bb(x[a>>2],e)>>2]}ib=c+16|0;return f|0}e=e+1|0;continue}}function dQ(a,b,c){var d=0,e=0;d=ib-16|0;ib=d;e=c&15;if(e){v[b+824|0]=e}c=c&240;if(c){v[b+823|0]=c>>>4}x[b+88>>2]=x[b+88>>2]|131072;Ab(d+8|0,a+1074312|0,80);if(!(!e|!zb(x[x[d+8>>2]>>2],x[d+12>>2]))){v[b+824|0]=y[b+824|0]<<2}ib=d+16|0}function Zba(a,b,c){a=a|0;b=b|0;c=c|0;a:{if(x[b+4>>2]!=8){break a}b=x[b>>2];if(Qb(b,9504,4)){break a}c=y[b+4|0]|y[b+5|0]<<8|(y[b+6|0]<<16|y[b+7|0]<<24);x[a+4228>>2]=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);x[a+4232>>2]=c;bt(a)}}function Oca(a,b,c){a=a|0;b=b|0;c=c|0;a:{if(x[b+4>>2]!=8){break a}b=x[b>>2];if(Qb(b,9504,4)){break a}c=y[b+4|0]|y[b+5|0]<<8|(y[b+6|0]<<16|y[b+7|0]<<24);x[a+4260>>2]=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);x[a+4264>>2]=c;ft(a)}}function fR(a,b){var c=0,d=0,e=0;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);if(b){ZQ(a,b);d=ib-16|0;ib=d;c=Wt(d,a,b);b=x[c+4>>2];e=x[c+8>>2];while(1){if((b|0)==(e|0)){ic(c);ib=d+16|0}else{rl(b,0,0);b=b+16|0;x[c+4>>2]=b;continue}break}}return a}function ej(a,b,c){c=x[c+4>>2]&176;if((c|0)==32){return b}a:{if((c|0)!=16){break a}b:{c:{c=y[a|0];switch(c-43|0){case 0:case 2:break c;default:break b}}return a+1|0}if((c|0)!=48|(b-a|0)<2|(y[a+1|0]|32)!=120){break a}a=a+2|0}return a}function bma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ib-16|0;ib=c;mB(c+8|0,b);d=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Yb(a,x[c+12>>2])}ib=c+16|0;a=(d|0)==(e|0);if(!a){Rb(b,0,4896)}return a|0}function Wf(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Nb(a+8|0);x[27524]=0;U(248,a|0,b|0,c|0);c=x[27524];x[27524]=0;a:{if((c|0)!=1){a=x[a>>2];x[27524]=0;Q(192,b|0,a|0)|0;a=x[27524];x[27524]=0;if((a|0)!=1){break a}}a=P()|0;ec(d);S(a|0);p()}}function N5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ib-32|0;ib=d;jl(d,c);c=d+16|0;x[c>>2]=b;$c(c+4|0,d);x[27524]=0;R(1083,a+4|0,c|0);a=x[27524];x[27524]=0;if((a|0)!=1){Ps(d+16|0);wb(d);ib=d+32|0;return}a=P()|0;Ps(d+16|0);wb(d);S(a|0);p()}function Qf(a,b,c){var d=0;a:{if(A[b+8>>2]<c>>>0){x[27524]=0;X(1098,17359,9058,435,6384);a=x[27524];x[27524]=0;if((a|0)==1){break a}p()}d=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=d;x[a+8>>2]=x[b+8>>2];x[a+12>>2]=c;return}V(0)|0;Sb();p()}function $2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{if(!y[a+44|0]){c=(c|0)>0?c:0;while(1){if((c|0)==(d|0)){break a}if((lb[x[x[a>>2]+52>>2]](a,x[b>>2])|0)==-1){return d|0}else{b=b+4|0;d=d+1|0;continue}}}c=Dk(b,4,c,x[a+32>>2])}return c|0}function tA(a,b){var c=0,d=0,e=0,f=0;w[a+24>>1]=0;x[a+20>>2]=0;c=3546895/+(b>>>0);d=c*.25;a:{if(F(d)<2147483648){b=~~d;break a}b=-2147483648}x[a+16>>2]=b;x[a>>2]=0;x[a+4>>2]=0;e=a,f=JS(c-+(b<<2)),x[e+8>>2]=f;x[a+12>>2]=kb;return a}function qz(a,b,c){var d=0,e=0;d=Td(a);a:{if(d){e=gc(a);while(1){a=d;d=y[a+16|0];if(Vn(c,d)){e=a;d=x[a>>2];if(d){continue}break a}if(!Vn(d,c)){break a}e=a+4|0;d=x[a+4>>2];if(d){continue}break}break a}a=gc(a);e=a}x[b>>2]=a;return e}function JO(a){var b=0,c=0,d=0;c=ib-544|0;ib=c;a:{if(!(y[a+480210|0]&128)|!x[a+24668>>2]){break a}d=a+1298224|0;b=a+1074992|0;a=tA(c,x[a+24620>>2]);while(1){if((b|0)==(d|0)){break a}rc(b+112|0,a,538);b=b+872|0;continue}}ib=c+544|0}function $ka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ib-16|0;ib=c;jB(c+8|0,b);d=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Yb(a,x[c+12>>2])}ib=c+16|0;a=(d|0)==(e|0);if(!a){Rb(b,0,33)}return a|0}function nja(a,b){a=a|0;b=b|0;var c=0;b=ib-32|0;ib=b;c=-1;a:{if(!dC(a,b+16|0)){break a}c=0;if(!NT(b+16|0)){break a}c=-1;if(!Xj(a,b+8|0)){break a}c=0;if(!x[b+12>>2]){break a}a=x[b+8>>2];c=(a&2139062143)==(a|0)}ib=b+32|0;return c|0}function KY(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ib-16|0;ib=c;vv(c+8|0,b);d=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Yb(a,x[c+12>>2])}ib=c+16|0;a=(d|0)==(e|0);if(!a){Rb(b,0,65)}return a|0}function IE(){var a=0,b=0,c=0;b=ib-16|0;ib=b;a=Kc(b,15021);a:{if(!Eb(a)){break a}c=1;if((Lg(a,14644)|0)!=-1){break a}if((Lg(a,16776)|0)!=-1){break a}if((Lg(a,13706)|0)!=-1){break a}c=(Lg(a,13749)|0)!=-1}wb(a);ib=b+16|0;return c|0}function HR(a,b,c,d){var e=0,f=0,g=0,h=0;e=ib-16|0;ib=e;h=x[a+4>>2];f=(h-d|0)+b|0;g=ei(e,a,c-f>>1);d=x[g+4>>2];a=f;while(1){if(a>>>0>=c>>>0){ic(g);Mq(b,f,h);ib=e+16|0}else{Pj(d,z[a>>1]);d=d+2|0;x[g+4>>2]=d;a=a+2|0;continue}break}}function DE(a){var b=0;if(!(Qb(a,13305,8)|(y[a+8|0]|y[a+9|0]<<8)!=14|(!(y[a+12|0]|y[a+13|0]<<8)|(y[a+14|0]|y[a+15|0]<<8|(y[a+16|0]<<16|y[a+17|0]<<24))<=0))){b=(y[a+18|0]|y[a+19|0]<<8|(y[a+20|0]<<16|y[a+21|0]<<24))>>>0>23}return b}function t5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=x[b>>2];d=x[b+8>>2];e=x[b+4>>2];a=0;a:while(1){if((a|0)!=(e|0)){f=(a<<2)+c|0;b=0;while(1)if((b|0)==(d|0)){a=a+1|0;continue a}else{x[x[f>>2]+(b<<2)>>2]=0;b=b+1|0;continue}}break}}function pg(a,b){var c=0,d=0,e=0,f=0;d=z[a+22>>1];e=d+z[a+20>>1]|0;c=z[a+24>>1]<<17;while(1){if((d|0)==(e|0)){a=(c|0)/32768|0}else{f=c;c=((d&127)<<2)+a|0;c=f-D(x[Bb(b,z[c+28>>1])>>2],w[c+26>>1])|0;d=d+1|0;continue}break}return a}function lY(a,b){a=a|0;b=b|0;var c=0,d=0;c=ib-16|0;ib=c;d=Ob(x[a>>2],x[a+8>>2],120);a:{if(!d){a=0;while(1){if((a|0)!=120){Jh(a+b|0);a=a+1|0;continue}break}break a}cc(c+8|0,b,120);sd(c,a,x[c+8>>2],x[c+12>>2])}ib=c+16|0;return d|0}function kna(a,b){a=a|0;b=b|0;var c=0,d=0;c=ib-16|0;ib=c;d=Ob(x[a>>2],x[a+8>>2],64);a:{if(!d){a=0;while(1){if((a|0)!=32){Mo((a<<1)+b|0);a=a+1|0;continue}break}break a}_u(c+8|0,b);sd(c,a,x[c+8>>2],x[c+12>>2])}ib=c+16|0;return d|0}function VT(a,b,c){var d=0,e=0,f=0,g=0;while(1){if((b|0)!=(c|0)){e=x[a+4>>2];f=e>>>8|0;d=x[a>>2];e=(e&255)<<24|d>>>8;d=(((d^y[b|0])&255)<<3)+21656|0;g=x[d>>2];d=x[d+4>>2]^f;x[a>>2]=e^g;x[a+4>>2]=d;b=b+1|0;continue}break}return a}function YK(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0,f=0;d=ib-16|0;ib=d;e=d,f=hL(c),x[e>>2]=f;c=x[ge(d+8|0,d)>>2];x[27524]=0;b=+sa(1075,a|0,+b,c|0);a=x[27524];x[27524]=0;if((a|0)!=1){Xc(d);ib=d+16|0;return+b}a=P()|0;Xc(d);S(a|0);p()}function WW(a,b,c,d){var e=0,f=0,g=0,h=0;e=ib-16|0;ib=e;h=x[a+4>>2];f=(h-d|0)+b|0;g=_l(e,a,c-f|0);d=x[g+4>>2];a=f;while(1){if(a>>>0>=c>>>0){ic(g);Mq(b,f,h);ib=e+16|0}else{Uk(d,y[a|0]);d=d+1|0;x[g+4>>2]=d;a=a+1|0;continue}break}}function xO(a,b,c){var d=0,e=0,f=0,g=0,h=0;g=c;h=c>>31;c=0;while(1){if((b|0)!=(c|0)){d=x[a>>2];e=x[a+4>>2];f=(d+e|0)/2|0;d=d-e|0;d=Dc(roa(qoa(d,d>>31,g,h),kb,256,0),kb);x[a+4>>2]=f-d;x[a>>2]=d+f;c=c+1|0;a=a+8|0;continue}break}}function hC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=x[a>>2];f=Fk(e,x[a+4>>2]);while(1){a:{c=d&65535;if(c>>>0>=f>>>0){break a}c=hg(e,c);if(!Mb(x[c>>2],x[c+4>>2])){break a}d=d+1|0;continue}break}return(vh(a,d&65535,b)?d:-1)&65535}function _q(a){var b=0,c=0,d=0,e=0;c=ib-16|0;ib=c;b=ib-16|0;ib=b;gr(b+8|0,c+15|0);d=x[b+12>>2];ld(b,a,x[b+8>>2],x[b+12>>2]);e=x[b+4>>2];if((e|0)==(d|0)){gd(a,x[b+12>>2])}ib=b+16|0;ib=c+16|0;return((d|0)==(e|0)?y[c+15|0]:0)&255}function Wja(a){a=a|0;var b=0,c=0,d=0;b=ib-32|0;ib=b;w[b+30>>1]=0;c=dc(b+8|0,b+30|0,2);kc(b+16|0,x[a>>2],x[a+8>>2],x[c>>2],x[c+4>>2]);a:{if(x[b+20>>2]!=2){break a}if(Qb(b+30|0,13614,2)){break a}Yb(a,2);d=1}ib=b+32|0;return d|0}function wfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ib-16|0;ib=c;iR(c+8|0,b);d=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Yb(a,x[c+12>>2])}ib=c+16|0;a=(d|0)==(e|0);if(!a){Xz(b)}return a|0}function roa(a,b,c,d){var e=0,f=0,g=0,h=0;f=b^d;g=f>>31;e=b>>31;a=a^e;h=a-e|0;e=(b^e)-((a>>>0<e>>>0)+e|0)|0;a=d>>31;b=c^a;f=f>>31;a=soa(h,e,b-a|0,(a^d)-((a>>>0>b>>>0)+a|0)|0)^f;b=a-f|0;kb=(g^kb)-((a>>>0<f>>>0)+g|0)|0;return b}function oQ(a,b,c){var d=0,e=0,f=0;d=ib-16|0;ib=d;a:{if(!c){break a}x[b+40>>2]=c;if(!c|x[a+480180>>2]!=256){break a}x[d+12>>2]=c>>>4;x[d+8>>2]=1;e=b,f=x[Yc(d+12|0,d+8|0)>>2],x[e+40>>2]=f;e=b,f=CA(c&255),x[e+44>>2]=f}ib=d+16|0}function av(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=ib-16|0;ib=f;if(b){e=ad(a);d=Eb(a);g=d+b|0;if(e-d>>>0<b>>>0){tm(a,e,g-e|0,d,d,0,0)}e=d;d=vc(a);SB(e+d|0,b,c);Wh(a,g);v[f+15|0]=0;oe(d+g|0,f+15|0)}ib=f+16|0;return a|0}function _ha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=ib-32|0;ib=d;e=Jf(x[b>>2],x[b+4>>2]);c=oS(d+8|0,c);x[27524]=0;X(733,a|0,b|0,e-1&65535,c|0);a=x[27524];x[27524]=0;if((a|0)!=1){$e(c);ib=d+32|0;return}a=P()|0;$e(c);S(a|0);p()}function sv(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ib-16|0;ib=c;OC(c+8|0,b);d=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Yb(a,x[c+12>>2])}ib=c+16|0;a=(d|0)==(e|0);if(!a){NC(b)}return a|0}function sd(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=ib-16|0;ib=e;g=x[b+8>>2];f=x[b>>2];x[e+8>>2]=c;x[e+12>>2]=d;h=x[x[f>>2]+28>>2];x[e>>2]=c;x[e+4>>2]=d;lb[h|0](a,f,g,e);x[b+8>>2]=x[b+8>>2]+x[a+4>>2];ib=e+16|0}function mu(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ib-16|0;ib=c;PT(c+8|0,b);d=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Yb(a,x[c+12>>2])}ib=c+16|0;a=(d|0)==(e|0);if(!a){QT(b)}return a|0}function cD(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ib-16|0;ib=c;eD(c+8|0,b);d=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Yb(a,x[c+12>>2])}ib=c+16|0;a=(d|0)==(e|0);if(!a){dD(b)}return a|0}function qt(a,b){var c=0;a:{b:{c:{switch(b-2|0){default:c=43852;if((b|0)==16777216){break a}if((b|0)!=32){break b}c=43704;break a;case 2:c=43700;break a;case 1:break b;case 0:break c}}c=43696;break a}c=43692}x[a>>2]=x[c>>2]}function Rd(a,b){var c=0,d=0,e=0,f=0,g=0;d=z[a+22>>1];g=d+z[a+20>>1]|0;c=d;while(1){a:{if((c|0)!=(g|0)){e=((c&127)<<2)+a|0;f=z[e+28>>1]+b|0;w[e+28>>1]=f;if((f&65535)>>>0<2048){break a}w[a+20>>1]=c-d}return}c=c+1|0;continue}}function IA(a,b){var c=0,d=0,e=0,f=0;c=a<<8;d=c&16711680;c=e;e=a<<24|d;f=c;d=b<<24|a>>>8;c=b<<8|a>>>24;a=f|(((b&255)<<24|a>>>8)&-16777216|((b&16777215)<<8|a>>>24)&16711680|(b>>>8&65280|b>>>24));kb=e|(d&65280|c&255);return a}function hq(a,b,c){var d=0,e=0,f=0,g=0,h=0;f=131072/(C[b-8>>3]-C[a>>3]);b=0;while(1){if((b|0)!=2048){d=-Be(f*C[We(a,b)>>3]);a:{if(F(d)<2147483648){e=~~d;break a}e=-2147483648}g=Bb(c,b),h=e,x[g>>2]=h;b=b+1|0;continue}break}}function gma(a,b){a=a|0;b=b|0;var c=0,d=0;c=ib-16|0;ib=c;x[a+480180>>2]=b;Hq(c,Iq(a));d=x[c+12>>2];b=a+1074320|0;x[b>>2]=x[c+8>>2];x[b+4>>2]=d;b=x[c+4>>2];x[a+1074312>>2]=x[c>>2];x[a+1074316>>2]=b;qt(a+8|0,Iq(a));ib=c+16|0}function w0(a){a=a|0;if(y[483696]){return x[120923]}if(!y[484856]){a=484832;while(1){a=Kb(a)+12|0;if((a|0)!=484856){continue}break}v[484856]=1}pd(484832,105008);pd(484844,105020);v[483696]=1;x[120923]=484832;return 484832}function qF(a,b,c,d,e){var f=0;f=ib-32|0;ib=f;x[f+24>>2]=a;x[f+28>>2]=b;x[f+16>>2]=d;x[f+20>>2]=e;x[f+8>>2]=c;x[f+12>>2]=0;a=xC(f+24|0,f+8|0);b=f+16|0;a=Ir(x[b>>2],x[b+4>>2],x[a>>2],x[a+4>>2])?a:b;ib=f+32|0;return x[a>>2]}function kB(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=zl(a);e=xd(x[a+4>>2],y[a+11|0]);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=nd(a);Ae(d+e|0,b,c);b=c+e|0;zq(a,b);ne(b+d|0,0);return a|0}wq(a,d,(c+e|0)-d|0,e,e,0,c,b)}return a|0}function hQ(a,b,c,d){var e=0;a=dd(Zn(a,z[c+70>>1],x[c+48>>2],b,0)-32768|0);a:{if(!d){break a}d=nl(c)-x[c+16>>2]|0;if((d|0)<2){break a}e=a;a=w[(D(b,872)+c|0)+1390>>1];a=dd(((e-a|0)/(d|0)|0)+a|0)}w[(D(b,872)+c|0)+1390>>1]=a}function NJ(a,b){var c=0,d=0,e=0;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);if(b){Pl(a,b);d=ib-16|0;ib=d;b=_l(d,a,b);c=x[b+4>>2];e=x[b+8>>2];while(1){if((c|0)==(e|0)){ic(b);ib=d+16|0}else{c=c+1|0;x[b+4>>2]=c;continue}break}}return a}function Hja(a,b){a=a|0;b=b|0;var c=0,d=0;c=ib-16|0;ib=c;d=Ob(x[a>>2],x[a+8>>2],6);a:{if(!d){a=0;while(1){if((a|0)!=6){Jh(a+b|0);a=a+1|0;continue}break}break a}XB(c+8|0,b);sd(c,a,x[c+8>>2],x[c+12>>2])}ib=c+16|0;return d|0}function lu(a,b){var c=0,d=0,e=0;if(x[a>>2]){OX(a);c=x[a>>2];oC(a);Ib(c);d=Db(a),e=0,x[d>>2]=e;x[a>>2]=0;x[a+4>>2]=0}x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];c=Db(b);d=Db(a),e=x[c>>2],x[d>>2]=e;x[c>>2]=0;x[b>>2]=0;x[b+4>>2]=0}function lT(a,b,c){var d=0;d=ib-16|0;ib=d;v[d+15|0]=a;a=0;if(!(c>>>0<25|b>>>0<25|(b>>>0>108|b>>>0>=c>>>0)|c>>>0>108)){v[d+14|0]=(z[(b<<1)+32638>>1]-z[(c<<1)+32638>>1]|0)/5;a=y[Ub(d+15|0,d+14|0)|0]}ib=d+16|0;return a&255}function i0(a){a=a|0;if(y[483688]){return x[120921]}if(!y[484824]){a=484800;while(1){a=Kb(a)+12|0;if((a|0)!=484824){continue}break}v[484824]=1}od(484800,13856);od(484812,13835);v[483688]=1;x[120921]=484800;return 484800}function Tba(a){a=a|0;var b=0;lb[x[x[a>>2]+132>>2]](a);my(a);x[a+4236>>2]=0;v[a+4202|0]=1;b=lb[x[x[a>>2]+196>>2]](a)|0;x[a+4328>>2]=0;x[a+4312>>2]=0;B[a+4240>>2]=b?E(.5):E(1);b=x[a+4256>>2];x[a+4324>>2]=b;x[a+4320>>2]=b}function NP(a,b){var c=0,d=0,e=0,f=0;x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];x[a+8>>2]=x[b+8>>2];d=Db(a);c=gc(a);a:{if(!x[d>>2]){x[a>>2]=c;break a}x[x[c>>2]+8>>2]=c;c=gc(b);x[b>>2]=c;x[c>>2]=0;e=Db(b),f=0,x[e>>2]=f}return a}function Ds(a){var b=0;a:{b=y[a+1376|0];b:{if(!b){b=-1;if(x[a+1384>>2]){break b}if(!Cx(a)){break b}b=y[a+1376|0];if(!b){break a}}v[a+1376|0]=b-1;x[a+1400>>2]=x[a+1400>>2]+1;b=df(a)}return b}aa(15690,13154,1578,5432);p()}function Cw(a,b,c,d,e){var f=0,g=0,h=0;f=ib-16|0;ib=f;g=zf(f+8|0,d);x[27524]=0;h=x[g+4>>2];x[f>>2]=x[g>>2];x[f+4>>2]=h;a=Mg(e,a,b,c,f);b=x[27524];x[27524]=0;if((b|0)!=1){Ud(d);ib=f+16|0;return a}a=P()|0;Ud(d);S(a|0);p()}function mla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=ib-16|0;ib=d;c=-1;a:{if(!Xj(a,d+8|0)){break a}e=x[d+12>>2];c=0;if(!(x[d+8>>2]==(Vm(8926)|0)&e>>>0>255&e>>>0<260)){break a}c=Ee(a,b,e>>>0<259?80:76,0)}ib=d+16|0;return c|0}function li(a,b,c){var d=0,e=0,f=0;d=ib-16|0;ib=d;cc(d+8|0,b,c);e=x[d+12>>2];kc(d,x[a>>2],x[a+8>>2],x[d+8>>2],x[d+12>>2]);f=x[d+4>>2];if((f|0)==(e|0)){Yb(a,x[d+12>>2])}ib=d+16|0;a=(e|0)==(f|0);if(!a){Rb(b,0,c)}return a}function hV(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function Ms(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=ib-16|0;ib=c;d=x[b>>2];b=tc(d,x[b+4>>2]);a=0;while(1){if((a|0)==(b|0)){ib=c+16|0}else{x[c+8>>2]=0;e=sc(c+8|0);f=Bb(d,a),g=x[e>>2],x[f>>2]=g;a=a+1|0;continue}break}}function GP(a,b,c,d){var e=0,f=0;e=x[(D(c,872)+b|0)+704>>2];a:{if(!(!(e&134218752)|(d|0)!=1)|e&67108864){break a}b=z[(D(c,872)+b|0)+1402>>1];b=(b?b-1|0:c)&65535;if(b>>>0>126){break a}f=y[((b<<5)+a|0)+480288|0]}return f}function sR(a,b){a:{if(y[a+76|0]==(b|0)){break a}v[a+76|0]=b;if(b){b=0;if(z[a+24>>1]==15){w[a+20>>1]=0;b=1}x[a+8>>2]=0;x[a+16>>2]=b;return}b:{switch(x[a+16>>2]+1|0){case 0:case 4:break a;default:break b}}x[a+16>>2]=3}}function lq(a,b,c){var d=0;d=ib-16|0;ib=d;Ab(d+8|0,c+1074312|0,102);a:{if(!zb(x[x[d+8>>2]>>2],x[d+12>>2])){break a}c=z[a+692>>1]+1|0;w[a+784>>1]=c;if(!(v[a+89|0]&1)){break a}w[a+784>>1]=c|32768}x[a+692>>2]=b;ib=d+16|0}function qoa(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=c>>>16|0;f=a>>>16|0;j=D(e,f);g=c&65535;h=a&65535;i=D(g,h);f=(i>>>16|0)+D(f,g)|0;e=(f&65535)+D(e,h)|0;kb=(D(b,c)+j|0)+D(a,d)+(f>>>16)+(e>>>16)|0;return i&65535|e<<16}function TV(a){var b=0;a:{b:{if(Qb(a,13833,4)){if(Qb(a,16257,4)){break a}if((y[a+34|0]|y[a+35|0]<<8)>>>0<=255){break b}break a}if((y[a+34|0]|y[a+35|0]<<8)>>>0>255){break a}}b=(y[a+36|0]|y[a+37|0]<<8)>>>0<4e3}return b}function Gq(a,b,c){var d=0,e=0;e=z[a+480192>>1];a:{if(e){if(!Wc(b)|c>>>0>e>>>0){break a}c=x[((c<<2)+a|0)+900380>>2];if(!c){break a}d=z[bc(c+236|0,b-1|0)>>1];break a}d=c}return(z[a+480190>>1]>=(d&65535)>>>0?d:0)&65535}function JN(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;tg(a+12|0,d);if(b){if(b>>>0>=2097152){Vg();p()}d=mc(b<<11)}else{d=0}x[a>>2]=d;c=d+(c<<11)|0;x[a+8>>2]=c;x[a+4>>2]=c;e=zc(a),f=d+(b<<11)|0,x[e>>2]=f;return a|0}function CI(a,b){var c=0,d=0,e=0;c=ib-256|0;ib=c;if((b|0)>=2){x[(b<<2)+a>>2]=c;rc(c,x[a>>2],4);while(1){e=(d<<2)+a|0;d=d+1|0;rc(x[e>>2],x[(d<<2)+a>>2],4);x[e>>2]=x[e>>2]+4;if((b|0)!=(d|0)){continue}break}}ib=c+256|0}function Ax(a){var b=0;a:{b:{while(1){if(x[a+1380>>2]!=-1){break b}b=0;if(!Cs(a)){break a}if(!(v[a+1375|0]&1)){continue}break}fc(a,32);return 0}x[a+1396>>2]=0;x[a+1400>>2]=0;x[a+1384>>2]=0;v[a+1376|0]=0;b=1}return b}function bA(a,b,c){var d=0;a:{switch(c+1|0){case 0:case 3:xR(a,b);return;default:break a}}d=ib-32|0;ib=d;x[d+28>>2]=c;w[d+24>>1]=0;x[d+12>>2]=2;Ow(d+16|0,a,d+24|0,x[Hb(d+28|0,d+12|0)>>2]);Rj(b,z[d+24>>1]);ib=d+32|0}function _Q(a,b){var c=0,d=0,e=0,f=0;e=C[a+48>>3];c=C[a+40>>3];C[a+48>>3]=c;f=C[a+64>>3];d=C[a+56>>3];C[a+64>>3]=d;C[a+40>>3]=b;b=e*C[a+16>>3]+(C[a>>3]*b+c*C[a+8>>3])-d*C[a+24>>3]-f*C[a+32>>3];C[a+56>>3]=b;return b}function Lu(a,b,c){var d=0,e=0,f=0;d=ib-16|0;ib=d;if(c>>>0<4294967280){a:{if(Dl(c)){ee(a,c);break a}e=Wg(c)+1|0;f=mc(e);td(a,f);hf(a,e);vd(a,c);a=f}a=Ae(a,b,c);v[d+15|0]=0;oe(a+c|0,d+15|0);ib=d+16|0;return}of();p()}function p1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=xn(a);e=Eb(a);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=vc(a);ui(d+(e<<2)|0,b,c);b=c+e|0;Wh(a,b);td(d+(b<<2)|0,0);return a|0}fG(a,d,(c+e|0)-d|0,e,e,0,c,b)}return a|0}function aq(a,b){a=rc(a,b,88);x[a+88>>2]=x[b+88>>2];rc(a+92|0,b+92|0,576);x[a+668>>2]=x[b+668>>2];rc(a+672|0,b+672|0,52);tz(a+724|0,b+724|0);tz(a+732|0,b+732|0);tz(a+740|0,b+740|0);rc(a+748|0,b+748|0,123);return a}function XR(a){var b=0;b=w[a+784>>1];if(b){x[a+692>>2]=(b&32767)-1;if((b|0)<0){x[a+88>>2]=x[a+88>>2]|256}w[a+784>>1]=0}b=y[a+795|0];if(b){v[a+795|0]=0;v[a+838|0]=b-1}b=y[a+796|0];if(b){v[a+796|0]=0;v[a+837|0]=b-1}}function Jn(a,b){var c=0,d=0,e=0;c=a*a;d=c*a;e=c*c;a=d*e*(e*(c*.009465647849436732+.002974357433599673)+(c*.024528318116654728+.05338123784456704))+(d*(c*.13339200271297674+.3333313950307914)+a);return E(b?-1/a:a)}function vm(a,b){var c=E(0),d=0,e=0;c=E(1);d=w[a+28>>1];a:{if((d|0)>(b|0)){break a}e=x[a+4>>2];if((tc(e,x[a+8>>2])+d<<16)-65536>>16<(b|0)){break a}c=B[Bb(e,b-d|0)>>2];c=c<=E(10000000036274937e-31)?E(1):c}return c}function Dla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=ib-16|0;ib=e;c=Af(a,c);Pd(e,x[a+36>>2]);a:{if(!c){Pc(e,a+32|0,5);f=0;if(zb(x[x[e>>2]>>2],x[e+4>>2])){break a}}LV(x[a+36>>2],b,d,0);f=c}af(a,f);ib=e+16|0}function z4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=ib-16|0;ib=c;x[c+4>>2]=1;e=c,f=mc(40),x[e+8>>2]=f;d=Tl(x[c+8>>2]);x[d>>2]=77800;d=rJ(zc(d));x[d+24>>2]=b;x[d>>2]=77948;b=a;a=kn(c);jn(b,zc(a),a);Ul(c);ib=c+16|0}function AV(a,b,c){var d=0,e=0;d=ib-16|0;ib=d;x[d>>2]=x[a+8>>2];e=x[a+8>>2];x[d+8>>2]=a+8;x[d+4>>2]=D(b,6)+e;b=x[d>>2];while(1){if(x[d+4>>2]!=(b|0)){Du(b,c);b=x[d>>2]+6|0;x[d>>2]=b;continue}break}Vd(d);ib=d+16|0}function xD(a,b){var c=0,d=0;c=ib-16|0;ib=c;a:{if(b>>>0<2){b:{if(!b){break b}if(!Ob(x[a>>2],x[a+8>>2],1)){break b}v[c+15|0]=0;Hg(a,c+15|0);d=v[c+15|0]}ib=c+16|0;a=d;break a}aa(11131,9027,137,14200);p()}return a}function rda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=ib-16|0;ib=e;c=Af(a,c);Pd(e,x[a+36>>2]);a:{if(!c){Pc(e,a+32|0,5);f=0;if(zb(x[x[e>>2]>>2],x[e+4>>2])){break a}}PN(d,x[a+36>>2],b);f=c}af(a,f);ib=e+16|0}function gea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ib-32|0;ib=c;a:{if(_h(a)>>>0<b>>>0){if(zh(1073741823)>>>0<b>>>0){break a}d=Db(a);e=a;a=cg(c+8|0,b,tc(x[a>>2],x[a+4>>2]),d);Dd(e,a);bg(a)}ib=c+32|0;return}_c();p()}function _U(a,b){var c=0,d=0,e=0;c=ib-16|0;ib=c;aV(c+8|0,b);d=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Yb(a,x[c+12>>2])}ib=c+16|0;a=(d|0)==(e|0);if(!a){$U(b)}return a}function RB(a,b){var c=0,d=0,e=0;c=ib-16|0;ib=c;IW(c+8|0,b);d=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Yb(a,x[c+12>>2])}ib=c+16|0;a=(d|0)==(e|0);if(!a){JW(b)}return a}function MR(a,b,c,d){var e=0;e=ib-16|0;ib=e;a=ei(e,a,d);d=ib-16|0;ib=d;x[d+8>>2]=b;while(1){if(Mb(b,c)){Pj(x[a+4>>2],z[b>>1]);b=Ye(d+8|0);x[a+4>>2]=x[a+4>>2]+2;b=x[b>>2];continue}break}ib=d+16|0;ic(a);ib=e+16|0}function Jk(a){wc(a+16|0,x[a>>2]);wc(a+8|0,x[a>>2]);if(A[a+12>>2]>=A[a+16>>2]){x[a+12>>2]=0;x[a+16>>2]=0;w[a+34>>1]=z[a+34>>1]&65511}if(A[a+4>>2]>=A[a+8>>2]){x[a+4>>2]=0;x[a+8>>2]=0;w[a+34>>1]=z[a+34>>1]&65529}}function sfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);c=ah(x[b>>2],x[b+4>>2]);if(c){Vz(a,c);d=ib-16|0;ib=d;e=x[b>>2];f=x[b+4>>2];b=ur(d,a,c);Eu(e,f,b+4|0);ic(b);ib=d+16|0}return a|0}function pfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ib-32|0;ib=c;a:{if(mn(a)>>>0<b>>>0){if(zh(536870911)>>>0<b>>>0){break a}d=Db(a);e=a;a=wr(c+8|0,b,ah(x[a>>2],x[a+4>>2]),d);Dd(e,a);vr(a)}ib=c+32|0;return}_c();p()}function iea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ib-32|0;ib=c;a:{if(ak(a)>>>0<b>>>0){if(zh(357913941)>>>0<b>>>0){break a}d=Db(a);e=a;a=Pk(c+8|0,b,wd(x[a>>2],x[a+4>>2]),d);Hr(e,a);vQ(a)}ib=c+32|0;return}_c();p()}function gfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ib-32|0;ib=c;a:{if(Nz(a)>>>0<b>>>0){if(zh(613566756)>>>0<b>>>0){break a}d=Db(a);e=a;a=CQ(c+8|0,b,Mz(x[a>>2],x[a+4>>2]),d);BQ(e,a);AQ(a)}ib=c+32|0;return}_c();p()}function WU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ib-32|0;ib=c;a:{if(_m(a)>>>0<b>>>0){if(zh(2147483647)>>>0<b>>>0){break a}d=Db(a);e=a;a=Uj(c+8|0,b,Oc(x[a>>2],x[a+4>>2]),d);Dd(e,a);Ui(a)}ib=c+32|0;return}_c();p()}function Vy(a,b){var c=0,d=0;c=x[b+4>>2];x[a+24648>>2]=x[b>>2];x[a+24652>>2]=c;d=x[b+20>>2];c=a+24664|0;x[c>>2]=x[b+16>>2];x[c+4>>2]=d;d=x[b+12>>2];c=a+24656|0;x[c>>2]=x[b+8>>2];x[c+4>>2]=d;DO(a+24648|0);JO(a)}function VH(a,b){a=a|0;b=b|0;var c=0,d=0;c=x[a>>2];a:{if(!c){break a}d=x[c+24>>2];b:{if((d|0)==x[c+28>>2]){b=lb[x[x[c>>2]+52>>2]](c,b)|0;break b}x[c+24>>2]=d+4;x[d>>2]=b}if(!Hn(b)){break a}x[a>>2]=0}return a|0}function Eia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ib-32|0;ib=c;a:{if(ak(a)>>>0<b>>>0){if(zh(357913941)>>>0<b>>>0){break a}d=Db(a);e=a;a=Pk(c+8|0,b,wd(x[a>>2],x[a+4>>2]),d);YS(e,a);XS(a)}ib=c+32|0;return}_c();p()}function Dca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ib-16|0;ib=c;a=oj(a);if(a){d=x[b+4>>2];b=x[b>>2];x[c+8>>2]=b;x[c+12>>2]=d;e=x[x[a>>2]+72>>2];x[c>>2]=b;x[c+4>>2]=d;a=lb[e|0](a,c)|0}else{a=1}ib=c+16|0;return a|0}function $da(a,b){a=a|0;b=b|0;var c=0;b=ib-16|0;ib=b;c=-1;a:{if(!Xj(a,b+8|0)){break a}c=0;if(!mO(x[b+8>>2],x[b+12>>2])){break a}a=nT(a,b);if(!a){Ho(b)}c=-1;if(!a){break a}c=lO(x[b>>2])}a=c;ib=b+16|0;return a|0}function zR(a,b){var c=0,d=0,e=0;e=x[a>>2];c=x[a+4>>2];d=b+4|0;while(1){if((c|0)!=(e|0)){c=c-32|0;dA(x[d>>2]-32|0,c);x[d>>2]=x[d>>2]-32;continue}break}oc(a,d);oc(a+4|0,b+8|0);oc(Db(a),zc(b));x[b>>2]=x[b+4>>2]}function dE(a,b){var c=0,d=0,e=0;e=x[a>>2];c=x[a+4>>2];d=b+4|0;while(1){if((c|0)!=(e|0)){c=c-36|0;Uv(x[d>>2]-36|0,c);x[d>>2]=x[d>>2]-36;continue}break}oc(a,d);oc(a+4|0,b+8|0);oc(Db(a),zc(b));x[b>>2]=x[b+4>>2]}function Xy(a,b){var c=0;c=x[b+24>>2];x[a+24628>>2]=c?c>>>0>=512?512:c:1;a:{if(!(x[b+16>>2]!=x[a+24620>>2]|x[b+20>>2]!=x[a+24624>>2])){c=0;if(x[b+12>>2]==x[a+24616>>2]){break a}}c=1}rc(a+24604|0,b,40);EO(a,c)}function TB(a,b){var c=0,d=0,e=0;e=x[a>>2];c=x[a+4>>2];d=b+4|0;while(1){if((c|0)!=(e|0)){c=c-20|0;WB(x[d>>2]-20|0,c);x[d>>2]=x[d>>2]-20;continue}break}oc(a,d);oc(a+4|0,b+8|0);oc(Db(a),zc(b));x[b>>2]=x[b+4>>2]}function Hw(a,b,c){var d=0;d=x[a+16>>2];if(!d){x[a+36>>2]=1;x[a+24>>2]=c;x[a+16>>2]=b;return}a:{if((b|0)==(d|0)){if(x[a+24>>2]!=2){break a}x[a+24>>2]=c;return}v[a+54|0]=1;x[a+24>>2]=2;x[a+36>>2]=x[a+36>>2]+1}}function Hr(a,b){var c=0,d=0,e=0;e=x[a>>2];c=x[a+4>>2];d=b+4|0;while(1){if((c|0)!=(e|0)){c=c-12|0;fp(x[d>>2]-12|0,c);x[d>>2]=x[d>>2]-12;continue}break}oc(a,d);oc(a+4|0,b+8|0);oc(Db(a),zc(b));x[b>>2]=x[b+4>>2]}function zea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;b=(b-a|0)/160|0;while(1){if((b|0)>0){b=b-1|0;x[a>>2]=x[c>>2];d=a+4|0;if((d|0)!=(c+4|0)){_y(d,x[c+4>>2],x[c+8>>2])}rc(a+16|0,c+16|0,144);a=a+160|0;continue}break}}function cZ(a,b){a=a|0;b=b|0;var c=0,d=0;c=ib-48|0;ib=c;d=-1;a:{if(!SD(a,c+8|0)){break a}d=0;if(!RD(c+8|0)){break a}if(b){a=x[b>>2];if(!x[b+4>>2]&a>>>0<ac(x[c+12>>2])-8>>>0){break a}}d=1}ib=c+48|0;return d|0}function RA(a,b){var c=0,d=0,e=0,f=0;d=b?224:240;e=qE(a);a:while(1){if((a|0)!=(e|0)){f=ud(a);b=a;while(1)if((b|0)==(f|0)){a=a+16|0;continue a}else{c=((y[Jb(b,0)|0]&d)!=0)+c|0;b=b+4|0;continue}}break}return c}function JS(a){a=a*4294967296;if(F(a)<0x8000000000000000){kb=F(a)>=1?~~(a>0?H(J(a*2.3283064365386963e-10),4294967295):K((a-+(~~a>>>0>>>0))*2.3283064365386963e-10))>>>0:0;return~~a>>>0}kb=-2147483648;return 0}function kv(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+16|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function DP(a,b){var c=0;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;c=x[b+28>>2];x[a+24>>2]=x[b+24>>2];x[a+28>>2]=c;c=x[b+20>>2];x[a+16>>2]=x[b+16>>2];x[a+20>>2]=c;c=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=c}function Ad(a,b){var c=0,d=0;c=ib-16|0;ib=c;a:{if(b>>>0<2){b:{if(!b){break b}if(!Ob(x[a>>2],x[a+8>>2],1)){break b}v[c+15|0]=0;Hg(a,c+15|0);d=y[c+15|0]}ib=c+16|0;break a}aa(11131,9027,137,14200);p()}return d}function qfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=Nb(a);d=zg(a+12|0);v[a+32|0]=c;x[a+28>>2]=0;x[a+24>>2]=b;x[27524]=0;R(771,a|0,1);b=x[27524];x[27524]=0;if((b|0)!=1){return a|0}b=P()|0;UQ(d);YQ(a);S(b|0);p()}function mi(a,b,c){var d=0,e=0,f=0;d=ib-16|0;ib=d;cc(d+8|0,b,c);e=x[d+12>>2];kc(d,x[a>>2],x[a+8>>2],x[d+8>>2],x[d+12>>2]);f=x[d+4>>2];if((f|0)==(e|0)){Yb(a,x[d+12>>2])}ib=d+16|0;if((e|0)!=(f|0)){Rb(b,0,c)}}function yia(a,b){a=a|0;b=b|0;var c=0,d=0;c=ib-16|0;ib=c;Fm(a,b);b=Cb(x[a>>2]);x[c+8>>2]=b;a=Cb(x[a+4>>2]);while(1){if(Mb(b,a)){d=y[b|0]+(d&255)|0;v[b|0]=d;b=x[Ie(c+8|0)>>2];continue}else{ib=c+16|0}break}}function vfa(a,b){a=a|0;b=b|0;var c=0;c=ib-16|0;ib=c;a:{if(!Ob(x[a>>2],x[a+8>>2],27)){a=0;while(1){if((a|0)!=27){Jh(a+b|0);a=a+1|0;continue}break}break a}iR(c+8|0,b);sd(c,a,x[c+8>>2],x[c+12>>2])}ib=c+16|0}function uR(a){var b=0,c=0,d=0;b=z[a+20>>1];w[a+28>>1]=z[a+22>>1]<<1|(y[x[a+16>>2]+3842|0]?b>>>9|0:b>>>8&1);b=0;while(1){if((b|0)!=4){c=(b<<2)+a|0;d=x[c>>2];if(d){ho(d);tR(x[c>>2])}b=b+1|0;continue}break}}function ML(a,b){var c=0,d=0;c=-1;a:{if((b|0)<0){break a}d=x[a+24>>2];if(xj(Tb(x[d+484360>>2],y[d+484376|0]))>>>0<=b>>>0){break a}a=x[a+24>>2];c=z[bc(x[Tb(x[a+484360>>2],y[a+484376|0])>>2],b)>>1]}return c}function Lna(a,b){a=a|0;b=b|0;var c=0;c=ib-16|0;ib=c;a:{if(!Ob(x[a>>2],x[a+8>>2],64)){a=0;while(1){if((a|0)!=64){Jh(a+b|0);a=a+1|0;continue}break}break a}_u(c+8|0,b);sd(c,a,x[c+8>>2],x[c+12>>2])}ib=c+16|0}function eU(a,b){a=a|0;b=b|0;var c=0;c=ib-16|0;ib=c;a:{if(!Ob(x[a>>2],x[a+8>>2],32)){a=0;while(1){if((a|0)!=32){Jh(a+b|0);a=a+1|0;continue}break}break a}cU(c+8|0,b);sd(c,a,x[c+8>>2],x[c+12>>2])}ib=c+16|0}function aba(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=ib-16|0;ib=f;b=Dc(roa(qoa(d,d>>31,b,0),kb,1e3,0),kb);x[a+16>>2]=0;x[a+12>>2]=b+c;TM(a,e);b=x[a+12>>2];x[f+12>>2]=0;SN(a,b,f+12|0);ib=f+16|0}function Pf(a,b,c,d,e){var f=0;f=ib-256|0;ib=f;if(!(e&73728|(c|0)<=(d|0))){d=c-d|0;c=d>>>0<256;Rb(f,b&255,c?d:256);if(!c){while(1){Bf(a,f,256);d=d-256|0;if(d>>>0>255){continue}break}}Bf(a,f,d)}ib=f+256|0}function m9(a,b){a=a|0;b=b|0;var c=0,d=0;a:{c=x[b+52>>2];if(c&16){d=x[b+48>>2];c=x[b+28>>2];if(d>>>0<c>>>0){x[b+48>>2]=c;d=c}Zh(a,x[b+24>>2],d);break a}if(c&8){Zh(a,x[b+12>>2],x[b+20>>2]);break a}Kb(a)}}function ie(a,b){var c=0,d=0,e=0;b=b+7&-8;x[a+8>>2]=b+x[a+8>>2];d=x[a+80>>2];a:{if(d){c=b;b=x[a+88>>2];e=c+b|0;c=0;if((e|0)>x[a+92>>2]){break a}x[a+88>>2]=e;return b+d|0}if(!b){return 0}c=Gd(b)}return c}function en(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ib-16|0;ib=d;a:{if(c){Kc(d,c);break a}Kb(d)}x[27524]=0;U(11,a|0,b|0,d|0);a=x[27524];x[27524]=0;if((a|0)!=1){wb(d);ib=d+16|0;return}a=P()|0;wb(d);S(a|0);p()}function eV(a,b){a=a|0;b=b|0;var c=0,d=0;c=ib-16|0;ib=c;XB(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Yb(a,x[c+12>>2])}ib=c+16|0;return(b|0)==(d|0)|0}function Xha(a,b){a=a|0;b=b|0;var c=0,d=0;c=ib-16|0;ib=c;if((b|0)>=0){d=2147483647;a=Ut(a);if(a>>>0<=1073741822){x[c+12>>2]=a<<1;x[c+8>>2]=b+31&-32;d=x[Yc(c+12|0,c+8|0)>>2]}ib=c+16|0;return d|0}_c();p()}function Nh(a,b){a=a|0;b=b|0;var c=0,d=0;c=ib-16|0;ib=c;dn(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Yb(a,x[c+12>>2])}ib=c+16|0;return(b|0)==(d|0)|0}function IK(a,b){a=a|0;b=b|0;var c=0;a=jk(a);x[a+4>>2]=0;x[a>>2]=49200;if(lb[x[x[b>>2]+8>>2]](b)|0){b=lb[x[x[b>>2]+8>>2]](b)|0}else{b=21631}c=Gd(xf(b)+1|0);x[a+4>>2]=c;if(c){rc(c,b,xf(b)+1|0)}return a|0}function DW(a){var b=0;a:{if(Qb(a,3873,4)|y[a+68|0]!=13|(y[a+69|0]!=10|y[a+70|0]!=26)){break a}if(Qb(a+71|0,13694,4)|y[a+75|0]!=1|y[a+76|0]){break a}b=((y[a+116|0]|y[a+117|0]<<8)-1&65535)>>>0<9}return b}function wn(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ib-32|0;ib=c;a:{if(sp(a)>>>0<b>>>0){if(zh(-1)>>>0<b>>>0){break a}d=Db(a);e=a;a=am(c+8|0,b,cd(x[a>>2],x[a+4>>2]),d);Dd(e,a);$l(a)}ib=c+32|0;return}_c();p()}function UX(a,b){a=a|0;b=b|0;var c=0;c=ib-16|0;ib=c;a:{if(!Ob(x[a>>2],x[a+8>>2],8)){a=0;while(1){if((a|0)!=8){Jh(a+b|0);a=a+1|0;continue}break}break a}dn(c+8|0,b);sd(c,a,x[c+8>>2],x[c+12>>2])}ib=c+16|0}function PG(a,b,c,d,e,f){var g=0,h=0,i=0;g=ib-16|0;ib=g;v[g+15|0]=0;v[g+14|0]=f;v[g+13|0]=e;v[g+12|0]=37;if(f){Qi(g+13|0,g+14|0)}h=c,i=(ab(b|0,cd(b,x[c>>2])|0,g+12|0,d|0,a|0)|0)+b|0,x[h>>2]=i;ib=g+16|0}function Og(a){var b=0,c=0,d=0,e=0;b=ib-16|0;ib=b;c=2;if(a>>>0>=2){x[b+12>>2]=a>>>1;x[b+8>>2]=a^-1;d=b,e=x[Hb(b+12|0,b+8|0)>>2]+a|0,x[d+12>>2]=e;x[b+8>>2]=-1;c=x[Hb(b+12|0,b+8|0)>>2]}ib=b+16|0;return c}function Aka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);if(b){if(zh(1073741823)>>>0<b>>>0){_c();p()}c=CD(b);x[a>>2]=c;x[a+4>>2]=c;d=Db(a),e=(b<<2)+c|0,x[d>>2]=e;lB(a,b)}return a|0}function IY(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);if(b){if(zh(214748364)>>>0<b>>>0){_c();p()}c=VC(b);x[a>>2]=c;x[a+4>>2]=c;d=Db(a),e=D(b,20)+c|0,x[d>>2]=e;YC(a,b)}return a|0}function Fda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=ib-16|0;ib=d;c=Af(a,c);Pd(d,x[a+36>>2]);a:{if(!c){Pc(d,a+32|0,5);e=0;if(zb(x[x[d>>2]>>2],x[d+4>>2])){break a}}OV(x[a+36>>2],b);e=c}af(a,e);ib=d+16|0}function u_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=ib-16|0;ib=d;f=x[x[b>>2]+20>>2];e=x[c+12>>2];x[d+8>>2]=x[c+8>>2];x[d+12>>2]=e;e=x[c+4>>2];x[d>>2]=x[c>>2];x[d+4>>2]=e;lb[f|0](a,b,d,8);ib=d+16|0}function mh(a,b){var c=0,d=0,e=0;c=Eb(a);a:{if((c|0)!=(Eb(b)|0)){break a}d=Jc(a);b=Jc(b);if(!kf(a)){while(1){e=!c;if(!c|y[d|0]!=y[b|0]){break a}b=b+1|0;d=d+1|0;c=c-1|0;continue}}e=!Rp(d,b,c)}return e}function lca(a){a=a|0;var b=0,c=0,d=0;b=ib-32|0;ib=b;a:{if(_h(a)>>>0<=12){if(zh(1073741823)>>>0<=12){break a}c=Db(a);d=a;a=cg(b+8|0,13,tc(x[a>>2],x[a+4>>2]),c);Dd(d,a);bg(a)}ib=b+32|0;return}_c();p()}function fU(a,b){a=a|0;b=b|0;var c=0,d=0;d=x[a>>2];c=65535;a:{if(!Ce(d,x[a+4>>2],b)){break a}d=hC(a,x[hg(d,b)+12>>2]);c=65535;if((d|0)==65535){break a}c=x[a>>2];a=hg(c,b);dO(hg(c,d),a);c=d}return c|0}function c8(a,b){a=a|0;b=b|0;var c=0;a=x[a+8>>2];a:{if(Qe(b)){c=0}else{c=a;if(de(b,48928)){break a}c=a+88|0;if(de(b,48940)){break a}c=a+92|0;if(de(b,48952)){break a}c=de(b,48965)?a+96|0:0}}return c|0}function X3(a,b){a=a|0;b=b|0;var c=0;a=Ts(a);x[a>>2]=92688;c=Kb(a+32|0);x[a+44>>2]=0;x[a+48>>2]=8;x[27524]=0;R(93,a|0,b|0);b=x[27524];x[27524]=0;if((b|0)!=1){return a|0}b=P()|0;wb(c);Pn(a);S(b|0);p()}function wT(a){var b=0,c=0,d=0;d=y[a+32|0]|y[a+33|0]<<8;b=y[a+34|0]|y[a+35|0]<<8;a=b+(y[a+36|0]|y[a+37|0]<<8)|0;c=a>>>0<b>>>0?1:c;b=a;a=c<<1|a>>>31;b=b<<1;c=d+b|0;a=c>>>0<b>>>0?a+1|0:a;kb=a;return c}function i_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=ib-16|0;ib=e;x[e+12>>2]=d;d=xd(x[b+4>>2],y[b+11|0]);if(d>>>0<c>>>0){yk();p()}b=nd(b);x[e+8>>2]=d-c;PD(a,b+c|0,x[Hb(e+12|0,e+8|0)>>2]);ib=e+16|0}function hS(a){var b=0,c=0,d=0;d=y[a+64|0]|y[a+65|0]<<8;b=y[a+70|0]|y[a+71|0]<<8;a=b+(y[a+72|0]|y[a+73|0]<<8)|0;c=a>>>0<b>>>0?1:c;b=a;a=c<<2|a>>>30;b=b<<2;c=d+b|0;a=c>>>0<b>>>0?a+1|0:a;kb=a;return c}function cl(a){a=a|0;var b=0;x[a>>2]=93884;x[27524]=0;R(70,a|0,0);b=x[27524];x[27524]=0;if((b|0)!=1){_b(a+28|0);Ib(x[a+32>>2]);Ib(x[a+36>>2]);Ib(x[a+48>>2]);Ib(x[a+60>>2]);return a|0}V(0)|0;Sb();p()}function bga(a){a=a|0;var b=0;b=ib-16|0;ib=b;a:{if(Jq(a,10203)){UJ(b,17550,a);a=Jc(b);x[27524]=0;R(41,44,a|0);a=x[27524];x[27524]=0;if((a|0)!=1){break a}a=P()|0;wb(b);S(a|0);p()}ib=b+16|0;return}p()}function L5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ib-16|0;ib=d;dK(d,c);a=x[a+1298472>>2];x[27524]=0;U(380,a|0,b|0,d|0);a=x[27524];x[27524]=0;if((a|0)!=1){xb(d);ib=d+16|0;return}a=P()|0;xb(d);S(a|0);p()}function GM(a){var b=0,c=0,d=E(0);if(!a){return E(1)}if((a|0)>=-99999){b=+(a|0)*3.321928094887362/2e3;c=b+.5;a:{if(F(c)<2147483648){a=~~c;break a}a=-2147483648}d=E(ki(b-+(a|0)))}else{d=E(0)}return d}function $X(a,b){var c=0;c=ib-16|0;ib=c;a:{if(!Ob(x[a>>2],x[a+8>>2],512)){a=0;while(1){if((a|0)!=128){Ho((a<<2)+b|0);a=a+1|0;continue}break}break a}uC(c+8|0,b);sd(c,a,x[c+8>>2],x[c+12>>2])}ib=c+16|0}function yv(a,b){var c=0;c=ib-16|0;ib=c;a:{if(!Ob(x[a>>2],x[a+8>>2],256)){a=0;while(1){if((a|0)!=256){Jh(a+b|0);a=a+1|0;continue}break}break a}cc(c+8|0,b,256);sd(c,a,x[c+8>>2],x[c+12>>2])}ib=c+16|0}function sU(a,b){var c=0,d=0,e=0;c=ib-16|0;ib=c;yU(c+8|0,b);d=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Yb(a,x[c+12>>2])}ib=c+16|0;if((d|0)!=(e|0)){zU(b)}}function y7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ib-16|0;ib=d;a=x[a+4>>2];b=Pg(d,b);x[27524]=0;X(974,a|0,b|0,c|0,1);a=x[27524];x[27524]=0;if((a|0)!=1){wb(b);ib=d+16|0;return}a=P()|0;wb(b);S(a|0);p()}function Sd(a,b){var c=0,d=0,e=0;d=z[a+24>>1];if((d|0)!=(b&65535)){c=z[a+22>>1]-1&127;w[a+22>>1]=c;e=z[a+20>>1];if(e>>>0<=127){w[a+20>>1]=e+1}c=(c<<2)+a|0;w[c+26>>1]=b-d;w[c+28>>1]=0;w[a+24>>1]=b}}function HW(a){var b=0,c=0,d=0;a:{if(Qb(a,21620,11)){break a}c=a+215|0;a=a+63|0;while(1){b=(a|0)==(c|0);if(b|y[a+16|0]>3|y[a+17|0]>3){break a}d=a;a=a+19|0;if(y[d+18|0]<16){continue}break}}return b}function $Q(a,b,c,d,e,f){x[a+40>>2]=0;x[a+44>>2]=0;C[a+32>>3]=f;C[a+24>>3]=e;C[a+16>>3]=d;C[a+8>>3]=c;C[a>>3]=b;x[a+48>>2]=0;x[a+52>>2]=0;x[a+56>>2]=0;x[a+60>>2]=0;a=a- -64|0;x[a>>2]=0;x[a+4>>2]=0}function nj(a){var b=0;b=32767;a:{if(a>=E(32766.5)){break a}b=32768;if(a<=E(-32767.5)){break a}a=E(a+E(.5));b:{if(E(F(a))<E(2147483648)){b=~~a;break b}b=-2147483648}b=b+(b>>15)|0}return b<<16>>16}function Lr(a,b,c,d){var e=0,f=0,g=0;e=b+4|0;g=c;f=x[a>>2];c=x[a+4>>2]-f|0;d=x[e>>2]+D(g,(c|0)/(d|0)|0)|0;x[e>>2]=d;if((c|0)>0){rc(d,f,c)}oc(a,e);oc(a+4|0,b+8|0);oc(Db(a),zc(b));x[b>>2]=x[b+4>>2]}function z6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ib-16|0;ib=d;b=x[b+4>>2];c=Pg(d,c);x[27524]=0;U(960,a|0,b|0,c|0);a=x[27524];x[27524]=0;if((a|0)!=1){wb(c);ib=d+16|0;return}a=P()|0;wb(c);S(a|0);p()}function kT(a,b){var c=0,d=0,e=0;c=ib-16|0;ib=c;IW(c+8|0,b);d=x[c+12>>2];ld(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){gd(a,x[c+12>>2])}ib=c+16|0;a=(d|0)==(e|0);if(!a){JW(b)}return a}function dM(a,b){var c=E(0),d=E(0);if(!((b|0)<0|z[a+480188>>1]<=b>>>0)){a=D(b,872)+a|0;c=E(E(y[a+1075834|0])*E(.0078125));d=E(c*c);c=E(E(y[a+1075835|0])*E(.0078125));c=E(M(E(d+E(c*c))))}return c}function dC(a,b){var c=0,d=0,e=0;c=ib-16|0;ib=c;Oq(c+8|0,b);d=x[c+12>>2];ld(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){gd(a,x[c+12>>2])}ib=c+16|0;a=(d|0)==(e|0);if(!a){cX(b)}return a}function Xu(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function Xj(a,b){var c=0,d=0,e=0;c=ib-16|0;ib=c;dn(c+8|0,b);d=x[c+12>>2];ld(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){gd(a,x[c+12>>2])}ib=c+16|0;a=(d|0)==(e|0);if(!a){Zj(b)}return a}function WG(a,b,c,d){var e=0,f=0;e=ib-16|0;ib=e;Pw(e+8|0,b);f=c;ri(x[e+12>>2],c,d);b=ib-16|0;ib=b;x[b+12>>2]=x[x[e+12>>2]+4>>2];x[b+8>>2]=0;c=x[Ve(b+8|0,b+12|0)>>2];ib=b+16|0;cc(a,f,c);ib=e+16|0}function TT(a,b){var c=0,d=0,e=0;c=ib-16|0;ib=c;PT(c+8|0,b);d=x[c+12>>2];ld(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){gd(a,x[c+12>>2])}ib=c+16|0;a=(d|0)==(e|0);if(!a){QT(b)}return a}function SD(a,b){var c=0,d=0,e=0;c=ib-16|0;ib=c;pr(c+8|0,b);d=x[c+12>>2];ld(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){gd(a,x[c+12>>2])}ib=c+16|0;a=(d|0)==(e|0);if(!a){qr(b)}return a}function R7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=ib-16|0;ib=d;e=x[a+4>>2];a=x[b+4>>2];b=x[b>>2];x[d+8>>2]=b;x[d+12>>2]=a;f=x[c>>2];c=x[c+4>>2];x[d>>2]=b;x[d+4>>2]=a;by(e,d,f,c,1);ib=d+16|0}function MO(a){var b=0,c=0;a=a+906300|0;c=rj(a);while(1){if((a|0)!=(c|0)){b=x[a>>2];a:{if(!b){break a}if(!(lb[x[x[b>>2]+120>>2]](b)|0)){break a}lb[x[x[b>>2]+100>>2]](b)}a=a+160|0;continue}break}}function Ih(a,b){var c=0;c=x[a>>2];a=Xd(b);b=x[c+8>>2];if(tc(b,x[c+12>>2])>>>0>a>>>0){c=x[Bb(b,a)>>2]!=0}else{c=0}if(!c){a=jk(ba(4)|0);x[a>>2]=108652;ha(a|0,108788,1135);p()}return x[Bb(b,a)>>2]}function EE(a,b){var c=0,d=0,e=0;c=ib-16|0;ib=c;CE(c+8|0,b);d=x[c+12>>2];ld(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){gd(a,x[c+12>>2])}ib=c+16|0;a=(d|0)==(e|0);if(!a){fw(b)}return a}function CX(a,b){var c=0,d=0,e=0;c=ib-16|0;ib=c;Zu(c+8|0,b);d=x[c+12>>2];ld(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){gd(a,x[c+12>>2])}ib=c+16|0;a=(d|0)==(e|0);if(!a){lC(b)}return a}function AU(a,b){var c=0,d=0,e=0;c=ib-16|0;ib=c;yU(c+8|0,b);d=x[c+12>>2];ld(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){gd(a,x[c+12>>2])}ib=c+16|0;a=(d|0)==(e|0);if(!a){zU(b)}return a}function gv(a,b,c){var d=0;a=(a&65535)>>>D(c,3)|0;d=a>>>2&1|y[b+12|0]&-8;v[b+12|0]=d|a<<1&6;if(!(!(a>>>9-(c<<1)&1)|(a&3)!=1)){a=y[b+13|0]|y[b+14|0]<<8;v[b+15|0]=a;v[b+16|0]=a>>>8;v[b+12|0]=d|4}}function fC(a,b){var c=0;c=ib-16|0;ib=c;x[c+12>>2]=1;x[c+8>>2]=a>>>4;b=Vb(128/(D(x[Ve(c+12|0,c+8|0)>>2],b)|0)|0,1,15);v[c+7|0]=1;v[c+6|0]=a&15;a=y[mf(c+7|0,c+6|0)|0];ib=c+16|0;return a|b<<4&240}function vI(a){var b=0,c=0,d=0;d=x[a>>2];while(1){c=v[d|0];if(hk(c)){d=d+1|0;x[a>>2]=d;if(b>>>0<=214748364){c=c-48|0;b=D(b,10);b=(c|0)>(b^2147483647)?-1:c+b|0}else{b=-1}continue}break}return b}function hW(a,b,c){var d=0,e=0;d=ib-16|0;ib=d;a=Fh(d,a,b);b=x[a+4>>2];e=x[a+8>>2];while(1){if((b|0)==(e|0)){ic(a);ib=d+16|0}else{Lm(b,z[c>>1]|z[c+2>>1]<<16);b=b+4|0;x[a+4>>2]=b;continue}break}}function YI(a,b){var c=0,d=0,e=0,f=E(0),g=E(0),h=0;b=(b|0)>0?b:0;h=a+2304|0;while(1){if((b|0)!=(d|0)){c=d<<2;e=c+a|0;f=B[e>>2];c=c+h|0;g=B[c>>2];B[e>>2]=f+g;B[c>>2]=f-g;d=d+1|0;continue}break}}function RT(a){var b=0,c=0,d=0,e=0;kb=0;d=y[a+4|0];e=y[a+92|0];c=y[a+94|0]|y[a+95|0]<<8;b=c+y[a+93|0]|0;a=0;a=b>>>0<c>>>0?1:a;c=b;b=e+b|0;a=b>>>0<c>>>0?a+1|0:a;c=b<<2;b=d+c|0;b=b-96|0;return b}function FM(a,b){var c=0,d=0,e=0,f=0;if(a>E(.9999989867210388)){d=0}else{a=E(a*a);c=+a;e=32768/(1-c);f=c;c=gf(31415.926535897932/+b);d=Al(e*(1-(f*c+M(+E(a+a)*(1-c)-+E(a*a)*(1-c*c)))))}return d}function Yy(a,b){var c=0;a=QS(a,b);v[a+12|0]=y[b+12|0];c=y[b+13|0]|y[b+14|0]<<8|(y[b+15|0]<<16|y[b+16|0]<<24);v[a+13|0]=c;v[a+14|0]=c>>>8;v[a+15|0]=c>>>16;v[a+16|0]=c>>>24;v[a+17|0]=y[b+17|0]}function wg(a,b){var c=0,d=0;c=ib-16|0;ib=c;x[c+12>>2]=b;d=b;b=zh(1073741823);if(d>>>0<=b>>>0){a=_h(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[Yc(c+8|0,c+12|0)>>2]}ib=c+16|0;return b}_c();p()}function vj(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;a:{d=sl(a,b);if((d|0)==255){break a}pk(a,b);jq(a,b,0,0);if(!c){break a}e=bc(a+26|0,d),f=65535,w[e>>1]=f;a=Jb(a+62|0,b);v[a|0]=y[a|0]|128}}function ip(a,b,c,d,e,f){var g=0,h=0;tg(a+12|0,d);if(b){if(b>>>0>=f>>>0){Vg();p()}d=mc(D(b,e))}else{d=0}x[a>>2]=d;c=d+D(c,e)|0;x[a+8>>2]=c;x[a+4>>2]=c;g=zc(a),h=d+D(b,e)|0,x[g>>2]=h;return a}function gG(a){a=a|0;var b=0,c=0,d=0;x[a>>2]=98472;d=a+8|0;while(1){b=x[a+8>>2];if(tc(b,x[a+12>>2])>>>0>c>>>0){b=x[Bb(b,c)>>2];if(b){ln(b)}c=c+1|0;continue}break}wb(a+152|0);CG(d);return a|0}function aK(){var a=0,b=0,c=0,d=0;a=ib-16|0;ib=a;b=mc(1298480);x[27524]=0;c=T(1086,b|0)|0;d=x[27524];x[27524]=0;if((d|0)!=1){b=x[uf(a+8|0,c)>>2];ib=a+16|0;return b|0}a=P()|0;Ib(b);S(a|0);p()}function Vj(a,b){var c=0,d=0;c=ib-16|0;ib=c;x[c+12>>2]=b;d=b;b=zh(2147483647);if(d>>>0<=b>>>0){a=_m(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[Yc(c+8|0,c+12|0)>>2]}ib=c+16|0;return b}_c();p()}function xr(a,b){var c=0,d=0;c=ib-16|0;ib=c;x[c+12>>2]=b;d=b;b=zh(536870911);if(d>>>0<=b>>>0){a=mn(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[Yc(c+8|0,c+12|0)>>2]}ib=c+16|0;return b}_c();p()}function xS(a,b){var c=0,d=0;c=ib-16|0;ib=c;x[c+12>>2]=b;d=b;b=zh(268435455);if(d>>>0<=b>>>0){a=du(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[Yc(c+8|0,c+12|0)>>2]}ib=c+16|0;return b}_c();p()}function pB(a,b){var c=0,d=0;c=ib-16|0;ib=c;x[c+12>>2]=b;d=b;b=zh(715827882);if(d>>>0<=b>>>0){a=Wu(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[Yc(c+8|0,c+12|0)>>2]}ib=c+16|0;return b}_c();p()}function oq(a,b){var c=0,d=0;c=ib-16|0;ib=c;x[c+12>>2]=b;d=b;b=zh(134217727);if(d>>>0<=b>>>0){a=oo(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[Yc(c+8|0,c+12|0)>>2]}ib=c+16|0;return b}_c();p()}function on(a,b){var c=0,d=0;c=ib-16|0;ib=c;x[c+12>>2]=b;d=b;b=zh(357913941);if(d>>>0<=b>>>0){a=ak(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[Yc(c+8|0,c+12|0)>>2]}ib=c+16|0;return b}_c();p()}function oea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=ib-16|0;ib=d;e=z[a+28>>1];w[d+8>>1]=e;f=d,g=(tc(x[a+4>>2],x[a+8>>2])+e|0)-1|0,w[f+10>>1]=g;a=VN(a,b,c,d+8|0);ib=d+16|0;return a|0}function fE(a,b){var c=0,d=0;c=ib-16|0;ib=c;x[c+12>>2]=b;d=b;b=zh(119304647);if(d>>>0<=b>>>0){a=Vv(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[Yc(c+8|0,c+12|0)>>2]}ib=c+16|0;return b}_c();p()}function WA(a,b,c,d){var e=0,f=0,g=0;e=ib-16|0;ib=e;f=x[b+12>>2];x[e+8>>2]=c;x[e+12>>2]=d;g=x[x[b>>2]+28>>2];x[e>>2]=c;x[e+4>>2]=d;lb[g|0](a,b,f,e);x[b+12>>2]=x[b+12>>2]+x[a+4>>2];ib=e+16|0}function VE(a,b){var c=0,d=0;c=ib-16|0;ib=c;x[c+12>>2]=b;d=b;b=zh(178956970);if(d>>>0<=b>>>0){a=Jr(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[Yc(c+8|0,c+12|0)>>2]}ib=c+16|0;return b}_c();p()}function VB(a,b){var c=0,d=0;c=ib-16|0;ib=c;x[c+12>>2]=b;d=b;b=zh(214748364);if(d>>>0<=b>>>0){a=XC(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[Yc(c+8|0,c+12|0)>>2]}ib=c+16|0;return b}_c();p()}function KB(a,b){var c=0,d=0,e=0;c=ib-16|0;ib=c;d=c,e=(xp(b)+-4.8737671609324025)*(a&32768?28.85390081777927:34.624680981335125),C[d+8>>3]=e;uQ(c+8|0,127);a=Ak(C[c+8>>3]);ib=c+16|0;return a}function vC(a,b){var c=0,d=0;c=ib-16|0;ib=c;Lo(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Yb(a,x[c+12>>2])}ib=c+16|0;return(b|0)==(d|0)}function uV(a,b){var c=0,d=0;c=ib-16|0;ib=c;tV(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Yb(a,x[c+12>>2])}ib=c+16|0;return(b|0)==(d|0)}function rU(a,b){var c=0,d=0;c=ib-16|0;ib=c;qU(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Yb(a,x[c+12>>2])}ib=c+16|0;return(b|0)==(d|0)}function qX(a,b){var c=0,d=0;c=ib-16|0;ib=c;uv(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Yb(a,x[c+12>>2])}ib=c+16|0;return(b|0)==(d|0)}function ot(a){var b=0;x[27524]=0;a=T(818,a|0)|0;b=x[27524];x[27524]=0;a:{if((b|0)==1){_(V(0)|0)|0;x[27524]=0;Z(18);b=x[27524];x[27524]=0;a=0;if((b|0)==1){break a}}return a}V(0)|0;Sb();p()}function h8(a,b){a=a|0;b=b|0;var c=0;c=ib-16|0;ib=c;dK(c,b);a=x[a+1298472>>2];x[27524]=0;U(380,a|0,1,c|0);a=x[27524];x[27524]=0;if((a|0)!=1){xb(c);ib=c+16|0;return}a=P()|0;xb(c);S(a|0);p()}function gX(a,b){var c=0,d=0;c=ib-16|0;ib=c;Zu(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Yb(a,x[c+12>>2])}ib=c+16|0;return(b|0)==(d|0)}function fv(a,b){var c=0,d=0;c=ib-16|0;ib=c;Ko(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Yb(a,x[c+12>>2])}ib=c+16|0;return(b|0)==(d|0)}function au(a){var b=0;a:{if(Qb(a,13549,4)|y[a+4|0]){break a}if(Fb(y[a+6|0]|y[a+7|0]<<8)>>>0>1){break a}if(Fb(y[a+12|0]|y[a+13|0]<<8)){break a}b=(Fb(y[a+16|0]|y[a+17|0]<<8)|0)==20}return b}function aX(a,b){var c=0,d=0;c=ib-16|0;ib=c;_u(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Yb(a,x[c+12>>2])}ib=c+16|0;return(b|0)==(d|0)}function aE(a,b){var c=0,d=0;c=ib-16|0;ib=c;CE(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Yb(a,x[c+12>>2])}ib=c+16|0;return(b|0)==(d|0)}function _C(a){var b=0;b=x[a+72>>2];x[a+72>>2]=b-1|b;b=x[a>>2];if(b&8){x[a>>2]=b|32;return-1}x[a+4>>2]=0;x[a+8>>2]=0;b=x[a+44>>2];x[a+28>>2]=b;x[a+20>>2]=b;x[a+16>>2]=b+x[a+48>>2];return 0}function Zo(a,b){var c=0,d=0;c=ib-16|0;ib=c;Ph(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Yb(a,x[c+12>>2])}ib=c+16|0;return(b|0)==(d|0)}function YT(a,b){var c=0,d=0;c=ib-16|0;ib=c;cB(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Yb(a,x[c+12>>2])}ib=c+16|0;return(b|0)==(d|0)}function Vo(a,b){var c=0,d=0;c=ib-16|0;ib=c;Zm(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Yb(a,x[c+12>>2])}ib=c+16|0;return(b|0)==(d|0)}function TD(a,b){var c=0,d=0;c=ib-16|0;ib=c;pr(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Yb(a,x[c+12>>2])}ib=c+16|0;return(b|0)==(d|0)}function Or(a,b,c){var d=0;d=ib-16|0;ib=d;cc(d+8|0,b,c);b=x[d+12>>2];kc(d,x[a>>2],x[a+8>>2],x[d+8>>2],x[d+12>>2]);c=x[d+4>>2];if((b|0)==(c|0)){Yb(a,x[d+12>>2])}ib=d+16|0;return(b|0)==(c|0)}function Hg(a,b){var c=0,d=0;c=ib-16|0;ib=c;gr(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Yb(a,x[c+12>>2])}ib=c+16|0;return(b|0)==(d|0)}function HC(a,b){var c=0,d=0;c=ib-16|0;ib=c;GC(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Yb(a,x[c+12>>2])}ib=c+16|0;return(b|0)==(d|0)}function FP(a,b,c){var d=0,e=0;d=ib-16|0;ib=d;a=ur(d,a,b);b=x[a+4>>2];e=x[a+8>>2];while(1){if((b|0)==(e|0)){ic(a);ib=d+16|0}else{EP(b,x[c>>2],x[c+4>>2]);b=b+8|0;x[a+4>>2]=b;continue}break}}function AH(a,b,c,d){a:{if(!a){break a}b:{switch(b+2|0){case 0:v[a|0]=c;return;case 1:w[a>>1]=c;return;case 2:case 3:x[a>>2]=c;return;case 5:break b;default:break a}}x[a>>2]=c;x[a+4>>2]=d}}function $W(a,b){var c=0,d=0;c=ib-16|0;ib=c;Oq(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Yb(a,x[c+12>>2])}ib=c+16|0;return(b|0)==(d|0)}function $N(a,b){var c=0,d=0;c=ib-16|0;ib=c;x[c+12>>2]=b;d=b;b=zh(82595524);if(d>>>0<=b>>>0){a=rt(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[Yc(c+8|0,c+12|0)>>2]}ib=c+16|0;return b}_c();p()}function lx(a,b,c,d,e,f,g,h,i){var j=0;j=ib-16|0;ib=j;Ng(j,b,c,d,e,f,g,h,i^-2147483648);d=x[j>>2];c=x[j+4>>2];b=x[j+12>>2];x[a+8>>2]=x[j+8>>2];x[a+12>>2]=b;x[a>>2]=d;x[a+4>>2]=c;ib=j+16|0}function GA(a,b){var c=0,d=0;d=ib-32|0;ib=d;c=Db(a);c=cg(d+8|0,wg(a,tc(x[a>>2],x[a+4>>2])+1|0),tc(x[a>>2],x[a+4>>2]),c);pq(x[c+8>>2],x[b>>2]);x[c+8>>2]=x[c+8>>2]+4;Dd(a,c);bg(c);ib=d+32|0}function FR(a){a=a|0;var b=0,c=0;b=ib-32|0;ib=b;v[a+16|0]=0;c=hA(b,x[a+12>>2]);x[27524]=0;R(759,a|0,c|0);a=x[27524];x[27524]=0;if((a|0)!=1){tl(c);ib=b+32|0;return}a=P()|0;tl(c);S(a|0);p()}function un(a,b){var c=0,d=0,e=0;a:{c=uH(b);if(c>>>0<1073741808){b:{if(js(c)){ee(a,c);break b}d=fm(c)+1|0;e=Ii(d);td(a,e);hf(a,d);vd(a,c);a=e}ui(a,b,c);td((c<<2)+a|0,0);break a}of();p()}}function jG(a,b){var c=0,d=0;d=ib-32|0;ib=d;c=Db(a);c=am(d+8|0,Zl(a,cd(x[a>>2],x[a+4>>2])+1|0),cd(x[a>>2],x[a+4>>2]),c);Uk(x[c+8>>2],y[b|0]);x[c+8>>2]=x[c+8>>2]+1;Dd(a,c);$l(c);ib=d+32|0}function cS(a){var b=0,c=0;a:{b:{c=a&240;if((c|0)!=192){if((c|0)==240){break b}b=3;if((c|0)!=208){break a}}b=2;break a}a=a+15&255;b=1;if(a>>>0>2){break a}b=131842>>>(a<<3)|0}return b&255}function M2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;if(d>>>0<4294967280){a:{if(Dl(d)){ee(a,c);break a}e=Wg(d)+1|0;d=mc(e);td(a,d);hf(a,e);vd(a,c);a=d}ne(Ae(a,b,c)+c|0,0);return}of();p()}function raa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=ib-16|0;ib=f;x[f+8>>2]=x[a+8>>2];g=x[a+4>>2];x[f>>2]=x[a>>2];x[f+4>>2]=g;a=tM(f,b,c,d,0,0,0,0,e);ib=f+16|0;return a|0}function L2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=x[a+84>>2];d=c+256|0;f=at(e,0,d);d=f?f-e|0:d;c=c>>>0>d>>>0?d:c;rc(b,e,c);b=e+d|0;x[a+84>>2]=b;x[a+8>>2]=b;x[a+4>>2]=c+e;return c|0}function Fg(a,b){a=a|0;b=b|0;var c=0,d=0;c=ib+-64|0;ib=c;d=Ey(c+8|0,a);x[27524]=0;U(205,a|0,b|0,d|0);a=x[27524];x[27524]=0;if((a|0)!=1){ll(d);ib=c- -64|0;return}a=P()|0;ll(d);S(a|0);p()}function Ei(a,b){var c=0,d=0;c=y[a|0];d=y[b|0];a:{if(!c|(d|0)!=(c|0)){break a}while(1){d=y[b+1|0];c=y[a+1|0];if(!c){break a}b=b+1|0;a=a+1|0;if((c|0)==(d|0)){continue}break}}return c-d|0}function CV(a,b,c,d){var e=0;e=ib-16|0;ib=e;x[e+12>>2]=b;x[e+8>>2]=d;c=Rp(a,c,x[Hb(e+12|0,e+8|0)>>2]);a:{if(c){break a}c=0;if((b|0)==(d|0)){break a}c=b>>>0<d>>>0?-1:1}ib=e+16|0;return c}function py(a){var b=0,c=0,d=0;C[a+4272>>3]=C[a+4280>>3];c=a;d=a+4296|0;a=0;while(1){if(a>>>0<32){a=a+15|0;b=Wn(d)|b<<15;continue}break}C[c+4280>>3]=E(E(b|0)*E(-4.656612873077393e-10))}function Q1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=ib-16|0;ib=g;x[g+8>>2]=624576549;x[g+12>>2]=1394948685;h=a;a=g+16|0;b=fk(h,b,c,d,e,f,g+8|0,a);ib=a;return b|0}function OV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ib-16|0;ib=c;dg(a,c+14|0);e=z[c+14>>1];RO(b,e);while(1){if((d|0)==(e|0)){$y(b);ib=c+16|0}else{wk(a,Bb(x[b>>2],d));d=d+1|0;continue}break}}function _la(a,b){a=a|0;b=b|0;var c=0,d=0;c=ib-16|0;ib=c;d=Ob(x[a>>2],x[a+8>>2],12);a:{if(!d){v[c|0]=0;hi(b,12,c);break a}Oq(c+8|0,b);sd(c,a,x[c+8>>2],x[c+12>>2])}ib=c+16|0;return d|0}function Ln(a){var b=0,c=0;b=ib-16|0;ib=b;a:{if(!QJ(y[a+20|0])){x[27524]=0;R(1091,b+8|0,a|0);c=x[27524];x[27524]=0;if((c|0)==1){break a}}v[a+20|0]=255;ib=b+16|0;return}V(0)|0;Sb();p()}function Js(a){var b=0,c=0,d=0;c=1;while(1){if(c){c=0;b=x[a+4>>2];d=((b<<2)+(Hv(x[a>>2],1)^270549120)|0)+2019860093|0;x[a>>2]=d;b=b+D(Hv(d,16),5)|0;x[a+4>>2]=b;continue}break}return b}function A5(a,b){a=a|0;b=b|0;var c=0,d=0;c=ib-16|0;ib=c;d=x[18267];x[c+8>>2]=x[18266];x[c+12>>2]=d;d=x[18265];x[c>>2]=x[18264];x[c+4>>2]=d;lb[x[Dp(c,ik(y[b+20|0]))>>2]](a,b);ib=c+16|0}function xh(a,b,c){a:{if(b>>>0<=c>>>0){a=ba(8)|0;x[27524]=0;b=T(197,a|0)|0;c=x[27524];x[27524]=0;if((c|0)!=1){break a}b=P()|0;ca(a|0);S(b|0);p()}return y[a+c|0]}ha(b|0,26072,172);p()}function Zl(a,b){var c=0,d=0;c=ib-16|0;ib=c;x[c+12>>2]=b;d=b;b=zh(-1);if(d>>>0<=b>>>0){a=sp(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[Yc(c+8|0,c+12|0)>>2]}ib=c+16|0;return b}_c();p()}function Yh(a){var b=0;a=$h(a);b=2147483647;a:{if(a>=E(2147483648)){break a}b=-2147483648;if(a<=E(-2147483648)){break a}b=~~a;if(E(F(a))<E(2147483648)){break a}b=-2147483648}return b}function dma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ib-16|0;ib=d;pV(b,c);c=Ob(x[a>>2],x[a+8>>2],c<<2);if(c){oV(d+8|0,x[b>>2],x[b+4>>2]);sd(d,a,x[d+8>>2],x[d+12>>2])}ib=d+16|0;return c|0}function dia(a,b){a=a|0;b=b|0;var c=0,d=0;c=ib-16|0;ib=c;d=Ob(x[a>>2],x[a+8>>2],4);a:{if(!d){v[c|0]=0;XD(b,4,c);break a}Ph(c+8|0,b);sd(c,a,x[c+8>>2],x[c+12>>2])}ib=c+16|0;return d|0}function cg(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;tg(a+12|0,d);if(b){d=Ii(b)}else{d=0}x[a>>2]=d;c=d+(c<<2)|0;x[a+8>>2]=c;x[a+4>>2]=c;e=zc(a),f=d+(b<<2)|0,x[e>>2]=f;return a|0}function bm(a,b){x[a+28>>2]=0;w[a+24>>1]=65535;x[a+16>>2]=0;x[a+20>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;v[a|0]=0;x[a+32>>2]=11;x[a+36>>2]=b;Nb(a+40|0);Nb(a+52|0);Rb(a- -64|0,0,48);return a}function DM(a,b,c,d,e){a=a|0;b=b|0;c=+c;d=d|0;e=e|0;var f=0,g=0;f=ib-16|0;ib=f;x[f+8>>2]=x[a+8>>2];g=x[a+4>>2];x[f>>2]=x[a>>2];x[f+4>>2]=g;c=CM(f,b,c,d,e,0,0,0,0);ib=f+16|0;return+c}function ut(a,b){var c=0;a=qP(a);x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=x[b+12>>2];x[a+16>>2]=x[b+16>>2];c=x[b+28>>2];x[a+24>>2]=x[b+24>>2];x[a+28>>2]=c}function iw(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=ib-16|0;ib=e;x[e+12>>2]=d;d=Eb(b);if(d>>>0<c>>>0){yk();p()}b=Jc(b);x[e+8>>2]=d-c;Lu(a,b+c|0,x[Hb(e+12|0,e+8|0)>>2]);ib=e+16|0}function Tz(a){var b=0,c=0;b=x[a>>2];c=x[b>>2];a:{if(!c){while(1){c=Hh(b);b=x[b+8>>2];if(c){continue}break}break a}while(1){b=c;c=x[b+4>>2];if(c){continue}break}}x[a>>2]=b;return a}function OZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ib-16|0;ib=d;lE(b,c);c=Ob(x[a>>2],x[a+8>>2],c<<3);if(c){kE(d+8|0,x[b>>2],x[b+4>>2]);sd(d,a,x[d+8>>2],x[d+12>>2])}ib=d+16|0;return c|0}function Ks(a){var b=0,c=0,d=0;b=ib-16|0;ib=b;x[b+12>>2]=12;while(1){x[b+8>>2]=32;if(A[Hb(b+12|0,b+8|0)>>2]<=c>>>0){ib=b+16|0;a=d&4095}else{c=c+15|0;d=Wn(a);continue}break}return a}function F_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=ib-16|0;ib=e;g=x[a+4>>2];f=x[b+4>>2];a=x[b>>2];x[e>>2]=a;x[e+4>>2]=f;x[e+8>>2]=a;x[e+12>>2]=f;cy(g,e,c,d,1);ib=e+16|0}function EZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ib-16|0;ib=d;x[d+12>>2]=c;c=0;a=lb[x[x[a>>2]+24>>2]](a)|0;if(a>>>0>b>>>0){x[d+8>>2]=a-b;c=x[Hb(d+12|0,d+8|0)>>2]}ib=d+16|0;return c|0}function lQ(a,b,c,d){a:{if((a|0)!=67108864){break a}a=D(d,872)+c|0;x[a+704>>2]=x[a+704>>2]&-129;a=d^1;if(a>>>0>=(b&65535)>>>0){break a}a=D(a,872)+c|0;x[a+704>>2]=x[a+704>>2]&-129}}function gia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ib-16|0;ib=d;PS(b,c);if(Ob(x[a>>2],x[a+8>>2],c<<8)){c=x[b>>2];cc(d+8|0,c,Gh(c,x[b+4>>2])<<8);sd(d,a,x[d+8>>2],x[d+12>>2])}ib=d+16|0}function NZ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;d=!b|(b>>>0>d>>>0|a>>>0>=d>>>0|d-a>>>0<b>>>0);a:{if(d){break a}a=a+b|0;if(cd(x[c>>2],x[c+4>>2])>>>0>=a>>>0){break a}Yi(c,a)}return!d|0}function G_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ib-16|0;ib=c;e=x[a+4>>2];d=x[b+4>>2];a=x[b>>2];x[c>>2]=a;x[c+4>>2]=d;x[c+8>>2]=a;x[c+12>>2]=d;a=mM(e,c,1);ib=c+16|0;jb=kb;return a|0}function zO(a){var b=0,c=0,d=0;b=ib-16|0;ib=b;while(1){x[b+12>>2]=7;x[b+8>>2]=32;if(A[Hb(b+12|0,b+8|0)>>2]<=c>>>0){ib=b+16|0;a=d&127}else{c=c+15|0;d=Wn(a);continue}break}return a}function ZC(a,b,c){var d=0,e=0;d=ib-16|0;ib=d;a=Fh(d,a,b);b=x[a+4>>2];e=x[a+8>>2];while(1){if((b|0)==(e|0)){ic(a);ib=d+16|0}else{pq(b,x[c>>2]);b=b+4|0;x[a+4>>2]=b;continue}break}}function No(a,b,c){var d=0,e=0;d=ib-16|0;ib=d;a=ei(d,a,b);b=x[a+4>>2];e=x[a+8>>2];while(1){if((b|0)==(e|0)){ic(a);ib=d+16|0}else{Pj(b,z[c>>1]);b=b+2|0;x[a+4>>2]=b;continue}break}}function Du(a,b){var c=0;c=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);v[a|0]=c;v[a+1|0]=c>>>8;v[a+2|0]=c>>>16;v[a+3|0]=c>>>24;b=y[b+4|0]|y[b+5|0]<<8;v[a+4|0]=b;v[a+5|0]=b>>>8}function Cy(a,b,c){var d=0,e=0;d=ib-16|0;ib=d;a=Fh(d,a,b);b=x[a+4>>2];e=x[a+8>>2];while(1){if((b|0)==(e|0)){ic(a);ib=d+16|0}else{lk(b,B[c>>2]);b=b+4|0;x[a+4>>2]=b;continue}break}}function xl(a,b){var c=0,d=0,e=0;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];c=Db(b);d=Db(a),e=x[c>>2],x[d>>2]=e;x[c>>2]=0;x[b>>2]=0;x[b+4>>2]=0;return a}function fD(a){var b=0,c=0;a:{if(Qb(a,14172,3)){break a}b=y[a+3|0];b:{if(b>>>0<=7){if((b|0)==1){break b}break a}if(b>>>0>14){break a}}c=(y[a+40|0]-1&255)>>>0<32|b>>>0<9}return c}function Vaa(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=0,f=E(0);if(b>>>0<=12){c=Ld(c,E(0));d=a+4208|0;if((b|0)==12){c=E($h(E(c*E(3)))/E(3));b=12}e=Bb(d,b),f=c,B[e>>2]=f;v[a+5046|0]=1}}function To(a,b,c){var d=0,e=0;d=ib-16|0;ib=d;a=_l(d,a,b);b=x[a+4>>2];e=x[a+8>>2];while(1){if((b|0)==(e|0)){ic(a);ib=d+16|0}else{Uk(b,y[c|0]);b=b+1|0;x[a+4>>2]=b;continue}break}}function Sla(a,b){a=a|0;b=b|0;var c=0;c=ib-32|0;ib=c;x[c+24>>2]=0;x[c+28>>2]=0;x[c+16>>2]=0;x[c+20>>2]=0;x[c+8>>2]=0;x[c+12>>2]=0;x[c>>2]=0;x[c+4>>2]=0;NV(b,c);MV(a,c);ib=c+32|0}function Nda(a,b){a=a|0;b=b|0;var c=0,d=0;d=ib-32|0;ib=d;c=-1;a:{if(!EE(a,d+8|0)){break a}c=0;if(!iO(d+8|0)|(x[d+16>>2]!=x[b>>2]|x[b+4>>2]?b:0)){break a}c=1}ib=d+32|0;return c|0}function F$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){a=x[b>>2];if(a>>>0<=127){a=x[(a<<2)+98544>>2]}else{a=0}x[d>>2]=a;d=d+4|0;b=b+4|0;continue}break}return c|0}function Ac(a,b){var c=0,d=0;c=ib-16|0;ib=c;if(kf(a)){Ib(x[a>>2])}d=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=d;x[a+8>>2]=x[b+8>>2];ee(b,0);v[c+15|0]=0;oe(b,c+15|0);ib=c+16|0;return a}function NE(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=zl(a);d=xd(x[a+4>>2],y[a+11|0]);e=d+1|0;if((c|0)==(d|0)){cz(a,c,e-c|0,c,c,0)}c=nd(a);hJ(c+d|0,1,b);zq(a,e);ne(c+e|0,0);return a|0}function MQ(a,b,c,d){var e=0,f=0;e=ib-16|0;ib=e;while(1){if(c){f=ql(z[c+16>>1],x[c+20>>2],a,b);d=f?d:c;c=x[(f?c+4|0:c)>>2];continue}break}a=x[Wb(e+8|0,d)>>2];ib=e+16|0;return a}function KE(a){var b=0;a:{b:{if(a>>>0>=18285141){if(a>>>0>18350591){break b}b=1;if((a|0)!=18350080){break a}}return 0}b=0;if((a|0)==18350592){break a}b=(a&-256)!=(a|0)}return b}function jna(a,b){a=a|0;b=b|0;if(!$W(a,b)){v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+8|0]=0;v[b+9|0]=0;v[b+10|0]=0;v[b+11|0]=0}}function N4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ib-16|0;ib=d;x[d+12>>2]=c;Lx(a,b,c);c=0;a=x[a+16>>2];if(a>>>0>b>>>0){x[d+8>>2]=a-b;c=x[Hb(d+8|0,d+12|0)>>2]}ib=d+16|0;return c|0}function Kp(a){var b=0;b=x[a+24>>2];x[27524]=0;Y(819,b|0);b=x[27524];x[27524]=0;if((b|0)!=1){ve(a+68|0);nf(a+36|0);hl(a+32|0);lh(a+24|0);kh(a+4|0);return Xc(a)}V(0)|0;Sb();p()}function Hm(a){var b=0,c=0;b=x[27280];c=a+7&-8;a=b+c|0;a:{if(a>>>0<=b>>>0?c:0){break a}if(a>>>0>mb()<<16>>>0){if(!(fb(a|0)|0)){break a}}x[27280]=a;return b}x[12e4]=48;return-1}function i$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ib-16|0;ib=d;lb[x[x[a>>2]+12>>2]](d+8|0,a,b);a=x[d+8>>2];b=x[c>>2];a=pc(x[d+12>>2],x[c+4>>2])&(a|0)==(b|0);ib=d+16|0;return a|0}function QO(a,b){a=a|0;b=b|0;var c=0;c=ib-16|0;ib=c;OO(c,b+80|0);x[27524]=0;U(11,a|0,0,c|0);a=x[27524];x[27524]=0;if((a|0)!=1){wb(c);ib=c+16|0;return}a=P()|0;wb(c);S(a|0);p()}function Bia(a,b){a=a|0;b=b|0;var c=0;c=ib-16|0;ib=c;b=-1;a:{if(!Xj(a,c+8|0)){break a}b=0;if(!RS(c+8|0)){break a}b=-1;if(!kg(a,4)){break a}b=oT(a)>>>31|0}ib=c+16|0;return b|0}function Sq(a,b){a=a|0;b=b|0;var c=0,d=0;c=x[a>>2];d=x[a+4>>2];if(Oc(c,d)>>>0>b>>>0){a=x[a+24>>2];b=Ml(c,d,b);a=Ce(x[a+484344>>2],x[a+484348>>2],z[b>>1])}else{a=0}return a|0}function Ema(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ib-16|0;ib=d;a:{if(a){lb[x[x[a>>2]+8>>2]](a,b,c);break a}if((b|0)>=6){break a}VO(d,9101,10800,171,42);AE(a,d,b,a,c)}ib=d+16|0}function uB(a,b,c){var d=0,e=0;d=ib-16|0;ib=d;a=Rq(d,a,b);b=x[a+4>>2];e=x[a+8>>2];while(1){if((b|0)==(e|0)){ic(a);ib=d+16|0}else{Du(b,c);b=b+6|0;x[a+4>>2]=b;continue}break}}function qv(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ib-16|0;ib=d;Yi(b,c);if(Ob(x[a>>2],x[a+8>>2],c)){c=x[b>>2];cc(d+8|0,c,cd(c,x[b+4>>2]));sd(d,a,x[d+8>>2],x[d+12>>2])}ib=d+16|0}function nT(a,b){var c=0,d=0;c=ib-16|0;ib=c;Ph(c+8|0,b);b=x[c+12>>2];ld(c,a,x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){gd(a,x[c+12>>2])}ib=c+16|0;return(b|0)==(d|0)}function ida(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=ib-16|0;ib=e;f=x[c>>2];if(f>>>0<cd(a,b)>>>0){a=Tk(e,Jb(a,f),z[c+20>>1]);g=Bw(d,a);Zb(a)}ib=e+16|0;return g|0}function de(a,b){var c=0;a:{c=xf(b);if((c|0)==(Eb(a)|0)){x[27524]=0;a=W(365,a|0,b|0,c|0)|0;b=x[27524];x[27524]=0;if((b|0)==1){break a}a=!a}else{a=0}return a}V(0)|0;Sb();p()}function cja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ib-16|0;ib=d;x[d+8>>2]=b;while(1){if(Mb(b,c)){x[d+4>>2]=x[b>>2];VA(a,d+4|0);b=x[Pe(d+8|0)>>2];continue}else{ib=d+16|0}break}}function TW(a){var b=0;a:{if(Qb(a,16694,4)){break a}if(ac(y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24))-257>>>0<4294967053){break a}b=!Fb(y[a+8|0]|y[a+9|0]<<8)}return b}function Ig(a,b,c,d){var e=0;a=((b|0)/8|0)+a|0;e=xh(x[d>>2],x[d+4>>2],a);return((xh(x[d>>2],x[d+4>>2],a+1|0)<<8|e<<16|xh(x[d>>2],x[d+4>>2],a+2|0))<<(b&7)&16777215)>>>24-c|0}function am(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;tg(a+12|0,d);if(b){d=mc(b)}else{d=0}x[a>>2]=d;c=c+d|0;x[a+8>>2]=c;x[a+4>>2]=c;e=zc(a),f=b+d|0,x[e>>2]=f;return a|0}function Sh(a,b){a=a|0;b=b|0;var c=0;c=ib-32|0;ib=c;v[c+24|0]=0;fj(c+8|0,c+24|0);Bn(c+16|0,a,x[c+8>>2],x[c+12>>2]);a=x[c+20>>2];v[b|0]=y[c+24|0];ib=c+32|0;return(a|0)==1|0}function Pka(){var a=0,b=0,c=0;a=ib-16|0;ib=a;b=mc(1);x[27524]=0;Z(32);c=x[27524];x[27524]=0;if((c|0)!=1){b=x[uf(a+8|0,b)>>2];ib=a+16|0;return b|0}a=P()|0;Ib(b);S(a|0);p()}function N6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ib-16|0;ib=c;d=x[a+4>>2];a=x[b+4>>2];b=x[b>>2];x[c>>2]=b;x[c+4>>2]=a;x[c+8>>2]=b;x[c+12>>2]=a;e=nM(d,c,1);ib=c+16|0;return+e}function pf(a,b,c){var d=0,e=0,f=0;d=ib-16|0;ib=d;x[d+8>>2]=c;x[d+4>>2]=31;e=d,f=NX(b,c),x[e+12>>2]=f;c=b;b=pC(d+4|0);wh(c,c+b|0,a);e=Jb(a,b),f=0,v[e|0]=f;PX(a);ib=d+16|0}function j_(a){a=a|0;var b=0,c=0;b=ib-16|0;ib=b;cE(b,0,a);x[27524]=0;a=T(129,b|0)|0;c=x[27524];x[27524]=0;if((c|0)!=1){wb(b);ib=b+16|0;return a|0}a=P()|0;wb(b);S(a|0);p()}function Hna(a,b){a=a|0;b=b|0;var c=0;c=ib-16|0;ib=c;dn(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);if((b|0)==x[c+4>>2]){Yb(a,x[c+12>>2])}ib=c+16|0}function FD(a,b,c){var d=0,e=0;a:{b:{if(Dl(c)){ee(a,c);break b}if(c>>>0>=4294967280){break a}d=Wg(c)+1|0;e=mc(d);td(a,e);hf(a,d);vd(a,c);a=e}Ae(a,b,c+1|0);return}of();p()}function D$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a:{while(1){if((c|0)==(d|0)){break a}a=x[c>>2];if(!(a>>>0>127|!(x[(a<<2)+98544>>2]&b))){c=c+4|0;continue}break}d=c}return d|0}function m7(a,b){a=a|0;b=b|0;var c=0,d=0;c=ib-16|0;ib=c;d=x[a+4>>2];a=x[b+4>>2];b=x[b>>2];x[c>>2]=b;x[c+4>>2]=a;x[c+8>>2]=b;x[c+12>>2]=a;a=oM(d,c,1);ib=c+16|0;return a|0}function km(a){a=a<<8&16711680|a<<24|(a>>>8&65280|a>>>24);a=a>>>4&252645135|(a&252645135)<<4;a=a>>>2&858993459|(a&858993459)<<2;return a>>>1&1431655765|(a&1431655765)<<1}function Vea(a,b){a=a|0;b=b|0;var c=0,d=0;c=ib-16|0;ib=c;d=Ob(x[a>>2],x[a+8>>2],16);a:{if(!d){SC(b);break a}uv(c+8|0,b);sd(c,a,x[c+8>>2],x[c+12>>2])}ib=c+16|0;return d|0}function QF(a,b,c){var d=0;a:{if(!a){a=ba(8)|0;x[27524]=0;c=T(c|0,a|0)|0;d=x[27524];x[27524]=0;if((d|0)!=1){break a}b=P()|0;ca(a|0);S(b|0);p()}return}ha(c|0,b|0,962);p()}function FZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=lb[x[x[a>>2]+24>>2]](a)|0;a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function Ew(a,b,c,d,e){var f=0;a:{f=ot(4332);if(f){x[27524]=0;ja(e|0,f|0,a|0,b|0,c|0,d|0)|0;a=x[27524];x[27524]=0;if((a|0)==1){break a}}return f}a=P()|0;Ib(f);S(a|0);p()}function lB(a,b){var c=0,d=0;c=ib-16|0;ib=c;a=Fh(c,a,b);b=x[a+4>>2];d=x[a+8>>2];while(1){if((b|0)==(d|0)){ic(a);ib=c+16|0}else{Ho(b);b=b+4|0;x[a+4>>2]=b;continue}break}}function XE(a,b){var c=0,d=0;c=ib-16|0;ib=c;a=_l(c,a,b);b=x[a+4>>2];d=x[a+8>>2];while(1){if((b|0)==(d|0)){ic(a);ib=c+16|0}else{WE(b);b=b+1|0;x[a+4>>2]=b;continue}break}}function UC(a,b){var c=0,d=0;c=ib-16|0;ib=c;a=ei(c,a,b);b=x[a+4>>2];d=x[a+8>>2];while(1){if((b|0)==(d|0)){ic(a);ib=c+16|0}else{Nv(b);b=b+2|0;x[a+4>>2]=b;continue}break}}function Tt(a,b){var c=0,d=0;c=ib-16|0;ib=c;a=Fh(c,a,b);b=x[a+4>>2];d=x[a+8>>2];while(1){if((b|0)==(d|0)){ic(a);ib=c+16|0}else{fS(b);b=b+4|0;x[a+4>>2]=b;continue}break}}function Jea(a,b){a=a|0;b=b|0;var c=0;a=zg(a);c=Ni(x[b>>2]);b=Gf(b);x[27524]=0;U(813,a|0,c|0,b|0);b=x[27524];x[27524]=0;if((b|0)!=1){return a|0}b=P()|0;QP(a);S(b|0);p()}function E$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){a:{if((c|0)!=(d|0)){a=x[c>>2];if(a>>>0>127|!(x[(a<<2)+98544>>2]&b)){break a}}else{c=d}return c|0}c=c+4|0;continue}}function so(a,b){a=a|0;b=b|0;var c=0,d=0;c=ib-16|0;ib=c;d=Ob(x[a>>2],x[a+8>>2],4);a:{if(!d){rV(b);break a}Ph(c+8|0,b);sd(c,a,x[c+8>>2],x[c+12>>2])}ib=c+16|0;return d|0}function nu(a){var b=0,c=0,d=0,e=0;while(1){a:{if((b|0)==32){e=c;break a}d=y[a+b|0];if((d-1&255)>>>0<31|((c^1)&1?0:d)){break a}b=b+1|0;c=!d|c;continue}break}return e&1}function ZI(a){var b=0,c=0;a:{if(y[a|0]!=255){break a}b=y[a+1|0];if((b&240)!=240&(b&254)!=226|!(b&6)){break a}a=y[a+2|0];if((a&240)==240){break a}c=(a&12)!=12}return c}function p7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=ib-16|0;ib=d;e=x[b+4>>2];b=x[c+4>>2];c=x[c>>2];x[d>>2]=c;x[d+4>>2]=b;x[d+8>>2]=c;x[d+12>>2]=b;lM(a,e,d,1);ib=d+16|0}function mD(a,b,c){var d=0;d=ib-16|0;ib=d;a=Uo(d,a+8|0,b);b=x[a>>2];while(1){if((b|0)!=x[a+4>>2]){Pj(b,z[c>>1]);b=x[a>>2]+2|0;x[a>>2]=b;continue}break}Vd(a);ib=d+16|0}function Qb(a,b,c){var d=0,e=0,f=0;a:{if(!c){break a}while(1){d=y[a|0];e=y[b|0];if((d|0)==(e|0)){b=b+1|0;a=a+1|0;c=c-1|0;if(c){continue}break a}break}f=d-e|0}return f}function P7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=ib-16|0;ib=d;e=x[a+4>>2];a=x[b+4>>2];b=x[b>>2];x[d>>2]=b;x[d+4>>2]=a;x[d+8>>2]=b;x[d+12>>2]=a;ey(e,d,c,1);ib=d+16|0}function Nia(a,b){a=a|0;b=b|0;var c=0,d=0;c=ib-48|0;ib=c;d=-1;a:{if(!kT(a,c)){break a}d=0;if(!jT(c)){break a}d=Ee(a,b,iT(y[c+31|0],y[c+33|0]),kb)}ib=c+48|0;return d|0}function Lja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ib-16|0;ib=d;lE(b,c);if(Ob(x[a>>2],x[a+8>>2],c<<3)){kE(d+8|0,x[b>>2],x[b+4>>2]);sd(d,a,x[d+8>>2],x[d+12>>2])}ib=d+16|0}function wV(a,b,c){var d=0;d=ib-16|0;ib=d;a=qw(d,a+8|0,b);b=x[a>>2];while(1){if((b|0)!=x[a+4>>2]){Uk(b,y[c|0]);b=x[a>>2]+1|0;x[a>>2]=b;continue}break}Vd(a);ib=d+16|0}function rZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ib-16|0;ib=d;x[d+12>>2]=c;c=0;a=x[a+16>>2];if(a>>>0>b>>>0){x[d+8>>2]=a-b;c=x[Hb(d+12|0,d+8|0)>>2]}ib=d+16|0;return c|0}function pk(a,b){var c=0,d=0,e=0;a:{c=sl(a,b);if((c|0)==255){break a}if(qk(x[a>>2])){break a}d=Jb(a+8|0,c);e=y[d|0]&223;v[d|0]=e;ph(x[a>>2],x[a+4>>2],b,Qt(c)|176,e)}}function mT(a,b){var c=0;c=ib-32|0;ib=c;XT(c+24|0,a);ye(c+16|0,b);a=x[c+20>>2];x[c+8>>2]=x[c+16>>2];x[c+12>>2]=a;a=Nc(x[c+24>>2],x[c+28>>2],c+8|0);ib=c+32|0;return a}function gB(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ib-16|0;ib=d;pV(b,c);if(Ob(x[a>>2],x[a+8>>2],c<<2)){oV(d+8|0,x[b>>2],x[b+4>>2]);sd(d,a,x[d+8>>2],x[d+12>>2])}ib=d+16|0}function Vl(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=or(b);d=zl(a);if(c>>>0<=d>>>0){wB(a,ai(nd(a),b,c),c);break a}e=a;a=xd(x[a+4>>2],y[a+11|0]);wq(e,d,c-d|0,a,0,a,c,b)}}function L7(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0;d=ib-16|0;ib=d;e=x[a+4>>2];a=x[b+4>>2];b=x[b>>2];x[d>>2]=b;x[d+4>>2]=a;x[d+8>>2]=b;x[d+12>>2]=a;dy(e,d,c,1);ib=d+16|0}function bS(a){var b=0,c=0;a:{if(y[a|0]!=255){break a}b=y[a+1|0];if((b&224)!=224|(b&24)==8|!(b&6)){break a}a=y[a+2|0];if((a&12)==12){break a}c=(a&240)!=240}return c}function Y3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=ib-16|0;ib=e;a=vx(Ra(x[a+60>>2],b|0,c|0,d&255,e+8|0)|0);ib=e+16|0;kb=a?-1:x[e+12>>2];return(a?-1:x[e+8>>2])|0}function W7(a,b){a=a|0;b=b|0;var c=0;a=ba(8)|0;x[27524]=0;b=Q(1013,a|0,11993)|0;c=x[27524];x[27524]=0;if((c|0)!=1){ha(b|0,108556,172);p()}b=P()|0;ca(a|0);S(b|0);p()}function VA(a,b){a=a|0;b=b|0;var c=0;if(A[a+4>>2]<A[Db(a)>>2]){c=ib-16|0;ib=c;a=Fh(c,a,1);pq(x[a+4>>2],x[b>>2]);x[a+4>>2]=x[a+4>>2]+4;ic(a);ib=c+16|0;return}GA(a,b)}function PD(a,b,c){var d=0,e=0;if(c>>>0<4294967280){a:{if(Dl(c)){ee(a,c);break a}d=Wg(c)+1|0;e=mc(d);td(a,e);hf(a,d);vd(a,c);a=e}ne(Ae(a,b,c)+c|0,0);return}of();p()}function O4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;Lx(a,b,c);a=x[a+16>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function Kma(a,b){a=a|0;b=b|0;var c=0;c=ib-16|0;ib=c;a:{if(!Ob(x[b>>2],x[b+8>>2],12)){w[c>>1]=0;_V(a,6,c);break a}Oq(c+8|0,a);sd(c,b,x[c+8>>2],x[c+12>>2])}ib=c+16|0}function J1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=a;h=b;a=lb[x[x[a+8>>2]+20>>2]](a+8|0)|0;b=vc(a);return ek(g,h,c,d,e,f,b,b+(Eb(a)<<2)|0)|0}function GZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ib-16|0;ib=d;x[d+12>>2]=c;c=0;a=x[a+8>>2];if(a>>>0>b>>>0){x[d+8>>2]=a-b;c=x[Hb(d+12|0,d+8|0)>>2]}ib=d+16|0;return c|0}function GV(a,b,c){var d=0,e=0,f=0;d=ib-16|0;ib=d;b=gc(b);a=sh(a,mc(32),th(d+8|0,b));b=x[a>>2]+16|0;w[b>>1]=z[x[c>>2]>>1];Kb(b+4|0);e=gc(a),f=1,v[e+4|0]=f;ib=d+16|0}function wja(a,b){a=a|0;b=b|0;var c=0;c=ib-16|0;ib=c;a:{if(!Ob(x[b>>2],x[b+8>>2],8)){w[c>>1]=0;_V(a,4,c);break a}dn(c+8|0,a);sd(c,b,x[c+8>>2],x[c+12>>2])}ib=c+16|0}function nka(){var a=0,b=0,c=0;a=ib-16|0;ib=a;b=Kc(a,10203);x[27524]=0;Y(36,b|0);c=x[27524];x[27524]=0;if((c|0)!=1){wb(b);ib=a+16|0;return}a=P()|0;wb(b);S(a|0);p()}function nP(a){var b=0,c=0,d=0,e=0;b=ib-16|0;ib=b;d=b,e=roa(x[a>>2],x[a+4>>2],1e6,0),x[d>>2]=e;x[b+4>>2]=kb;c=Oe(b+8|0,b);a=x[c>>2];ib=b+16|0;kb=x[c+4>>2];return a}function eI(a,b){var c=0,d=0,e=0,f=0;c=x[a+24>>2];if((c|0)==x[a+28>>2]){return e=a,f=Ke(b),d=x[x[a>>2]+52>>2],lb[d](e|0,f|0)|0}x[a+24>>2]=c+1;v[c|0]=b;return Ke(b)}function zS(a){x[a>>2]=0;x[a+4>>2]=0;x[a+88>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;tA(a+112|0,48e3);x[a+668>>2]=0;sA(a+724|0);sA(a+732|0);sA(a+740|0);Bg(a+788|0);return a}function oja(a,b){a=a|0;b=b|0;var c=0;c=ib-16|0;ib=c;a:{if(!Ob(x[b>>2],x[b+8>>2],5)){v[c|0]=0;hi(a,5,c);break a}Ko(c+8|0,a);sd(c,b,x[c+8>>2],x[c+12>>2])}ib=c+16|0}function fna(a,b){a=a|0;b=b|0;var c=0;c=ib-16|0;ib=c;a:{if(!Ob(x[b>>2],x[b+8>>2],6)){v[c|0]=0;hi(a,6,c);break a}XB(c+8|0,a);sd(c,b,x[c+8>>2],x[c+12>>2])}ib=c+16|0}function pC(a){var b=0,c=0;a:{c=Bb(a,3);if((c|0)==(a|0)){break a}b=a;while(1){b=b+4|0;if((c|0)==(b|0)){break a}a=qo(x[b>>2],x[a>>2])?b:a;continue}}return x[a>>2]}function nea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ib-16|0;ib=c;d=c,e=Mi(b),x[d+12>>2]=e;x[c+8>>2]=0;d=a,e=x[Oj(c+12|0,c+8|0,43856)>>2],x[d+36>>2]=e;Qp(a);ib=c+16|0}function mq(a){x[a+8>>2]=0;x[a+12>>2]=0;x[a>>2]=128;x[a+4>>2]=256;x[a+32>>2]=363;x[a+36>>2]=952;x[a+16>>2]=48e3;x[a+20>>2]=2;x[a+24>>2]=128;x[a+28>>2]=0;return a}function g3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=ib-16|0;ib=e;x[e>>2]=c;x[e+4>>2]=d;x[e+8>>2]=c;x[e+12>>2]=d;a=PH(a,e,b);x[a>>2]=93564;ib=e+16|0;return a|0}function Um(a,b){a=a|0;b=b|0;var c=0;c=ib-16|0;ib=c;a:{if(!Ob(x[b>>2],x[b+8>>2],4)){v[c|0]=0;hi(a,4,c);break a}Ph(c+8|0,a);sd(c,b,x[c+8>>2],x[c+12>>2])}ib=c+16|0}function S_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ib-16|0;ib=d;x[d+12>>2]=x[c>>2];a=lb[x[x[a>>2]+16>>2]](a,b,d+12|0)|0;if(a){x[c>>2]=x[d+12>>2]}ib=d+16|0;return a|0}function Nk(a,b){a=a|0;b=b|0;var c=0;if(!Ue(y[b+11|0])){c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;x[a+8>>2]=x[b+8>>2];return a|0}FD(a,x[b>>2],x[b+4>>2]);return a|0}function eS(a,b){var c=0;c=x[a+4>>2];a:{if((b|0)>=0){b=b+c|0;c=x[a>>2]+(b>>>3&536870908)|0;break a}b=b+c|0;c=x[a>>2]+((b-31|0)/32<<2)|0}x[a>>2]=c;x[a+4>>2]=b&31}function XO(a){var b=0,c=0,d=0;b=x[a+112>>2];if((b|0)>=11){c=378;while(1){if(c|d){WO(a);b=c;c=b-1|0;d=d-!b|0;continue}break}b=0}x[a+112>>2]=b+1;a=WO(a);return a}function MB(a){var b=0,c=0;b=ib-16|0;ib=b;w[b+14>>1]=a;Mf(b+14|0,4095);a=z[b+14>>1];c=uW(ki(+((a&255)>>>0)*.00390625)*32768);ib=b+16|0;return c>>>15-(a>>>8|0)|0}function Gja(a,b){a=a|0;b=b|0;var c=0,d=0;d=ib-80|0;ib=d;c=-1;a:{if(!CX(a,d+8|0)){break a}c=0;if(!bU(d+8|0)){break a}c=Ee(a,b,aU(d+8|0),kb)}ib=d+80|0;return c|0}function Fq(a){var b=0,c=0,d=0,e=0;b=x[a+4>>2];c=x[b>>2];x[a+4>>2]=c;if(c){pm(c,a)}x[b+8>>2]=x[a+8>>2];d=x[a+8>>2]+(Hh(a)?0:4)|0,e=b,x[d>>2]=e;x[b>>2]=a;pm(a,b)}function Eq(a){var b=0,c=0,d=0,e=0;b=x[a>>2];c=x[b+4>>2];x[a>>2]=c;if(c){pm(c,a)}x[b+8>>2]=x[a+8>>2];d=x[a+8>>2]+(Hh(a)?0:4)|0,e=b,x[d>>2]=e;x[b+4>>2]=a;pm(a,b)}function xv(a,b){a=a|0;b=b|0;var c=0;c=ib-16|0;ib=c;a:{if(!Ob(x[b>>2],x[b+8>>2],2)){v[c|0]=0;TC(a,c);break a}Zm(c+8|0,a);sd(c,b,x[c+8>>2],x[c+12>>2])}ib=c+16|0}function xfa(a,b){a=a|0;b=b|0;a=sc(a);v[a+534|0]=0;x[a+4>>2]=0;x[27524]=0;R(764,a|0,b|0);b=x[27524];x[27524]=0;if((b|0)!=1){return a|0}b=P()|0;Cj(a);S(b|0);p()}function oka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=Nb(a+8|0);x[27524]=0;U(248,a|0,b|0,c|0);a=x[27524];x[27524]=0;if((a|0)!=1){break a}a=P()|0;ec(d);S(a|0);p()}}function mJ(a,b){var c=0,d=0;d=a+4|0;c=cd(x[d>>2],x[a+8>>2]);a=x[a+16>>2]+b|0;if(c>>>0<a>>>0){a:{if(c){b=Og(c);if(a>>>0<=b>>>0){break a}}b=nJ(a,65536)}Yi(d,b)}}function Y8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=a;a=b+28|0;d=Gp(d,a);qL(a,c);x[27524]=0;R(70,b|0,1);a=x[27524];x[27524]=0;if((a|0)==1){a=P()|0;_b(d);S(a|0);p()}}function P1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=a;h=b;a=lb[x[x[a+8>>2]+20>>2]](a+8|0)|0;b=Jc(a);return fk(g,h,c,d,e,f,b,Eb(a)+b|0)|0}function LF(a,b,c){var d=E(0);a:{if((b|0)<0|z[a+480188>>1]<=b>>>0){break a}a=D(b,872)+a|0;if(!(v[a+1075081|0]&1)){break a}d=E(E(y[a+c|0])*E(.0078125))}return d}function Hca(a){a=a|0;var b=0,c=0,d=0;b=ib-16|0;ib=b;zN(b+8|0,a,0);c=x[b+12>>2];if(c){a=x[a+20>>2];x[a+148>>2]=-1;d=a+4|0;a=x[b+8>>2];_y(d,a,Jb(a,c))}ib=b+16|0}function Cs(a){var b=0;a:{if((df(a)|0)!=79){break a}if((df(a)|0)!=103){break a}if((df(a)|0)!=103){break a}b=(df(a)|0)==83}if(!b){fc(a,30);return 0}return RI(a)}function wk(a,b){var c=0;c=ib-32|0;ib=c;x[c+24>>2]=0;pw(c+8|0,c+24|0);Bn(c+16|0,a,x[c+8>>2],x[c+12>>2]);a=x[c+20>>2];cm(b,x[c+24>>2]);ib=c+32|0;return(a|0)==4}function tY(a,b){a=a|0;b=b|0;var c=0,d=0;c=ib-16|0;ib=c;x[c+12>>2]=-1;if(Hg(a,c+8|0)){x[c+4>>2]=y[c+8|0];d=IC(a,b,x[Hb(c+4|0,c+12|0)>>2])}ib=c+16|0;return d|0}function bK(a,b){var c=0;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;c=x[b+20>>2];x[a+16>>2]=x[b+16>>2];x[a+20>>2]=c;c=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=c}function _W(a){var b=0;if(!(Qb(a,17825,8)|y[a+8|0]>1|((y[a+9|0]-1&255)>>>0>7|(y[a+10|0]|y[a+11|0]<<8)>>>0>4096))){b=(y[a+12|0]|y[a+13|0]<<8)>>>0<4097}return b}function YV(a,b){var c=0;c=qoa(b&65535,0,384,0);b=a&65535;a=b>>>30|0;b=b<<2;c=c+b|0;a=a+kb|0;a=b>>>0>c>>>0?a+1|0:a;b=c+256|0;a=b>>>0<256?a+1|0:a;kb=a;return b}function Mm(a){var b=0;b=2147483647;a:{if(a>=2147483647){break a}b=-2147483648;if(a<=-2147483648){break a}if(F(a)<2147483648){return~~a}b=-2147483648}return b}function MC(a,b){a=a|0;b=b|0;var c=0,d=0;c=ib-16|0;ib=c;x[c+12>>2]=-1;if(Hg(a,c+8|0)){x[c+4>>2]=y[c+8|0];d=FC(a,b,x[Hb(c+4|0,c+12|0)>>2])}ib=c+16|0;return d|0}function Ld(a,b){var c=0,d=0,e=E(0);c=ib-16|0;ib=c;x[c+8>>2]=1065353216;B[c+12>>2]=b;d=c,e=Tf(a),B[d+4>>2]=e;a=B[xq(c+4|0,c+12|0,c+8|0)>>2];ib=c+16|0;return a}function wA(a){var b=0;a=Be(a);b=32767;a:{if(a>=32767){break a}b=32768;if(a<=-32768){break a}b=~~a;if(F(a)<2147483648){break a}b=-2147483648}return b<<16>>16}function ld(a,b,c,d){var e=0,f=0,g=0;e=ib-16|0;ib=e;f=x[b+12>>2];x[e+8>>2]=c;x[e+12>>2]=d;g=x[x[b>>2]+28>>2];x[e>>2]=c;x[e+4>>2]=d;lb[g|0](a,b,f,e);ib=e+16|0}function _D(a){var b=0;if(!(Qb(a,15511,4)|(y[a+4|0]-16&255)>>>0<249|((y[a+5|0]-16&255)>>>0<249|(y[a+6|0]-16&255)>>>0<249))){b=(y[a+7|0]-9&255)>>>0<7}return b}function UB(a,b,c,d){var e=0,f=0;tg(a+12|0,d);if(b){d=VC(b)}else{d=0}x[a>>2]=d;c=d+D(c,20)|0;x[a+8>>2]=c;x[a+4>>2]=c;e=zc(a),f=d+D(b,20)|0,x[e>>2]=f;return a}function Pk(a,b,c,d){var e=0,f=0;tg(a+12|0,d);if(b){d=LE(b)}else{d=0}x[a>>2]=d;c=d+D(c,12)|0;x[a+8>>2]=c;x[a+4>>2]=c;e=zc(a),f=d+D(b,12)|0,x[e>>2]=f;return a}function MM(a){a=a|0;var b=0;x[a+4240>>2]=0;x[a+4244>>2]=0;b=a+4264|0;x[b>>2]=0;x[b+4>>2]=0;b=a+4256|0;x[b>>2]=0;x[b+4>>2]=0;a=a+4248|0;x[a>>2]=0;x[a+4>>2]=0}function D2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=0;while(1){if((b|0)!=(c|0)){a=x[b>>2]+(a<<4)|0;d=a&-268435456;a=(d|d>>>24)^a;b=b+4|0;continue}break}return a|0}function tT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ib-16|0;ib=d;while(1){if((b|0)==(c|0)){ib=d+16|0}else{x[d+12>>2]=x[b>>2];VA(a,d+12|0);b=b+4|0;continue}break}}function mc(a){a=a|0;var b=0;a=a?a:1;a:{while(1){b=Gd(a);if(b){break a}b=x[121341];if(b){lb[b|0]();continue}break}ha(qm(ba(4)|0)|0,108196,26);p()}return b|0}function cf(a,b){var c=0;c=x[a>>2];x[a>>2]=b;a:{if(c){a=x[gc(a)>>2];x[27524]=0;Y(a|0,c|0);a=x[27524];x[27524]=0;if((a|0)==1){break a}}return}V(0)|0;Sb();p()}function cP(){var a=0,b=0,c=0,d=0;a=ib-16|0;ib=a;b=a+8|0;while(1){if(c>>>0<32){c=c+48|0;d=dz(110136);continue}break}x[b>>2]=d;Wn(b);ib=a+16|0;return x[b>>2]}function bia(a,b){a=a|0;b=b|0;var c=0,d=0;d=ib-48|0;ib=d;c=-1;a:{if(!kT(a,d)){break a}c=0;if(!qS(d)){break a}c=Ee(a,b,pS(y[d+47|0]),kb)}ib=d+48|0;return c|0}function Yb(a,b){a=a|0;b=b|0;var c=0;c=Ob(x[a>>2],x[a+8>>2],b);a:{if(c){b=x[a+8>>2]+b|0;break a}b=x[a>>2];b=lb[x[x[b>>2]+24>>2]](b)|0}x[a+8>>2]=b;return c|0}function WN(a,b){var c=0;c=ib-16|0;ib=c;a=Ym(c,a+8|0,b);b=x[a>>2];while(1){if((b|0)!=x[a+4>>2]){fS(b);b=x[a>>2]+4|0;x[a>>2]=b;continue}break}Vd(a);ib=c+16|0}function O5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;while(1){if((a|0)!=(b|0)){d=x[c>>2];x[d>>2]=x[a>>2];Pg(d+4|0,a+4|0);x[c>>2]=x[c>>2]+16;a=a+16|0;continue}break}}function MF(a,b,c){var d=E(0);a:{if((b|0)<0|z[a+480188>>1]<=b>>>0){break a}a=D(b,872)+a|0;if(v[a+1075081|0]&1){break a}d=E(E(y[a+c|0])*E(.0078125))}return d}function G2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=0;while(1){if((b|0)!=(c|0)){a=v[b|0]+(a<<4)|0;d=a&-268435456;a=(d|d>>>24)^a;b=b+1|0;continue}break}return a|0}function wr(a,b,c,d){var e=0,f=0;tg(a+12|0,d);if(b){d=jE(b)}else{d=0}x[a>>2]=d;c=d+(c<<3)|0;x[a+8>>2]=c;x[a+4>>2]=c;e=zc(a),f=d+(b<<3)|0,x[e>>2]=f;return a}function wS(a,b,c,d){var e=0,f=0;tg(a+12|0,d);if(b){d=vS(b)}else{d=0}x[a>>2]=d;c=d+(c<<4)|0;x[a+8>>2]=c;x[a+4>>2]=c;e=zc(a),f=d+(b<<4)|0,x[e>>2]=f;return a}function vt(a,b){var c=0,d=0,e=E(0);c=ib-16|0;ib=c;B[c+12>>2]=b;x[c+8>>2]=0;x[c+4>>2]=1065353216;d=a,e=B[xq(c+12|0,c+8|0,c+4|0)>>2],B[d+144>>2]=e;ib=c+16|0}function Vt(a,b,c,d){var e=0,f=0;tg(a+12|0,d);if(b){d=rS(b)}else{d=0}x[a>>2]=d;c=d+(c<<5)|0;x[a+8>>2]=c;x[a+4>>2]=c;e=zc(a),f=d+(b<<5)|0,x[e>>2]=f;return a}function Uj(a,b,c,d){var e=0,f=0;tg(a+12|0,d);if(b){d=Mv(b)}else{d=0}x[a>>2]=d;c=d+(c<<1)|0;x[a+8>>2]=c;x[a+4>>2]=c;e=zc(a),f=d+(b<<1)|0,x[e>>2]=f;return a}function NA(a,b,c){var d=0;d=ib-16|0;ib=d;x[d+8>>2]=a;c=c&65535;while(1){if(!(!Mb(a,b)|(c|0)==z[a>>1])){a=x[Ye(d+8|0)>>2];continue}break}ib=d+16|0;return a}function Lfa(a,b){a=a|0;b=b|0;a=Nb(a);v[a+16|0]=0;x[a+12>>2]=b;x[27524]=0;Y(758,a|0);b=x[27524];x[27524]=0;if((b|0)!=1){return a|0}b=P()|0;fA(a);S(b|0);p()}function BV(a,b,c,d){var e=0,f=0;tg(a+12|0,d);if(b){d=xV(b)}else{d=0}x[a>>2]=d;c=d+D(c,6)|0;x[a+8>>2]=c;x[a+4>>2]=c;e=zc(a),f=d+D(b,6)|0,x[e>>2]=f;return a}function tq(a,b){var c=0,d=0;a:{if(!a){break a}c=qoa(a,0,b,0);d=kb;if((a|b)>>>0<65536){break a}c=d?-1:c}a=Gd(c);if(!(!a|!(y[a-4|0]&3))){Rb(a,0,c)}return a}function sZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=x[a+16>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function qj(a,b,c,d){var e=0;e=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=e;e=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=e;C[a>>3]=C[a>>3]-c;C[a+8>>3]=C[a+8>>3]-d}function oi(a){var b=0,c=0;b=a*a;c=b*a;return E(c*(b*b)*(b*2718311493989822e-21+-.00019839334836096632)+(c*(b*.008333329385889463+-.16666666641626524)+a))}function Zi(a,b,c,d,e){a:{e=ot(e);if(e){x[27524]=0;fa(d|0,e|0,a|0,b|0,c|0)|0;a=x[27524];x[27524]=0;if((a|0)==1){break a}}return e}a=P()|0;Ib(e);S(a|0);p()}function ZD(a,b){a=a|0;b=b|0;var c=0,d=0;c=a;a=x[b>>2];d=(lb[x[x[a>>2]+20>>2]](a)|0)+x[b+8>>2]|0;a=x[b>>2];dc(c,d,(lb[x[x[a>>2]+24>>2]](a)|0)-x[b+8>>2]|0)}function SX(a,b,c){var d=0;b=b-a>>2;while(1){if((b|0)>0){d=x[c>>2];v[a|0]=d;v[a+1|0]=d>>>8;v[a+2|0]=d>>>16;v[a+3|0]=d>>>24;b=b-1|0;a=a+4|0;continue}break}}function Fx(a,b){var c=0;while(1){c=(b|0)>=120?120:b;a=E(a*E(B[((c&3)<<2)+81056>>2]*E(1073741824>>>(c>>2)|0)));b=b-c|0;if((b|0)>0){continue}break}return a}function Pg(a,b){a=a|0;b=b|0;var c=0;if(!kf(b)){c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;x[a+8>>2]=x[b+8>>2];return a|0}FD(a,x[b>>2],x[b+4>>2]);return a|0}function Laa(a){a=a|0;var b=0,c=E(0);v[a+4202|0]=1;b=a,c=Jz(E(E(E(E(A[x[a+16>>2]+24620>>2])/E(3))+E(-80))/E(15920)),E(0),E(1)),B[b+4272>>2]=c;OM(a);MM(a)}function HZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=x[a+8>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function kda(a){a=a|0;var b=0;b=ib-16|0;ib=b;Pc(b,a+32|0,4);if(!zb(x[x[b>>2]>>2],x[b+4>>2])){rw(a)}a=x[Wb(b+8|0,Cb(x[a+52>>2]))>>2];ib=b+16|0;return a|0}function jda(a){a=a|0;var b=0;b=ib-16|0;ib=b;Pc(b,a+32|0,4);if(!zb(x[x[b>>2]>>2],x[b+4>>2])){rw(a)}a=x[Wb(b+8|0,Cb(x[a+56>>2]))>>2];ib=b+16|0;return a|0}function Ug(a){var b=0,c=0;b=x[a>>2];c=x[b+4>>2];a:{if(!c){while(1){if(!Hh(b)){b=x[b+8>>2];continue}break}b=x[b+8>>2];break a}b=cW(c)}x[a>>2]=b;return a}function Kn(a,b){var c=0,d=0;b=b+7&-8;d=x[a+80>>2];a:{if(d){b=x[a+92>>2]-b|0;c=0;if((b|0)<x[a+88>>2]){break a}x[a+92>>2]=b;return b+d|0}c=Gd(b)}return c}function w$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;while(1){if((b|0)!=(c|0)){a=x[b>>2];v[e|0]=a>>>0<128?a:d;e=e+1|0;b=b+4|0;continue}break}return c|0}function ve(a){var b=0,c=0;if(x[a>>2]){c=x[a>>2];b=x[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-12|0;Zb(b);continue}break}x[a+4>>2]=c;b=x[a>>2];ak(a);Ib(b)}}function nH(a,b,c){var d=0;d=ib-32|0;ib=d;x[d+28>>2]=c;x[d+24>>2]=0;x[d+12>>2]=4;Ow(d+16|0,a,d+24|0,x[Hb(d+28|0,d+12|0)>>2]);cm(b,x[d+24>>2]);ib=d+32|0}function bd(a,b){a=a|0;b=b|0;var c=0,d=0;a:{if(A[a+8>>2]<b>>>0){d=x[a>>2];c=0;if(lb[x[x[d>>2]+24>>2]](d)>>>0<b>>>0){break a}}x[a+8>>2]=b;c=1}return c|0}function Z2(a,b){a=a|0;b=b|0;var c=0,d=0;b=bx(b);x[a+36>>2]=b;c=a,d=bh(b),x[c+44>>2]=d;c=a,d=En(x[a+36>>2]),v[c+53|0]=d;if(x[a+44>>2]>=9){ms(5566);p()}}function Wl(a){var b=0,c=0;if(x[a>>2]){c=x[a>>2];b=x[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-12|0;$b(b);continue}break}x[a+4>>2]=c;b=x[a>>2];ak(a);Ib(b)}}function R2(a,b){a=a|0;b=b|0;var c=0,d=0;b=fx(b);x[a+36>>2]=b;c=a,d=bh(b),x[c+44>>2]=d;c=a,d=En(x[a+36>>2]),v[c+53|0]=d;if(x[a+44>>2]>=9){ms(5566);p()}}function Qx(a){var b=0,c=0;if(x[a>>2]){c=x[a>>2];b=x[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-16|0;Ps(b);continue}break}x[a+4>>2]=c;b=x[a>>2];du(a);Ib(b)}}function QS(a,b){var c=0,d=0,e=0;Ku(a);x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];c=Db(b);d=Db(a),e=x[c>>2],x[d>>2]=e;x[c>>2]=0;x[b>>2]=0;x[b+4>>2]=0;return a}function Om(a,b){var c=0,d=0,e=0;$B(a);x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];c=Db(b);d=Db(a),e=x[c>>2],x[d>>2]=e;x[c>>2]=0;x[b>>2]=0;x[b+4>>2]=0;return a}function LT(a){var b=0,c=0;if(x[a>>2]){c=x[a>>2];b=x[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-56|0;ku(b);continue}break}x[a+4>>2]=c;b=x[a>>2];JT(a);Ib(b)}}function KU(a){var b=0,c=0;if(x[a>>2]){c=x[a>>2];b=x[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-24|0;yb(b);continue}break}x[a+4>>2]=c;b=x[a>>2];Jr(a);Ib(b)}}function _p(a,b,c){var d=0;a:{if(b&134218752){break a}if(!uj(c)){break a}b=y[c+34|0];if((b+5&255)>>>0<6){break a}d=x[Nd(a+906300|0,b-1|0)>>2]}return d}function On(a,b){x[a+20>>2]=0;x[a+24>>2]=b;x[a+12>>2]=0;x[a+4>>2]=4098;x[a+8>>2]=6;x[a+16>>2]=!b;Rb(a+32|0,0,40);lI(a+28|0);x[a+72>>2]=0;x[a+76>>2]=-1}function GW(a,b){var c=0;c=qoa(b&255,0,9,0);b=a&255;a=b>>>31|0;b=b<<1;c=c+b|0;a=a+kb|0;a=b>>>0>c>>>0?a+1|0:a;b=c+11|0;a=b>>>0<11?a+1|0:a;kb=a;return b}function EV(a,b,c){var d=0;d=ib-32|0;ib=d;x[d+28>>2]=c;v[d+24|0]=0;x[d+12>>2]=1;Ow(d+16|0,a,d+24|0,x[Hb(d+28|0,d+12|0)>>2]);v[b|0]=y[d+24|0];ib=d+32|0}function EL(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=ib-32|0;ib=h;i=h+8|0;cJ(i,b,c,d,e,f,g);$c(a,h+20|0);Am(i);ib=h+32|0}function Aw(a,b,c,d){var e=0;e=ba(8)|0;x[27524]=0;a=Q(d|0,e|0,a|0)|0;d=x[27524];x[27524]=0;if((d|0)!=1){ha(a|0,c|0,b|0);p()}a=P()|0;ca(e|0);S(a|0);p()}function fQ(a,b,c){var d=0,e=0;x[b+56>>2]=0;d=b,e=Zn(a,z[b+70>>1],x[b+48>>2],c,0),w[d+68>>1]=e;if(!(!(y[a+480180|0]&5)|x[b+60>>2]==-1)){x[b+60>>2]=0}}function Tv(a,b){var c=0;c=ib-16|0;ib=c;a:{if(!Ob(x[b>>2],x[b+8>>2],3)){v[c|0]=0;hi(a,3,c);break a}Sv(c+8|0,a);sd(c,b,x[c+8>>2],x[c+12>>2])}ib=c+16|0}function QE(a){x[a>>2]=0;x[a+4>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;w[a+20>>1]=0;x[a+16>>2]=-1;x[a+8>>2]=0;x[a+12>>2]=0;x[a>>2]=0}function tP(a,b){var c=0,d=0,e=0;c=ib-16|0;ib=c;x[c>>2]=a;x[c+4>>2]=b;d=c,e=nP(c),x[d+8>>2]=e;x[c+12>>2]=kb;ib=c+16|0;kb=x[c+12>>2];return x[c+8>>2]}function sja(a,b){a=a|0;b=b|0;var c=0,d=0;d=ib-96|0;ib=d;c=-1;a:{if(!TT(a,d)){break a}c=0;if(!ST(d)){break a}c=Ee(a,b,RT(d),kb)}ib=d+96|0;return c|0}function o$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;while(1){if((b|0)!=(c|0)){a=v[b|0];v[e|0]=(a|0)<0?d:a;e=e+1|0;b=b+1|0;continue}break}return c|0}function h4(a,b,c){a=a|0;b=b|0;c=c|0;a:{a=Pg(a,b);x[27524]=0;Q(54,a+12|0,c|0)|0;b=x[27524];x[27524]=0;if((b|0)!=1){break a}b=P()|0;wb(a);S(b|0);p()}}function Vf(a){var b=0,c=0;b=ib-16|0;ib=b;a:{if(kf(a)){c=x[a>>2];v[b+15|0]=0;oe(c,b+15|0);vd(a,0);break a}v[b+14|0]=0;oe(a,b+14|0);ee(a,0)}ib=b+16|0}function Uia(a,b){a=a|0;b=b|0;var c=0,d=0;d=ib-96|0;ib=d;c=-1;a:{if(!TT(a,d)){break a}c=0;if(!xT(d)){break a}c=Ee(a,b,wT(d),kb)}ib=d+96|0;return c|0}function Ov(a,b,c,d,e){var f=0;while(1){if((d|0)!=(f|0)){B[b>>2]=E(x[a>>2])*e;B[c>>2]=E(x[a+4>>2])*e;f=f+1|0;c=c+4|0;a=a+8|0;b=b+4|0;continue}break}}function vQ(a){var b=0,c=0;c=x[a+4>>2];while(1){b=x[a+8>>2];if((b|0)!=(c|0)){b=b-12|0;x[a+8>>2]=b;Zb(b);continue}break}c=x[a>>2];if(c){ep(a);Ib(c)}}function sP(a,b){var c=0;c=ib-32|0;ib=c;x[c+16>>2]=a;x[c+20>>2]=b;a=Oe(c+24|0,tt(c+8|0,Oe(c,c+16|0)));b=x[a+4>>2];a=x[a>>2];ib=c+32|0;kb=b;return a}function kw(a){var b=0,c=0;c=x[a+4>>2];while(1){b=x[a+8>>2];if((b|0)!=(c|0)){b=b-12|0;x[a+8>>2]=b;$b(b);continue}break}c=x[a>>2];if(c){ep(a);Ib(c)}}function cA(a){var b=0,c=0;c=x[a+4>>2];while(1){b=x[a+8>>2];if((b|0)!=(c|0)){b=b-32|0;x[a+8>>2]=b;tl(b);continue}break}c=x[a>>2];if(c){ep(a);Ib(c)}}function Zy(a){if(y[a+480224|0]==2){return+A[a+1074420>>2]/1e4}return+A[a+24620>>2]/(+A[a+1074404>>2]*+(D(x[a+1074408>>2],x[a+1074416>>2])>>>0))*60}function ZN(a){var b=0,c=0;c=x[a+4>>2];while(1){b=x[a+8>>2];if((b|0)!=(c|0)){b=b-52|0;x[a+8>>2]=b;ll(b);continue}break}c=x[a>>2];if(c){zc(a);Ib(c)}}function Wv(a){var b=0,c=0;c=x[a+4>>2];while(1){b=x[a+8>>2];if((b|0)!=(c|0)){b=b-36|0;x[a+8>>2]=b;sr(b);continue}break}c=x[a>>2];if(c){zc(a);Ib(c)}}function Ru(a){var b=0,c=0;c=x[a+4>>2];while(1){b=x[a+8>>2];if((b|0)!=(c|0)){b=b-20|0;x[a+8>>2]=b;yb(b);continue}break}c=x[a>>2];if(c){zc(a);Ib(c)}}function IT(a){var b=0,c=0;c=x[a+4>>2];while(1){b=x[a+8>>2];if((b|0)!=(c|0)){b=b-56|0;x[a+8>>2]=b;ku(b);continue}break}c=x[a>>2];if(c){zc(a);Ib(c)}}function HX(a){var b=0,c=0;c=x[a+4>>2];while(1){b=x[a+8>>2];if((b|0)!=(c|0)){b=b-28|0;x[a+8>>2]=b;yd(b);continue}break}c=x[a>>2];if(c){zc(a);Ib(c)}}function BM(a,b){a=a|0;b=b|0;var c=0,d=0;d=ib-16|0;ib=d;c=Us(mc(12));x[c+8>>2]=b;x[c+4>>2]=a;x[c>>2]=49100;a=x[uf(d+8|0,c)>>2];ib=d+16|0;return a|0}function $_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;if(gh(a,x[b+8>>2],f)){Jw(b,c,d,e);return}a=x[a+8>>2];lb[x[x[a>>2]+20>>2]](a,b,c,d,e,f)}function mR(a){var b=0,c=0,d=0;d=y[a+26|0];b=d+27|0;while(1){if((c|0)==(d|0)){a=b&65535}else{b=y[(a+c|0)+27|0]+b|0;c=c+1|0;continue}break}return a}function fba(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=0,f=E(0);if(b>>>0<=1){c=Ld(c,E(0));if((b|0)==1){d=1;c=$h(c)}e=Bb(a+4208|0,d),f=c,B[e>>2]=f;UM(a)}}function f3(a,b){a=a|0;b=b|0;var c=0,d=0;c=x[a+40>>2];while(1){if(c){c=c-1|0;d=c<<2;lb[x[x[a+32>>2]+d>>2]](b,a,x[d+x[a+36>>2]>>2]);continue}break}}function cX(a){v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0}function af(a,b){var c=0;c=ib-16|0;ib=c;a:{if(!b){Pc(c+8|0,a+32|0,5);if(zb(x[x[c+8>>2]>>2],x[c+12>>2])){break a}}x[a+28>>2]=x[a+28>>2]+1}ib=c+16|0}function ZF(a){var b=0,c=0;c=a>>>23&255;b=0;a:{if(c>>>0<127){break a}b=2;if(c>>>0>150){break a}c=1<<150-c;b=0;if(c-1&a){break a}b=a&c?1:2}return b}function Fy(a,b,c,d){var e=0;e=ib-16|0;ib=e;a=Rq(e,a,d);c=c-b|0;if((c|0)>0){rc(x[a+4>>2],b,c);x[a+4>>2]=x[a+4>>2]+D((c>>>0)/6|0,6)}ic(a);ib=e+16|0}function $z(a,b,c){var d=0,e=0,f=0;d=sl(a,b);if((d|0)!=255){e=bc(a+26|0,d),f=c,w[e>>1]=f;a=a+62|0;e=Jb(a,b),f=255,v[e|0]=f;e=Jb(a,c),f=d,v[e|0]=f}}function wda(a,b){a=a|0;b=b|0;var c=0,d=0;c=ib-32|0;ib=c;w[c+24>>1]=b;b=c+24|0;Zm(c+16|0,b);d=x[c+16>>2];Zm(c+8|0,b);Tk(a,d,x[c+12>>2]);ib=c+32|0}function sN(a,b){var c=0;c=x[b+4>>2];if(x[a>>2]==(b|0)){x[a>>2]=c}if(c){x[c+8>>2]=x[b+8>>2]}a=x[b+8>>2];if(a){x[a+4>>2]=c}x[b+4>>2]=0;x[b+8>>2]=0}function iM(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=ib-32|0;ib=h;i=h+8|0;cJ(i,b,c,d,e,f,g);$c(a,i);Am(i);ib=h+32|0}function bE(a){a=a|0;var b=0;a=Kb(a);x[27524]=0;T(178,a+12|0)|0;b=x[27524];x[27524]=0;if((b|0)!=1){sc(a+32|0);return a|0}b=P()|0;xb(a);S(b|0);p()}function NC(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+7|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0}function ex(a){var b=0,c=0;b=ib-16|0;ib=b;c=-1;a:{if(qx(a)){break a}if((lb[x[a+32>>2]](a,b+15|0,1)|0)!=1){break a}c=y[b+15|0]}ib=b+16|0;return c}function QN(a){var b=0;b=ib-16|0;ib=b;B[b+12>>2]=F(a);x[b+8>>2]=646978941;x[b+4>>2]=1259902592;a=B[xq(b+12|0,b+8|0,b+4|0)>>2];ib=b+16|0;return a}function Cp(a,b){var c=0;a:{if(!ZI(b)|(y[b+1|0]^y[a+1|0])>>>0>1){break a}b=y[b+2|0];a=y[a+2|0];if((b^a)&12){break a}c=b>>>0<16^a>>>0>15}return c}function Bfa(a,b){a=a|0;b=b|0;var c=0,d=0;c=ib-32|0;ib=c;v[c+24|0]=b;b=c+24|0;gr(c+16|0,b);d=x[c+16>>2];gr(c+8|0,b);Tk(a,d,x[c+12>>2]);ib=c+32|0}function Bda(a,b){a=a|0;b=b|0;var c=0;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);c=tc(x[b>>2],x[b+4>>2]);if(c){Gk(a,c);bB(a,x[b>>2],x[b+4>>2],c)}return a|0}function uaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(!b){Zx(a,0,0,0,0,0,0,c,d);return}Zx(a,x[b>>2],x[b+4>>2],x[b+8>>2],x[b+12>>2],x[b+24>>2],b,c,d)}function _P(a,b){v[a+840|0]=b;v[a+812|0]=b;v[a+811|0]=b;v[a+809|0]=b;v[a+807|0]=b;v[a+806|0]=b;v[a+833|0]=b;v[a+826|0]=b>>>4;v[a+827|0]=b<<2&60}function Wi(a,b,c){if(a>>>0<b>>>0){rc(a,b,c);return}if(c){a=a+c|0;b=b+c|0;while(1){a=a-1|0;b=b-1|0;v[a|0]=y[b|0];c=c-1|0;if(c){continue}break}}}function Dk(a,b,c,d){var e=0;e=D(b,c);a:{if(x[d+76>>2]<0){a=wC(a,e,d);break a}a=wC(a,e,d)}if((e|0)==(a|0)){return b?c:0}return(a>>>0)/(b>>>0)|0}function DA(a,b){a=a|0;b=b|0;var c=0;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);c=cd(x[b>>2],x[b+4>>2]);if(c){Pl(a,c);Fu(a,x[b>>2],x[b+4>>2],c)}return a|0}function sj(a){var b=0,c=0;b=ib-16|0;ib=b;Ab(b+8|0,a+1074312|0,7);if(zb(x[x[b+8>>2]>>2],x[b+12>>2])){c=Nm(x[a+480180>>2])^1}ib=b+16|0;return c}function sT(a,b,c,d){var e=0;e=c&4;a:{b:{if(!(e|(b&255)!=4)){if(c&2){break b}Zc(a,8,1,0,10);return}b=16;if(e){break a}}b=8}Zc(a,b,c&2|1,0,d^1)}function kc(a,b,c,d,e){var f=0,g=0;f=ib-16|0;ib=f;x[f+8>>2]=d;x[f+12>>2]=e;g=x[x[b>>2]+28>>2];x[f>>2]=d;x[f+4>>2]=e;lb[g|0](a,b,c,f);ib=f+16|0}function dg(a,b){a=a|0;b=b|0;var c=0;c=ib-32|0;ib=c;w[c+24>>1]=0;bk(c+8|0,c+24|0);Bn(c+16|0,a,x[c+8>>2],x[c+12>>2]);Rj(b,z[c+24>>1]);ib=c+32|0}function aoa(a,b){a=a|0;b=b|0;var c=0;c=ib-16|0;ib=c;x[c+12>>2]=-1;if(Hg(a,c+8|0)){x[c+4>>2]=y[c+8|0];QX(a,b,x[Hb(c+4|0,c+12|0)>>2])}ib=c+16|0}function Xl(a,b){var c=0,d=0;d=x[a+4>>2];c=x[a+8>>2];while(1){if((c|0)!=(d|0)){c=c-b|0;x[a+8>>2]=c;continue}break}b=x[a>>2];if(b){zc(a);Ib(b)}}function Rz(a){var b=0,c=0;b=ib-16|0;ib=b;x[b+8>>2]=a;c=b+8|0;a=1;while(1){if((a|0)>0){Ug(c);a=a-1|0;continue}break}ib=b+16|0;return x[b+8>>2]}function RU(a){var b=0;if(!(Qb(a,15008,3)|(y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24))-2147483647>>>0<2147484072)){b=y[a+3|0]<6}return b}function Oja(a,b){a=a|0;b=b|0;a:{if(a>>>0>=515){a=Jg(b);Jg(b);break a}a=_g(b);_g(b)}while(1){if(a){if(a&1){Yb(b,260)}a=a>>>1|0;continue}break}}function HI(a,b,c,d,e,f){var g=0,h=0;g=x[a+32>>2];if(!y[a+23|0]){x[(c<<2)+g>>2]=b;return}h=g;g=d<<2;x[h+g>>2]=b;v[x[a+8>>2]+d|0]=e;x[f+g>>2]=c}function yY(a,b){a=a|0;b=b|0;var c=0;c=ib-16|0;ib=c;x[c+12>>2]=-1;if(Hg(a,c+8|0)){x[c+4>>2]=y[c+8|0];KC(a,b,x[Hb(c+4|0,c+12|0)>>2])}ib=c+16|0}function uS(a){var b=0,c=0;c=x[a+4>>2];b=x[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-32|0;x[a+8>>2]=b;continue}break}b=x[a>>2];if(b){ep(a);Ib(b)}}function ni(a){var b=0;a=a*a;b=a*a;return E(a*b*(a*2439044879627741e-20+-.001388676377460993)+(b*.04166662332373906+(a*-.499999997251031+1)))}function cn(a,b){var c=0;a=hn(a);x[a>>2]=78208;c=x[b+8>>2];x[a+4>>2]=x[b+4>>2];x[a+8>>2]=c;v[a+16|0]=y[b+16|0];x[a+12>>2]=x[b+12>>2];return a}function XS(a){var b=0,c=0;c=x[a+4>>2];b=x[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-12|0;x[a+8>>2]=b;continue}break}b=x[a>>2];if(b){ep(a);Ib(b)}}function Rf(a){a=a|0;var b=0;x[a>>2]=44344;x[x[a+20>>2]>>2]=0;b=x[a+16>>2];x[b+946300>>2]=x[b+946300>>2]-1;x[a+20>>2]=0;vN(a+44|0);return a|0}function Mt(a,b){var c=0,d=0;d=Jf(a,b);while(1){a:{c=d;if(!(c&65535)){c=0;break a}d=c-1|0;if(!Ce(a,b,d&65535)){continue}}break}return c&65535}function jC(a,b){var c=0,d=0,e=0;c=ib-16|0;ib=c;w[c+14>>1]=1;d=c,e=Gl(a,b),w[d+12>>1]=e;a=z[pe(c+14|0,c+12|0)>>1];ib=c+16|0;return a-1&65535}function Yz(a,b,c){var d=0;while(1){if((b|0)!=(c|0)){d=x[a>>2];x[a>>2]=d<<8^x[((y[b|0]^d>>>24)<<2)+29212>>2];b=b+1|0;continue}break}return a}function DL(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=ib-32|0;ib=g;h=g+8|0;dJ(h,b,c,d,e,f);$c(a,g+20|0);Am(h);ib=g+32|0}function sW(a){var b=0,c=0,d=0;b=ib-16|0;ib=b;c=b,d=ac(a),x[c+12>>2]=d;x[b+8>>2]=236;a=x[Yc(b+12|0,b+8|0)>>2];ib=b+16|0;kb=0;return a-216|0}function Po(a,b){var c=0;a:{if(!b){break a}if(!Ob(x[a>>2],x[a+8>>2],b)){break a}if(b>>>0<=3){c=wD(a,b);break a}c=Jg(a);Yb(a,b-4|0)}return c}function Me(a,b,c){v[a+11|0]=c;v[a+10|0]=b;v[a+12|0]=y[a+12|0]&251;w[a+8>>1]=65535;x[a>>2]=0;x[a+4>>2]=0;v[a+12|0]=y[a+12|0]&252|1;return a}function Lb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=ib-16|0;ib=d;if(b>>>0>=119){Cq(12106);p()}e=d+8|0;Ab(e,a,b);bf(e,c);ib=d+16|0;return a|0}function Gb(a,b){var c=0;if(Ue(y[a+11|0])){Ib(x[a>>2])}c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;x[a+8>>2]=x[b+8>>2];ee(b,0);ne(b,0);return a}function Dv(a,b){var c=0;a:{if(!b){break a}if(!Ob(x[a>>2],x[a+8>>2],b)){break a}if(b>>>0<=1){c=vD(a,1);break a}c=_g(a);Yb(a,b-2|0)}return c}function nl(a){var b=0,c=0,d=0;b=ib-16|0;ib=b;c=x[a+24>>2];d=x[a+40>>2];x[b+12>>2]=1;a=x[Yc(a+20|0,b+12|0)>>2];ib=b+16|0;return D(a,c+d|0)}function lI(a){var b=0,c=0;x[27524]=0;c=ga(1124)|0;b=x[27524];x[27524]=0;if((b|0)!=1){b=a;a=x[c>>2];x[b>>2]=a;fn(a);return}V(0)|0;Sb();p()}function cG(a,b,c,d,e){var f=0;f=c;c=0;a:{if(!d){break a}c=b>>8;if(!(b&1)){break a}c=Gw(x[d>>2],c)}lb[x[x[a>>2]+28>>2]](a,f,c+d|0,b&2?e:2)}function H$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=ib-16|0;ib=a;x[a+12>>2]=e;x[a+8>>2]=d-c;b=Hb(a+12|0,a+8|0);ib=a+16|0;return x[b>>2]}function lc(a,b){a=a|0;b=b|0;var c=0;a=jk(a);x[a+4>>2]=0;x[a>>2]=49200;c=Gd(Eb(b)+1|0);x[a+4>>2]=c;if(c){rc(c,Jc(b),Eb(b)+1|0)}return a|0}function dd(a){var b=0;b=ib-16|0;ib=b;x[b+12>>2]=a;x[b+8>>2]=-32768;x[b+4>>2]=32767;a=w[Ve(b+8|0,rd(b+12|0,b+4|0))>>1];ib=b+16|0;return a}function cfa(a){a=a|0;var b=0;b=x[a>>2];if(lb[x[x[b>>2]+32>>2]](b,0,32)|0){a=x[a>>2];a=lb[x[x[a>>2]+32>>2]](a,32,1)^1}else{a=0}return a|0}function Tj(a,b,c){var d=0,e=0,f=0;d=ib-16|0;ib=d;v[d+15|0]=b;v[d+14|0]=127;e=a,f=y[Ub(d+15|0,d+14|0)|0]|(c?-128:0),v[e+21|0]=f;ib=d+16|0}function Sj(a,b,c){var d=0,e=0,f=0;d=ib-16|0;ib=d;v[d+15|0]=b;v[d+14|0]=127;e=a,f=y[Ub(d+15|0,d+14|0)|0]|(c?-128:0),v[e+22|0]=f;ib=d+16|0}function OT(a){var b=0,c=0;b=ib-16|0;ib=b;c=x[a+4>>2];x[b>>2]=x[a>>2];x[b+4>>2]=c;c=Oe(b+8|0,b);a=x[c>>2];ib=b+16|0;kb=x[c+4>>2];return a}function KL(a,b){var c=0,d=0;a:{if(!Fs(b)){break a}c=x[a+484344>>2];if(!Ce(c,x[a+484348>>2],b&65535)){break a}d=x[Xb(c,b)+12>>2]}return d}function Gca(a,b){a=a|0;b=b|0;var c=0;b=ib-16|0;ib=b;c=x[a+20>>2];he(b,x[c+4>>2],x[c+8>>2]);yN(a,dc(b+8|0,x[b>>2],x[b+4>>2]),0);ib=b+16|0}function EA(a,b){var c=0,d=0;x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];x[a+8>>2]=x[b+8>>2];x[b>>2]=0;x[b+4>>2]=0;c=Db(b),d=0,x[c>>2]=d;return a}function CA(a){a=50-(D(y[(a>>>4|0)+31552|0],a&15)>>>4|0)|0;a=a>>>0>23863?65536:23863/(a>>>0)|0;return Dc((a+119315e4>>>0)/(a<<1>>>0)|0,0)}function vF(a,b,c){var d=0;while(1){if((a|0)!=(b|0)){d=x[a>>2];if(d>>>0<=127){d=x[(d<<2)+c>>2]}x[a>>2]=d;a=a+4|0;continue}break}return b}function rx(a,b){var c=0;if(b>>>0<=99){return sI(a,b)}if(b>>>0<=999){c=a;a=(b>>>0)/100|0;return ys(rI(c,a),D(a,-100)+b|0)}return kj(a,b)}function YW(a){var b=0,c=0,d=0;c=ib-16|0;ib=c;b=c+8|0;Tv(b,a);a=y[Jb(b,0)|0];d=y[Jb(b,1)|0];b=y[Jb(b,2)|0];ib=c+16|0;return a|d<<8|b<<16}function xP(a,b,c,d){var e=0;e=a+1074376|0;zz(a,e,b,c,d);e=0-y[(D(b,872)+e|0)+1428|0]|0;if(d){c=0}else{c=wt(x[a+480180>>2])}Tn(a,b,e,c)}function jr(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if((b|0)<0){_c();p()}b=(b-1>>>5|0)+1|0;c=CD(b);x[a+4>>2]=0;x[a>>2]=c;d=Db(a),e=b,x[d>>2]=e}function hM(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=ib-32|0;ib=g;h=g+8|0;dJ(h,b,c,d,e,f);$c(a,h);Am(h);ib=g+32|0}function gd(a,b){var c=0,d=0,e=0;c=kg(a,b);if(c){x[a+12>>2]=x[a+12>>2]+b;return c}d=a,e=lb[x[x[a>>2]+24>>2]](a)|0,x[d+12>>2]=e;return c}function XA(a){var b=0;b=Fb(y[a+26|0]|y[a+27|0]<<8);return((y[a+24|0]>15)+(y[a+25|0]>64)|0)+(Fb(y[a+22|0]|y[a+23|0]<<8)<<1>>>0<b>>>0)|0}function V3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=b;b=x[b>>2]+7&-8;x[c>>2]=b+16;d=a,e=mw(x[b>>2],x[b+4>>2],x[b+8>>2],x[b+12>>2]),C[d>>3]=e}function yca(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(!(!d|!Wc(c&255))){BN(a,8,E(0))}a=oj(a);if(a){lb[x[x[a>>2]+96>>2]](a,b,c,d,e)}}function Lea(a,b){a=a|0;b=b|0;a=sz(a);x[27524]=0;R(810,a|0,b|0);b=x[27524];x[27524]=0;if((b|0)==1){b=P()|0;bq(a);S(b|0);p()}return a|0}function $l(a){var b=0,c=0;c=x[a+4>>2];b=x[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-1|0;x[a+8>>2]=b;continue}break}a=x[a>>2];if(a){Ib(a)}}function x6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Ws(x[a+32>>2],b,c,d,2);if(a>>>0<=15){a=y[a+43760|0]}else{a=0}return(a>>>0<5?a+1|0:0)|0}function uba(a,b,c){a=a|0;b=b|0;c=E(c);var d=0;if(b>>>0<=4){c=Ld(c,E(0));d=((b<<2)+a|0)+4220|0;if((b|0)==4){c=$h(c)}B[d>>2]=c;XM(a)}}function uF(a,b,c){var d=0;while(1){if((a|0)!=(b|0)){d=v[a|0];if((d|0)>=0){d=x[(d<<2)+c>>2]}v[a|0]=d;a=a+1|0;continue}break}return b}function r7(a,b){a=a|0;b=b|0;var c=0;if((a|0)!=(b|0)){c=x[a+4>>2];if(c){Ib(c);x[a+4>>2]=0}x[a+4>>2]=x[b+4>>2];x[b+4>>2]=0}return a|0}function ffa(a,b){a=a|0;b=b|0;a=vC(a,b);if(!a){v[b+6|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b|0]=0;v[b+1|0]=0}return a|0}function ci(a,b,c){v[a|0]=b;v[a+1|0]=b>>>8;v[a+2|0]=b>>>16;v[a+3|0]=b>>>24;v[a+4|0]=c;v[a+5|0]=c>>>8;v[a+6|0]=c>>>16;v[a+7|0]=c>>>24}function aj(a,b){var c=0;if(kf(a)){c=x[a>>2];Kl(a);Ib(c)}c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;x[a+8>>2]=x[b+8>>2];ee(b,0);td(b,0)}function FU(a){var b=0;b=ib-16|0;ib=b;x[b+12>>2]=a;x[b+8>>2]=-128;x[b+4>>2]=127;a=v[Ve(b+8|0,rd(b+12|0,b+4|0))|0];ib=b+16|0;return a}function zs(a,b){var c=0,d=0;a:{if(b>>>0<=31){d=x[a>>2];c=a+4|0;break a}b=b-32|0;c=a}c=x[c>>2];x[a>>2]=d<<b;x[a+4>>2]=c<<b|d>>>32-b}function yP(a,b,c,d){var e=0;e=a+1074376|0;Az(a,e,b,c,d);e=y[(D(b,872)+e|0)+1427|0];if(d){c=0}else{c=wt(x[a+480180>>2])}Tn(a,b,e,c)}function sq(a,b){var c=0,d=0,e=0;if(zh(2147483647)>>>0<b>>>0){_c();p()}c=Mv(b);x[a>>2]=c;x[a+4>>2]=c;d=Db(a),e=(b<<1)+c|0,x[d>>2]=e}function oj(a){var b=0,c=0;b=$m(x[x[a+20>>2]+28>>2]);if(!(b>>>0>249|y[a+4200|0]>=b>>>0)){c=x[Nd(x[a+16>>2]+906300|0,b)>>2]}return c}function mx(a){a=a|0;var b=0;b=x[a+12>>2];if((b|0)==x[a+16>>2]){return lb[x[x[a>>2]+40>>2]](a)|0}x[a+12>>2]=b+1;return Ke(v[b|0])|0}function fg(a,b){a=a|0;b=b|0;var c=0,d=0;c=ib-16|0;ib=c;if(b>>>0>=119){Cq(12071);p()}d=c+8|0;Ab(d,a,b);bf(d,0);ib=c+16|0;return a|0}function Vh(a,b){var c=0,d=0;c=x[a>>2];d=x[a+4>>2];b=x[a+16>>2]+b|0;a=x[a+12>>2];b=(b|0)%(a|0)|0;return B[Mc(c,d,(b>>31&a)+b|0)>>2]}function Gk(a,b){var c=0,d=0,e=0;if(zh(1073741823)>>>0<b>>>0){_c();p()}c=Ii(b);x[a>>2]=c;x[a+4>>2]=c;d=Db(a),e=(b<<2)+c|0,x[d>>2]=e}function ZQ(a,b){var c=0,d=0,e=0;if(zh(268435455)>>>0<b>>>0){_c();p()}c=vS(b);x[a>>2]=c;x[a+4>>2]=c;d=Db(a),e=(b<<4)+c|0,x[d>>2]=e}function Vz(a,b){var c=0,d=0,e=0;if(zh(536870911)>>>0<b>>>0){_c();p()}c=jE(b);x[a>>2]=c;x[a+4>>2]=c;d=Db(a),e=(b<<3)+c|0,x[d>>2]=e}function Oea(a,b){a=a|0;b=b|0;var c=0,d=0;c=ib-16|0;ib=c;if(b>>>0>=250){Cq(12106);p()}d=c+8|0;Ab(d,a,b);uo(d);ib=c+16|0;return a|0}function O3(a){a=a|0;var b=0;if((lb[x[x[a>>2]+36>>2]](a)|0)!=-1){b=a;a=x[a+12>>2];x[b+12>>2]=a+1;a=Ke(v[a|0])}else{a=-1}return a|0}function Hu(a,b){var c=0,d=0,e=0;if(zh(715827882)>>>0<b>>>0){_c();p()}c=xV(b);x[a>>2]=c;x[a+4>>2]=c;d=Db(a),e=D(b,6)+c|0,x[d>>2]=e}function GI(a,b){a:{if(a&255){a=1;if((b|0)!=255){break a}aa(14224,13154,1180,5737);p()}if((b|0)==255){return 0}a=b>>>0>10}return a}function Bs(a,b){var c=0,d=0;c=x[a+4>>2];a:{if(b>>>0<=31){d=x[a>>2];break a}b=b-32|0;d=c;c=0}x[a+4>>2]=c>>>b;x[a>>2]=c<<32-b|d>>>b}function Ag(a){var b=0;b=ib-16|0;ib=b;x[b+12>>2]=a;x[b+8>>2]=0;x[b+4>>2]=255;a=y[Ve(b+8|0,rd(b+12|0,b+4|0))|0];ib=b+16|0;return a}function sD(a,b){var c=0;c=qoa(b&255,0,1536,0);b=kb;a=qoa(a&255,0,25,0);c=a+c|0;b=kb+b|0;b=a>>>0>c>>>0?b+1|0:b;a=c;kb=b;return a}function A2(a){a=a|0;var b=0,c=0;b=x[x[a>>2]>>2];c=x[b+8>>2];a=x[b+4>>2];b=x[b>>2]+(c>>1)|0;if(c&1){a=x[a+x[b>>2]>>2]}lb[a|0](b)}function z3(a){a=a|0;var b=0;if((lb[x[x[a>>2]+36>>2]](a)|0)!=-1){b=a;a=x[a+12>>2];x[b+12>>2]=a+4;a=x[a>>2]}else{a=-1}return a|0}function y$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){x[d>>2]=v[b|0];d=d+4|0;b=b+1|0;continue}break}return c|0}function x3(a,b){a=a|0;b=b|0;x[a+4>>2]=b;v[a|0]=0;b=x[x[b>>2]-12>>2]+b|0;if(fh(b)){b=x[b+72>>2];if(b){$H(b)}v[a|0]=1}return a|0}function sF(a,b,c){var d=0;d=ib-16|0;ib=d;x[d+8>>2]=a;x[d+12>>2]=b;x[d>>2]=c;x[d+4>>2]=0;a=hr(d+8|0,d);ib=d+16|0;return x[a>>2]}function pF(a,b,c,d){a=Nb(a);x[27524]=0;U(d|0,a|0,b|0,c|0);b=x[27524];x[27524]=0;if((b|0)!=1){return a}b=P()|0;uc(a);S(b|0);p()}function hY(a,b){a=a|0;b=b|0;x[a+4>>2]=b;v[a|0]=0;b=x[x[b>>2]-12>>2]+b|0;if(fh(b)){b=x[b+72>>2];if(b){Tm(b)}v[a|0]=1}return a|0}function eQ(a,b,c,d){a:{if(d>>>0>=64){d=-1;if(y[a+480180|0]&2){break a}}x[b+56>>2]=0;d=Zn(a,z[b+70>>1],x[b+48>>2],c,0)}return d}function Uz(a,b){var c=0;c=x[a+484360>>2];b=b&255;if(wj(c,x[a+484364>>2])>>>0<=b>>>0){return Tb(c,y[a+484376|0])}return Dj(c,b)}function Ud(a){var b=0;a=x[a+4>>2];if(a){if(ln(a)){a:{b=a+8|0;if(x[b>>2]){if((Yv(b)|0)!=-1){break a}}lb[x[x[a>>2]+16>>2]](a)}}}}function UG(a,b,c,d,e,f){a=lb[x[x[a+8>>2]+4>>2]](a+8|0)|0;a=is(c,d,a,a+288|0,f,e,0)-a|0;if((a|0)<=287){x[b>>2]=((a|0)/12|0)%12}}function RG(a,b,c,d,e,f){a=lb[x[x[a+8>>2]+4>>2]](a+8|0)|0;a=gs(c,d,a,a+288|0,f,e,0)-a|0;if((a|0)<=287){x[b>>2]=((a|0)/12|0)%12}}function Bx(a,b,c){var d=0;d=x[a+32>>2];if(A[a+40>>2]<d+c>>>0){x[a+96>>2]=1;return 0}rc(b,d,c);x[a+32>>2]=x[a+32>>2]+c;return 1}function Aq(a,b){var c=0;c=xd(x[a+4>>2],y[a+11|0]);if((c|0)==(xd(x[b+4>>2],y[b+11|0])|0)){a=jw(nd(a),nd(b),c)}else{a=1}return!a}function wR(a,b,c,d,e){x[a+12>>2]=e;x[a+8>>2]=d;x[a+4>>2]=c;x[a>>2]=b;if(b){vd(b,a)}if(c){vd(c,a)}if(d){vd(d,a)}if(e){vd(e,a)}}function q$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){v[d|0]=y[b|0];d=d+1|0;b=b+1|0;continue}break}return c|0}function hL(a){a=a|0;var b=0,c=0;b=ib-16|0;ib=b;c=Us(mc(8));x[c+4>>2]=a;x[c>>2]=50048;a=x[uf(b+8|0,c)>>2];ib=b+16|0;return a|0}function fF(a,b,c){a=$h(a);a:{if(a>=b){break a}c=0;if(a<=E(0)){break a}if(a<E(4294967296)&a>=E(0)){c=~~a>>>0;break a}}return c}function dt(a){var b=0;b=C[a+4248>>3]/+A[x[a+16>>2]+24620>>2];C[a+4264>>3]=b;if(y[a+4240|0]){C[a+4264>>3]=b*(C[a+4288>>3]/60)}}function Lq(a){var b=0;b=-1;a:{if(a>=4294967295){break a}b=0;if(a<=0){break a}if(a<4294967296&a>=0){return~~a>>>0}b=0}return b}function LC(a,b){var c=0;c=x[b+4>>2];if(c){cc(a,c,x[b>>2]);return}c=x[b+8>>2];b=x[b+12>>2];if(!pc(c,b)){he(a,c,b);return}Id(a)}function K$(a){a=a|0;var b=0;b=ib-16|0;ib=b;pi(qi(b+8|0,x[a+8>>2]));ib=b+16|0;a=x[a+8>>2];if(!a){return 1}return(lG(a)|0)==1|0}function JE(){var a=0,b=0,c=0;a=ib-16|0;ib=a;b=Kc(a,15021);if(Eb(b)){c=(Lg(b,13857)|0)!=-1}else{c=0}wb(b);ib=a+16|0;return c|0}function $J(a){a=a|0;var b=0,c=0;b=ib-16|0;ib=b;c=KJ(mc(8));x[c+4>>2]=a;x[c>>2]=73080;a=x[uf(b+8|0,c)>>2];ib=b+16|0;return a|0}function yl(a,b){var c=0;a:{if(A[a+12>>2]<b>>>0){c=0;if(lb[x[x[a>>2]+24>>2]](a)>>>0<b>>>0){break a}}x[a+12>>2]=b;c=1}return c}function gV(a,b){var c=0;c=ib-16|0;ib=c;a=Fh(c,a,1);Lm(x[a+4>>2],z[b>>1]|z[b+2>>1]<<16);x[a+4>>2]=x[a+4>>2]+4;ic(a);ib=c+16|0}function cr(a,b){return qo(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24),y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))?b:a}function Z_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(gh(a,x[b+8>>2],0)){Hw(b,c,d);return}a=x[a+8>>2];lb[x[x[a>>2]+28>>2]](a,b,c,d)}function Kw(a,b){var c=0,d=0,e=0,f=0;c=xf(b);d=mc(c+13|0);x[d+8>>2]=0;x[d+4>>2]=c;x[d>>2]=c;e=a,f=rc(zc(d),b,c+1|0),x[e>>2]=f}function HE(a){a=a|0;var b=0;a=Kb(a);x[27524]=0;R(140,a|0,13652);b=x[27524];x[27524]=0;if((b|0)==1){b=P()|0;xb(a);S(b|0);p()}}function sQ(a){Dz(a);x[a>>2]=0;x[a+4>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;a=zg(a);zg(a+12|0);v[a+24|0]=1}function qg(a,b,c){var d=0;d=4;a:{b:{switch(b-1|0){case 0:d=c;break a;case 1:break b;default:break a}}d=c?3:2}return fo(a,d)}function kl(a,b,c,d){var e=0;e=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=e;e=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=e;Iy(a,c,d)}function XU(a,b){a=a|0;b=b|0;var c=0;c=ib-16|0;ib=c;w[c+14>>1]=b;if((Gl(x[a>>2],x[a+4>>2])|0)!=65535){AC(a,c+14|0)}ib=c+16|0}function Vc(a,b,c){var d=0;d=a;a=c&31;if((c&63)>>>0>=32){c=b>>31;a=b>>a}else{c=b>>a;a=((1<<a)-1&b)<<32-a|d>>>a}kb=c;return a}function VG(a,b,c,d,e,f){a=lb[x[x[a+8>>2]>>2]](a+8|0)|0;a=is(c,d,a,a+168|0,f,e,0)-a|0;if((a|0)<=167){x[b>>2]=((a|0)/12|0)%7}}function SG(a,b,c,d,e,f){a=lb[x[x[a+8>>2]>>2]](a+8|0)|0;a=gs(c,d,a,a+168|0,f,e,0)-a|0;if((a|0)<=167){x[b>>2]=((a|0)/12|0)%7}}function PW(a){var b=0;a:{if(Qb(a,3863,4)){break a}if(Qb(a+44|0,17817,3)){break a}b=(y[a+47|0]|y[a+48|0]<<8)>>>0>97}return b}function eca(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=0;if(b>>>0<=2){d=(a+b|0)+4232|0,e=qh(E(Ld(c,E(0))*E(127))),v[d|0]=e;bt(a)}}function Zca(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=0;if(b>>>0<=3){d=(a+b|0)+4264|0,e=qh(E(Ld(c,E(0))*E(255))),v[d|0]=e;ft(a)}}function SM(a){a=a|0;var b=0,c=0;b=a+4960|0;c=a+4504|0;while(1){b=uc(b-24|0);if((c|0)!=(b|0)){continue}break}return Rf(a)|0}function yla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);d=b+c|0;c=Xh(b,d);if(c){Pl(a,c);Fu(a,b,d,c)}}function rO(a,b){var c=0;if(!(y[a|0]!=y[b|0]|C[a+8>>3]!=C[b+8>>3]|y[a+16|0]!=y[b+16|0])){c=x[a+20>>2]==x[b+20>>2]}return c}function hT(a){var b=0,c=0;while(1){b=c;if((b|0)!=8){c=b+1|0;if((y[a+b|0]-127&255)>>>0>160){continue}}break}return(b|0)==8}function gF(a,b){x[a>>2]=b;lI(a+4|0);x[a+24>>2]=0;x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;return a}function JA(a){x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;return a}function Bo(a){x[a+32>>2]=0;x[a+24>>2]=0;x[a+28>>2]=0;x[a>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[a+16>>2]=0;return a}function Au(a,b,c){c=c&255;while(1){a:{if(!b){a=0;break a}if(pc(y[a|0],c)){break a}b=b-1|0;a=a+1|0;continue}break}return a}function re(a,b,c){var d=0;a:{if((b|0)>(c|0)){break a}d=x[a>>2];if((d|0)>=(b|0)){b=c;if((d|0)<=(b|0)){break a}}x[a>>2]=b}}function Xo(a,b,c){var d=0;a:{if(b>>>0>c>>>0){break a}d=x[a>>2];if(d>>>0>=b>>>0){b=c;if(d>>>0<=b>>>0){break a}}x[a>>2]=b}}function p4(a,b,c){a=a|0;b=b|0;c=c|0;while(1){if((a|0)!=(b|0)){Pg(x[c>>2],a);x[c>>2]=x[c>>2]+12;a=a+12|0;continue}break}}function lN(a,b,c){var d=0,e=0;d=ad(a);if(d>>>0>=c>>>0){ny(a,ai(vc(a),b,c),c);return}e=a;a=Eb(a);qp(e,d,c-d|0,a,0,a,c,b)}function hh(a,b,c,d,e){var f=0;f=ib-16|0;ib=f;x[f+12>>2]=e;c=qi(f+8|0,c);a=ks(a,b,d,x[f+12>>2]);pi(c);ib=f+16|0;return a}function WH(a){var b=0;b=x[a+12>>2];if((b|0)==x[a+16>>2]){return lb[x[x[a>>2]+40>>2]](a)|0}x[a+12>>2]=b+4;return x[b>>2]}function QR(a,b,c,d,e,f,g){v[a+17|0]=g;v[a+16|0]=f;x[a+12>>2]=e;x[a+8>>2]=d;x[a+4>>2]=c;x[a>>2]=b;if(d){NR(a,1);NR(a,0)}}function PR(a,b,c,d,e,f,g){v[a+17|0]=g;v[a+16|0]=f;x[a+12>>2]=e;x[a+8>>2]=d;x[a+4>>2]=c;x[a>>2]=b;if(d){OR(a,1);OR(a,0)}}function FS(a){var b=0;if(!(y[a+35|0]&2)){a=a+68|0;b=9;while(1){if(b){x[a>>2]=268435456;b=b-1|0;a=a+4|0;continue}break}}}function DU(a,b){var c=0;c=ib-16|0;ib=c;a:{if(!kg(a,4)){rV(b);break a}Ph(c+8|0,b);WA(c,a,x[c+8>>2],x[c+12>>2])}ib=c+16|0}function Bi(a,b,c){c=y[c|0];while(1){a:{if((a|0)!=(b|0)){if((c|0)!=y[a|0]){break a}}else{a=b}return a}a=a+1|0;continue}}function z_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=b;b=0;return lb[a|0](h|b,c,d,e,b|f,g)|0}function saa(a){a=a|0;var b=0;b=ib-16|0;ib=b;if(a){a=qc(b+8|0,a);a=gy(x[a>>2],x[a+4>>2])}else{a=0}ib=b+16|0;return a|0}function df(a){var b=0;b=x[a+32>>2];a:{if(b>>>0>=A[a+40>>2]){x[a+96>>2]=1;a=0;break a}x[a+32>>2]=b+1;a=y[b|0]}return a}function bU(a){var b=0;if(!(Qb(a,13809,3)|y[a+3|0]>31|(v[a+27|0]<0|y[a+32|0]>64))){b=(y[a+33|0]-1&255)>>>0<32}return b}function _V(a,b,c){var d=0;while(1){if(b){d=y[c|0]|y[c+1|0]<<8;v[a|0]=d;v[a+1|0]=d>>>8;b=b-1|0;a=a+2|0;continue}break}}function WP(a,b,c,d){var e=0,f=0;if(c&255){e=a,f=Vb(x[a>>2]+((D((d^-1|-256)+b|0,c<<24>>24)|0)/2|0)|0,0,256),x[e>>2]=f}}function Ss(a){a=a|0;var b=0;x[a>>2]=49260;vd(a,0);b=x[a+8>>2];if(b){lb[x[x[b>>2]+4>>2]](b)}x[a+8>>2]=0;return om(a)|0}function Pl(a,b){var c=0,d=0,e=0;if(zh(-1)>>>0<b>>>0){_c();p()}c=mc(b);x[a>>2]=c;x[a+4>>2]=c;d=Db(a),e=b+c|0,x[d>>2]=e}function Ot(a){var b=0,c=0,d=0;d=a*a;a=0;b=1;c=1;while(1){a=a+2;c=d*c/(a*a);b=b+c;if(b*1e-7<c){continue}break}return b}function mfa(a){a=a|0;var b=0,c=0;b=ib-16|0;ib=b;c=uf(b+8|0,Rb(mc(6668),0,6668));ib=b+16|0;x[a>>2]=x[c>>2];return a|0}function jF(a,b,c){a=Be(a);a:{if(a>=b){break a}c=0;if(a<=0){break a}if(a<4294967296&a>=0){c=~~a>>>0;break a}}return c}function Ri(a){var b=0;while(1){a:{if((b|0)!=46){if(y[b+43792|0]!=(a|0)){break a}}else{b=0}return b}b=b+1|0;continue}}function Oaa(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=E(0);if(b>>>0<=2){c=Ld(c,E(0));d=Bb(a+4208|0,b),e=c,B[d>>2]=e;OM(a)}}function Jba(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=E(0);if(b>>>0<=5){c=Ld(c,E(0));d=Bb(a+4208|0,b),e=c,B[d>>2]=e;cN(a)}}function Haa(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=E(0);if(b>>>0<=3){c=Ld(c,E(0));d=Bb(a+4208|0,b),e=c,B[d>>2]=e;LM(a)}}function Bba(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=E(0);if(b>>>0<=4){c=Ld(c,E(0));d=Bb(a+4208|0,b),e=c,B[d>>2]=e;ZM(a)}}function $G(a,b,c){var d=0;d=ib-16|0;ib=d;x[d+12>>2]=c;b=qi(d+8|0,b);a=zH(a,9210,x[d+12>>2]);pi(b);ib=d+16|0;return a}function ap(a){var b=0,c=0;c=x[a>>2];b=x[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-36|0;sr(b);continue}break}x[a+4>>2]=c}function YR(a){x[a+700>>2]=0;w[a+842>>1]=0;x[a+688>>2]=0;x[a>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[a+16>>2]=0}function Xg(a){var b=0;Jm(a);b=$t(x[a>>2],Mk(z[a+34>>1]));x[a+20>>2]=b;if(!b){return 0}return Nj(x[a>>2],z[a+34>>1])}function OX(a){var b=0,c=0;c=x[a>>2];b=x[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-28|0;yd(b);continue}break}x[a+4>>2]=c}function zh(a){var b=0;b=ib-16|0;ib=b;x[b+12>>2]=a;x[b+8>>2]=2147483647;a=Hb(b+12|0,b+8|0);ib=b+16|0;return x[a>>2]}function eO(a){var b=0,c=0,d=0;if(x[a>>2]){Ic(a);b=x[a>>2];Wu(a);Ib(b);c=Db(a),d=0,x[c>>2]=d;x[a>>2]=0;x[a+4>>2]=0}}function OQ(a){var b=0,c=0,d=0;if(x[a>>2]){Ic(a);b=x[a>>2];mn(a);Ib(b);c=Db(a),d=0,x[c>>2]=d;x[a>>2]=0;x[a+4>>2]=0}}function Mi(a){var b=0;b=ib-16|0;ib=b;x[b+12>>2]=a;x[b+8>>2]=2147483647;a=x[Hb(b+12|0,b+8|0)>>2];ib=b+16|0;return a}function LR(a){var b=0,c=0,d=0;if(x[a>>2]){Ic(a);b=x[a>>2];_m(a);Ib(b);c=Db(a),d=0,x[c>>2]=d;x[a>>2]=0;x[a+4>>2]=0}}function Ku(a){var b=0,c=0,d=0;if(x[a>>2]){Ic(a);b=x[a>>2];_h(a);Ib(b);c=Db(a),d=0,x[c>>2]=d;x[a>>2]=0;x[a+4>>2]=0}}function EH(a,b,c,d,e,f,g,h,i){x[a>>2]=b;x[a+4>>2]=c;x[a+8>>2]=d;x[a+12>>2]=e&65535|(i>>>16&32768|e>>>16&32767)<<16}function $u(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ib-16|0;ib=d;Um(d+8|0,b);x[d+4>>2]=x[d+8>>2];Su(a,d+4|0,c);ib=d+16|0}function xT(a){var b=0;if(!(Qb(a+44|0,13818,4)|y[a+29|0]!=16)){b=((y[a+42|0]|y[a+43|0]<<8)-1&65535)>>>0<2}return b}function rc(a,b,c){var d=0;if(c){d=a;while(1){v[d|0]=y[b|0];d=d+1|0;b=b+1|0;c=c-1|0;if(c){continue}break}}return a}function RX(a,b,c,d,e){v[a+4|0]=b;v[a|0]=69;v[a+1|0]=99;v[a+2|0]=104;v[a+3|0]=111;v[a+7|0]=e;v[a+6|0]=d;v[a+5|0]=c}function EI(a,b,c){var d=0,e=0,f=0;e=c*c;C[a>>3]=e;f=c;d=c*134217729;c=d+(c-d);d=f-c;C[b>>3]=d*d+((c+c)*d+(c*c-e))}function Dd(a,b){var c=0;c=b+4|0;nq(x[a>>2],x[a+4>>2],c);oc(a,c);oc(a+4|0,b+8|0);oc(Db(a),zc(b));x[b>>2]=x[b+4>>2]}function vO(a,b){var c=0,d=0;c=x[a+4>>2];d=x[b+4>>2];if((c|0)==(d|0)){a=wO(x[a>>2],c,x[b>>2],d)}else{a=1}return!a}function ml(a,b){var c=0;c=b&15;if(c){v[a+824|0]=c<<2}b=b&240;if(b){v[a+823|0]=b>>>4}x[a+88>>2]=x[a+88>>2]|131072}function hs(a,b){a:{if((a|0)==(b|0)){break a}while(1){b=b-4|0;if(b>>>0<=a>>>0){break a}oc(a,b);a=a+4|0;continue}}}function dm(a,b){a:{if((a|0)==(b|0)){break a}while(1){b=b-1|0;if(b>>>0<=a>>>0){break a}Qi(a,b);a=a+1|0;continue}}}function cQ(a,b){var c=0;c=b&15;if(c){v[a+827|0]=c<<2}b=b&240;if(b){v[a+826|0]=b>>>4}x[a+88>>2]=x[a+88>>2]|262144}function bI(a,b){a=a|0;b=b|0;var c=0;c=x[a>>2];a:{if(!c){break a}if(!pc(eI(c,b),-1)){break a}x[a>>2]=0}return a|0}function YM(a){a=a|0;x[a+4244>>2]=0;x[a+4248>>2]=0;x[a+4228>>2]=0;x[a+4232>>2]=0;a=a+4252|0;x[a>>2]=0;x[a+4>>2]=0}function g8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(a){c=a;a=lb[x[x[b>>2]+8>>2]](b)|0;d=c,e=mg(a?a:21631),x[d>>2]=e}}function RS(a){if(Qb(a,13791,4)){a=0}else{a=(ac(y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24))|0)==1}return a}function $R(a){var b=0,c=0;c=x[a+4>>2];b=x[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-4|0;x[a+8>>2]=b;continue}break}}function ok(a,b){var c=0;c=1;a:{switch((b&255)-4|0){default:c=(a&255)==11;break;case 0:case 2:break a}}return c}function ij(a){a:{a=x[a+4>>2]&74;if(a){if((a|0)==64){return 8}if((a|0)!=8){break a}return 16}return 0}return 10}function a3(a,b){a=a|0;b=b|0;var c=0,d=0;lb[x[x[a>>2]+24>>2]](a)|0;b=bx(b);x[a+36>>2]=b;c=a,d=En(b),v[c+44|0]=d}function Vm(a){a=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);return a<<24|a<<8&16711680|(a>>>8&65280|a>>>24)}function U2(a,b){a=a|0;b=b|0;var c=0,d=0;lb[x[x[a>>2]+24>>2]](a)|0;b=fx(b);x[a+36>>2]=b;c=a,d=En(b),v[c+44|0]=d}function Sw(a,b,c){while(1){a:{if((a|0)!=(b|0)){if(x[a>>2]!=(c|0)){break a}}else{a=b}return a}a=a+4|0;continue}}function tF(a,b){var c=0,d=0;c=a+68|0;a=0;while(1){if((a|0)!=9){d=Bb(c,a);a=a+1|0;x[d>>2]=a<<b;continue}break}}function nG(a,b){var c=0;c=ib-16|0;ib=c;a=_l(c,a,1);Uk(x[a+4>>2],y[b|0]);x[a+4>>2]=x[a+4>>2]+1;ic(a);ib=c+16|0}function iT(a,b){var c=0;c=b&255;b=c>>>24|0;a=a&255?1120:1056;c=a+(c<<8)|0;b=a>>>0>c>>>0?b+1|0:b;kb=b;return c}function gh(a,b,c){if(!c){return x[a+4>>2]==x[b+4>>2]}if((a|0)==(b|0)){return 1}return!Ei(x[a+4>>2],x[b+4>>2])}function bf(a,b){var c=0;c=x[a+4>>2];if(b){a=x[a>>2];x[a>>2]=x[a>>2]|c;return}a=x[a>>2];x[a>>2]=x[a>>2]&(c^-1)}function Yu(a,b){var c=0;c=ib-16|0;ib=c;x[c+12>>2]=(D(a,b)>>>0)/255;re(c+12|0,0,15);ib=c+16|0;return y[c+12|0]}function XN(a){var b=0;b=ib-16|0;ib=b;x[b+12>>2]=a;x[b+8>>2]=32767;a=w[Hb(b+12|0,b+8|0)>>1];ib=b+16|0;return a}function Fl(a){var b=0;b=ib-16|0;ib=b;x[b+12>>2]=a;x[b+8>>2]=65535;a=z[Hb(b+12|0,b+8|0)>>1];ib=b+16|0;return a}function yO(a,b){a:{switch(b-1|0){default:return a+724|0;case 0:return a+732|0;case 1:break a}}return a+740|0}function qP(a){x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+28>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[a+16>>2]=0;return a}function ol(a,b,c,d){var e=0;e=ib-16|0;ib=e;x[e+12>>2]=d;x[e+8>>2]=c;dc(a,b,x[Hb(e+12|0,e+8|0)>>2]);ib=e+16|0}function Uu(a){var b=0;b=ib-16|0;ib=b;w[b+14>>1]=a;w[b+12>>1]=255;a=y[Tc(b+14|0,b+12|0)|0];ib=b+16|0;return a}function Pp(a,b){var c=0;c=ib-32|0;ib=c;Ph(c+16|0,b);Bn(c+24|0,a,x[c+16>>2],x[c+20>>2]);Ph(c+8|0,b);ib=c+32|0}function PO(a,b){var c=0;c=ib-16|0;ib=c;a=pA(c,a);pq(x[a+4>>2],x[b>>2]);x[a+4>>2]=x[a+4>>2]+4;ic(a);ib=c+16|0}function Fw(a,b,c,d,e,f,g){var h=0;h=b>>8;if(b&1){h=Gw(x[e>>2],h)}lb[x[x[a>>2]+20>>2]](a,c,d,e+h|0,b&2?f:2,g)}function x4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=x[c>>2];ri(x[b+24>>2],d,x[c+4>>2]);cc(a,d,x[x[b+24>>2]+4>>2])}function tR(a){var b=0;b=x[a+4>>2];w[a+70>>1]=y[((z[b+20>>1]>>>6|z[b+22>>1]<<4)&65535)+29072|0]>>>z[a+68>>1]}function sx(a,b){var c=0;if(b>>>0<=9999){return rx(a,b)}c=a;a=(b>>>0)/1e4|0;return kj(rx(c,a),D(a,-1e4)+b|0)}function gI(a){var b=0;b=x[a+12>>2];if((b|0)==x[a+16>>2]){return lb[x[x[a>>2]+36>>2]](a)|0}return Ke(v[b|0])}function TG(a,b,c,d,e){b=cj(b,c,d,e,4);if(!(y[d|0]&4)){x[a>>2]=((b|0)<69?b+2e3|0:(b|0)<100?b+1900|0:b)-1900}}function QG(a,b,c,d,e){b=bj(b,c,d,e,4);if(!(y[d|0]&4)){x[a>>2]=((b|0)<69?b+2e3|0:(b|0)<100?b+1900|0:b)-1900}}function tU(a,b){v[a+6|0]=255;x[a+16>>2]=0;w[a+4>>1]=0;x[a>>2]=0;if(b>=0){C[a+8>>3]=b;x[a+16>>2]=3}return a}function ql(a,b,c,d){a=a&65535;c=c&65535;a=(a|0)!=(c|0)?a>>>0<c>>>0?-1:1:0;if(Bj(a)){a=NQ(b,d)}return Ue(a)}function VI(a,b,c,d){B[d+4>>2]=a+c;a=E(a+E(c*E(-.5)));b=E(b*E(.8660253882408142));B[d+8>>2]=a-b;B[d>>2]=b+a}function Tka(a,b){a=a|0;b=b|0;if(!eV(a,b)){v[b+4|0]=0;v[b+5|0]=0;v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0}}function Nl(a){var b=0;b=ib-16|0;ib=b;x[b+12>>2]=a;x[b+8>>2]=255;a=y[Hb(b+12|0,b+8|0)|0];ib=b+16|0;return a}function Ey(a,b){a=Nb(a);x[a+20>>2]=0;x[a+12>>2]=0;x[a+16>>2]=0;Nb(a+24|0);Kb(a+36|0);x[a+48>>2]=b;return a}function Dm(a,b){var c=0;c=ib-16|0;ib=c;x[c+8>>2]=a;a=c+8|0;x[a>>2]=x[a>>2]+(b<<2);ib=c+16|0;return x[a>>2]}function zfa(){var a=0;a=ib-16|0;ib=a;if($a(a+12|0,4)|0){xs(x[12e4],12606);p()}ib=a+16|0;return x[a+12>>2]}function t8(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return KF(a,b,c,d,e,f,g,12941,1046)|0}function koa(a,b){a=a|0;b=b|0;var c=0;b=ib-16|0;ib=b;c=-1;if(Xj(a,b+8|0)){c=ZX(b+8|0)}ib=b+16|0;return c|0}function ir(a){var b=0;b=ib-16|0;ib=b;a=x[Wb(b+8|0,nd(a)+xd(x[a+4>>2],y[a+11|0])|0)>>2];ib=b+16|0;return a}function ST(a){var b=0;if(!(Qb(a,17812,4)|y[a+5|0]!=16|(y[a+54|0]-33&255)>>>0<224)){b=y[a+4|0]>95}return b}function Jna(a,b){a=a|0;b=b|0;var c=0;b=ib-80|0;ib=b;c=-1;if(CX(a,b+8|0)){c=BX(b+8|0)}ib=b+80|0;return c|0}function Jka(a,b){a=a|0;b=b|0;var c=0;b=ib-16|0;ib=b;c=-1;if(Xj(a,b+8|0)){c=RU(b+8|0)}ib=b+16|0;return c|0}function Et(a){var b=0,c=0;while(1){if(b>>>0>=8){a=c<<24>>24}else{b=b+15|0;c=Wn(a);continue}break}return a}function Cv(a,b){a:{switch(b-1|0){default:return a+48|0;case 0:return a+68|0;case 1:break a}}return a+88|0}function A8(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return KF(a,b,c,d,e,f,g,12873,1039)|0}function kG(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;x[e>>2]=c;x[h>>2]=f;return 3}function al(a){var b=0;b=x[a+12>>2];if((b|0)==x[a+16>>2]){return lb[x[x[a>>2]+36>>2]](a)|0}return x[b>>2]}function Zr(a,b,c,d,e,f){var g=0;g=b>>8;if(b&1){g=Gw(x[d>>2],g)}lb[x[x[a>>2]+24>>2]](a,c,d+g|0,b&2?e:2,f)}function YF(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=a;a=0;return _x(g|a,b,c,d,a|e,f)|0}function XQ(a,b){var c=0;c=x[a+484344>>2];if(Ce(c,x[a+484348>>2],b)){a=x[Xb(c,b)+12>>2]}else{a=1}return a}function JK(a,b){a=a|0;b=b|0;a=jk(a);x[a+4>>2]=0;x[a>>2]=49200;x[a+4>>2]=x[b+4>>2];x[b+4>>2]=0;return a|0}function te(a,b){a=Rl(a,x[b>>2],x[b+4>>2]);x[a+8>>2]=x[b+8>>2];Rl(a+12|0,x[b+12>>2],x[b+16>>2]);return a}function YO(a,b){var c=0;c=x[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-52|0;ll(c);continue}break}x[a+4>>2]=b}function WS(a,b){var c=0;c=x[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-12|0;VS(c);continue}break}x[a+4>>2]=b}function WC(a,b){var c=0;c=x[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-20|0;yb(c);continue}break}x[a+4>>2]=b}function RQ(a,b){var c=0;c=x[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-12|0;$e(c);continue}break}x[a+4>>2]=b}function Qja(a,b,c){a=a|0;b=b|0;c=c|0;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);if(b){sq(a,b);No(a,b,c)}return a|0}function Pb(a,b,c){var d=0;c=x[a+4>>2]+c|0;d=b;b=x[a>>2]+b|0;c=d>>>0>b>>>0?c+1|0:c;x[a>>2]=b;x[a+4>>2]=c}function CR(a,b){var c=0;c=x[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-32|0;tl(c);continue}break}x[a+4>>2]=b}function z7(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return uL(x[a+4>>2],b,c,d,e,f,g)|0}function uQ(a,b){var c=0,d=0;a:{if(b<0){break a}c=C[a>>3];if(!(c<0)){d=b;if(!(b<c)){break a}}C[a>>3]=d}}function m$(){if(y[483564]){return x[120890]}Gp(483556,jM());v[483564]=1;x[120890]=483556;return 483556}function eX(a){a:{if(Qb(a,14181,4)){break a}if(Qb(a+8|0,14162,4)){break a}return 1}return!Qb(a,14162,4)}function U7(a){a=a|0;var b=0;b=ib-16|0;ib=b;ye(b+8|0,a);a=gy(x[b+8>>2],x[b+12>>2]);ib=b+16|0;return a|0}function QV(a,b,c){a=a|0;b=b|0;c=c|0;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);if(b){Hu(a,b);uB(a,b,c)}return a|0}function JY(a,b,c){a=a|0;b=b|0;c=c|0;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);if(b){Gk(a,b);ZC(a,b,c)}return a|0}function Io(a,b,c){a=a|0;b=b|0;c=c|0;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);if(b){Pl(a,b);To(a,b,c)}return a|0}function D7(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return BL(x[a+4>>2],b,c,d,e,f,g)|0}function lG(a){var b=0,c=0;b=ib-16|0;ib=b;a=qi(b+8|0,a);c=x[x[120026]>>2];pi(a);ib=b+16|0;return c?4:1}function jZ(a){a=a|0;var b=0,c=0;b=ib-16|0;ib=b;c=-1;if(Xj(a,b+8|0)){c=_D(b+8|0)}ib=b+16|0;return c|0}function iS(a){if(((y[a+68|0]|y[a+69|0]<<8)-128&65535)>>>0>=65409){a=Qb(a,17660,17)}else{a=1}return!a}function iP(a){a=Kb(a);Kb(a+12|0);Kb(a+24|0);Kb(a+36|0);Kb(a+48|0);x[a+60>>2]=0;x[a+64>>2]=0;return a}function br(a,b,c){var d=0;d=ib-16|0;ib=d;if(b){v[d+15|0]=0;bO(a+36|0,b,Bi(b,b+c|0,d+15|0))}ib=d+16|0}function bC(a,b){if(b>>>0<=126){lf(((b<<5)+a|0)+480280|0);io((D(b,872)+a|0)+1074992|0,a,b,134217728)}}function Rb(a,b,c){var d=0;if(c){d=a;while(1){v[d|0]=b;d=d+1|0;c=c-1|0;if(c){continue}break}}return a}function RZ(a){a=a|0;var b=0,c=0;b=ib-32|0;ib=b;c=-1;if(EE(a,b+8|0)){c=DE(b+8|0)}ib=b+32|0;return c|0}function LB(a){a=a|0;var b=0;w[a+34>>1]=0;b=a+43|0;sm(b,b+22|0,78304);x[a+20>>2]=0;md(a,0);return a|0}function $V(a,b){var c=0,d=0,e=0;c=ib-16|0;ib=c;d=c,e=Fb(b&65535),w[d+14>>1]=e;GK(a,c+14|0);ib=c+16|0}function $B(a){var b=0,c=0;if(x[a>>2]){Ic(a);Ib(x[a>>2]);b=Db(a),c=0,x[b>>2]=c;x[a>>2]=0;x[a+4>>2]=0}}function kS(a){Zd(a+140|0);yb(a+120|0);yb(a+100|0);yb(a+80|0);yb(a+60|0);yb(a+40|0);yb(a+20|0);yb(a)}function k4(a,b){a=a|0;b=b|0;var c=0;c=ib-16|0;ib=c;JC(c+8|0,b);kr(a,x[c+8>>2],x[c+12>>2]);ib=c+16|0}function jv(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0}function fP(a){x[a+20>>2]=0;v[a+16|0]=7;x[a+8>>2]=1889785610;x[a+12>>2]=1072630333;v[a|0]=3;return a}function Zj(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0}function XY(a,b){a=a|0;b=b|0;var c=0;c=ib-16|0;ib=c;Xm(c+8|0,b);kr(a,x[c+8>>2],x[c+12>>2]);ib=c+16|0}function WY(a,b){a=a|0;b=b|0;x[a>>2]=0;x[a+4>>2]=0;vk(a+8|0,0);jr(a,127);DD(a,127,y[b|0]);return a|0}function Mj(a){a=a|0;var b=0,c=0;b=ib-16|0;ib=b;if(Vo(a,b+8|0)){c=Fb(z[b+8>>1])}ib=b+16|0;return c|0}function JV(a,b){var c=0;c=x[a>>2];x[a>>2]=b;if(c){HV(c+52|0);xb(c+40|0);uc(c+16|0);uc(c+4|0);Ib(c)}}function Go(a){a=a|0;var b=0,c=0;b=ib-16|0;ib=b;if(Zo(a,b+8|0)){c=ac(x[b+8>>2])}ib=b+16|0;return c|0}function CU(a){w[a+10>>1]=0;w[a+12>>1]=0;w[a+8>>1]=1084;x[a>>2]=0;x[a+4>>2]=40;w[a+14>>1]=0;return a}function Aca(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=oj(a);if(a){lb[x[x[a>>2]+88>>2]](a,b,c,d,e)}}function yV(a,b,c){var d=0;d=c;b=b-a|0;c=x[c>>2]+D((b|0)/-6|0,6)|0;x[d>>2]=c;if((b|0)>0){rc(c,a,b)}}function wca(a,b,c){a=a|0;b=b|0;c=c|0;a=oj(a);if(!a){return 0}return lb[x[x[a>>2]+104>>2]](a,b,c)|0}function v6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=qA(Ws(x[a+32>>2],b,c,d,3));return(a>>>0<5?a+1|0:0)|0}function oP(a,b){var c=0,d=0;c=x[a+4>>2];d=x[b+4>>2];return(c|0)<=(d|0)&A[b>>2]>A[a>>2]|(c|0)<(d|0)}function KO(a,b){if(b>>>0<=255){a=x[((b<<2)+a|0)+900380>>2];a=a?a+492|0:21631}else{a=21631}return a}function $c(a,b){var c=0;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;x[a+8>>2]=x[b+8>>2];BE(b);return a}function vka(a){a=a|0;var b=0;b=ib-16|0;ib=b;a=Vo(a,b+8|0);ib=b+16|0;return(a?z[b+8>>1]:0)<<16>>16}function sg(a,b,c){var d=0;d=c;c=x[a>>2];d=x[a+4>>2]-(d+(c>>>0<b>>>0)|0)|0;x[a>>2]=c-b;x[a+4>>2]=d}function mG(a,b,c,d,e){var f=0;f=ib-16|0;ib=f;e=qi(f+8|0,e);a=ls(a,b,c,d);pi(e);ib=f+16|0;return a}function d8(a,b){a=a|0;b=b|0;var c=0;b=Jc(b);c=x[a+4>>2];if(c){lb[c|0](b,x[a+8>>2]);return}_s(b,a)}function Zja(a,b){a=a|0;b=b|0;var c=0;b=ib-16|0;ib=b;c=-1;if(dC(a,b)){c=kU(b)}ib=b+16|0;return c|0}function VQ(a,b,c){var d=0;d=ib-16|0;ib=d;a=x[Wb(d+8|0,MQ(b,c,Td(a),gc(a)))>>2];ib=d+16|0;return a}function Ev(a){a=a|0;var b=0;b=ib-16|0;ib=b;a=Hg(a,b+15|0);ib=b+16|0;return(a?y[b+15|0]:0)<<24>>24}function R8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;lb[x[x[b>>2]+8>>2]](b,c);d=a;a=b+4|0;Gp(d,a);qL(a,c)}function Ix(a,b,c){b=(D(D(Gx(a),Hx(a,b)),125)>>>0)/(aJ(a,b)>>>0)|0;a=(a&6)==6?b&-4:b;return a?a:c}function ui(a,b,c){if(c){while(1){x[a>>2]=x[b>>2];a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}}function q9(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return PF(a,b,c,d,e,f,10602,1010)|0}function loa(a){a=a|0;var b=0;b=x[a+76>>2];if(pc(-1,b)){b=hD(a,32);x[a+76>>2]=b}return b<<24>>24}function Ow(a,b,c,d){var e=0;e=ib-16|0;ib=e;cc(e+8|0,c,d);WG(a,b,x[e+8>>2],x[e+12>>2]);ib=e+16|0}function Op(a,b){var c=0;c=ib-16|0;ib=c;x[c+8>>2]=x[a>>2];a=x[DB(c+8|0,b)>>2];ib=c+16|0;return a}function K3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;lb[x[x[a>>2]+12>>2]](a,b,c,d,e,f)|0}function J3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;lb[x[x[a>>2]+24>>2]](a,b,c,d,e,f)|0}function I3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;lb[x[x[a>>2]+16>>2]](a,b,c,d,e,f)|0}function H3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;lb[x[x[a>>2]+28>>2]](a,b,c,d,e,f)|0}function GF(a,b,c){var d=0;d=ib-16|0;ib=d;c=Kc(d,c);a=lc(a,c);wb(c);x[a>>2]=b;ib=d+16|0;return a}function G3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;lb[x[x[a>>2]+20>>2]](a,b,c,d,e,f)|0}function F3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;lb[x[x[a>>2]+44>>2]](a,b,c,d,e,f)|0}function D8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return PF(a,b,c,d,e,f,10557,1036)|0}function Bn(a,b,c,d){var e=0;e=ib-16|0;ib=e;lg(e+8|0,c,d);WG(a,b,x[e+8>>2],x[e+12>>2]);ib=e+16|0}function AA(a,b,c){b=b-a>>2;while(1){if((b|0)>0){x[a>>2]=x[c>>2];b=b-1|0;a=a+4|0;continue}break}}function zC(a,b){a=a|0;b=b|0;if(!fv(a,b)){v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0}}function o3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;lb[x[x[b>>2]+16>>2]](a,b,x[c+8>>2],x[c+12>>2],0,d)}function nla(a){a=a|0;var b=0;b=ib-16|0;ib=b;a=Zo(a,b+8|0);ib=b+16|0;return E(a?B[b+8>>2]:E(0))}function jY(a,b){a=a|0;b=b|0;if(!fv(a,b)){v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b|0]=0}}function hea(a,b){a=a|0;b=b|0;Ci(a);Ci(a);a:{if(b>>>0>=60){Yb(a,4);break a}Ci(a)}return Ci(a)|0}function dU(a){var b=0,c=0;b=1;c=x[a>>2];a:{if((c|0)>0){b=120;if(c>>>0<121){break a}}x[a>>2]=b}}function T_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;if(gh(a,x[b+8>>2],f)){Jw(b,c,d,e)}}function St(a,b){b=qoa(a,a>>31,b,b>>31)+5e5|0;a=kb;return Dc(roa(b,b>>>0<5e5?a+1|0:a,1e6,0),kb)}function Pv(a,b){a=UD(a,x[b>>2],x[b+4>>2]);x[a+8>>2]=x[b+8>>2];UD(a+12|0,x[b+12>>2],x[b+16>>2])}function B5(a){a=a|0;var b=0;b=ib-16|0;ib=b;a=x[uf(b+8|0,xl(mc(12),a))>>2];ib=b+16|0;return a|0}function zw(a,b,c,d){var e=0;x[a>>2]=x[b>>2];e=x[b>>2];x[a+8>>2]=b;x[a+4>>2]=(c<<d)+e;return a}function tX(a,b){return(Vb((D(a>>>4|0,b)>>>0)/15|0,1,15)<<4|Vb((D(a&15,b)>>>0)/15|0,1,15))&255}function tH(a){var b=0;b=x[120026];if(a){x[120026]=(a|0)==-1?483348:a}return(b|0)==483348?-1:b}function PB(a,b){var c=0;c=ib-16|0;ib=c;x[c+8>>2]=a;a=x[EW(c+8|0,0-b|0)>>2];ib=c+16|0;return a}function Oha(a,b){a=a|0;b=b|0;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);if(b){Gk(a,b);Tt(a,b)}return a|0}function L6(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;iM(a,x[b+4>>2],c,d,e,f,g)}function II(a){var b=0;b=+((a&2097151)>>>0);return E($j(+E((a|0)<0?-b:b),(a>>>21&1023)-788|0))}function GX(a){var b=0;if(!(Qb(a,26340,20)|(y[a+25|0]-9&255)>>>0<248)){b=v[a+47|0]>=0}return b}function F6(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;EL(a,x[b+4>>2],c,d,e,f,g)}function sm(a,b,c){b=b-a|0;while(1){if((b|0)>0){v[a|0]=y[c|0];b=b-1|0;a=a+1|0;continue}break}}function om(a){a=a|0;var b=0;x[a>>2]=49220;b=x[a+4>>2];if(b){Ib(Kp(b))}x[a+4>>2]=0;return a|0}function kD(a){var b=0;b=a&255;a=b>>>21|0;b=(b<<11)+2624|0;a=b>>>0<2624?a+1|0:a;kb=a;return b}function bv(a,b){a=a|0;b=b|0;var c=0,d=0;c=ib-16|0;ib=c;d=a;a=Kc(c,b);$c(d,a);wb(a);ib=c+16|0}function aC(a,b){a=a|0;b=b|0;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);if(b){Pl(a,b);XE(a,b)}return a|0}function _f(a,b){a=a|0;b=b|0;var c=0,d=0;c=ib-16|0;ib=c;d=a;a=xc(c,b);$c(d,a);xb(a);ib=c+16|0}function Zk(a){var b=0;b=ib-16|0;ib=b;a=x[Wb(b+8|0,vc(a)+(Eb(a)<<2)|0)>>2];ib=b+16|0;return a}function TS(a,b,c){var d=0;x[a>>2]=x[b>>2];d=x[b>>2];x[a+8>>2]=b;x[a+4>>2]=D(c,12)+d;return a}function Nc(a,b,c){var d=0;d=x[c+4>>2];if((d|0)==(b|0)){a=CV(a,b,x[c>>2],d)}else{a=1}return!a}function B6(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;hM(a,x[x[b+4>>2]+24>>2],c,d,e,f)}function A6(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;DL(a,x[x[b+4>>2]+24>>2],c,d,e,f)}function uH(a){var b=0,c=0;c=a;while(1){b=c;c=b+4|0;if(x[b>>2]){continue}break}return b-a>>2}function oT(a){var b=0,c=0;b=ib-16|0;ib=b;if(nT(a,b+8|0)){c=ac(x[b+8>>2])}ib=b+16|0;return c}function hG(a){a=a|0;var b=0;x[a>>2]=98492;b=x[a+8>>2];if(!(!b|!y[a+12|0])){Ib(b)}return a|0}function fka(a){a=a|0;var b=0,c=0;b=ib-32|0;ib=b;c=a;a=Oh(b+8|0);OU(c,a,0,0);yb(a);ib=b+32|0}function UY(a){a=a|0;var b=0;b=ib-16|0;ib=b;a=Hg(a,b+8|0);ib=b+16|0;return(a?y[b+8|0]:0)&255}function NB(a){var b=0,c=0;b=ib-16|0;ib=b;if(Vo(a,b+8|0)){c=se(w[b+8>>1])}ib=b+16|0;return c}function E6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Ws(x[x[a+4>>2]+24>>2],b,c,d,e)|0}function C3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;return lb[x[x[a>>2]+32>>2]](a,b,c,d,e)|0}function hK(a,b,c,d,e){if(!((b|0)==(c|0)|(d|0)>=0)){v[b|0]=45;d=NM(d);b=b+1|0}_J(a,b,c,d,e)}function gg(a){var b=0,c=0;while(1){c=b&65535;if(c>>>0<127){bC(a,c);b=b+1|0;continue}break}}function NT(a){a:{if(Qb(a,17605,4)){break a}if(Qb(a+8|0,14219,4)){break a}return 1}return 0}function Ija(a){a=a|0;var b=0;b=ib-16|0;ib=b;a=Nh(a,b+8|0);ib=b+16|0;return+(a?C[b+8>>3]:0)}function Cz(a){var b=0;x[a+84>>2]=0;x[a+88>>2]=0;b=x[a+80>>2];x[a+92>>2]=b;x[a+96>>2]=b<<12}function Baa(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;Zx(a,b,c,d,e,0,0,f,g)}function AD(a,b){if((a&4088)>>>0>=520){b=Hv(0-toa(b^1230262859,25)|0,4)^1247037516}return b}function zca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=oj(a);if(a){lb[x[x[a>>2]+92>>2]](a,b,c,d)}}function pS(a){var b=0;b=a&255;a=b>>>27|0;b=(b<<5)+259|0;a=b>>>0<259?a+1|0:a;kb=a;return b}function fI(a){var b=0;b=x[a>>2];if(b){if(!pc(gI(b),-1)){return!x[a>>2]}x[a>>2]=0}return 1}function aw(a,b){a=a|0;b=b|0;b=b-1|0;if(b>>>0<=4){b=x[(b<<2)+21632>>2]}else{b=9680}xc(a,b)}function Yl(a,b,c){var d=E(0);if(b>>>0<=c>>>0){d=B[Bb(a+4208|0,b)>>2]}else{d=E(0)}return d}function Yf(a,b){var c=0;c=ib-16|0;ib=c;x[c+8>>2]=a;a=x[DB(c+8|0,b)>>2];ib=c+16|0;return a}function Wg(a){var b=0;if(a>>>0>=11){b=a+16&-16;a=b-1|0;a=(a|0)==11?b:a}else{a=10}return a}function UD(a,b,c){var d=0;d=ib-16|0;ib=d;b=Rl(d+8|0,b,c);wE(b,a);Ud(b);ib=d+16|0;return a}function TM(a,b){var c=0;c=x[a+12>>2];if((c|0)>0){x[a+20>>2]=(x[a+16>>2]+(b+c|0)|0)%(c|0)}}function Ns(a){if(QJ(a)){a=ba(4)|0;x[a>>2]=0;a=jk(a);x[a>>2]=107720;ha(a|0,107756,26);p()}}function Lw(a,b,c){var d=0;d=ib-16|0;ib=d;c=qi(d+8|0,c);a=tx(a,b);pi(c);ib=d+16|0;return a}function Cca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=oj(a);if(a){lb[x[x[a>>2]+76>>2]](a,b,c,d)}}function Bca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=oj(a);if(a){lb[x[x[a>>2]+84>>2]](a,b,c,d)}}function toa(a,b){var c=0,d=0;c=b&31;d=(-1>>>c&a)<<c;c=a;a=0-b&31;return d|(c&-1<<a)>>>a}
function or(a){var b=0;while(1){if(!pc(y[a|0],0)){a=a+1|0;b=b+1|0;continue}break}return b}function oX(a,b,c){var d=0;d=ib-16|0;ib=d;ci(d+8|0,b,c);ib=d+16|0;return x[d+8>>2]==(a|0)}function dA(a,b){a=xl(a,b);$c(a+12|0,b+12|0);w[a+28>>1]=z[b+28>>1];x[a+24>>2]=x[b+24>>2]}
function ax(a,b,c,d){var e=0;e=ib-16|0;ib=e;x[e+12>>2]=d;a=ks(a,b,c,d);ib=e+16|0;return a}function _g(a){var b=0;b=ib-16|0;ib=b;a=Vo(a,b+8|0);ib=b+16|0;return(a?z[b+8>>1]:0)&65535}function Vp(a,b,c){a=a+1074992|0;return x[(a+D(b,872)|0)+680>>2]>x[(a+D(c,872)|0)+680>>2]}function VM(a,b){a=a|0;b=b|0;var c=0;c=Eb(a);if(c>>>0<b>>>0){av(a,b-c|0,0);return}wN(a,b)}function Fp(a){a=a|0;var b=0;x[a>>2]=49200;b=x[a+4>>2];if(b){Ib(b);x[a+4>>2]=0}return a|0}function By(a,b){if((a|0)>=0){return(a>>>0)%(b>>>0)|0}return(((a^-1)>>>0)%(b>>>0)^-1)+b|0}function yt(a){var b=0;b=ib-16|0;ib=b;a=x[Wb(b+8|0,Jc(a)+Eb(a)|0)>>2];ib=b+16|0;return a}function ny(a,b,c){var d=0;d=ib-16|0;ib=d;Wh(a,c);v[d+15|0]=0;oe(b+c|0,d+15|0);ib=d+16|0}function jt(a,b){var c=0;c=Jc(a);if(c>>>0<=b>>>0){a=Eb(a)+c>>>0>=b>>>0}else{a=0}return a}function gP(a){var b=0;b=a+4e4|0;while(1){b=ez(b-160|0);if((b|0)!=(a|0)){continue}break}}function dw(){var a=0,b=0;a=ib-16|0;ib=a;b=uf(a+8|0,Nb(mc(12)));ib=a+16|0;return x[b>>2]}function XT(a,b){var c=0;c=ib-16|0;ib=c;Xm(c+8|0,b);DV(a,x[c+8>>2],x[c+12>>2]);ib=c+16|0}function Re(a){var b=0;b=ib-16|0;ib=b;a=Hg(a,b+15|0);ib=b+16|0;return(a?y[b+15|0]:0)&255}function LP(a,b){var c=0;c=y[a+851|0];if(c&1){v[a+851|0]=c|64;x[a+852>>2]=x[a+852>>2]+b}}function Eh(a){var b=0;b=ib-16|0;ib=b;a=x[Wb(b+8|0,vc(a)+Eb(a)|0)>>2];ib=b+16|0;return a}function Eca(a,b){a=a|0;b=b|0;a=oj(a);if(!a){return 1}return lb[x[x[a>>2]+68>>2]](a,b)|0}function yH(a,b){var c=0;c=ib-16|0;ib=c;x[c+12>>2]=b;a=zH(a,11084,b);ib=c+16|0;return a}function xq(a,b,c){var d=E(0);d=B[a>>2];if(!zu(d,B[b>>2])){b=zu(B[c>>2],d)?c:a}return b}function vZ(a){a=a|0;var b=0;b=x[a+4>>2];return(lb[x[x[b>>2]+20>>2]](b)|0)+x[a+12>>2]|0}function qw(a,b,c){var d=0;x[a>>2]=x[b>>2];d=x[b>>2];x[a+8>>2]=b;x[a+4>>2]=c+d;return a}function ln(a){var b=0;b=Yv(a+4|0);if((b|0)==-1){lb[x[x[a>>2]+8>>2]](a)}return(b|0)==-1}function ky(a,b,c,d){if(!((b|0)==(c|0)|(d|0)>=0)){v[b|0]=45;d=NM(d);b=b+1|0}hy(a,b,c,d)}function fO(a,b,c){var d=0;d=b-a|0;if((a|0)!=(b|0)){Wi(c,a,d)}return D((d|0)/6|0,6)+c|0}function XH(a){var b=0;b=x[a>>2];if(b){if(!Hn(al(b))){return!x[a>>2]}x[a>>2]=0}return 1}function Bg(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;return a}function BB(a){var b=0;b=oA(a);while(1){if((a|0)!=(b|0)){PX(a);a=a+32|0;continue}break}}function $p(a,b,c){a=nl(a)-x[a+16>>2]|0;if(a>>>0>=2){c=E(E(E(c-b)/E(a>>>0))+b)}return c}function xE(a,b){var c=0;c=ib-16|0;ib=c;b=zf(c+8|0,b);wE(b,a);Ud(b);ib=c+16|0;return a}function v_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;lb[x[x[b>>2]+16>>2]](a,b,c,d,e,8)}function tv(a,b){a=a|0;b=b|0;var c=0;c=ib-16|0;ib=c;v[c+15|0]=b;ZK(a,c+15|0);ib=c+16|0}function p9(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return OF(a,b,c,d,e,12429,1011)|0}function nR(a,b){return(a>>>0<=62?63-(D((b^-1)&63,(a?a+1|0:0)&255)>>>6|0)|b&192:b)&255}function _s(a,b){a=a|0;b=b|0;b=ib-16|0;ib=b;x[b>>2]=a;uM(17834,b);Zs(109136);ib=b+16|0}function _Z(){var a=0;a:{if(KE(19988503)){break a}if(JE()){break a}a=IE()^1}return a|0}function _X(a,b,c){v[a+2|0]=1;b=b&15;if(c){b=y[b+26288|0]}else{b=(b<<2)+4|0}v[a+4|0]=b}function EU(a){var b=0;b=a+24|0;while(1){b=wb(b-12|0);if((b|0)!=(a|0)){continue}break}}function Cc(a,b){var c=0,d=0;c=ib-16|0;ib=c;d=c+8|0;Xm(d,a);Ol(d,b);ib=c+16|0;return a}function CS(a){var b=0;b=a+36|0;while(1){b=wb(b-12|0);if((b|0)!=(a|0)){continue}break}}function C8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return OF(a,b,c,d,e,12329,1037)|0}function z8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return JF(a,b,c,d,e,9564,1040)|0}function xu(a,b){var c=0;c=ib-16|0;ib=c;w[c+14>>1]=b;tu(a+236|0,128,c+14|0);ib=c+16|0}function wH(a){return(a|0)!=0&(a|0)!=105216&(a|0)!=105240&(a|0)!=483264&(a|0)!=483288}function u$(a,b){a=a|0;b=b|0;if((b|0)>=0){b=x[((b&255)<<2)+96992>>2]}return b<<24>>24}function s8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return JF(a,b,c,d,e,9636,1047)|0}function s$(a,b){a=a|0;b=b|0;if((b|0)>=0){b=x[((b&255)<<2)+95456>>2]}return b<<24>>24}function nq(a,b,c){var d=0;d=c;b=b-a|0;c=x[c>>2]-b|0;x[d>>2]=c;if((b|0)>0){rc(c,a,b)}}function n0(a){a=a|0;a=484856;while(1){a=Gc(a-12|0);if((a|0)!=484832){continue}break}}function m0(a){a=a|0;a=484784;while(1){a=Gc(a-12|0);if((a|0)!=484496){continue}break}}function l0(a){a=a|0;a=484184;while(1){a=Gc(a-12|0);if((a|0)!=484016){continue}break}}function ju(a,b){a:{if(b){break a}if(a>>>0<=3){a=a|-16;break a}a=a>>>2|0}return a&255}function fm(a){var b=0;if(a>>>0>=2){b=a+4&-4;a=b-1|0;a=(a|0)==2?b:a}else{a=1}return a}function f2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return yF(b,c,d,e,f,1)|0}function d2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return yF(b,c,d,e,f,0)|0}function bB(a,b,c,d){var e=0;e=ib-16|0;ib=e;a=Fh(e,a,d);Eu(b,c,a+4|0);ic(a);ib=e+16|0}function a4(a,b){a=a|0;b=b|0;a=z[a>>1];b=z[b>>1];return(a>>>0<b>>>0?-1:a>>>0>b>>>0)|0}function _$(a){a=a|0;a=484480;while(1){a=wb(a-12|0);if((a|0)!=484192){continue}break}}function Z$(a){a=a|0;a=484008;while(1){a=wb(a-12|0);if((a|0)!=483840){continue}break}}function X1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return wF(b,c,d,e,f,1)|0}function V1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return wF(b,c,d,e,f,0)|0}function Ml(a,b,c){a=a|0;b=b|0;c=c|0;if(Oc(a,b)>>>0<=c>>>0){Av();p()}return(c<<1)+a|0}function JG(a,b){var c=0,d=0;cf(a,ce(b));b=gc(b);c=gc(a),d=x[b>>2],x[c>>2]=d;return a}function Fu(a,b,c,d){var e=0;e=ib-16|0;ib=e;a=_l(e,a,d);Eu(b,c,a+4|0);ic(a);ib=e+16|0}function Ct(a,b){if(!(v[b+851|0]&1&x[a+480180>>2]==8)){Ty(a,b,0);Ty(a,b,1);Ty(a,b,2)}}function BE(a){var b=0;while(1){if((b|0)!=3){x[(b<<2)+a>>2]=0;b=b+1|0;continue}break}}function AR(a,b,c,d){var e=0;e=ib-16|0;ib=e;a=ei(e,a,d);Eu(b,c,a+4|0);ic(a);ib=e+16|0}function $3(a,b){a=a|0;b=b|0;a=x[a>>2];b=x[b>>2];return(a>>>0<b>>>0?-1:a>>>0>b>>>0)|0}function $$(a){a=a|0;a=484824;while(1){a=wb(a-12|0);if((a|0)!=484800){continue}break}}function zG(a,b){a:{if(!(y[a+120|0]|b>>>0>30)){v[a+120|0]=1;break a}a=Ii(b)}return a}function zA(a,b){var c=0;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;x[a+8>>2]=x[b+8>>2]}function yw(a,b){var c=0;while(1){if((b|0)!=(c|0)){Jh(a+c|0);c=c+1|0;continue}break}}function naa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return sM(a,b,c,d,0,0,0,0,e)|0}function jf(a){a=a|0;var b=0;b=x[a>>2];return(lb[x[x[b>>2]+24>>2]](b)|0)-x[a+8>>2]|0}function dca(a,b){a=a|0;b=b|0;return E(b>>>0<=2?E(E(y[(a+b|0)+4232|0])/E(127)):E(0))}function Yca(a,b){a=a|0;b=b|0;return E(b>>>0<=3?E(E(y[(a+b|0)+4264|0])/E(255)):E(0))}function Wn(a){var b=0;b=a;a=x[a>>2];x[b>>2]=D(a,214013)+2531011;return a>>>16&32767}function Qg(a,b,c){var d=0;d=C[a>>3];if(!jS(d,C[b>>3])){b=jS(C[c>>3],d)?c:a}return b}function Oj(a,b,c){var d=0;d=x[a>>2];if(!tp(d,x[b>>2])){b=tp(x[c>>2],d)?c:a}return b}function Jj(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;Bg(a)}function Ce(a,b,c){if(Sm(a,b,c)){a=hg(a,c);a=Mb(x[a>>2],x[a+4>>2])}else{a=0}return a}function AS(a,b,c,d,e,f){a=Wb(a,b);Wb(a+4|0,c);Wb(a+8|0,d);Wb(a+12|0,e);Wb(a+16|0,f)}function zf(a,b){x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];x[b>>2]=0;x[b+4>>2]=0;return a}function sO(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){if(y[gc(a)+4|0]){$b(b+16|0)}Ib(b)}}function rba(a){a=a|0;v[a+4202|0]=1;x[a+4256>>2]=x[x[a+16>>2]+24620>>2];XM(a);WM(a)}function oG(a){a=a|0;x[a>>2]=99576;if(x[a+8>>2]!=(Fd()|0)){vH(x[a+8>>2])}return a|0}function Yd(a){var b=0;b=ib-16|0;ib=b;x[b+12>>2]=50184;lo(a,50080,b+12|0);ib=b+16|0}function Qca(a){a=a|0;v[a+4202|0]=1;x[a+4232>>2]=x[x[a+16>>2]+24620>>2];ft(a);DN(a)}function PQ(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){if(y[gc(a)+4|0]){QQ(b+16|0)}Ib(b)}}function Jp(a){a=a|0;x[a+56>>2]=93224;x[a>>2]=93204;Vs(a+4|0);cl(a+56|0);return a|0}function Hx(a,b){return y[(D(a>>>1&3,15)+D(a>>>3&1,45)+((b&240)>>>4)|0)+79953|0]<<1}function FV(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){if(y[gc(a)+4|0]){rB(b+16|0)}Ib(b)}}function E7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return AL(x[a+4>>2],b,c,d,e)|0}function Cl(a,b){var c=0,d=0,e=0;c=x[a+24>>2];d=a,e=Xe(ki(b)*+(c>>>0)),x[d+24>>2]=e}function Cf(a){a=a|0;x[a+60>>2]=93388;x[a>>2]=93368;Vs(a+8|0);cl(a+60|0);return a|0}function A7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return tL(x[a+4>>2],b,c,d,e)|0}function kp(a,b,c,d){x[a>>2]=b;b=x[b+4>>2];x[a+4>>2]=b;x[a+8>>2]=b+(c<<d);return a}function hp(a,b,c,d){x[a>>2]=b;b=x[b+4>>2];x[a+4>>2]=b;x[a+8>>2]=b+D(c,d);return a}function dz(a){var b=0;b=ib-16|0;ib=b;Wb(b+8|0,a+116|0);a=XO(a);ib=b+16|0;return a}function bQ(a,b){var c=0;c=b&15;if(c){v[a+830|0]=c}b=b&240;if(b){v[a+829|0]=b>>>4}}function Xt(a,b){a=Fb(a&65535);b=Fb(b&65535);return(a|0)!=(b|0)?a>>>0<b>>>0?-1:1:0}function LI(a,b){b=x[a+32>>2]+b|0;x[a+32>>2]=b;if(b>>>0>=A[a+40>>2]){x[a+96>>2]=1}}function Jg(a){var b=0;b=ib-16|0;ib=b;a=Zo(a,b+8|0);ib=b+16|0;return a?x[b+8>>2]:0}function uM(a,b){var c=0;c=ib-16|0;ib=c;x[c+12>>2]=b;xI(109136,a,b,0,0);ib=c+16|0}function tu(a,b,c){while(1){if(b){w[a>>1]=z[c>>1];b=b-1|0;a=a+2|0;continue}break}}function qS(a){if((y[a+14|0]-53&255)>>>0>=252){a=Qb(a,15558,14)}else{a=1}return!a}function no(a,b){a=rc(a,b,34);w[a+34>>1]=z[b+34>>1];rc(a+36|0,b+36|0,68);return a}function kJ(a,b){a=hn(a);v[a+8|0]=0;x[a+4>>2]=b;x[a>>2]=76892;Nb(a+12|0);return a}function RN(a,b,c){while(1){if(b){B[a>>2]=B[c>>2];b=b-1|0;a=a+4|0;continue}break}}function w7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return SF(a,b,c,d,e,1077)|0}function rJ(a){a=hn(a);x[a>>2]=77356;Nb(a+4|0);v[a+20|0]=0;x[a+16>>2]=0;return a}function ke(a){var b=0;b=ib-16|0;ib=b;a=x[Wb(b+8|0,vc(a))>>2];ib=b+16|0;return a}function jL(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Tr(a,b,c,d,e,1061)|0}function gL(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Tr(a,b,c,d,e,1063)|0}function fL(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Tr(a,b,c,d,e,1065)|0}function eg(a){var b=0;b=ib-16|0;ib=b;a=x[Wb(b+8|0,gc(a))>>2];ib=b+16|0;return a}function b8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Ur(a,b,c,d,e,1062)|0}function a8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Ur(a,b,c,d,e,1064)|0}function WK(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Dw(a,b,c,d,e,1062)|0}function VK(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Qr(a,b,c,d,e,1062)|0}function UK(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Dw(a,b,c,d,e,1064)|0}function Ti(a){var b=0;b=ib-16|0;ib=b;a=x[Wb(b+8|0,nd(a))>>2];ib=b+16|0;return a}function TK(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Qr(a,b,c,d,e,1064)|0}function SK(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Dw(a,b,c,d,e,1066)|0}function RK(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Qr(a,b,c,d,e,1066)|0}function Ni(a){var b=0;b=ib-16|0;ib=b;a=x[Wb(b+8|0,Cb(a))>>2];ib=b+16|0;return a}function Gf(a){var b=0;b=ib-16|0;ib=b;a=x[Wb(b+8|0,eg(a))>>2];ib=b+16|0;return a}function Ek(a,b){var c=0;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;hc(a+8|0,b+8|0)}function Bt(a){var b=0;b=ib-16|0;ib=b;a=x[Wb(b+8|0,Jc(a))>>2];ib=b+16|0;return a}function A_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=lb[a|0](b,c,d)|0;jb=kb;return a|0}function $7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Ur(a,b,c,d,e,1066)|0}function zg(a){var b=0,c=0;sc(a+4|0);vk(a+8|0,0);b=a,c=gc(a),x[b>>2]=c;return a}function uw(a,b){b=a+b|0;while(1){b=xb(b-12|0);if((b|0)!=(a|0)){continue}break}}function rM(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return SF(a,b,c,d,e,957)|0}function fi(a){return(Wj(x[a>>2],x[a+4>>2])|0)!=(0-Wj(x[a+12>>2],x[a+16>>2])|0)}function eL(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Tr(a,b,c,d,e,982)|0}function XD(a,b,c){while(1){if(b){v[a|0]=y[c|0];b=b-1|0;a=a+1|0;continue}break}}function WF(){var a=0;a=ib-16|0;x[a+8>>2]=0;x[a+12>>2]=1048576;return C[a+8>>3]}function V9(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Ur(a,b,c,d,e,956)|0}function QK(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Qr(a,b,c,d,e,956)|0}function G$(a,b,c){a=a|0;b=b|0;c=c|0;return(x[(c<<2)+98544>>2]&b)!=0&c>>>0<=127}function D_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;lb[a|0](b,c,d,e,f)}function $0(){var a=0,b=0,c=0;a=Wd(484912);x[a>>2]=99576;b=a,c=Fd(),x[b+8>>2]=c}function y4(a){a=a|0;a=x[a+24>>2];return iJ(x[(x[x[a>>2]-12>>2]+a|0)+16>>2])^1}function x_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return lb[a|0](b,c,d,e)|0}function vea(a,b){a=a|0;b=b|0;if(A[a+4>>2]<A[Db(a)>>2]){PO(a,b);return}GA(a,b)}function v0(a){a=a|0;if(!y[483792]){un(483780,99812);v[483792]=1}return 483780}function t0(a){a=a|0;if(!y[483824]){un(483812,99896);v[483824]=1}return 483812}function r0(a){a=a|0;if(!y[483728]){un(483716,99740);v[483728]=1}return 483716}function pv(a,b){return Xe(ki((+(a|0)*128+ +(b|0))*.0006510416666666666)*8363)}function p0(a){a=a|0;if(!y[483760]){un(483748,99776);v[483760]=1}return 483748}function mo(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0}function l$(a,b){a=a|0;b=b|0;a=jk(a);x[a>>2]=108248;Kw(a+4|0,Jc(b));return a|0}function h0(a){a=a|0;if(!y[483776]){Kc(483764,13445);v[483776]=1}return 483764}function e$(a,b,c){a=a|0;b=b|0;c=c|0;if(!y[485360]){v[485360]=1}dc(a,c,109580)}function d6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;return qK(a-88|0,b,c,d,e)|0}function b0(a){a=a|0;if(!y[483744]){Kc(483732,13699);v[483744]=1}return 483732}function UW(a,b){a=a|0;b=b|0;if(x[a+4>>2]!=x[Db(a)>>2]){nG(a,b);return}jG(a,b)}function My(a,b){a=a|0;b=b|0;if(x[a+4>>2]!=x[Db(a)>>2]){PO(a,b);return}GA(a,b)}function zy(a,b){if((a|0)>=0){return(a|0)%(b|0)|0}return((a^-1)%(b|0)^-1)+b|0}function yy(a,b){if((a|0)>=0){return(a|0)/(b|0)|0}return((a+1|0)/(b|0)|0)-1|0}function tba(a,b){a=a|0;b=b|0;return E(b>>>0<=4?B[((b<<2)+a|0)+4220>>2]:E(0))}function oS(a,b){a=HT(a,b);v[a+16|0]=y[b+16|0];x[a+12>>2]=x[b+12>>2];return a}function lj(a,b,c){if(x[a+80>>2]){x[a+92>>2]=x[a+92>>2]+(c+7&-8);return}Ib(b)}function kj(a,b){var c=0;c=a;a=(b>>>0)/100|0;return ys(ys(c,a),D(a,-100)+b|0)}function f7(a,b){a=a|0;b=b|0;a=x[a+4>>2];return JL(x[a+24>>2],B[a+48>>2],b)|0}function f0(a){a=a|0;if(!y[483808]){Kc(483796,9201);v[483808]=1}return 483796}function d0(a){a=a|0;if(!y[483712]){Kc(483700,5268);v[483712]=1}return 483700}function Y_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(gh(a,x[b+8>>2],0)){Hw(b,c,d)}}function YA(a){if(Ue(y[a+11|0])){ne(x[a>>2],0);vd(a,0);return}ne(a,0);ee(a,0)}function Iz(a){var b=0;if(!(y[a+2|0]|(y[a|0]|y[a+1|0]))){b=!y[a+3|0]}return b}function Il(a,b){var c=0,d=0;c=ib-16|0;ib=c;d=c+8|0;JC(d,a);Ol(d,b);ib=c+16|0}function HQ(a){x[a>>2]=0;x[a+4>>2]=0;x[a>>2]=-2078137563;x[a+4>>2]=-873292572}function Fe(a,b){var c=0,d=0;c=ib-16|0;ib=c;d=c+8|0;Iv(d,a);Ol(d,b);ib=c+16|0}function y8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return rn(a,b,c,d,12830,1041)|0}function w8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return rn(a,b,c,d,12904,1043)|0}function cH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;lb[x[x[a>>2]+32>>2]](a,b,c,d)|0}function ae(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=x[b+8>>2];Yb(b,c);$v(a,b,d,c)}function _G(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;lb[x[x[a>>2]+48>>2]](a,b,c,d)|0}function Q5(a,b){a=a|0;b=b|0;Tm(x[a+4>>2]);YD($D(x[a+4>>2],b));Tm(x[a+4>>2])}function Le(a){var b=0;b=ib-16|0;ib=b;lv(b+8|0,a);ib=b+16|0;return x[b+8>>2]}function HP(a,b,c){var d=0;return!b|!(y[a+35|0]&4?!a|(c|0)!=1:1)?d:y[b+34|0]}function Ej(a){var b=0;b=ib-16|0;ib=b;a=x[uf(b+8|0,a)>>2];ib=b+16|0;return a}function EG(a){var b=0;b=ib-16|0;ib=b;x[b+8>>2]=a;ib=b+16|0;return x[b+8>>2]}function Cb(a){var b=0;b=ib-16|0;ib=b;a=x[Wb(b+8|0,a)>>2];ib=b+16|0;return a}function xA(a,b){return(+(a>>>0)+ +(b|0)*4294967296)*2.3283064365386963e-10}function x8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return rn(a,b,c,d,9519,1042)|0}function v8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return rn(a,b,c,d,9597,1044)|0}function u8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return rn(a,b,c,d,9399,1045)|0}function ps(a,b,c,d,e,f,g,h){return lb[x[x[a>>2]+12>>2]](a,b,c,d,e,f,g,h)|0}function oN(a){a=a|0;x[a>>2]=46316;uc(a+4276|0);uc(a+4264|0);return Rf(a)|0}function h3(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)!=1){QH(a,c);return}Kc(a,7868)}function h2(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return zF(b,c,d,e,1)|0}function gR(a,b){b=1/(1/(b*6.283185307179586/3546895)+1);$Q(a,b,0,0,b+-1,0)}function e2(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return zF(b,c,d,e,0)|0}function cW(a){var b=0;while(1){b=a;a=x[a>>2];if(a){continue}break}return b}function aJ(a,b){a=a^-1;return x[(b&12)+79956>>2]>>>(a>>>3&1)>>>(a>>>4&1)|0}function _l(a,b,c){x[a>>2]=b;b=x[b+4>>2];x[a+4>>2]=b;x[a+8>>2]=b+c;return a}function Z1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return xF(b,c,d,e,1)|0}function W1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return xF(b,c,d,e,0)|0}function TH(a,b,c,d,e,f,g,h){return lb[x[x[a>>2]+16>>2]](a,b,c,d,e,f,g,h)|0}function Gg(a,b){var c=0;c=a;a=x[a+8>>2];b=a-b|0;x[c+8>>2]=a>>>0>=b>>>0?b:0}function C$(a,b){a=a|0;b=b|0;if(b>>>0<=127){b=x[(b<<2)+96992>>2]}return b|0}function B8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return rn(a,b,c,d,9368,1038)|0}function A$(a,b){a=a|0;b=b|0;if(b>>>0<=127){b=x[(b<<2)+95456>>2]}return b|0}function ys(a,b){b=z[(b<<1)+92352>>1];v[a|0]=b;v[a+1|0]=b>>>8;return a+2|0}function sk(a){var b=0;b=z[a+172>>1];a=z[a+156>>1];return(lS(a)?b:a)&65535}function qca(a,b){a=a|0;b=b|0;a=x[a+20>>2];v[a+24|0]=y[a+24|0]&253|(b?2:0)}function oE(a,b){a=a|0;b=b|0;a=jk(a);x[a>>2]=108248;Kw(a+4|0,b);return a|0}function h$(a,b,c){a=a|0;b=b|0;c=c|0;return pc(a,x[b+4>>2])&x[b>>2]==(c|0)}function Xv(a,b,c){var d=0;d=b-a|0;if((a|0)!=(b|0)){Wi(c,a,d)}return c+d|0}function Nf(a,b,c){x[a+8>>2]=b;x[a+12>>2]=c;x[a>>2]=0;x[a+4>>2]=0;return a}function uU(a,b){v[a+6|0]=255;x[a+16>>2]=b;w[a+4>>1]=0;x[a>>2]=0;return a}function nd(a){var b=0,c=0,d=0;return b=x[a>>2],c=a,d=Ue(y[a+11|0]),d?b:c}function nE(a,b){a=zf(a,b);x[a+8>>2]=x[b+8>>2];zf(a+12|0,b+12|0);return a}function fd(a,b){a=xE(a,b);x[a+8>>2]=x[b+8>>2];xE(a+12|0,b+12|0);return a}function Zc(a,b,c,d,e){v[a+3|0]=e;v[a+2|0]=d;v[a+1|0]=c;v[a|0]=b;return a}function Pw(a,b){var c=0,d=0;c=Wb(a,x[x[b>>2]-12>>2]+b|0),d=b,x[c+4>>2]=d}function Oe(a,b){var c=0;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;return a}function Ob(a,b,c){a=a|0;b=b|0;c=c|0;return lb[x[x[a>>2]+32>>2]](a,b,c)|0}function Kla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=c,e=Po(a,b),x[d>>2]=e}function K7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return zL(x[a+4>>2],b,c,d)|0}function Jla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=c,e=Dv(a,b),w[d>>1]=e}function J7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return xL(x[a+4>>2],b,c,d)|0}function H7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return yL(x[a+4>>2],b,c,d)|0}function G7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return wL(x[a+4>>2],b,c,d)|0}function F7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return CL(x[a+4>>2],b,c,d)|0}function Eu(a,b,c){b=b-a|0;if((b|0)>0){rc(x[c>>2],a,b);x[c>>2]=b+x[c>>2]}}function Co(a,b,c){a=a|0;b=b|0;c=c|0;return lb[x[x[a>>2]+48>>2]](a,b,c)|0}function B7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return vL(x[a+4>>2],b,c,d)|0}function $k(a,b,c){a=a|0;b=b|0;c=c|0;return lb[x[x[a>>2]+12>>2]](a,b,c)|0}function oI(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;Nf(a,-1,-1)}function dx(a,b){var c=0;c=Xs(a+4|0);x[a>>2]=94016;x[c>>2]=94036;On(c,b)}function cx(a,b){var c=0;c=JH(a+4|0);x[a>>2]=94384;x[c>>2]=94404;On(c,b)}function cm(a,b){v[a|0]=b;v[a+1|0]=b>>>8;v[a+2|0]=b>>>16;v[a+3|0]=b>>>24}function Vg(){var a=0;a=qm(ba(4)|0);x[a>>2]=108132;ha(a|0,108208,26);p()}function zl(a){if(Ue(y[a+11|0])){a=Ju(x[a+8>>2])-1|0}else{a=10}return a}function zK(a){a=a|0;return+(+A[x[a+32>>2]+480240>>2]*152587890625e-16)}function yx(a){return((Ch(a)+(Ch(a)<<8)|0)+(Ch(a)<<16)|0)+(Ch(a)<<24)|0}function vR(a,b){x[a+4>>2]=0;x[a+8>>2]=0;x[a>>2]=b?b:49716;x[a+12>>2]=0}function uc(a){var b=0;if(x[a>>2]){Ic(a);b=x[a>>2];_h(a);Ib(b)}return a}function rp(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;x[e>>2]=c;return 3}function qc(a,b){var c=0,d=0;x[a>>2]=b;c=a,d=xf(b),x[c+4>>2]=d;return a}function pX(a,b,c){a=a&255;return a>>>0>=(b&255)>>>0&a>>>0<=(c&255)>>>0}function oR(a){if(a>>>0<=8){return y[a+29200|0]}return y[a+29191|0]|256}function nf(a){var b=0;if(x[a>>2]){Ic(a);b=x[a>>2];Jr(a);Ib(b)}return a}function lma(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;iF(a,b,c,d,e,117)}function iN(a){a=a|0;return E(E(E(B[Bb(a+4208|0,5)>>2]*E(198))+E(-99)))}function gC(a,b,c){var d=0;d=(b|0)/(c|0)|0;x[a>>2]=d;x[a+4>>2]=b-D(c,d)}function ZS(a){var b=0;if(x[a>>2]){WS(a,x[a>>2]);b=x[a>>2];ak(a);Ib(b)}}function Xna(a){a=a|0;x[a+16>>2]=x[a+16>>2]|1;if(v[a+20|0]&1){wa();p()}}function Sc(a){var b=0;if(x[a>>2]){WC(a,x[a>>2]);b=x[a>>2];XC(a);Ib(b)}}function Ria(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;iF(a,b,c,d,e,143)}function R_(a){a=a|0;if(!a){return 0}return(rz(a,107804,107948)|0)!=0|0}function tz(a,b){x[a>>2]=x[b>>2];w[a+4>>1]=z[b+4>>1];v[a+6|0]=y[b+6|0]}function t7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return FF(a,b,c,d,1077)|0}function sB(a,b){if(b){sB(a,x[b>>2]);sB(a,x[b+4>>2]);rB(b+16|0);Ib(b)}}function rr(a){x[a>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;return a}function qB(a,b){if(b){qB(a,x[b>>2]);qB(a,x[b+4>>2]);rB(b+16|0);Ib(b)}}function kU(a){if(Qb(a,13813,4)){a=1}else{a=Qb(a+8|0,13866,4)}return!a}function hA(a,b){a=Nb(a);Kb(a+12|0);w[a+28>>1]=0;x[a+24>>2]=b;return a}function gq(a,b){if(b){gq(a,x[b>>2]);gq(a,x[b+4>>2]);QQ(b+16|0);Ib(b)}}function dL(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Sr(a,b,c,d,1067)|0}function cL(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Sr(a,b,c,d,1069)|0}function bL(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Sr(a,b,c,d,1071)|0}function _7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Rr(a,b,c,d,1068)|0}function Zt(a,b){a=a&255;b=b&255;return(a|0)!=(b|0)?a>>>0<b>>>0?-1:1:0}function Z7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Rr(a,b,c,d,1070)|0}function Yk(a,b){a=a|0;b=b|0;v[a|0]=2;v[a+1|0]=3;v[a+2|0]=0;v[a+3|0]=4}function Y7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Rr(a,b,c,d,1072)|0}function X7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Rr(a,b,c,d,1074)|0}function PK(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Pr(a,b,c,d,1068)|0}function OK(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Pr(a,b,c,d,1070)|0}function NK(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Pr(a,b,c,d,1072)|0}function MK(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Pr(a,b,c,d,1074)|0}function Ly(a,b){if(b){Ly(a,x[b>>2]);Ly(a,x[b+4>>2]);$b(b+16|0);Ib(b)}}function Kz(a,b){if(b){Kz(a,x[b>>2]);Kz(a,x[b+4>>2]);Am(b+16|0);Ib(b)}}function Iw(a,b,c){if(!(x[a+28>>2]==1|x[a+4>>2]!=(b|0))){x[a+28>>2]=c}}function Gka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Cw(a,b,c,d,575)|0}function $K(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Sr(a,b,c,d,1073)|0}function yr(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Cw(a,b,c,d,173)|0}function v7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return FF(a,b,c,d,957)|0}function sl(a,b){a=y[Jb(a+62|0,b)|0];return(a<<24>>24<0?-1:a&127)&255}function ZW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Cw(a,b,c,d,337)|0}function YJ(a,b){var c=0;c=x[a>>2];x[a>>2]=b;if(c){Ln(c+120|0);Ib(c)}}function VO(a,b,c,d,e){x[a+12>>2]=e;x[a+8>>2]=d;x[a+4>>2]=c;x[a>>2]=b}function Mw(a){a=a|0;if(x[a+8>>2]!=(Fd()|0)){vH(x[a+8>>2])}return a|0}function B_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;lb[a|0](b,c,d,e)}function BS(a,b,c,d,e){a=Wb(a,b);Wb(a+4|0,c);Wb(a+8|0,d);Wb(a+12|0,e)}function y_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return lb[a|0](b,c,d)|0}function qC(a,b){var c=0;c=ib-16|0;ib=c;zD(c,a,32);ED(c,b);ib=c+16|0}function mS(a,b){a=EA(a,b);v[a+16|0]=y[b+16|0];x[a+12>>2]=x[b+12>>2]}function gm(a,b){return b?a<<8&16711680|a<<24|(a>>>8&65280|a>>>24):a}function g1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;Pg(a,f)}function dV(a,b){x[a>>2]=x[b>>2];w[a+4>>1]=z[b+4>>1];hc(a+8|0,b+8|0)}function cv(a,b){var c=0;c=ib-16|0;ib=c;zD(c,a,64);ED(c,b);ib=c+16|0}function B2(a){a=a|0;var b=0;b=x[120892]+1|0;x[120892]=b;x[a+4>>2]=b}function zL(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return IF(a,b,c,d,4)|0}function yL(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return IF(a,b,c,d,2)|0}function xL(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return HF(a,b,c,d,4)|0}function xC(a,b){return Ir(x[b>>2],x[b+4>>2],x[a>>2],x[a+4>>2])?b:a}function wL(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return HF(a,b,c,d,2)|0}function mV(a){v[a+4|0]=0;v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0}function hr(a,b){return Gv(x[b>>2],x[b+4>>2],x[a>>2],x[a+4>>2])?b:a}function gp(a,b){return x[b+8>>2]==x[a+8>>2]&x[a+12>>2]==x[b+12>>2]}function UF(a,b,c,d,e,f,g){return La(a|0,b|0,c|0,d|0,e|0,f|0,g|0)|0}function OO(a,b){var c=0;c=ib-16|0;ib=c;KA(c,1,b);Fc(a,c);ib=c+16|0}function Mc(a,b,c){if(tc(a,b)>>>0<=c>>>0){Av();p()}return(c<<2)+a|0}function KP(a,b){x[a+852>>2]=x[a+852>>2]+b;v[a+851|0]=y[a+851|0]|64}function x$(a,b,c){a=a|0;b=b|0;c=c|0;return(b>>>0<128?b:c)<<24>>24}function id(a){a=(a|0)>=32767?32767:a;return(a|0)<=-32768?-32768:a}function cO(a,b){if((a|0)!=(b|0)){SU(a,x[b>>2],x[b+4>>2])}return a}function SR(a,b){var c=0,d=0;c=Wb(a,x[b>>2]),d=y[b+4|0],v[c+4|0]=d}function Kaa(a,b,c){a=a|0;b=b|0;c=c|0;return Zi(a,b,c,937,86224)|0}function BG(a,b,c){a:{if((a|0)==(b|0)){v[b+120|0]=0;break a}Ib(b)}}function xba(a,b,c){a=a|0;b=b|0;c=c|0;return Zi(a,b,c,931,4268)|0}function xZ(a){a=a|0;a=x[a+4>>2];return lb[x[x[a>>2]+12>>2]](a)|0}function xK(a){a=a|0;return+(+x[x[a+32>>2]+1074456>>2]*.00390625)}function wZ(a){a=a|0;a=x[a+4>>2];return lb[x[x[a>>2]+16>>2]](a)|0}function vn(a,b){if(A[a+4>>2]<A[Db(a)>>2]){nG(a,b);return}jG(a,b)}function sh(a,b,c){a=Wb(a,b);eW(a+4|0,x[c>>2],x[c+4>>2]);return a}function ola(a,b){a=a|0;b=b|0;a=Ou(a,b);x[a>>2]=108456;return a|0}function iba(a,b,c){a=a|0;b=b|0;c=c|0;return Zi(a,b,c,933,4228)|0}function gca(a,b,c){a=a|0;b=b|0;c=c|0;return Zi(a,b,c,926,4236)|0}function eK(a,b,c){a=a|0;b=b|0;c=c|0;return cK(a,b,Jc(c),Eb(c))|0}function cda(a,b,c){a=a|0;b=b|0;c=c|0;return Zi(a,b,c,902,4268)|0}function c5(a,b){a=a|0;b=b|0;if(!x[27524]){x[27524]=a;x[27525]=b}}function XF(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return nL(a,b,c,d)|0}function Raa(a,b,c){a=a|0;b=b|0;c=c|0;return Zi(a,b,c,936,4276)|0}function Oba(a,b,c){a=a|0;b=b|0;c=c|0;return Zi(a,b,c,929,4280)|0}function OU(a,b,c,d){a=te(a,b);w[a+22>>1]=d;w[a+20>>1]=c;return a}function Nca(a,b,c){a=a|0;b=b|0;c=c|0;return Zi(a,b,c,910,4304)|0}function Lj(a,b){if(xg(x[a>>2],x[a+4>>2])>>>0>b>>>0){v[a+16|0]=b}}function Jo(a,b){x[a>>2]=x[(x[x[b>>2]-12>>2]+b|0)+24>>2];return a}function Jc(a){var b=0,c=0,d=0;return b=x[a>>2],c=a,d=kf(a),d?b:c}function Hma(a,b){a=a|0;b=b|0;a=Ou(a,b);x[a>>2]=108404;return a|0}function Eba(a,b,c){a=a|0;b=b|0;c=c|0;return Zi(a,b,c,930,4276)|0}function DI(a,b){a=BI(a-1|0);if(!a){a=BI(b);a=a?a+32|0:0}return a}function Br(a,b){a=a|0;b=b|0;return lb[x[x[a>>2]+32>>2]](a,0,b)|0}function $o(a,b,c){a=zf(a,b);x[a+8>>2]=0;zf(a+12|0,c);Ud(c);Ud(b)}function $aa(a,b,c){a=a|0;b=b|0;c=c|0;return Zi(a,b,c,934,5048)|0}function zaa(a,b){a=a|0;b=b|0;if(!b){return 3}x[b>>2]=a;return 0}function yZ(a){a=a|0;a=x[a+4>>2];return lb[x[x[a>>2]+8>>2]](a)|0}function xQ(a,b){a=a|0;b=b|0;a=Ou(a,b);x[a>>2]=108268;return a|0}function uq(a,b,c){a=Fb(a&65535);return(a|0)>=(b|0)&(a|0)<=(c|0)}function tE(a,b,c){a=hn(a);x[a+8>>2]=c;x[a+4>>2]=b;x[a>>2]=78208}function iz(a){xb(a+48|0);xb(a+36|0);xb(a+24|0);xb(a+12|0);xb(a)}function PM(a){return E(E(B[Bb(a+4208|0,11)>>2]*E(19980))+E(20))}function Ir(a,b,c,d){return a>>>0<c>>>0&(b|0)<=(d|0)|(b|0)<(d|0)}function we(a){var b=0;if(x[a>>2]){Ic(a);b=x[a>>2];mn(a);Ib(b)}}function po(a){var b=0;if(x[a>>2]){Ic(a);b=x[a>>2];kV(a);Ib(b)}}function ow(a){var b=0;b=ib-16|0;B[b+12>>2]=a;return B[b+12>>2]}function os(a,b){a=a|0;b=b|0;return lb[x[x[a>>2]+44>>2]](a,b)|0}function jd(a){var b=0;if(x[a>>2]){Ic(a);b=x[a>>2];_m(a);Ib(b)}}function iu(a){var b=0;if(x[a>>2]){Ic(a);b=x[a>>2];Db(a);Ib(b)}}function hfa(a,b){a=a|0;b=b|0;a=iV(a,b);if(!a){hV(b)}return a|0}function hP(a){var b=0;if(x[a>>2]){Ic(a);b=x[a>>2];hX(a);Ib(b)}}function fu(a){var b=0;if(x[a>>2]){Ic(a);b=x[a>>2];yA(a);Ib(b)}}function fA(a){var b=0;if(x[a>>2]){ER(a);b=x[a>>2];oo(a);Ib(b)}}function ct(a){var b=0;if(x[a>>2]){Ic(a);b=x[a>>2];vy(a);Ib(b)}}function Zd(a){var b=0;if(x[a>>2]){OX(a);b=x[a>>2];oC(a);Ib(b)}}function ZO(a){var b=0;if(x[a>>2]){st(a);b=x[a>>2];rt(a);Ib(b)}}function Yr(a){var b=0;b=ib-16|0;C[b+8>>3]=a;return C[b+8>>3]*a}function YQ(a){var b=0;if(x[a>>2]){TQ(a);b=x[a>>2];ak(a);Ib(b)}}function Xw(a,b){a=a|0;b=b|0;return lb[x[x[a>>2]+12>>2]](a,b)|0}function Xc(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){gt(b)}return a}function VS(a){var b=0;if(x[a>>2]){Ic(a);b=x[a>>2];ak(a);Ib(b)}}function VC(a){if(a>>>0>=214748365){Vg();p()}return mc(D(a,20))}function Un(a,b,c,d){a=Zt(a,c);if(Bj(a)){a=NQ(b,d)}return Ue(a)}function SO(a){var b=0;if(x[a>>2]){ap(a);b=x[a>>2];Vv(a);Ib(b)}}function QM(a){return E(E(B[Bb(a+4208|0,0)>>2]*E(1e4))+E(-1e4))}function Np(a,b,c){if(!b){return 0}return at(a,Ke(c<<24>>24),b)}function NS(a){var b=0;if(x[a>>2]){Ic(a);b=x[a>>2];Vv(a);Ib(b)}}function Li(a){var b=0;if(x[a>>2]){Ic(a);b=x[a>>2];oo(a);Ib(b)}}function LE(a){if(a>>>0>=357913942){Vg();p()}return mc(D(a,12))}function Jl(a,b){a=a|0;b=b|0;return lb[x[x[a>>2]+28>>2]](a,b)|0}function J6(a,b){a=a|0;b=b|0;return E(eM(x[x[a+4>>2]+24>>2],b))}function I6(a,b){a=a|0;b=b|0;return E(dM(x[x[a+4>>2]+24>>2],b))}function I$(a){a=a|0;a=x[a+8>>2];if(!a){return 1}return lG(a)|0}function H6(a,b){a=a|0;b=b|0;return E(aM(x[x[a+4>>2]+24>>2],b))}function Gv(a,b,c,d){return(b|0)==(d|0)&a>>>0<c>>>0|b>>>0<d>>>0}function Gm(a){var b=0;if(x[a>>2]){Ic(a);b=x[a>>2];du(a);Ib(b)}}function Gc(a){var b=0;if(kf(a)){b=x[a>>2];Kl(a);Ib(b)}return a}function Dma(a,b){a=a|0;b=b|0;a=bW(a,b);if(!a){aW(b)}return a|0}function DQ(a){var b=0;if(x[a>>2]){Ic(a);b=x[a>>2];Nz(a);Ib(b)}}function D6(a,b){a=a|0;b=b|0;return E(cM(x[x[a+4>>2]+24>>2],b))}function Ck(a){var b=0;if(x[a>>2]){Ic(a);b=x[a>>2];Wu(a);Ib(b)}}function C6(a,b){a=a|0;b=b|0;return E(bM(x[x[a+4>>2]+24>>2],b))}function z1(a,b){a=a|0;b=b|0;IP(a,mx(x[b>>2])<<24>>24,x[b>>2])}function yo(a,b){a=a|0;b=b|0;a=$W(a,b);if(!a){cX(b)}return a|0}function yQ(a,b){a=a|0;b=b|0;a=qX(a,b);if(!a){Xu(b)}return a|0}function xV(a){if(a>>>0>=715827883){Vg();p()}return mc(D(a,6))}function uT(a){return y[a+15|0]<<12|y[a+14|0]<<4|y[a+13|0]<<20}function qu(a,b){a=a|0;b=b|0;a=aX(a,b);if(!a){Vu(b)}return a|0}function qba(a,b,c){a=a|0;b=b|0;c=c|0;return Ew(a,b,c,0,932)|0}function mr(a,b){var c=0;c=b+1|0;x[a>>2]=x[a>>2]>(c|0)?c:b+2|0}function kr(a,b,c){a=a|0;b=b|0;c=c|0;Zh(a,b,Bi(b,b+c|0,78304))}function kg(a,b){return lb[x[x[a>>2]+32>>2]](a,x[a+12>>2],b)|0}function kP(a,b,c,d){w[a>>1]=b;v[a+2|0]=y[c|0];v[a+3|0]=y[d|0]}function jba(a,b,c){a=a|0;b=b|0;c=c|0;return Ew(a,b,c,1,932)|0}function ii(a,b){a=a|0;b=b|0;a=Nh(a,b);if(!a){Zj(b)}return a|0}function fN(a){a=a|0;return rk(E(B[Bb(a+4208|0,4)>>2]*E(4)))|0}function eB(a,b){a=a|0;b=b|0;a=Zo(a,b);if(!a){Ho(b)}return a|0}function bw(a,b){a=a|0;b=b|0;a=iE(a,b);if(!a){hE(b)}return a|0}function ac(a){return a<<8&16711680|a<<24|(a>>>8&65280|a>>>24)}function _N(a){if(a>>>0>=82595525){Vg();p()}return mc(D(a,52))}function Yba(a,b,c){a=a|0;b=b|0;c=c|0;return Ew(a,b,c,0,928)|0}function Uv(a,b){a=$c(a,b);hc(a+12|0,b+12|0);ge(a+32|0,b+32|0)}function Rv(a,b){a=a|0;b=b|0;a=TD(a,b);if(!a){qr(b)}return a|0}function Q6(a,b){a=a|0;b=b|0;return KL(x[x[a+4>>2]+24>>2],b)|0}function NX(a,b){if(!b){return-1}b=Np(a,b,0);return b?b-a|0:-1}function LO(a,b){return b>>>0>=4e3?21631:((b<<5)+a|0)+946304|0}function K5(a,b,c){a=a|0;b=b|0;c=c|0;rR(a,0,x[b+1298404>>2],c)}function FO(a,b,c,d){w[a+4>>1]=c;v[a+6|0]=b;x[a>>2]=d;return a}function Cr(a,b){a=a|0;b=b|0;a=aE(a,b);if(!a){fw(b)}return a|0}function CC(a,b){a=a|0;b=b|0;a=vC(a,b);if(!a){jv(b)}return a|0}function AB(a,b){a=a|0;b=b|0;a=uV(a,b);if(!a){nB(b)}return a|0}function zk(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){gc(a);Ib(b)}}function yE(a,b){var c=0;c=x[a>>2];x[a>>2]=b;if(c){Ib(ec(c))}}function xca(a){a=a|0;a=oj(a);if(a){lb[x[x[a>>2]+100>>2]](a)}}function nJ(a,b){a=(a+b|0)-1|0;return a-((a>>>0)%(b>>>0)|0)|0}function gN(a){a=a|0;return E(E(B[Bb(a+4208|0,2)>>2]*E(10)))}
function dna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;kF(a,b,c,d,359)}function Yla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;nF(a,b,c,d,117)}function Wla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;kF(a,b,c,d,466)}function Rl(a,b,c){x[a+4>>2]=c;x[a>>2]=b;if(c){fn(c)}return a}function Pba(a){a=a|0;return E(E(B[Bb(a+4208|0,6)>>2]*E(20)))}function Mna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;nF(a,b,c,d,143)}function Ii(a){if(a>>>0>=1073741824){Vg();p()}return mc(a<<2)}function I7(a,b,c){a=a|0;b=b|0;c=c|0;return+sL(x[a+4>>2],b,c)}function Bh(a,b,c){return(x[((c&255)<<2)+a>>2]&b)!=0&(c|0)>=0}function Bea(a){a=a|0;a=Ou(a,21631);x[a>>2]=108348;return a|0}function $O(a,b){var c=0;c=x[a>>2];x[a>>2]=b;if(c){Ib(Cj(c))}}function vS(a){if(a>>>0>=268435456){Vg();p()}return mc(a<<4)}function rS(a){if(a>>>0>=134217728){Vg();p()}return mc(a<<5)}function qy(a){a=a|0;x[a+32>>2]=0;x[a+28>>2]=x[a+28>>2]&-7|2}function pZ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;cc(a,x[d>>2],0)}function oc(a,b){var c=0;c=x[a>>2];x[a>>2]=x[b>>2];x[b>>2]=c}function kba(a){a=a|0;return E(E(B[Bb(a+4208|0,6)>>2]*E(4)))}function jE(a){if(a>>>0>=536870912){Vg();p()}return mc(a<<3)}function fJ(a){a=a|0;x[a>>2]=77744;ec(a+24|0);return Gs(a)|0}function dP(a){x[a>>2]=0;Nb(a+4|0);Rb(a+16|0,0,144);return a}function cka(a,b,c){a=a|0;b=b|0;c=c|0;return pF(a,b,c,37)|0}
function Vs(a){a=a|0;x[a>>2]=92688;wb(a+32|0);return Pn(a)|0}function Ry(a,b){var c=0;c=z[a>>1];w[a>>1]=z[b>>1];w[b>>1]=c}function Ou(a,b){a=jk(a);x[a>>2]=108228;Kw(a+4|0,b);return a}function BK(a){a=a|0;return+(65536/+A[x[a+32>>2]+480244>>2])}function BI(a){return v[(D(0-a&a,124511785)>>>27|0)+88992|0]}function $i(a){var b=0;o(+a);b=j(1)|0;j(0)|0;return b>>>20|0}function $g(a,b,c,d){kb=b-((a>>>0<c>>>0)+d|0)|0;return a-c|0}function zt(a,b){if(b){zt(a,x[b>>2]);zt(a,x[b+4>>2]);Ib(b)}}function z$(a,b,c){a=a|0;b=b|0;c=c|0;return vF(b,c,95456)|0}function vA(a,b){if(b){vA(a,x[b>>2]);vA(a,x[b+4>>2]);Ib(b)}}function uA(a,b){if(b){uA(a,x[b>>2]);uA(a,x[b+4>>2]);Ib(b)}}function t$(a,b,c){a=a|0;b=b|0;c=c|0;return uF(b,c,96992)|0}function sI(a,b){if(b>>>0<=9){return rI(a,b)}return ys(a,b)}function r$(a,b,c){a=a|0;b=b|0;c=c|0;return uF(b,c,95456)|0}function qi(a,b){var c=0,d=0;c=a,d=tH(b),x[c>>2]=d;return a}function iK(a,b){a=a|0;b=+b;EF(a,b,1e4,1074420,9311,512,32)}function el(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){Ib(nf(b))}}function dB(a,b){if(b){dB(a,x[b>>2]);dB(a,x[b+4>>2]);Ib(b)}}function Yv(a){var b=0;b=a;a=x[a>>2]-1|0;x[b>>2]=a;return a}function RP(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){Ib(uz(b))}}function Qn(a,b){return(((a<<12&b>>31)+b|0)/4096|0)%(a|0)|0}function Px(a,b,c,d,e,f){return CF(a,b,c,d,e,f,73140,73936)}function Pq(a){return x[a+20>>2]+(x[a+8>>2]-x[a+24>>2]|0)|0}function Ox(a,b,c,d,e,f){return CF(a,b,c,d,e,f,74016,74780)}function ND(a,b){return kB(a,nd(b),xd(x[b+4>>2],y[b+11|0]))}function MU(a){var b=0;b=x[a+100>>2];x[a+100>>2]=0;return b}function MJ(a,b){a=a|0;b=b|0;return Xh(x[b>>2],x[b+4>>2])|0}function LJ(a,b){a=a|0;b=b|0;return $d(x[b>>2],x[b+4>>2])|0}function JB(a,b){if(b){JB(a,x[b>>2]);JB(a,x[b+4>>2]);Ib(b)}}function IB(a,b){if(b){IB(a,x[b>>2]);IB(a,x[b+4>>2]);Ib(b)}}function C_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;lb[a|0](b,c,d)}function BX(a){return!Qb(a,14167,4)&(y[a+4|0]-1&255)>>>0<10}function B$(a,b,c){a=a|0;b=b|0;c=c|0;return vF(b,c,96992)|0}function At(a,b){if(b){At(a,x[b>>2]);At(a,x[b+4>>2]);Ib(b)}}function $Y(a){a=a|0;a=pE(a,13282);x[a>>2]=26092;return a|0}function uo(a){var b=0;b=x[a>>2];x[b>>2]=x[b>>2]|x[a+4>>2]}function p$(a,b,c){a=a|0;b=b|0;c=c|0;return((b|0)<0?c:b)|0}function m_(a){a=a|0;a=xQ(a,7904);x[a>>2]=41848;return a|0}function d3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;kb=0;return 0}function _T(a){var b=0;a=a+8|0;b=a>>>0<8?1:b;kb=b;return a}function Tl(a){a=uE(a);x[a+8>>2]=0;x[a>>2]=105140;return a}function S5(a,b,c){a=a|0;b=b|0;c=c|0;$c(a,cK(c,0,b,xf(b)))}function QL(a){return xj(Tb(x[a+484360>>2],y[a+484376|0]))}function Mq(a,b,c){if((a|0)!=(b|0)){b=b-a|0;Wi(c-b|0,a,b)}}function LZ(a){a=a|0;a=pE(a,8652);x[a>>2]=30516;return a|0}function J5(a){a=a|0;$x(a,2,100);Lj(x[a+24>>2]+484360|0,0)}function Iy(a,b,c){C[a>>3]=C[a>>3]+b;C[a+8>>3]=C[a+8>>3]+c}function Fn(a,b,c,d){x[a+16>>2]=d;x[a+12>>2]=c;x[a+8>>2]=b}function Eb(a){if(kf(a)){return x[a+4>>2]}return y[a+11|0]}function zq(a,b){if(Ue(y[a+11|0])){vd(a,b);return}ee(a,b)}function yK(a,b){a=a|0;b=+b;EF(a,b,256,1074456,11648,1,0)}function ko(a){x[a>>2]=0;x[a+4>>2]=0;vk(a+8|0,0);return a}function hx(a,b,c){x[a+28>>2]=c;x[a+20>>2]=b;x[a+24>>2]=b}function bg(a){var b=0;$R(a);b=x[a>>2];if(b){mA(a);Ib(b)}}function ZE(a,b,c){a=a|0;b=b|0;c=c|0;Lu(a,b,c);return a|0}function Xp(a){return((a-65&255)>>>0<26?a+32|0:a)<<24>>24}function XJ(a,b){var c=0;c=x[a>>2];x[a>>2]=b;if(c){gt(c)}}function VF(a,b,c){b=Na(967,a|0,b|0,c|0)|0;kb=jb;return b}function QI(a){while(1){if((Ds(a)|0)!=-1){continue}break}}function LX(a,b){v[a|0]=y[b|0];v[a+1|0]=y[b+1|0];return a}function Hla(a,b,c){a=a|0;b=b|0;c=c|0;Zh(a,b,cd(b,c)+b|0)}function Dx(a,b){return x[((a>>>24^b)<<2)+478976>>2]^a<<8}function Dc(a,b){return qF(a,b,2147483647,-2147483648,-1)}function CG(a){if(x[a>>2]){Ic(a);BG(Nw(a),x[a>>2],_h(a))}}function $A(a,b){var c=0;c=x[a>>2];x[a>>2]=b;if(c){Ib(c)}}function wu(a){uc(a+88|0);uc(a+68|0);uc(a+48|0);return a}function wG(a){a=a|0;x[a>>2]=99664;wb(a+16|0);return a|0}function vG(a){a=a|0;x[a>>2]=99624;wb(a+12|0);return a|0}function qL(a,b){fn(x[b>>2]);ln(x[a>>2]);x[a>>2]=x[b>>2]}function o9(a,b){a=a|0;b=b|0;return sn(a,b,11775,1012)|0}function nI(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Nf(a,-1,-1)}function mj(a){return df(a)|df(a)<<8|df(a)<<16|df(a)<<24}function mba(a){a=a|0;return B[Bb(a+4208|0,1)>>2]<E(1)|0}function lW(a){a=a|0;x[a>>2]=108228;bG(a+4|0);return a|0}function g4(a,b,c){a=a|0;b=b|0;c=c|0;return Gd(D(b,c))|0}function cba(a){a=a|0;UM(a);v[a+4202|0]=1;x[a+4224>>2]=0}function bu(a,b){oc(a,b);oc(a+4|0,b+4|0);oc(Db(a),Db(b))}function _v(a){a=a|0;x[a>>2]=108248;bG(a+4|0);return a|0}function Z8(a,b){a=a|0;b=b|0;return sn(a,b,11678,1019)|0}function YB(a,b){v[x[a>>2]]=y[b|0];v[x[a+4>>2]]=y[b+1|0]}function X8(a,b){a=a|0;b=b|0;return RF(a,b,13254,1020)|0}function Wz(a,b){C[a>>3]=C[a>>3]*b;C[a+8>>3]=C[a+8>>3]*b}function Rba(a){a=a|0;return B[Bb(a+4208|0,3)>>2]<E(1)|0}function Qi(a,b){var c=0;c=y[a|0];v[a|0]=y[b|0];v[b|0]=c}function OP(a,b){a=NP(a,b);NP(a+12|0,b+12|0);v[a+24|0]=1}function O8(a,b){a=a|0;b=b|0;return sn(a,b,11713,1027)|0}function MZ(a,b,c){a=a|0;b=b|0;c=c|0;$v(a,b,x[b+8>>2],c)}function M8(a,b){a=a|0;b=b|0;return sn(a,b,11743,1029)|0}function Ho(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0}function Gs(a){a=a|0;x[a>>2]=76892;ec(a+12|0);return a|0}function G8(a,b){a=a|0;b=b|0;return sn(a,b,11839,1032)|0}function E8(a,b){a=a|0;b=b|0;return sn(a,b,11807,1033)|0}function Ah(a,b,c){v[a|0]=y[a|0]|b;x[a+4>>2]=x[a+4>>2]|c}function ts(a){a=a|0;x[a>>2]=92624;_b(a+4|0);return a|0}function qJ(a){a=a|0;x[a>>2]=77356;ec(a+4|0);return a|0}function maa(a,b){a=a|0;b=b|0;return RF(a,b,6435,960)|0}function mE(a){a=a|0;x[a>>2]=43136;Ud(a+4|0);return a|0}function lo(a,b,c){x[a>>2]=b;x[a+4>>2]=x[c>>2];return a}function lO(a){return(a|0)==1179012417|(a|0)==538987841}function lH(a,b,c){a=Wb(a,b);Wb(a+4|0,x[c>>2]);return a}function kn(a){var b=0;b=x[a+8>>2];x[a+8>>2]=0;return b}function bG(a){a=Jx(x[a>>2]);if((Yv(a+8|0)|0)<0){Ib(a)}}function afa(a,b,c){a=a|0;b=b|0;c=c|0;aF(a,b,c,802,801)}function ad(a){if(kf(a)){a=Kl(a)-1|0}else{a=10}return a}function Yda(a,b,c){a=a|0;b=b|0;c=c|0;aF(a,b,c,873,872)}function Pn(a){a=a|0;x[a>>2]=92560;_b(a+4|0);return a|0}function PL(a){return Mt(x[a+484344>>2],x[a+484348>>2])}function OB(a){a=a&255;return Wc(a)^1|(a-49&255)>>>0<36}function Nb(a){x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);return a}function Mg(a,b,c,d,e){return Pa(a|0,b|0,c|0,d|0,e|0)|0}function Ls(a){a=a|0;x[a>>2]=50268;Qx(a+4|0);return a|0}function EQ(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){Ib(b)}}function Bd(a,b,c){return a>>>0<b>>>0?b:a>>>0<c>>>0?a:c}function AG(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){ln(b)}}function $I(a,b,c){x[a+4>>2]=0;x[a>>2]=b;x[a+8>>2]=c<<3}function $D(a,b){a=a|0;b=b|0;return oD(a,Jc(b),Eb(b))|0}function xn(a){if(kf(a)){a=Kl(a)-1|0}else{a=1}return a}function s1(a,b){a=a|0;b=b|0;dc(a,WH(x[b>>2]),x[b>>2])}function pO(a,b){return D(b&65535,a&65535)+7>>>3&65535}function o7(a,b,c){a=a|0;b=b|0;c=c|0;SL(a,x[b+4>>2],c)}function n3(a){a=a|0;return Jp(x[x[a>>2]-12>>2]+a|0)|0}function l3(a){a=a|0;return Cf(x[x[a>>2]-12>>2]+a|0)|0}function kma(a,b){a=a|0;b=b|0;dk(a,b,409,1042,-1332,2)}function kI(a){a=a|0;return vs(x[x[a>>2]-12>>2]+a|0)|0}function ih(a,b){a=a|0;b=b|0;lb[x[x[b>>2]+20>>2]](a,b)}function hm(a,b){x[a+16>>2]=!x[a+24>>2]|(x[a+16>>2]|b)}function dI(a){a=a|0;return us(x[x[a>>2]-12>>2]+a|0)|0}function _ba(a,b,c){a=a|0;b=b|0;c=c|0;dc(a,b+4228|0,7)}function Wia(a,b){a=a|0;b=b|0;dk(a,b,263,1042,-1332,2)}function Vka(a){a=a|0;Cj(110128);Cj(110120);wb(110108)}function Vb(a,b,c){return(a|0)<(b|0)?b:(a|0)<(c|0)?a:c}function Uh(a,b){a=a|0;b=b|0;lb[x[x[b>>2]+24>>2]](a,b)}function Th(a,b){a=a|0;b=b|0;lb[x[x[b>>2]+28>>2]](a,b)}function Pca(a,b,c){a=a|0;b=b|0;c=c|0;dc(a,b+4260|0,8)}function Ola(a,b){a=a|0;b=b|0;dk(a,b,104,1042,-1332,2)}function O7(a,b,c){a=a|0;b=b|0;c=c|0;$x(x[a+4>>2],b,c)}function NQ(a,b){return(a|0)!=(b|0)?a>>>0<b>>>0?-1:1:0}function Mha(a,b){a=a|0;b=b|0;if(!YT(a,b)){Rb(b,0,40)}}function H2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Zh(a,c,d)}function Gx(a){return(a&6)==6?384:1152>>>((a&14)==2)|0}function Gla(a,b){a=a|0;b=b|0;return Kc(a,b?b:21631)|0}function E2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;pH(a,c,d)}function Ch(a){var b=0;b=Ds(a);x[a+1396>>2]=0;return b}function Bp(a){return y[a+2|0]&2?(y[a+1|0]&6)==6?4:1:0}function zr(a,b){a=hc(a,b);Rb(a+20|0,0,1040);return a}function zn(a,b){return lb[x[x[a>>2]+52>>2]](a,b,0)|0}function yf(a,b,c,d){v[a+8|0]=d;x[a+4>>2]=c;x[a>>2]=b}function xc(a,b){a=a|0;b=b|0;PD(a,b,or(b));return a|0}function xb(a){if(Ue(y[a+11|0])){Ib(x[a>>2])}return a}function vca(a){a=a|0;v[a+4202|0]=1;dt(a);py(a);xN(a)}function vN(a){uc(a+36|0);uc(a+24|0);ct(a+12|0);ct(a)}function uz(a){bq(a+223860|0);ec(a+223848|0);return a}function u3(a,b){a=a|0;b=b|0;dk(a,b,104,1025,-1284,4)}function pM(a,b){kb=0-(((a|0)!=0)+b|0)|0;return 0-a|0}function mY(a,b){a=a|0;b=b|0;dk(a,b,263,1025,-1284,2)}function jH(a,b,c){a=rH(a,b,c,0,-2147483648);return a}function hj(a){a=a|0;return lb[x[x[a>>2]+16>>2]](a)|0}function hO(a,b){return(b>>>0>15?63:v[a+b|0])<<24>>24}function gj(a){a=a|0;return lb[x[x[a>>2]+12>>2]](a)|0}function gO(a,b){return(b>>>0>45?63:v[a+b|0])<<24>>24}function ec(a){if(x[a>>2]){Ic(a);Ib(x[a>>2])}return a}function eC(a,b){a=te(a,b);Rb(a+20|0,0,1040);return a}function e3(a,b){a=a|0;b=b|0;dk(a,b,104,1025,-1284,2)}function bh(a){a=a|0;return lb[x[x[a>>2]+24>>2]](a)|0}function _o(a,b,c){x[a+4>>2]=c;x[a>>2]=b;if(c){fn(c)}}function Zf(a,b,c,d){b=b+d|0;kb=a+c>>>0<c>>>0?b+1|0:b}function Y6(a,b){a=a|0;b=b|0;return ML(x[a+4>>2],b)|0}function X4(a,b){a=a|0;b=b|0;wQ(x[a>>2],b);return a|0}function W2(a,b){a=a|0;b=b|0;dk(a,b,107,1025,-1284,2)}function Rka(a,b,c){a=a|0;b=b|0;c=c|0;SU(a,b,Bb(b,c))}function N7(a,b){a=a|0;b=b|0;pL(x[x[a+4>>2]+24>>2],b)}function Lka(a,b,c){a=a|0;b=b|0;c=c|0;$c(a,eK(c,0,b))}function Kc(a,b){a=a|0;b=b|0;Lu(a,b,xf(b));return a|0}function An(a,b){return lb[x[x[a>>2]+36>>2]](a,b,0)|0}function s_(a,b){a=a|0;b=b|0;dk(a,b,12,1058,-1332,2)}function poa(a){if(a){return 31-G(a-1^a)|0}return 32}function nt(a){a=a|0;a=Oh(a);x[a+20>>2]=0;return a|0}function n7(a){a=a|0;return QL(x[x[a+4>>2]+24>>2])|0}function lba(a){a=a|0;return E(B[Bb(a+4208|0,3)>>2])}function l7(a){a=a|0;return YL(x[x[a+4>>2]+24>>2])|0}function kX(a,b,c,d){return ip(a,b,c,d,40,107374183)}function kA(a){a=Nb(a);x[a+12>>2]=0;w[a+16>>1]=65280}function k7(a){a=a|0;return Hp(x[x[a+4>>2]+24>>2])|0}function k3(a,b){a=a|0;b=b|0;dk(a,b,12,1025,-1284,2)}function i7(a){a=a|0;return Cg(x[x[a+4>>2]+24>>2])|0}function h7(a){a=a|0;return PL(x[x[a+4>>2]+24>>2])|0}function fe(a,b,c){v[a|0]=b;v[a+1|0]=y[c|0];return a}function eE(a,b,c,d){return ip(a,b,c,d,36,119304648)}function e7(a){a=a|0;return IL(x[x[a+4>>2]+24>>2])|0}function a7(a){a=a|0;return $L(x[x[a+4>>2]+24>>2])|0}function _6(a){a=a|0;return WL(x[x[a+4>>2]+24>>2])|0}function Wr(a,b,c,d,e,f){Ma(a|0,b|0,c|0,d|0,e|0,f|0)}function Vja(a,b,c){a=a|0;b=b|0;c=c|0;hF(a,b,c,28,2)}function UE(a,b,c,d){return ip(a,b,c,d,24,178956971)}function T6(a){a=a|0;return Ip(x[x[a+4>>2]+24>>2])|0}function Qv(a){a=a|0;return lb[x[x[a>>2]+8>>2]](a)|0}function Qba(a){a=a|0;return E(B[Bb(a+4208|0,1)>>2])}function Nq(a,b,c,d,e){dc(a,b+d|0,(e|0)==-1?c-d|0:e)}function LD(a,b){return(y[b+34|0]&8)>>>3&(a&2050)==2}function IX(a,b,c,d){return ip(a,b,c,d,28,153391690)}function G6(a){a=a|0;return ZL(x[x[a+4>>2]+24>>2])|0}function F0(){Wd(485144);yG(485152);x[121286]=102512}function El(a){a=(a|0)>=120?120:a;return(a|0)<=1?1:a}function EN(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0}function D0(){Wd(485160);yG(485168);x[121290]=102668}function $6(a){a=a|0;return XL(x[x[a+4>>2]+24>>2])|0}function zD(a,b,c){v[a+8|0]=1;x[a+4>>2]=c;x[a>>2]=b}function yn(a,b,c){x[a>>2]=b;x[a+4>>2]=c-b;return a}function uj(a){if(!a){return 0}return zj(y[a+31|0])}function sA(a){v[a+6|0]=0;w[a+4>>1]=65535;x[a>>2]=0}function rE(a){return AI(a,E(15845632502852868e13))}function mZ(a,b){a=a|0;b=b|0;return oD(a,b,xf(b))|0}function kka(a,b,c){a=a|0;b=b|0;c=c|0;hF(a,b,c,4,3)}function jz(a,b){x[a>>2]=b;x[a+4>>2]=b>>31;return a}function jN(a){a=a|0;return E(B[Bb(a+4208|0,0)>>2])}function hw(a,b){a=a|0;b=b|0;return kB(a,b,or(b))|0}function h6(a,b,c){a=a|0;b=b|0;c=c|0;uK(a-88|0,b,c)}function goa(a,b){a=a|0;b=b|0;vw(a,b,263,274,-1332)}function f6(a,b,c){a=a|0;b=b|0;c=c|0;sK(a-88|0,b,c)}function eR(a,b){x[a+8>>2]=0;x[a+12>>2]=0;C[a>>3]=b}function ce(a){var b=0;b=x[a>>2];x[a>>2]=0;return b}function T7(a){a=a|0;return gy(x[a>>2],x[a+4>>2])|0}function So(a,b,c){dc(a,(c>>>3&536870908)+b|0,c&31)}function Sl(a){a=a|0;a=zc(a);lb[x[x[a>>2]>>2]](a)|0}function Rp(a,b,c){if(!c){return 0}return Qb(a,b,c)}function QD(a){return AI(a,E(2524354896707238e-44))}function Oka(a,b,c){a=a|0;b=b|0;c=c|0;mF(a,b,c,256)}function Mv(a){if((a|0)<0){Vg();p()}return mc(a<<1)}function Jja(a,b){a=a|0;b=b|0;return li(a,b,1030)|0}function Gp(a,b){b=x[b>>2];x[a>>2]=b;fn(b);return a}function FK(a){a=a|0;a=x[a+4>>2];return(a?a:5014)|0}function E_(a){a=a|0;a=lb[a|0]()|0;jb=kb;return a|0}function CQ(a,b,c,d){return ip(a,b,c,d,7,613566757)}function Aja(a,b){a=a|0;b=b|0;return Or(a,b,1100)|0}function Aj(a){if(!a){return 0}return x[a+44>>2]!=0}function Ab(a,b,c){dc(a,(c>>>3&536870908)+b|0,1<<c)}function $ha(a,b,c){a=a|0;b=b|0;c=c|0;$c(a,hw(b,c))}function $e(a){var b=0;b=x[a>>2];if(b){Db(a);Ib(b)}}function zka(a,b){a=a|0;b=b|0;return li(a,b,826)|0}function ym(a){tj(a+724|0);tj(a+732|0);tj(a+740|0)}function vE(a,b,c){a=a|0;b=b|0;c=c|0;$c(a,ND(b,c))}function uE(a){x[a+4>>2]=0;x[a>>2]=107700;return a}function pE(a,b){a=oE(a,b);x[a>>2]=108508;return a}function jma(a,b,c){a=a|0;b=b|0;c=c|0;mp(a,b,c,85)}function j6(a,b,c){a=a|0;b=b|0;c=+c;wK(a-88|0,b,c)}function hka(a,b,c){a=a|0;b=b|0;c=c|0;Mr(a,b,c,79)}function gka(a,b,c){a=a|0;b=b|0;c=c|0;Mr(a,b,c,78)}function g6(a,b){a=a|0;b=b|0;return tK(a-88|0,b)|0}function e6(a,b){a=a|0;b=b|0;return rK(a-88|0,b)|0}function co(a,b,c){if((a|0)!=(b|0)){Wi(c,a,b-a|0)}}function b4(a,b){a=a|0;b=b|0;return jp(a,b,1127)|0}function Z5(a,b,c){a=a|0;b=b|0;c=+c;mK(a-92|0,b,c)}function X5(a,b,c){a=a|0;b=b|0;c=+c;kK(a-92|0,b,c)}function Vda(a,b){a=a|0;b=b|0;return li(a,b,225)|0}function V6(a){a=a|0;return+VL(x[x[a+4>>2]+24>>2])}function Una(a,b,c){a=a|0;b=b|0;c=c|0;Mr(a,b,c,80)}function Uaa(a,b){a=a|0;b=b|0;return E(Yl(a,b,12))}function UU(a,b,c){a=a|0;b=b|0;c=c|0;$c(a,aG(b,c))}function Sda(a,b){a=a|0;b=b|0;return li(a,b,326)|0}function M7(a,b){a=a|0;b=+b;return+rL(x[a+4>>2],b)}function M6(a){a=a|0;return+Zy(x[x[a+4>>2]+24>>2])}function M3(a,b){a=a|0;b=b|0;return jp(a,b,1131)|0}function Lk(a,b){return(a&65535)>>>0<(b&65535)>>>0}function Fka(a,b){a=a|0;b=b|0;return li(a,b,422)|0}function E3(a,b){a=a|0;b=b|0;return jp(a,b,1129)|0}function C5(a,b){a=a|0;b=b|0;return jp(a,b,1126)|0}function Bma(a,b){a=a|0;b=b|0;return li(a,b,308)|0}function A3(a,b){a=a|0;b=b|0;return jp(a,b,1130)|0}function z5(a,b,c){a=a|0;b=b|0;c=c|0;dF(a,b,c,61)}function vx(a){if(!a){return 0}x[12e4]=a;return-1}function v5(a,b,c){a=a|0;b=b|0;c=c|0;cF(a,b,c,61)}function t_(a,b){a=a|0;b=b|0;vw(a,b,12,290,-1332)}function rt(a){return(x[Db(a)>>2]-x[a>>2]|0)/52|0}function rl(a,b,c){C[a+8>>3]=c;C[a>>3]=b;return a}function qja(a,b){a=a|0;b=b|0;return li(a,b,71)|0}function oC(a){return(x[Db(a)>>2]-x[a>>2]|0)/28|0}function nZ(a,b){a=a|0;b=b|0;vw(a,b,12,257,-1284)}function mO(a,b){return(a|0)==1179011410&b>>>0>80}function lD(a){return!Qb(a,26176,25)&y[a+34|0]<65}function kV(a){return(x[Db(a)>>2]-x[a>>2]|0)/33|0}function j4(a,b,c){a=a|0;b=b|0;c=c|0;Mr(a,b,c,74)}function iL(a){x[a+4>>2]=0;x[a>>2]=49220;return a}function i5(a,b,c){a=a|0;b=b|0;c=c|0;eF(a,b,c,72)}function i4(a,b,c){a=a|0;b=b|0;c=c|0;dF(a,b,c,72)}function hla(a,b){a=a|0;b=b|0;return li(a,b,91)|0}function hX(a){return(x[Db(a)>>2]-x[a>>2]|0)/40|0}function gY(a,b,c){a=a|0;b=b|0;c=c|0;mp(a,b,c,81)}function eq(a,b){x[a+4>>2]=256;x[a>>2]=b;return a}function eba(a,b){a=a|0;b=b|0;return E(Yl(a,b,1))}function e4(a,b,c){a=a|0;b=b|0;c=c|0;cF(a,b,c,72)}function dc(a,b,c){x[a+4>>2]=c;x[a>>2]=b;return a}function cla(a,b){a=a|0;b=b|0;if(!iV(a,b)){hV(b)}}function bea(a,b){a=a|0;b=b|0;if(!aE(a,b)){fw(b)}}function ak(a){return(x[Db(a)>>2]-x[a>>2]|0)/12|0}function _F(a){return(a<<1)+16777216>>>0<16777217}function Xda(a,b){a=a|0;b=b|0;return li(a,b,73)|0}function XC(a){return(x[Db(a)>>2]-x[a>>2]|0)/20|0}function Wh(a,b){if(kf(a)){vd(a,b);return}ee(a,b)}function Vv(a){return(x[Db(a)>>2]-x[a>>2]|0)/36|0}function Vba(a,b){a=a|0;b=b|0;return E(Yl(a,b,6))}function VV(a){if(!(a&255)){return 1}return Wc(a)}function Sja(a,b){a=a|0;b=b|0;if(!vC(a,b)){jv(b)}}function R5(a){a=a|0;x[a>>2]=50048;return Us(a)|0}function Qz(a,b,c){x[a>>2]=b;x[a+4>>2]=c;return a}function Qda(a,b){a=a|0;b=b|0;return li(a,b,60)|0}function PY(a,b,c){a=a|0;b=b|0;c=c|0;mp(a,b,c,87)}function Naa(a,b){a=a|0;b=b|0;return E(Yl(a,b,2))}function N2(a,b,c){a=a|0;b=b|0;c=c|0;mp(a,b,c,86)}function Jr(a){return(x[Db(a)>>2]-x[a>>2]|0)/24|0}function Jma(a,b){a=a|0;b=b|0;if(!bW(a,b)){aW(b)}}function JT(a){return(x[Db(a)>>2]-x[a>>2]|0)/56|0}function J2(a,b,c){a=a|0;b=b|0;c=c|0;mp(a,b,c,88)}function Ima(a,b){a=a|0;b=b|0;return li(a,b,78)|0}function Hba(a,b){a=a|0;b=b|0;return E(Yl(a,b,5))}function Gaa(a,b){a=a|0;b=b|0;return E(Yl(a,b,3))}function FH(a){return(hk(a)|0)!=0|(a|32)-97>>>0<6}function Dna(a,b){a=a|0;b=b|0;if(!qX(a,b)){Xu(b)}}function D5(a,b,c){a=a|0;b=b|0;c=c|0;eF(a,b,c,61)}function Bm(a,b,c){x[a+4>>2]=c;w[a>>1]=b;return a}function Aba(a,b){a=a|0;b=b|0;return E(Yl(a,b,4))}function zJ(a,b){a=a|0;b=b|0;Sk(a,b,74812,74820)}function yJ(a,b){a=a|0;b=b|0;Sk(a,b,75624,75632)}function xJ(a,b){a=a|0;b=b|0;Sk(a,b,75640,75648)}function uJ(a,b){a=a|0;b=b|0;Sk(a,b,76452,76460)}function tJ(a,b){a=a|0;b=b|0;Sk(a,b,76468,76476)}function sY(a,b){a=a|0;b=b|0;if(!HC(a,b)){kv(b)}}function ov(a,b){a=a|0;b=b|0;if(!Vo(a,b)){Mo(b)}}function lna(a,b){a=a|0;b=b|0;lp(a,b,358,357,8)}
function lg(a,b,c){var d=0;d=a;a=b;yn(d,a,a+c|0)}function kW(a,b){a=a|0;b=b|0;if(!TD(a,b)){qr(b)}}function jn(a,b,c){a=Id(a);x[a+4>>2]=c;x[a>>2]=b}function i6(a,b){a=a|0;b=b|0;return+vK(a-88|0,b)}function ht(a){a=a|0;uc(a+4208|0);return Rf(a)|0}function hd(a,b,c,d){return Hd(a,D(Cg(b),c)+d|0)}function hB(a,b){a=a|0;b=b|0;if(!uV(a,b)){nB(b)}}function dN(a){a=a|0;uc(a+4256|0);return Rf(a)|0}function bX(a,b){a=a|0;b=b|0;if(!aX(a,b)){Vu(b)}}function aA(a){x[a+24>>2]=z[a+20>>1]<<z[a+22>>1]}function Y5(a,b){a=a|0;b=b|0;return+lK(a-92|0,b)}function Wu(a){return(x[Db(a)>>2]-x[a>>2]|0)/6|0}function W5(a,b){a=a|0;b=b|0;return+jK(a-92|0,b)}function Tx(a,b){x[a>>2]=x[b>>2];$c(a+4|0,b+4|0)}function Rna(a,b){a=a|0;b=b|0;return av(a,1,b)|0}function Nz(a){return(x[Db(a)>>2]-x[a>>2]|0)/7|0}function KR(a,b){x[a>>2]=x[a>>2]+(b<<1);return a}function IP(a,b,c){x[a+4>>2]=c;v[a|0]=b;return a}function EW(a,b){x[a>>2]=x[a>>2]+D(b,6);return a}function EJ(a,b){a=a|0;b=b|0;Sk(a,b,73976,73984)}function DV(a,b,c){dc(a,b,Bi(b,b+c|0,78304)-b|0)}function CN(a){a=a|0;ec(a+4208|0);return Rf(a)|0}function Bl(a,b,c){v[a+2|0]=c;w[a>>1]=b;return a}function BC(a,b){a=a|0;b=b|0;if(!iE(a,b)){hE(b)}}function Ao(a,b){a=a|0;b=b|0;if(!Nh(a,b)){Zj(b)}}function AX(a,b){a=gX(a,b);if(!a){lC(b)}return a}function AJ(a,b){a=a|0;b=b|0;Sk(a,b,74796,74804)}function yba(a){a=a|0;v[a+4202|0]=1;ZM(a);YM(a)}function yG(a){var b=0,c=0;b=a,c=Fd(),x[b>>2]=c}function tI(a,b){if(!a){return 0}return tx(a,b)}function rm(a,b){return zu(B[b>>2],B[a>>2])?b:a}function rd(a,b){return tp(x[b>>2],x[a>>2])?b:a}function pe(a,b){return Lk(z[a>>1],z[b>>1])?b:a}function pI(a,b,c){a=a|0;b=b|0;c=c|0;return a|0}function oy(a,b){return zu(B[a>>2],B[b>>2])?b:a}function nV(a){return!Qb(a,13871,4)&y[a+4|0]<32}function kja(a,b){a=a|0;b=b|0;lp(a,b,660,659,8)}function jla(a,b){a=a|0;b=b|0;lp(a,b,509,508,6)}function ioa(a,b){a=a|0;b=b|0;lp(a,b,299,298,8)}function f8(a){a=a|0;return GF(a,49160,12485)|0}function _ca(a,b,c){a=a|0;b=b|0;c=c|0;lN(a,b,c)}function Yc(a,b){return qo(x[a>>2],x[b>>2])?b:a}function Vk(a){return lb[x[x[a>>2]+36>>2]](a)|0}function Ve(a,b){return tp(x[a>>2],x[b>>2])?b:a}function Tc(a,b){return Lk(z[b>>1],z[a>>1])?b:a}function TY(a,b){a=a|0;b=b|0;dq(a,b);return a|0}function Saa(a){a=a|0;RM(a);iy(a);v[a+4202|0]=1}function SB(a,b,c){if(b){Rb(a,Ke(c),b)}return a}function Qh(a,b,c){return Ha(972,a|0,b|0,c|0)|0}function IU(a){var b=0;b=x[a>>2];Ie(a);return b}function Hb(a,b){return qo(x[b>>2],x[a>>2])?b:a}function Fba(a){a=a|0;v[a+4202|0]=1;aN(a);cN(a)}function En(a){return lb[x[x[a>>2]+28>>2]](a)|0}function EC(a,b){return(b&255)==2&(a&255)>>>0<3}function Dz(a){if(y[a+24|0]){SP(a);v[a+24|0]=0}}function DJ(a,b){a=a|0;b=b|0;Sk(a,b,73992,74e3)}function Cu(a,b){a=a|0;b=b|0;return Ob(a,b,1)^1}function Cja(a,b){a=a|0;b=b|0;lp(a,b,629,628,8)}function yX(a,b,c){a=a|0;b=b|0;c=c|0;IC(a,b,c)}function vB(a,b,c){a=a|0;b=b|0;c=c|0;FC(a,b,c)}function tn(a,b,c,d,e){Qa(a|0,b|0,c|0,d|0,e|0)}function th(a,b){v[a+4|0]=0;x[a>>2]=b;return a}function tC(a,b,c){a=a|0;b=b|0;c=c|0;QX(a,b,c)}function rg(a,b,c){a=roa(a,b,c,c>>31);return a}function qm(a){a=jk(a);x[a>>2]=108112;return a}function qA(a){return a>>>0<=45?y[a+43712|0]:0}function lR(a){Xz(a);Rb(a+27|0,0,255);return a}function j$(a,b,c){a=a|0;b=b|0;c=c|0;dc(a,c,b)}function e8(a){a=a|0;return GF(a,49180,8139)|0}function as(a,b){return(a&255)>>>0<(b&255)>>>0}function ZX(a){return!Qb(a,15462,4)&y[a+4|0]<4}function Vr(a,b,c,d,e){Ga(a|0,b|0,c|0,d|0,e|0)}function Qt(a){return(a>>>0<9?a:a-9|256)&65535}function P6(a){a=a|0;return+C[x[a+4>>2]+16>>3]}function Oi(a,b){return(D(b,104)+a|0)+484380|0}function JR(a){x[a>>2]=0;x[a+4>>2]=-1;return a}function Eda(a,b){a=a|0;b=b|0;$y(cO(a+24|0,b))}function E5(a,b){a=a|0;b=b|0;$c(a,mL(b,17620))}function Bja(a,b){a=a|0;b=b|0;return YT(a,b)|0}function Bf(a,b,c){if(!(y[a|0]&32)){wC(b,c,a)}}function $m(a){return(a>>>0<=127?-1:a^128)&255}function yp(a,b){a=a|0;b=b|0;return hI(a,b)^1}function xma(a,b){a=a|0;b=b|0;xw(a,b,17,3,16)}function wc(a,b){if(A[a>>2]>b>>>0){x[a>>2]=b}}function wb(a){if(kf(a)){Ib(x[a>>2])}return a}function wX(a){v[a+12|0]=y[a+12|0]|2;return a}function w4(a){a=a|0;x[a>>2]=77800;return a|0}function vy(a){return x[Db(a)>>2]-x[a>>2]>>11}function vl(a,b,c,d){return(b-d|0)+(a-c<<3)|0}function vM(a,b){a=a|0;b=b|0;return mL(a,b)|0}function ss(a,b){a=a|0;b=b|0;return YH(a,b)^1}function r4(a){a=a|0;x[a>>2]=77412;return a|0}function oZ(a){a=a|0;x[a>>2]=42760;return a|0}function n_(a,b){a=a|0;b=b|0;return NE(a,b)|0}function n9(a){a=a|0;return NF(a,7057,1016)|0}function mf(a,b){return as(y[a|0],y[b|0])?b:a}function m3(a){a=a|0;SH(x[x[a>>2]-12>>2]+a|0)}function jj(a,b){a=a|0;b=b|0;return hI(a,b)|0}function j3(a){a=a|0;RH(x[x[a>>2]-12>>2]+a|0)}function iI(a){a=a|0;nx(x[x[a>>2]-12>>2]+a|0)}function gk(a,b){a=a|0;b=b|0;return YH(a,b)|0}function gi(a,b){if(x[a>>2]>(b|0)){x[a>>2]=b}}function foa(a,b){a=a|0;b=b|0;xw(a,b,44,2,44)}function eY(a,b,c){a=a|0;b=b|0;c=c|0;return 0}function cI(a){a=a|0;kx(x[x[a>>2]-12>>2]+a|0)}function ana(a,b){a=a|0;b=b|0;oF(a,b,362,361)}function a_(a,b){a=a|0;b=b|0;return hw(a,b)|0}function Yw(){ha(qm(ba(4)|0)|0,108196,26);p()}function Xs(a){a=lL(a);x[a>>2]=93856;return a}function Ww(a,b,c){a=rH(a,b,c,-1,-1);return a}function Wd(a){a=uE(a);x[a>>2]=99952;return a}function W8(a){a=a|0;return NF(a,6594,1024)|0}function Us(a){a=a|0;x[a>>2]=50028;return a|0}function Ub(a,b){return as(y[b|0],y[a|0])?b:a}function UH(a,b){a=a|0;b=b|0;return ND(a,b)|0}function Qna(a,b){a=a|0;b=b|0;oF(a,b,305,304)}function OW(a){kb=0;a=(a&65535)-98|0;return a}function O6(a){a=a|0;return x[x[a+4>>2]+8>>2]}function Mf(a,b){if(z[a>>1]>b>>>0){w[a>>1]=b}}function MX(a,b){a=a|0;b=b|0;return aG(a,b)|0}function K4(a){a=a|0;x[a>>2]=76992;return a|0}function JH(a){a=lL(a);x[a>>2]=94248;return a}function Id(a){x[a>>2]=0;x[a+4>>2]=0;return a}function Gu(a,b){a=a|0;b=b|0;return Nk(a,b)|0}function DZ(a){a=a|0;x[a>>2]=78072;return a|0}function DG(a,b,c){a=a|0;b=b|0;c=c|0;return-1}function C4(a){a=a|0;x[a>>2]=76492;return a|0}function AT(a){a=qoa(a&65535,0,80,0);return a}function A4(a,b){a=a|0;b=b|0;AF(a,b,1110,308)}function $S(a){return Xe(443250/+(a>>>0)*1e4)}function yA(a){return x[Db(a)>>2]-x[a>>2]>>8}function xd(a,b){if(!Ue(b)){a=Ke(b)}return a}function sz(a){v[a+24|0]=0;v[a|0]=0;return a}function ry(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0}function rk(a){return fF(a,E(4294967296),-1)}function qZ(a){a=a|0;x[a>>2]=43e3;return a|0}function oo(a){return x[Db(a)>>2]-x[a>>2]>>5}function mn(a){return x[Db(a)>>2]-x[a>>2]>>3}function mA(a){return x[zc(a)>>2]-x[a>>2]>>2}function ly(a){return E(E(a*E(7900))+E(100))}function j7(a,b){a=a|0;b=b|0;NL(a,x[b+4>>2])}function ik(a){a=a&255;return(a|0)==255?-1:a}function eG(a,b,c){a=a|0;b=b|0;c=c|0;QH(a,c)}function e1(a){a=a|0;be(a,484864,Xd(483376))}function du(a){return x[Db(a)>>2]-x[a>>2]>>4}function d1(a){a=a|0;be(a,484872,Xd(483384))}function c7(a,b){a=a|0;b=b|0;GL(a,x[b+4>>2])}function c1(a){a=a|0;be(a,484880,Xd(483580))}function b7(a,b){a=a|0;b=b|0;gM(a,x[b+4>>2])}function b1(a){a=a|0;be(a,484896,Xd(483572))}function a1(a){a=a|0;be(a,484904,Xd(483588))}function _m(a){return x[Db(a)>>2]-x[a>>2]>>1}function _h(a){return x[Db(a)>>2]-x[a>>2]>>2}function _3(a){a=a|0;return hb(x[a+60>>2])|0}function _0(a){a=a|0;be(a,484912,Xd(483596))}function Z0(a){a=a|0;be(a,484928,Xd(483604))}function Yo(a,b,c,d){a=roa(a,b,c,d);return a}function Y0(a){a=a|0;be(a,484936,Xd(483620))}function X6(a,b){a=a|0;b=b|0;LL(a,x[b+4>>2])}function X0(a){a=a|0;be(a,484944,Xd(483612))}function W6(a,b){a=a|0;b=b|0;FL(a,x[b+4>>2])}function W0(a){a=a|0;be(a,484952,Xd(483628))}function V0(a){a=a|0;be(a,484960,Xd(483636))}function U4(a,b){a=a|0;b=b|0;AF(a,b,1106,52)}function U0(a){a=a|0;be(a,484984,Xd(483644))}function TU(a,b,c){w[a>>1]=b;v[a+2|0]=y[c|0]}function T0(a){a=a|0;be(a,485016,Xd(483392))}function S0(a){a=a|0;be(a,485024,Xd(483400))}function R6(a,b){a=a|0;b=b|0;TL(a,x[b+4>>2])}function R0(a){a=a|0;be(a,485032,Xd(483408))}function Q7(a,b){a=a|0;b=b|0;ay(x[a+4>>2],b)}function Q4(a){a=a|0;oJ(a);return x[a+16>>2]}function Q0(a){a=a|0;be(a,485040,Xd(483416))}function P0(a){a=a|0;be(a,485048,Xd(483456))}function O0(a){a=a|0;be(a,485056,Xd(483464))}function N0(a){a=a|0;be(a,485064,Xd(483472))}function M0(a){a=a|0;be(a,485072,Xd(483480))}function L0(a){a=a|0;be(a,485080,Xd(483488))}function K0(a){a=a|0;be(a,485088,Xd(483496))}function J0(a){a=a|0;be(a,485096,Xd(483504))}function I0(a){a=a|0;be(a,485104,Xd(483512))}function Hh(a){return x[x[a+8>>2]>>2]==(a|0)}function H0(a){a=a|0;be(a,485112,Xd(483424))}function G0(a){a=a|0;be(a,485128,Xd(483432))}function E0(a){a=a|0;be(a,485144,Xd(483440))}function C0(a){a=a|0;be(a,485160,Xd(483448))}function B0(a){a=a|0;be(a,485176,Xd(483520))}function A0(a){a=a|0;be(a,485184,Xd(483528))}function yi(a,b){a=a|0;b=b|0;return E(E(0))}function vc(a){if(kf(a)){a=x[a>>2]}return a}function ul(a,b){return a<<24>>24<b<<24>>24}function uk(a,b){return a<<16>>16<b<<16>>16}function sp(a){return x[Db(a)>>2]-x[a>>2]|0}function pca(a,b,c){a=a|0;b=b|0;c=c|0;Id(a)}function im(a){a=a|0;mx(x[a>>2]);return a|0}function gt(a){a=a|0;lb[x[x[a>>2]+4>>2]](a)}function g7(a){a=a|0;return OL(x[a+4>>2])|0}function ai(a,b,c){if(c){Wi(a,b,c)}return a}function Zna(a,b){a=a|0;b=b|0;Nr(a,b,297,2)}function WL(a){return A[a+1074420>>2]/1e4|0}function U6(a){a=a|0;return _L(x[a+4>>2])|0}function Tca(a,b){a=a|0;b=b|0;v[a+4201|0]=b}function Sm(a,b,c){return Jf(a,b)>>>0>c>>>0}function S4(a){a=a|0;oJ(a);return x[a+4>>2]}function Lm(a,b){w[a>>1]=b;w[a+2>>1]=b>>>16}function Gn(a){a=a|0;WH(x[a>>2]);return a|0}function GJ(a){v[a+4|0]=0;v[a|0]=0;return a}function Fha(a,b){a=a|0;b=b|0;Nr(a,b,576,3)}function Ff(a,b){if(y[a|0]>b>>>0){v[a|0]=b}}function FG(a,b,c){return Xv(EG(a),EG(b),c)}function EM(a){return Yh(E(GM(a)*E(32768)))}function DB(a,b){x[a>>2]=x[a>>2]+b;return a}function Ae(a,b,c){if(c){rc(a,b,c)}return a}function yq(a){x[a>>2]=x[a>>2]+12;return a}function xda(a,b){a=a|0;b=b|0;Pg(a,b+36|0)}function su(a,b){a=a|0;b=b|0;Nr(a,b,577,2)}function sr(a){Ar(a+32|0);yb(a+12|0);xb(a)}function rv(a){a=a|0;return Ih(a,483580)|0}function rf(a,b,c){a=qoa(c,0,a,b);return a}function qq(a){x[a>>2]=x[a>>2]+16;return a}function pea(a,b){a=a|0;b=b|0;cp(a+40|0,b)}function ou(a){x[a>>2]=x[a>>2]+52;return a}function od(a,b){a=a|0;b=b|0;lN(a,b,xf(b))}function ms(a){a=a|0;Aw(a,172,108556,1013)}function ll(a){wb(a+36|0);uc(a+24|0);Ck(a)}function ku(a){$e(a+24|0);ec(a+12|0);ec(a)}function ix(a){a=a|0;return Ih(a,483572)|0}function gA(a){x[a>>2]=x[a>>2]+32;return a}function fx(a){a=a|0;return Ih(a,483588)|0}function doa(a,b){a=a|0;b=b|0;cp(a+12|0,b)}function bx(a){a=a|0;return Ih(a,483596)|0}function aB(a,b){a=a|0;b=b|0;Nr(a,b,576,2)}function Zw(a){a=a|0;return Ih(a,483636)|0}function Xk(a,b){lb[x[x[b>>2]+44>>2]](a,b)}function Wk(a,b){lb[x[x[b>>2]+32>>2]](a,b)}function Uf(a){x[a>>2]=x[a>>2]+20;return a}function Tw(a){a=a|0;return Ih(a,483644)|0}function Qm(a){x[a>>2]=x[a>>2]+28;return a}function LS(a,b,c,d){dc(a,b,(d|0)==-1?c:d)}function L3(a){a=a|0;return Ih(a,483392)|0}function Kl(a){return x[a+8>>2]&2147483647}function Jm(a){iA(x[a+20>>2]);x[a+20>>2]=0}function JZ(a){a=a|0;return x[a+4>>2]!=0|0}function JP(a,b){return sF(a,b,2147483647)}function JM(a){return E(E(a*E(96))+E(-96))}function Gia(a,b){a=a|0;b=b|0;lF(a,b,2,31)}function Fs(a){return(a|0)<=65535&(a|0)>=0}function D3(a){a=a|0;return Ih(a,483408)|0}function AI(a,b){return E(ow(a?E(-b):b)*b)}function $r(a,b){lb[x[x[b>>2]+40>>2]](a,b)}function $na(a,b){a=a|0;b=b|0;Zq(a+36|0,b)}function vs(a){a=a|0;cl(a+8|0);return a|0}function vma(a,b){a=a|0;b=b|0;mi(a,b,282)}function us(a){a=a|0;cl(a+4|0);return a|0}function tQ(a,b){if(B[a>>2]>b){B[a>>2]=b}}function se(a){return Fb(a&65535)<<16>>16}function rI(a,b){v[a|0]=b+48;return a+1|0}function r6(a,b){a=a|0;b=b|0;EK(a-88|0,b)}function q6(a,b){a=a|0;b=b|0;DK(a-88|0,b)}function pj(a,b){x[a>>2]=x[b>>2];return a}function oK(a,b){a=a|0;b=b|0;DF(a,b,2048)}function nK(a,b){a=a|0;b=b|0;DF(a,b,4096)}function l4(a,b){a=a|0;b=b|0;Nk(a,b+12|0)}function c6(a,b){a=a|0;b=b|0;pK(a-88|0,b)}function bl(a){a=a|0;return gI(a)<<24>>24}function aG(a,b){return Xr(a,Jc(b),Eb(b))}function _5(a,b){a=a|0;b=b|0;nK(a-92|0,b)}function Ye(a){x[a>>2]=x[a>>2]+2;return a}function Xaa(a){a=a|0;return x[a+4260>>2]}function X$(a,b){a=a|0;b=b|0;Pg(a,b+16|0)}function Wna(a,b){a=a|0;b=b|0;mi(a,b,136)}function VL(a){return+A[a+1074420>>2]/1e4}function TF(a){a=Fa(a|0)|0;kb=jb;return a}function S6(a){a=a|0;return+UL(x[a+4>>2])}function Rt(a){sm(a,jo(a),78304);return a}function Rn(a,b){return x[a>>2]-x[b>>2]|0}function Rja(a,b){a=a|0;b=b|0;mi(a,b,274)}function R$(a,b){a=a|0;b=b|0;Pg(a,b+12|0)}function Pe(a){x[a>>2]=x[a>>2]+4;return a}function Nt(a){x[a>>2]=x[a>>2]+8;return a}function Mja(a,b){a=a|0;b=b|0;mi(a,b,106)}function Kx(a,b,c){dc(a,(c<<12)+b|0,4096)}function KM(a){a=a|0;Rb(a+4296|0,0,81928)}function If(a){a=a|0;Oh(a+8|0);return a|0}function Ie(a){x[a>>2]=x[a>>2]+1;return a}function IR(a){x[a>>2]=x[a>>2]-2;return a}function Hk(a){x[a>>2]=x[a>>2]+6;return a}function Ep(a){a=a|0;Kp(a+8|0);return a|0}function Bna(a,b){a=a|0;b=b|0;lF(a,b,3,8)}function $ba(a){a=a|0;v[a+4202|0]=1;qN(a)}function $5(a,b){a=a|0;b=b|0;oK(a-92|0,b)}function xaa(a){a=a|0;return(a|0)==277|0}function wma(a,b){a=a|0;b=b|0;br(a,b,17)}function wE(a,b){oc(a,b);oc(a+4|0,b+4|0)}function tj(a){w[a+4>>1]=65535;x[a>>2]=0}function t6(a){a=a|0;return Ep(a-88|0)|0}function rs(a,b){x[a+24>>2]=x[a+24>>2]+b}function p6(a,b){a=a|0;b=+b;CK(a-88|0,b)}function n6(a,b){a=a|0;b=+b;AK(a-88|0,b)}function l6(a,b){a=a|0;b=+b;yK(a-88|0,b)}function ic(a){x[x[a>>2]+4>>2]=x[a+4>>2]}function hf(a,b){x[a+8>>2]=b|-2147483648}function gna(a,b){a=a|0;b=b|0;mi(a,b,34)}function eW(a,b,c){x[a>>2]=b;x[a+4>>2]=c}function b6(a){a=a|0;return Ep(a-92|0)|0}function ag(a,b){a=roa(0,a,b,0);return a}function _k(a){return(a|0)==32|a-9>>>0<5}function _d(a,b){return(b|0)!=0&(a|0)!=0}function ZU(a,b){a=a|0;b=b|0;mi(a,b,284)}function WJ(a){return(vc(a)+Eb(a)|0)-1|0}function W$(a,b){a=a|0;b=b|0;un(a,99696)}function V5(a){a=a|0;return Ep(a-96|0)|0}function V$(a,b){a=a|0;b=b|0;un(a,99716)}function T5(a,b){a=a|0;b=+b;iK(a-96|0,b)}function Sca(a){a=a|0;return y[a+4201|0]}function Rj(a,b){v[a|0]=b;v[a+1|0]=b>>>8}function Rca(a){a=a|0;return y[a+4202|0]}function Q$(a,b){a=a|0;b=b|0;Kc(a,11176)}function P$(a,b){a=a|0;b=b|0;Kc(a,11293)}function Nka(a,b){a=a|0;b=b|0;mi(a,b,42)}function Mk(a){return D(an(a),Md(a))&255}function Kja(a,b){a=a|0;b=b|0;mi(a,b,72)}function Fi(a,b){return x[a>>2]!=x[b>>2]}function wx(a){return(q(a),j(2))>>>20|0}function wY(a,b){a=a|0;b=b|0;br(a,b,11)}function uW(a){return jF(a,65535,65535)}function nk(a,b){return Bz(a&255,b&255)}function iG(a,b){a=a|0;b=b|0;return b|0}function eM(a,b){return MF(a,b,1075834)}function cM(a,b){return LF(a,b,1075834)}function bla(a,b){a=a|0;b=b|0;KC(a,b,8)}function bi(a){return(a&65535)>>>0<3999}function bM(a,b){return LF(a,b,1075835)}function aM(a,b){return MF(a,b,1075835)}function XX(a,b){a=a|0;b=b|0;mi(a,b,50)}function Ul(a){a=x[a+8>>2];if(a){Ib(a)}}function Sg(a,b,c){v[a+4|0]=c;x[a>>2]=b}function SI(a){x[a+4>>2]=x[a+4>>2]|8192}function Pu(a,b,c){return a<b?b:a>c?c:a}function Pna(a){a=a|0;return x[a+12>>2]}function OG(a,b){a=a|0;b=b|0;wf(a,1,45)}function NG(a,b){a=a|0;b=b|0;XG(a,1,45)}function MV(a,b){a=a|0;b=b|0;br(a,b,32)}function Jz(a,b,c){return a<b?b:a>c?c:a}function Iaa(a){a=a|0;return-2013527448}function HY(a,b){a=a|0;b=b|0;mi(a,b,59)}function Fb(a){return(a<<8|a>>>8)&65535}function FT(a,b,c,d){return vl(c,d,a,b)}function CP(a,b){return(sl(a,b)|0)!=255}function yaa(a,b){a=a|0;b=b|0;return 2}function wv(a,b,c){return hp(a,b,c,20)}function wB(a,b,c){zq(a,c);ne(b+c|0,0)}function vba(a){a=a|0;return-281111764}function uZ(a){a=a|0;return x[a+16>>2]}function qh(a){return fF(a,E(255),255)}function pw(a,b){x[a+4>>2]=4;x[a>>2]=b}function oba(a){a=a|0;return-271958638}function o6(a){a=a|0;return+BK(a-88|0)}function nX(a,b,c){return hp(a,b,c,40)}function m6(a){a=a|0;return+zK(a-88|0)}function k6(a){a=a|0;return+xK(a-88|0)}function jk(a){x[a>>2]=108808;return a}function hu(a,b,c){return hp(a,b,c,12)}function he(a,b,c){yn(a,b,cd(b,c)+b|0)}function gw(a,b){x[a+4>>2]=3;x[a>>2]=b}function gba(a){a=a|0;return-620920304}function fj(a,b){x[a+4>>2]=1;x[a>>2]=b}function dW(a,b,c){Bl(a,b&65535,c&255)}function bs(a){a=a|0;return 2147483647}function bk(a,b){x[a+4>>2]=2;x[a>>2]=b}function Yaa(a){a=a|0;return-275227023}function Xba(a){a=a|0;return-270114148}function Vd(a){x[x[a+8>>2]>>2]=x[a>>2]}function UR(a,b,c){return pF(a,b,c,42)}function TJ(a){return a?(a|0)==2?3:2:1}function RE(a,b,c){return hp(a,b,c,24)}function Paa(a){a=a|0;return 302837129}function Lba(a){a=a|0;return-285139079}function Kca(a){a=a|0;return 542066252}function Ht(a,b){return qF(a,b,-1,0,0)}function Hi(a,b){return vc(a)+(b<<2)|0}function HN(a){a=a|0;return 1869112133}function Eha(a){a=a|0;vT(a);return a|0}function Cba(a){a=a|0;return-284078960}function Aaa(a,b){a=a|0;b=b|0;return 3}function zo(a,b){w[a+8>>1]=b;return a}function zj(a){return(a-1&255)>>>0<17}function ws(a,b){a=a|0;b=b|0;return-1}function vi(a,b,c){$c($c(a,b)+12|0,c)}function ur(a,b,c){return kp(a,b,c,3)}function tS(a,b,c){return zw(a,b,c,5)}function sy(a,b){a=a|0;b=b|0;return 1}function sE(a){a=a|0;return x[a+8>>2]}function rT(a){return(a|0)>=120?120:a}function rA(a,b,c){return kp(a,b,c,5)}function qf(a,b,c){return hd(a,b,c,0)}function pi(a){a=x[a>>2];if(a){tH(a)}}function oV(a,b,c){cc(a,b,tc(b,c)<<2)}function nQ(a,b){return(0-b|0)!=(a|0)}function mL(a,b){return Xr(a,b,xf(b))}function lS(a){return(a&65535)==65534}function lL(a){x[a>>2]=93884;return a}function kf(a){return y[a+11|0]>>>7|0}function kO(a,b){Zc(a,b&4?16:8,1,0,0)}function kE(a,b,c){cc(a,b,ah(b,c)<<3)}function hn(a){x[a>>2]=76944;return a}function hI(a,b){return fI(a)^fI(b)^1}function ei(a,b,c){return kp(a,b,c,1)}function Yq(a){a=a|0;return x[a+4>>2]}function Ym(a,b,c){return zw(a,b,c,2)}function YL(a){return x[a+1074424>>2]}function YH(a,b){return XH(a)^XH(b)^1}function YE(a){a=E(a-a);return E(a/a)}function Y2(a){a=a|0;return HH(a,0)|0}function Xx(a){x[a>>2]=49864;return a}function XL(a){return x[a+1074416>>2]}function X2(a){a=a|0;return HH(a,1)|0}function Wx(a){x[a>>2]=49888;return a}function Wt(a,b,c){return kp(a,b,c,4)}function Vx(a){x[a>>2]=49968;return a}function Ux(a){x[a>>2]=50008;return a}function Uo(a,b,c){return zw(a,b,c,1)}function Te(a,b){x[a+4>>2]=b;return a}function Sna(a,b){a=a|0;b=b|0;It(a,b)}function Rq(a,b,c){return hp(a,b,c,6)}function Q2(a){a=a|0;return GH(a,0)|0}function P2(a){a=a|0;return GH(a,1)|0}function Nm(a){return(a&740327453)!=0}function M4(a){a=a|0;return y[a+40|0]}function LU(a){UI(a);Ge(x[a+80>>2],a)}function KJ(a){x[a>>2]=50348;return a}function Jf(a,b){return Fk(a,b)&65535}function Gea(a,b){a=a|0;b=b|0;lP(a,b)}function Fh(a,b,c){return kp(a,b,c,2)}function FJ(a){x[a>>2]=73960;return a}function AM(a,b){a=a|0;b=b|0;return 0}function $L(a){return z[a+1074448>>1]}function zx(a){return!Qb(a,109128,6)}function xU(a,b){if(!rU(a,b)){PA(b)}}function wi(a,b){a=a|0;b=b|0;Pg(a,b)}function tna(a){a=a|0;return YW(a)|0}function rh(a){nf(a+52|0);ec(a+40|0)}function qn(a,b){a=a|0;b=b|0;XK(a,b)}function qM(a){a=a|0;QF(a,49024,961)}function pT(a){return(a&255)>>>0<129}function o_(a,b){a=a|0;b=b|0;_O(a,b)}function oB(a,b){a=a|0;b=b|0;GK(a,b)}function kea(a){a=a|0;return Ci(a)|0}function jy(a,b){a=a|0;b=b|0;VM(a,b)}function gS(a,b,c,d){eS(dc(a,b,c),d)}function fy(a){a=a|0;QF(a,49080,963)}function fr(a,b){a=a|0;b=b|0;Tv(a,b)}function fn(a){x[a+4>>2]=x[a+4>>2]+1}function bba(a){a=a|0;x[a+4224>>2]=0}function ZL(a){return z[a+480214>>1]}function ZB(a,b,c){Wb(Wb(a,b)+4|0,c)}function YP(a){return(a+5&255)>>>0<2}function XK(a,b){a=a|0;b=b|0;Rs(a,b)}function Vq(a,b){a=a|0;b=b|0;$M(a,b)}function Ut(a){return x[Db(a)>>2]<<5}function Uea(a){a=a|0;return bh(a)|0}function T$(a){a=a|0;return v[a+8|0]}function S$(a){a=a|0;return v[a+9|0]}function Rs(a,b){a=a|0;b=b|0;Nk(a,b)}function Rma(a){a=a|0;return NB(a)|0}function Qu(a,b){return y[a+b|0]!=63}function Nd(a,b){return D(b,160)+a|0}function Kj(a,b){a=a|0;b=b|0;xX(a,b)}function KS(a,b){return D(b,872)+a|0}function Ip(a){return z[a+480192>>1]}function IV(a,b){a=a|0;b=b|0;Gu(a,b)}function IL(a){return x[a+480272>>2]}function Hp(a){return z[a+480190>>1]}function HM(a){x[a>>2]=0;x[a+4>>2]=0}function H4(a){a=a|0;return y[a+8|0]}function FN(a,b,c){a=a|0;b=b|0;c=c|0}function Dha(a){a=a|0;return Ii(a)|0}function Cg(a){return z[a+480188>>1]}function $Z(a,b){a=a|0;b=b|0;PE(a,b)}function $M(a,b){a=a|0;b=b|0;wi(a,b)}function zv(a,b){w[a>>1]=b;return a}function zda(a){a=a|0;br(a,21631,1)}function yu(a,b){return(b-a|0)/33|0}function xe(a,b,c){return lH(a,b,c)}function xX(a,b){vX(a,x[a+16>>2]|b)}function wt(a){return!(a&204473357)}function wj(a,b){return xg(a,b)&255}function wd(a,b){return(b-a|0)/12|0}function vg(a){return E(F(a))==E(O)}function v3(a){a=a|0;return al(a)|0}function tr(a,b){return(b-a|0)/36|0}function sf(a,b){return D(b,24)+a|0}function rq(a,b){return(b-a|0)/56|0}function qo(a,b){return a>>>0<b>>>0}function pc(a,b){return(a|0)==(b|0)}function lZ(a){a=a|0;bE(Rb(a,0,36))}function lV(a,b){return D(b,33)+a|0}function kZ(a){a=a|0;return Oh(a)|0}function jw(a,b,c){return Qb(a,b,c)}function ji(a,b,c){return Xv(a,b,c)}function hg(a,b){return D(b,52)+a|0}function ge(a,b){return vk(a,ce(b))}function eu(a,b){return D(b,36)+a|0}function bq(a){if(y[a+24|0]){SP(a)}}function ar(a){a=a|0;return Re(a)|0}function _B(a){a=a|0;return mc(a)|0}function Yg(a,b){return D(b,20)+a|0}function YX(a){a=a|0;return Qv(a)|0}function Xi(a,b){return(b-a|0)/24|0}function Wq(a,b){return(b-a|0)/28|0}function Wp(a){return pX(a,251,255)}function Wb(a,b){x[a>>2]=b;return a}function Tk(a,b,c){return ZE(a,b,c)}function Tb(a,b){return De(a,b&255)}function Qq(a,b){return(b-a|0)/40|0}function PZ(a){a=a|0;return Jg(a)|0}function OH(a){a=a|0;return _v(a)|0}function Kv(a){v[a+2|0]=0;w[a>>1]=0}function Kf(a,b){return(b-a|0)/20|0}function JU(a,b){return Yf(a,0-b|0)}function ID(a){a=a|0;return _g(a)|0}function Hy(a,b){return D(b,28)+a|0}function HL(a){a=a|0;return cl(a)|0}function Gl(a,b){return Fl(Oc(a,b))}function Fk(a,b){return(b-a|0)/52|0}function FA(a,b){return D(b,56)+a|0}function Cd(a,b){return D(b,12)+a|0}function CB(a,b,c){return at(a,b,c)}function Bq(a){return(a&255)==1?1:2}function Ak(a){return jF(a,255,255)}function yma(a){a=a|0;return+jI(a)}function ye(a,b){dc(a,Jc(b),Eb(b))}function y6(a,b){a=a|0;b=b|0;fM(a)}function xk(a,b){return(b-a|0)/6|0}function xi(a){a=a|0;v[a+4202|0]=0}function um(a){return E(F(a))<E(O)}function tp(a,b){return(a|0)<(b|0)}function sw(a,b){return!(b>>>31|0)}function pp(a,b){v[a|0]=b;return a}function nr(a,b){return(b<<11)+a|0}function mt(a,b){return(a-b|0)/6|0}function lw(a,b){return _l(a,b,12)}function iV(a,b){return Or(a,b,18)}function iE(a,b){return Or(a,b,20)}function hy(a,b,c,d){ww(a,b,c,d,9)}function gx(a){return pc(a,-1)?0:a}function gl(a,b){return(a+b|0)-1|0}function gE(a,b){return _l(a,b,36)}function fo(a,b){return(b<<13)+a|0}function f4(a,b){a=a|0;b=b|0;Ib(b)}function e_(a){a=a|0;en(a,1,13404)}function bW(a,b){return Or(a,b,56)}function ZP(a){we(a+8|0);RP(a+4|0)}function Z6(a,b){a=a|0;b=b|0;RL(a)}function Yx(a,b,c,d){ww(a,b,c,d,4)}function Ue(a){return(a&128)>>>7|0}function Rk(a){return(a&255)>>>0>1}function Rh(a,b){a=a|0;b=b|0;Kb(a)}function QJ(a){return(ik(a)|0)==-1}function PJ(a,b){a=a|0;b=b|0;ec(b)}function OJ(a,b){a=a|0;b=b|0;Km(b)}function Nj(a,b){return D(Mk(b),a)}function Mz(a,b){return(b-a|0)/7|0}function Mo(a){v[a|0]=0;v[a+1|0]=0}function Mn(a,b){x[a+1298472>>2]=b}function LK(a,b,c,d){ww(a,b,c,d,2)}function LG(a){return Ih(a,483464)}function KX(a,b){return _l(a,b,28)}function KG(a){return Ih(a,483456)}function Ju(a){return a&2147483647}function IG(a){return Ih(a,483480)}function Hd(a,b){return D(b,6)+a|0}function HG(a){return Ih(a,483472)}function Ec(a,b){return sF(a,b,-1)}function AW(a){return y[a+1|0]!=63}function $E(a){C[(ib-16|0)+8>>3]=a}function xy(a){x[a>>2]=x[a>>2]+24}function uea(a){a=a|0;Dg(a,xj(a))}function sc(a){x[a>>2]=0;return a}function qe(a,b){return!Qb(a,b,4)}function pL(a,b){x[a+480272>>2]=b}function pA(a,b){return _l(a,b,4)}function ng(a,b){return Jc(a)+b|0}function mH(a,b){return lH(a,0,b)}function ika(a){a=a|0;_f(a,16796)}function ija(a){a=a|0;XU(a,65535)}function iA(a){if(a){Ib(a+-64|0)}}function i3(a){a=a|0;return 10344}function hk(a){return a-48>>>0<10}function g$(a){a=a|0;return 13102}function f$(a){a=a|0;return 10224}function ez(a){ec(a+4|0);return a}function dX(a){Aw(a,25,108436,24)}function bc(a,b){return(b<<1)+a|0}function aI(a){return gF(a,92624)}function Xn(a){return a+1074328|0}function Xla(a){a=a|0;_f(a,16165)}function We(a,b){return(b<<3)+a|0}function Wc(a){return pX(a,1,120)}function Ts(a){return gF(a,92560)}function Tf(a){return a!=a?E(0):a}function Td(a){return x[gc(a)>>2]}function Sx(a,b){return rO(a,b)^1}function Qc(a,b){return vc(a)+b|0}function Pm(a){x[a>>2]=2;return a}function P_(a){a=a|0;return 12988}function O_(a){a=a|0;return 10718}function Mb(a,b){return pc(a,b)^1}function Kk(a){w[a>>1]=0;return a}function Kh(a){x[a>>2]=1;return a}function Kd(a,b){return(b<<4)+a|0}function Jq(a,b){return de(a,b)^1}function JQ(a,b){return _l(a,b,8)}function JD(a){return(a&16)>>>4|0}function Gw(a,b){return x[a+b>>2]}function Em(a,b){return(b<<8)+a|0}function De(a,b){return(b<<5)+a|0}function Cq(a){Aw(a,25,108488,27)}function Bb(a,b){return(b<<2)+a|0}function tg(a,b){Wb(sc(a)+4|0,b)}function tN(a){return(a&8)>>>3|0}function pna(a){a=a|0;_f(a,3892)}function nY(a){a=a|0;_f(a,4361)}
function nD(a){sm(a,bp(a),78304)}function jka(a){a=a|0;_f(a,3988)}function ig(a,b,c,d){yf(a,c,d,b)}function fh(a){return!x[a+16>>2]}function c$(a){a=a|0;return 6869}function bJ(a,b){return ah(a,b)}
function _K(a){a=a|0;Ss(a);Ib(a)}function YU(a,b){rc(a,b+4|0,256)}function WZ(a){a=a|0;_f(a,16823)}function Uq(a,b,c){mF(a,b,c,128)}function Ula(a){a=a|0;_f(a,4487)}function Sia(a){a=a|0;_f(a,4168)}function Q_(a){a=a|0;return 9783}function Nla(a){a=a|0;_f(a,4381)}function N_(a){a=a|0;return 5723}function MH(a){x[a+72>>2]=482392}function Kr(a){v[a|0]=0;return a}function KW(a,b,c){rF(a,b,c,256)}function KK(a){a=a|0;om(a);Ib(a)}function KH(a){x[a+72>>2]=482476}function KD(a){return(a&2)>>>1|0}function Hv(a,b){return toa(a,b)}function HK(a){a=a|0;Fp(a);Ib(a)}function Eka(a){a=a|0;bv(a,3883)}function Bv(a,b,c){rF(a,b,c,128)}function Bka(a){a=a|0;bv(a,4890)}function zp(a){return a<<24>>24}function zb(a,b){return(a&b)!=0}function yh(a,b){return!xd(a,b)}function yb(a){Ud(a+12|0);Ud(a)}function yD(a,b){return vD(a,b)}function vk(a,b){return Wb(a,b)}function vf(a,b){return Hg(a,b)}function vH(a){if(wH(a)){Ib(a)}}function ug(a){return Ji(a)?0:a}function uf(a,b){return vk(a,b)}function u0(a){a=a|0;Gc(483780)}function tl(a){xb(a+12|0);jd(a)}function s6(a){a=a|0;Qs(a-88|0)}function s0(a){a=a|0;Gc(483812)}function ro(a,b){return Lk(a,b)}function rC(a,b,c){yf(a,c,30,b)}function q0(a){a=a|0;Gc(483716)}function pW(a,b,c){yf(a,c,24,b)}function pP(a){return a<<16>>16}function oh(a){return YP(a&255)}function oH(a,b){return wd(a,b)}function o0(a){a=a|0;Gc(483748)}function nC(a,b){return Do(b,a)}function lt(a,b){return uk(a,b)}function jX(a,b){Lr(a,b,40,-40)}function hc(a,b){return nE(a,b)}function g0(a){a=a|0;wb(483764)}function fW(a,b){return qo(a,b)}function e0(a){a=a|0;wb(483796)}function di(a,b,c){yf(a,c,13,b)}function cs(a){a=a|0;return 127}function c0(a){a=a|0;wb(483700)}function a6(a){a=a|0;Qs(a-92|0)}function a0(a){a=a|0;wb(483732)}function _i(a,b){return a>>>b&1}function Zaa(a){a=a|0;Ib(SM(a))}function YS(a,b){Lr(a,b,12,-12)}function Xh(a,b){return cd(a,b)}function Xe(a){return Lq(Be(a))}function Xb(a,b){return hg(a,b)}function XZ(a){a=a|0;_f(a,4535)}function XW(a,b){return to(b,a)}function Wy(a){w[a+480214>>1]=0}function Wj(a,b){return b-a>>11}function Waa(a){a=a|0;return 13}function Vn(a,b){return as(a,b)}function U5(a){a=a|0;Qs(a-96|0)}function TE(a,b){Lr(a,b,24,-24)}function Se(a,b,c){yf(a,c,32,b)}function SP(a){QP(a+12|0);PP(a)}function Rg(a,b){return Mb(a,b)}function Qd(a){return(a&255)!=0}function QC(a){return(a&255)==1}function Pi(a,b,c){yf(a,c,28,b)}function Pc(a,b,c){dc(a,b,1<<c)}function Oz(a,b){return Oc(a,b)}function Nw(a){return Db(a+8|0)}function Mh(a,b){return Cv(a,b)}function Mba(a){a=a|0;Ib(dN(a))}function ME(a,b){return $c(a,b)}function Ll(a,b,c){yf(a,c,22,b)}function Lf(a){xb(a+20|0);xb(a)}function Lca(a){a=a|0;Ib(CN(a))}function KA(a,b,c){yf(a,c,64,b)}function Ik(a,b){return xd(a,b)}function Hj(a,b,c){yf(a,c,20,b)}function Hf(a){a=a|0;return a|0}function Hc(a,b){return nr(a,b)}function Gi(a,b){return(a|b)!=0}function Fv(a,b){return wD(a,b)}function Ft(a){UQ(a+12|0);YQ(a)}function Dp(a,b){return Bb(a,b)}function Dj(a,b){return De(a,b)}function Cj(a){$A(a,0);return a}function Bw(a,b){return mh(a,b)}function Bk(a,b,c){yf(a,c,12,b)}function Am(a){wb(a+12|0);wb(a)}function Al(a){return Mm(Be(a))}function AO(a,b){return yO(a,b)}function $d(a,b){return tc(a,b)}function zZ(a){a=a|0;Ib(mE(a))}function xg(a,b){return b-a>>5}function xG(a){a=a|0;Ib(Mw(a))}function wN(a,b){ny(a,vc(a),b)}function vu(a,b){return a-b>>2}function vV(a,b){yn(a,b,ud(b))}function v$(a){a=a|0;Ib(hG(a))}function uy(a){a=a|0;Ib(ht(a))}function u5(a){a=a|0;Ib(Ls(a))}function u4(a){a=a|0;Ib(fJ(a))}function tk(a,b){return b-a>>4}function tc(a,b){return b-a>>2}function qI(){return(eb()|0)>0}function qH(a,b){bF(a,b,13430)}function qE(a){return a+1024|0}function px(a){a=a|0;Ib(cl(a))}function pn(a){a=a|0;Ib(lW(a))}function pJ(a){a=a|0;Ib(qJ(a))}function p3(a){a=a|0;Ib(Vs(a))}function ox(a){a=a|0;Ib(Pn(a))}function oe(a,b){v[a|0]=y[b|0]}function oA(a){return a+4896|0}function nx(a){a=a|0;Ib(vs(a))}function nN(a){a=a|0;Ib(oN(a))}function n$(a){a=a|0;Ib(gG(a))}function kx(a){a=a|0;Ib(us(a))}function kL(a){a=a|0;Ib(Fp(a))}function jx(a){a=a|0;Ib(ts(a))}function gu(a){return a>>>27^a}function gn(a){a=a|0;Ib(_v(a))}function fc(a,b){x[a+100>>2]=b}function ah(a,b){return b-a>>3}function ZH(a,b){bF(a,b,21631)}function Y$(a){a=a|0;Ib(wG(a))}function U$(a){a=a|0;Ib(vG(a))}function SH(a){a=a|0;Ib(Jp(a))}function RH(a){a=a|0;Ib(Cf(a))}function Qs(a){a=a|0;Ib(Ep(a))}function Oc(a,b){return b-a>>1}function O$(a){a=a|0;Ib(oG(a))}function Md(a){return a&64?2:1}function MS(a){return a+4096|0}function Kba(a){a=a|0;return 6}function KT(a,b){xw(a,b,5,3,4)}function Jca(a){a=a|0;return 9}function I4(a){a=a|0;Ib(Gs(a))}function Hn(a){return(a|0)==-1}function Gh(a,b){return b-a>>8}function Ge(a,b){if(!a){Ib(b)}}function Do(a,b){return a-b>>1}function Dl(a){return a>>>0<11}function CD(a){return mc(a<<2)}function Bz(a,b){return a<<8|b}function $s(a){a=a|0;Ib(Rf(a))}function zM(){return 19988503}function to(a,b){return a-b|0}function tf(a){return F(a)==O}function sC(a){return!x[a>>2]}function rj(a){return a+4e4|0}function rN(a){a=a|0;return 3}function qk(a){return Ed(a)^1}function qV(a){Bo(Rb(a,0,40))}function qO(a,b,c){rl(a,b,-c)}function mN(a){a=a|0;return 7}function mI(a){a=a|0;return-1}function mB(a,b){cc(a,b,4896)}function lr(a,b){yf(a,b,26,3)}function js(a){return a>>>0<2}function jh(a){return(a&5)!=0}function jc(a){a=a|0;return 0}function iJ(a){return jh(a)^1}function go(a,b){x[a+36>>2]=b}function ed(a,b){Gp(a,b+28|0)}function cd(a,b){return b-a|0}function bY(a,b){cc(a,b,1954)}function an(a){return a&1?2:1}function _e(a,b){w[a+28>>1]=b}function _M(a){a=a|0;return 5}function ZT(a,b){cc(a,b,1108)}function Sn(a){a=a|0;return 4}function QA(a,b){cc(a,b,1024)}function Os(a,b){x[a+32>>2]=b}function Oo(a){return a>>>0<5}function OA(a){return a+128|0}function MT(a,b){yf(a,b,33,1)}function LW(a,b){yf(a,b,40,2)}function Kq(a){return a+256|0}function Kb(a){BE(a);return a}function Je(a){a=a|0;return 1}function Jb(a,b){return a+b|0}function He(a){a=a|0;return 2}function Ed(a){return(a|0)!=0}function Bj(a){return!(a&255)}function BQ(a,b){Lr(a,b,7,-7)}function zc(a){return a+12|0}function zT(a,b){cc(a,b,608)}function xW(a,b){cc(a,b,206)}function wh(a,b,c){Xv(a,b,c)}function w3(a){a=a|0;xX(a,1)}function vq(a,b){return a<<b}function vo(a){return a+14|0}function vd(a,b){x[a+4>>2]=b}function ud(a){return a+16|0}function uC(a,b){cc(a,b,512)}function st(a){YO(a,x[a>>2])}function sV(a,b){cc(a,b,128)}function rW(a,b){cc(a,b,236)}function rD(a,b){cc(a,b,497)}function qs(a,b){Gp(a,b+4|0)}function qU(a,b){cc(a,b,130)}function pm(a,b){x[a+8>>2]=b}function oU(a,b){cc(a,b,600)}function nW(a){return a+10|0}function kd(a,b){return a>>b}function jo(a){return a+32|0}function iW(a,b){cc(a,b,102)}function iU(a,b){cc(a,b,126)}function hi(a,b,c){XD(a,b,c)}function hJ(a,b,c){Rb(a,c,b)}function ev(a,b){cc(a,b,192)}function ee(a,b){v[a+11|0]=b}function dS(a,b){cc(a,b,263)}function cw(a,b){yE(a,ce(b))}function cc(a,b,c){dc(a,b,c)}function bp(a){return a+20|0}function bT(a,b){cc(a,b,204)}function _j(a){return a-36|0}function ZR(a){return a+48|0}function XV(a,b){cc(a,b,576)}function Up(a,b){B[a+8>>2]=b}function UV(a,b){cc(a,b,674)}function Tp(a,b){B[a+4>>2]=b}function TQ(a){RQ(a,x[a>>2])}function Sp(a,b){v[a+33|0]=b}function SQ(a,b,c){ef(a,c,b)}function QB(a,b){yf(a,b,8,2)}function Pz(a){v[a+6152|0]=0}function Py(a,b){v[a+34|0]=b}function PV(a){return a+36|0}function Oy(a,b){v[a+32|0]=b}function Ny(a,b){v[a+35|0]=b}function Ne(a,b){a=a|0;b=b|0}function LA(a,b){$A(a,ce(b))}function Jx(a){return a-12|0}function Im(a,b,c){So(a,b,c)}function Ic(a){vd(a,x[a>>2])}function IS(a,b){rc(a,b,128)}function IQ(a,b,c){Qz(a,b,c)}function HB(a){return a-28|0}function GO(a){return a-32|0}function FX(a,b){cc(a,b,610)}function FW(a,b){cc(a,b,218)}function FQ(a,b,c){ff(a,c,b)}function Eo(a,b){te(a,b+8|0)}function ER(a){CR(a,x[a>>2])}function EP(a,b,c){eW(a,b,c)}function DT(a,b){cc(a,b,146)}function CW(a,b){cc(a,b,157)}function zu(a,b){return a<b}function yk(){Cq(10943);p()}function yU(a,b){cc(a,b,30)}function yM(){return 458752}function vv(a,b){cc(a,b,65)}function uv(a,b){cc(a,b,16)}function tV(a,b){cc(a,b,80)}function pr(a,b){cc(a,b,36)}function of(){dX(10943);p()}function oW(a){return a+6|0}function mX(a,b){rc(a,b,40)}function jg(a,b){v[a+3|0]=b}function jS(a,b){return a<b}function jD(a,b){cc(a,b,38)}function jB(a,b){cc(a,b,33)}function it(a){Rb(a,0,2048)}function iR(a,b){cc(a,b,27)}function gc(a){return a+4|0}function gD(a,b){mi(a,b,37)}function fz(a){Rb(a,0,4096)}function eD(a,b){cc(a,b,41)}function cU(a,b){cc(a,b,32)}function cB(a,b){cc(a,b,40)}function aY(a){Rb(a,0,1954)}function aV(a,b){cc(a,b,52)}function _u(a,b){cc(a,b,64)}function Zu(a,b){cc(a,b,66)}function Zp(a){Rb(a,0,8192)}function Ze(a){return a+2|0}function Xm(a,b){dc(a,b,32)}function Wm(a){return a&127}function Tu(a,b){cc(a,b,22)}function Tq(a){x[a+12>>2]=0}function Si(a){return a+3|0}function Qo(a,b){v[a+1|0]=b}function Qe(a){return!Eb(a)}function PT(a,b){cc(a,b,96)}function Oq(a,b){cc(a,b,12)}function OC(a,b){cc(a,b,11)}function NW(a,b){cc(a,b,98)}function NM(a){return 0-a|0}function Lc(a){return a+1|0}function Ke(a){return a&255}function JC(a,b){dc(a,b,20)}function Iv(a,b){dc(a,b,22)}function IW(a,b){cc(a,b,48)}function GC(a,b){cc(a,b,17)}function Fj(a){return a-4|0}function Db(a){return a+8|0}function CE(a,b){cc(a,b,24)}function yc(a){x[a+8>>2]=0}function yT(a){Rb(a,0,608)}function yS(a){Rb(a,0,256)}function wl(a,b){So(a,b,0)}function wW(a){Rb(a,0,206)}function uu(a){dB(a,Td(a))}function uO(a){Ly(a,Td(a))}function td(a,b){x[a>>2]=b}function qW(a){Rb(a,0,236)}function qD(a){Rb(a,0,497)}function pl(a){Kz(a,Td(a))}function nU(a){Rb(a,0,600)}function lk(a,b){B[a>>2]=b}function kN(a,b){RN(a,3,b)}function hU(a){Rb(a,0,126)}function gr(a,b){cc(a,b,1)}function gW(a){JB(a,Td(a))}function dn(a,b){cc(a,b,8)}function aT(a){Rb(a,0,204)}function _c(){dX(7666);p()}function _b(a){ln(x[a>>2])}function Zm(a,b){cc(a,b,2)}function XB(a,b){cc(a,b,6)}function WV(a){Rb(a,0,576)}function UQ(a){gq(a,Td(a))}function TC(a,b){hi(a,2,b)}function Sv(a,b){cc(a,b,3)}function S7(a){a=a|0;wM(a)}function RV(a){Rb(a,0,192)}function QP(a){zt(a,Td(a))}function Ph(a,b){cc(a,b,4)}function PP(a){At(a,Td(a))}function PA(a){Rb(a,0,130)}function Nu(a){IB(a,Td(a))}function Lo(a,b){cc(a,b,7)}function Ko(a,b){cc(a,b,5)}function KV(a){qB(a,Td(a))}function Ji(a){return a!=a}function HV(a){sB(a,Td(a))}function Fr(a){a=a|0;Gr(a)}function EX(a){Rb(a,0,610)}function ES(a){uA(a,Td(a))}function Daa(a){a=a|0;jb=a}function DS(a){vA(a,Td(a))}function CY(a){a=a|0;Oh(a)}function CT(a){Rb(a,0,146)}function Bc(a){a=a|0;Ib(a)}function BW(a){Rb(a,0,157)}function Av(){Cq(7666);p()}function qr(a){Rb(a,0,36)}function oL(){return 2048}function nm(a){wb(a+16|0)}function ne(a,b){v[a|0]=b}function nB(a){Rb(a,0,80)}function lC(a){Rb(a,0,66)}function k8(){return ib|0}function iD(a){Rb(a,0,38)}function fV(a){Rb(a,0,33)}function dD(a){Rb(a,0,41)}function d7(a){a=a|0;ib=a}function aW(a){Rb(a,0,56)}function Wo(a){return a&1}function Vu(a){Rb(a,0,64)}function Qj(a){xb(a+16|0)}function QT(a){Rb(a,0,96)}function MW(a){Rb(a,0,98)}function JW(a){Rb(a,0,48)}function IN(a){Xl(a,2048)}function $U(a){Rb(a,0,52)}function yd(a){yb(a+8|0)}function xR(a,b){dg(a,b)}function wy(a,b){ge(a,b)}function si(a,b){Sh(a,b)}function rB(a){xb(a+4|0)}function pq(a,b){Wb(a,b)}function mC(a,b){Ek(a,b)}function lv(a,b){LC(a,b)}function lU(a){yw(a,512)}function iB(a,b){dV(a,b)}function fp(a,b){ME(a,b)}function dY(a,b){ZK(a,b)}function aO(a,b){YO(a,b)}function WB(a,b){hc(a,b)}function Uk(a,b){pp(a,b)}function UT(a,b){te(a,b)}function SS(a,b){xl(a,b)}function Rc(a){ec(a+8|0)}function QQ(a){we(a+8|0)}function Ps(a){wb(a+4|0)}function Pj(a,b){zv(a,b)}function Od(a,b){vd(a,b)}function Kt(a,b){IO(a,b)}function Kg(a){a=a|0;p()}function BR(a,b){CR(a,b)}function $f(a,b){vX(a,b)}function xo(a){tF(a,16)}function iX(a){Xl(a,40)}function dh(a){uw(a,24)}function SE(a){Xl(a,24)}function SC(a){yw(a,16)}function Ro(a){tF(a,11)}function OE(a){uw(a,48)}function Kka(){wa();p()}function Jh(a){v[a|0]=0}function Er(a){uw(a,36)}function zV(a){Xl(a,6)}function yg(a){JV(a,0)}function vr(a){Xl(a,8)}function rV(a){yw(a,4)}function lh(a){ZJ(a,0)}function kh(a){XJ(a,0)}function hz(a){aP(a,0)}function hl(a){YJ(a,0)}function gz(a){$O(a,0)}function dG(){xa();p()}function b$(){dG();p()}function Ui(a){Xl(a,2)}function Uc(a){cf(a,0)}function DO(a){eP(a,0)}function Ar(a){yE(a,0)}function AQ(a){Xl(a,7)}function gK(a){Ie(a)}function fS(a){sc(a)}function ep(a){zc(a)}function Zb(a){wb(a)}function WE(a){Kr(a)}function US(a){Nb(a)}function OS(a){Pe(a)}function Nv(a){Kk(a)}function MA(a){Hk(a)}function LQ(a){ko(a)}function Km(a){uc(a)}function Df(a){a=a|0}function $b(a){xb(a)}
// EMSCRIPTEN_END_FUNCS
e=y;var lb=c([null,xc,vE,Nk,CZ,en,nZ,mZ,cE,$D,YD,uD,PY,hY,loa,dv,Kj,Xna,$,rv,Jl,bI,bh,Co,Hma,lW,Hf,ola,Vka,Pka,Kka,Dka,nka,VA,cka,Yja,bga,cja,tT,U3,S3,xs,tT,zfa,rfa,xQ,It,dq,Pea,Nea,Gea,Dea,_B,bO,Pg,Kc,uda,_ca,$M,VM,jy,wi,jM,F9,u9,m9,Y8,R8,D3,C3,f3,XK,C7,_O,K6,w6,u6,eK,D5,z5,v5,i5,Y4,R4,D4,o4,i4,e4,d4,wi,c4,b4,X3,T3,Q3,M3,E3,A3,u3,UH,k3,e3,b3,W2,N2,M2,kB,J2,mx,wa,Ob,v_,u_,t_,s_,r_,q_,qn,p_,o_,UH,n_,m_,ha,k_,j_,i_,Rs,h_,g_,f_,JE,IE,e_,iw,d_,dp,a_,Fr,cp,Vl,_f,ZZ,dp,$Z,_Z,YZ,c_,XZ,FE,WZ,FE,b_,HE,VZ,UZ,TZ,qn,SZ,bd,Ob,PZ,bw,OZ,bh,NZ,zE,MZ,Ok,zE,yr,LZ,_v,Zv,lZ,KZ,BZ,AZ,kZ,Yi,fZ,eZ,Qv,bE,dZ,iea,jea,wQ,gea,hea,My,nt,Yb,kea,ae,ZD,aZ,$Y,ID,ZY,YY,ID,UY,Ev,TY,Ada,jf,oka,Vea,_Y,ar,Wf,ooa,Uea,Ana,Kda,zda,bD,aD,KY,JY,$C,IY,Eg,HY,GY,Fc,FY,EY,Fg,vh,DY,CY,zY,MC,yY,xY,wY,qv,rR,pD,fK,vY,uY,tY,sY,rY,tv,qY,CC,zd,Zq,nY,mY,iv,hv,lY,kY,jY,BC,iY,AC,sv,gY,xv,ioa,Xq,hoa,Lb,fg,_f,goa,tC,foa,od,Mj,eoa,doa,coa,YX,XX,md,boa,Go,aoa,$na,_na,UX,TX,Yi,bv,Zna,Yna,Ifa,Wna,Zg,Vna,Una,Qna,Ij,Tna,Sna,MX,Rna,Nh,If,Mna,Lna,Kna,zX,Hna,Ij,Gj,Gna,Fna,Sq,Ena,iC,yX,Dna,Cna,Bna,fX,bX,xna,una,wn,sna,Dg,DX,tna,qv,ZW,rna,qna,cC,pna,Zv,ona,aC,UW,vW,lna,Xq,wo,kna,jna,XX,ina,hna,gna,RW,fna,Um,ena,dna,cna,ana,Ij,QW,bna,Nh,If,hC,Xma,Uma,bD,Qma,Pma,Oma,Lma,Xq,Kma,Jma,Ao,RW,Ima,Gma,_f,Fma,Ema,Dma,Cma,Bma,mW,Ama,zma,ZE,yma,xma,wma,zC,kW,vma,uma,tma,Mfa,sma,jW,rma,jW,Rma,qma,Ij,Nh,If,Lh,lma,kma,jma,gma,fma,ema,dma,cma,Ao,bma,ama,$la,AB,VY,_la,Zla,Yla,Xla,Wla,SY,Vla,Ula,Tla,Sla,aC,QV,Rla,Qla,_f,Pla,Ola,kC,mma,Nla,Mla,nma,Lla,Kla,Jla,xB,xB,vB,Ila,Hla,OV,xB,Gla,w_,Fla,Ela,Dla,Cla,Bla,Ala,zla,LV,sd,so,nla,oB,yla,kda,jda,ida,hda,gda,fda,xla,wla,dg,vla,ula,tla,sla,vE,Hfa,Ffa,wda,Ida,Jda,rla,qla,pla,rea,dda,IV,Dfa,Cfa,Bfa,Afa,jla,ila,hla,gla,fla,ela,dla,cla,bla,ala,$ka,Zka,Yka,_ka,eV,If,ZU,hB,Uka,gB,Tka,Ska,Rka,Qka,fB,Oka,Ev,$C,Nka,XU,WU,kr,eB,Mka,wf,Lka,UU,Ao,ov,Ao,kW,fr,_f,zX,Ao,wn,Hka,Gka,Fka,Eka,aB,su,Cka,Bka,Aka,zka,yka,xka,cD,wka,vka,uka,tka,ska,rka,qka,pka,tB,mka,lka,kka,_f,NV,MV,EB,jka,ika,iv,Zv,hka,gka,mfa,lfa,kfa,Vq,fka,Io,$u,Zh,Tea,qfa,Lt,GQ,Sea,Rea,pQ,Gt,kQ,Qea,aQ,pR,Oea,Zz,vj,ii,Wja,Vja,qu,dka,Cu,Sja,Io,Rja,Qja,fU,so,Pja,Oja,eU,Nja,Mja,Lja,pu,Kja,Jja,Ija,Hja,Cja,HA,Bja,Aja,zja,Ij,Nh,If,ii,wja,vja,uja,tja,gB,qja,pja,pu,oja,Lda,lja,kja,Gj,WT,HA,sv,jja,ija,hja,gja,mu,fja,mu,eja,Br,WY,aja,Ij,bja,dja,DA,HT,Nh,If,qu,Zia,Wia,hB,Via,Sia,Ria,vT,eU,AB,Qia,iv,_f,Hia,Gia,BC,Fia,Eia,Dia,Cia,LB,Go,zia,yia,xia,wia,via,uia,Fm,PS,tia,sia,ria,qia,pia,oia,nia,mia,lia,kia,jia,iia,hia,gB,gia,fia,eia,Cu,dia,cia,Xq,cfa,bw,YX,jfa,ifa,Xq,hfa,ii,bw,gfa,ffa,efa,$ha,_ha,Zha,Yha,Xha,Wha,jr,Tha,Sha,Rha,Qha,Pha,Oha,Nha,Mha,Lha,Kha,Jha,l_,PE,Iha,_f,Hha,Gha,Ml,nfa,Nfa,_B,FR,Kfa,Jfa,Gfa,Efa,yfa,qR,wfa,vfa,hR,ufa,tfa,sfa,eo,WQ,pfa,ofa,yo,afa,Gj,yQ,Cr,fea,eea,dea,sea,XY,cea,Rv,Cr,CC,bea,yQ,_ea,aea,dfa,Ij,Nh,If,bfa,Ij,Nh,If,$ea,Ij,Nh,If,Yea,MX,Vq,Mea,Lea,Kea,Jea,Iea,Hea,Lfa,Eha,_R,Fea,mc,Cea,Dda,Bea,RZ,jZ,cZ,hZ,zea,yea,bZ,iZ,QZ,gZ,RO,xea,wea,vea,QO,bz,uea,tea,xfa,qea,pea,oea,nea,YN,tda,hw,NE,AE,My,lea,IV,av,dr,Xea,Zea,Zda,Yda,Gj,Xda,HA,Wda,Vda,Uda,qu,Tda,ii,Sda,Rda,Qda,Pda,Oda,Ij,Nh,If,_da,Hda,Gda,Fda,Eda,Sh,em,Cda,Bda,yda,rda,qda,pda,oda,nda,VN,vda,Qp,UN,Qk,Sh,dg,lda,eda,mda,sda,bda,ada,tca,$ca,kk,JN,cg,SN,Mca,uca,am,oca,nca,lca,kca,jca,My,mca,le,Gu,Gu,me,ica,hca,fca,_y,pN,Nba,Dba,wba,pba,hba,_aa,aba,Qaa,Jaa,BM,_s,Caa,Baa,V4,W4,xM,uaa,wM,vM,mea,Z4,qaa,BM,oaa,G5,w5,J5,rM,eJ,qM,fy,laa,f8,Fp,e8,UJ,oM,Iba,mM,paa,nM,_9,lM,ZE,S5,gaa,E5,ey,UU,dy,cy,by,X9,V9,qM,fy,S9,R9,Q9,P9,O9,N9,M9,L9,K9,J9,I9,H9,G9,E9,D9,C9,B9,A9,z9,y9,x9,w9,v9,t9,s9,iM,hM,gM,oE,k4,K5,fM,UL,B5,TL,SL,jl,m4,n4,RL,q4,OL,NL,xda,LL,fy,JL,GL,FL,Nn,l4,EL,DL,CL,BL,AL,zL,yL,xL,wL,vL,uL,tL,ay,sL,rL,NO,ru,$x,_x,j8,nL,i8,h8,g8,hL,b8,rM,a8,x7,$7,w7,_7,v7,Z7,u7,Y7,t7,X7,s7,V7,B4,eJ,Lp,Wea,Dr,TO,O5,M5,lP,I5,Eea,F5,k$,Xr,C5,A5,x5,Aea,H5,P5,L5,aw,aa,X4,aK,$J,_x,sJ,U4,T4,J4,jJ,A4,z4,v4,p4,j4,h4,HO,Fha,g4,f4,a4,$3,W3,V3,PH,OH,m$,L3,K3,J3,I3,H3,G3,F3,x3,bh,w3,Hf,d$,l$,g3,OH,c3,Tm,$H,fx,bx,L2,K2,Zw,Uh,Th,is,Ib,Yw,yp,jj,bl,Xw,im,B2,A2,hj,ih,cH,gj,ix,Tw,Uh,Th,gs,ss,gk,v3,Jl,Gn,hj,ih,_G,gj,g2,b2,VH,Y1,os,Co,T1,ds,Df,B1,ms,A1,z1,y1,MG,w1,u1,t1,$k,s1,MG,q1,p1,n1,m1,j1,i1,e1,d1,c1,b1,a1,$0,_0,Z0,Y0,X0,W0,V0,U0,T0,S0,R0,Q0,P0,O0,N0,M0,L0,K0,J0,I0,H0,G0,F0,E0,D0,C0,B0,A0,z0,l0,m0,n0,u0,s0,q0,o0,Z$,_$,$$,g0,e0,c0,a0,_B,Dha,dG,gn,Yq,Cha,Bha,Aha,zha,yha,xha,wha,vha,uha,tha,sha,rha,qha,pha,oha,nha,mha,lha,kha,jha,iha,hha,gha,fha,eha,dha,cha,bha,aha,$ga,_ga,Zga,Yga,Xga,Wga,Vga,Uga,Tga,Sga,Rga,Qga,Pga,Oga,Nga,Mga,Lga,Kga,Jga,Iga,Hga,Gga,Fga,Ega,Dga,Cga,Bga,Aga,zga,yga,xga,wga,vga,uga,tga,sga,rga,qga,pga,oga,nga,mga,lga,kga,jga,iga,hga,gga,fga,ega,dga,cga,aga,$fa,_fa,Zfa,Yfa,Xfa,Wfa,Vfa,Ufa,Tfa,Sfa,Rfa,Qfa,Pfa,Ofa,gn,Vha,Uha,ima,hma,Uia,Tia,Nia,Mia,Xka,Wka,Gja,Fja,lla,kla,koa,joa,$ma,_ma,BY,AY,pY,oY,yja,xja,Yia,Xia,bia,aia,Jna,Ina,zna,yna,OY,NY,MY,LY,nja,mja,$ia,_ia,Uja,Tja,mla,eY,Wma,Vma,pma,oma,Ona,Nna,nna,mna,sja,rja,$da,Nda,Mda,Nma,Mma,Tma,Sma,Zja,Xja,Bia,Aia,Eja,Dja,Zma,Yma,Pia,Oia,Jia,Iia,wna,vna,Lia,Kia,eka,$ja,_ja,RY,QY,noa,moa,Jka,Ika,bka,aka,pn,Yq,oZ,Bc,Sl,AM,Bc,Hf,Bc,jc,Je,Je,jc,jc,pZ,FZ,EZ,qZ,Bc,Sl,Bc,mE,zZ,yZ,xZ,wZ,vZ,uZ,tZ,sZ,rZ,ht,uy,gt,HN,jc,Df,jc,jc,jc,Ne,Sn,Zca,Yca,Xca,Wca,Vca,yi,sy,sy,ry,FN,ry,EN,ry,EN,Df,eY,Uca,Tca,Sca,Rca,Qca,xi,DN,qca,jc,jc,Je,qy,He,He,Je,Pca,Oca,Ne,Df,Ne,Df,CN,Lca,Kca,jc,Df,jc,jc,jc,Ne,Jca,BN,Ica,Hca,Gca,Fca,yi,Eca,Dca,Cca,Bca,Aca,zca,yca,xca,wca,vca,xi,xN,jc,jc,Je,He,He,Je,zN,yN,Rf,Kg,b$,sca,ty,rca,jc,pca,FN,Yba,Oba,Eba,xba,qba,iba,$aa,Raa,Kaa,jba,cda,Nca,gca,ht,uy,HN,jc,Df,jc,jc,jc,Ne,rN,eca,dca,cca,bca,aca,yi,$ba,xi,qN,jc,jc,Je,He,He,Je,_ba,Zba,dN,Mba,Lba,jc,Df,jc,jc,jc,Ne,Kba,Jba,Hba,Gba,yi,Fba,xi,aN,jc,jc,Je,He,He,$s,Cba,jc,Df,jc,jc,jc,Ne,_M,Bba,Aba,zba,yi,yba,xi,YM,jc,jc,Je,He,He,ht,uy,vba,jc,Df,jc,jc,jc,Ne,_M,uba,tba,sba,yi,rba,xi,WM,jc,jc,Je,He,He,oN,nN,oba,jc,Df,jc,jc,jc,Ne,mN,nba,Vba,Uba,yi,Tba,xi,Sba,jc,jc,Je,He,He,Ne,Df,jN,mba,lba,iN,kba,gN,fN,nN,Xba,mN,Wba,jN,Rba,Qba,iN,Pba,gN,fN,$s,gba,jc,Df,jc,jc,jc,Ne,He,fba,eba,dba,yi,cba,xi,bba,jc,jc,Je,He,He,SM,Zaa,Yaa,jc,Df,jc,jc,Xaa,Ne,Waa,Vaa,Uaa,Taa,yi,Saa,xi,iy,jc,jc,Je,He,He,Ne,Df,$s,Paa,jc,Df,jc,jc,jc,Ne,rN,Oaa,Naa,Maa,yi,Laa,xi,MM,jc,jc,Je,He,He,$s,Iaa,jc,Df,jc,jc,jc,Ne,Sn,Haa,Gaa,Faa,yi,Eaa,xi,KM,jc,jc,Je,He,He,Us,Bc,d8,kL,FK,kL,HK,om,KK,Ss,_K,Ep,Qs,x6,v6,EK,DK,CK,BK,AK,zK,yK,xK,wK,vK,uK,tK,sK,rK,qK,pK,oK,nK,mK,lK,kK,jK,iK,t6,s6,r6,q6,p6,o6,n6,m6,l6,k6,j6,i6,h6,g6,f6,e6,d6,c6,b6,a6,$5,_5,Z5,Y5,X5,W5,V5,U5,T5,Hf,Kg,Hf,Kg,Hf,Kg,Hf,Kg,Kg,R5,Bc,Q5,Ls,u5,N5,Hf,Kg,Hf,Bc,t5,s5,Kg,MJ,LJ,MJ,LJ,Ne,Ms,Ne,Ms,PJ,OJ,PJ,OJ,Bc,y5,Hf,Bc,r5,q5,Bc,EJ,DJ,Kg,n5,BJ,m5,BJ,p5,CJ,o5,CJ,Bc,l5,k5,Bc,AJ,zJ,Is,Is,Is,Is,j5,Nx,Nx,Nx,Bc,h5,g5,Bc,yJ,xJ,d5,vJ,b5,vJ,f5,wJ,e5,wJ,Bc,a5,$4,Bc,uJ,tJ,Hs,Hs,Hs,Hs,_4,Mx,Mx,Mx,C4,Bc,Sl,Bc,Gs,I4,Je,Je,H4,G4,Yq,F4,E4,Kg,Kg,K4,Bc,Sl,Bc,qJ,pJ,Je,jc,Je,S4,Q4,P4,O4,N4,M4,L4,Kg,r4,Bc,Sl,Bc,fJ,u4,t4,s4,Kg,w4,Bc,Sl,Bc,pJ,y4,x4,DZ,Bc,Sl,Bc,Bc,JZ,Je,Je,Yq,sE,IZ,HZ,GZ,Ne,Ms,Ne,Ms,_3,Z3,Y3,Pn,ox,Ne,pI,oI,nI,jc,jc,P3,mI,O3,ws,N3,ws,ts,jx,Ne,pI,oI,nI,jc,jc,B3,mI,z3,ws,y3,ws,Vs,p3,q3,o3,t3,s3,r3,Jp,SH,n3,m3,us,kx,dI,cI,Cf,RH,l3,j3,vs,nx,kI,iI,Hf,Bc,i3,j$,i$,h$,h3,gn,R3,jc,d3,ox,R2,Q2,P2,O2,HL,px,cl,px,ox,U2,IH,T2,S2,jx,Z2,Y2,X2,V2,vs,nx,kI,iI,HL,px,jx,a3,IH,$2,_2,us,kx,dI,cI,gG,n$,gt,hG,v$,u$,t$,s$,r$,iG,q$,p$,o$,oG,O$,N$,M$,L$,K$,jc,J$,I$,vG,U$,T$,S$,R$,Q$,P$,wG,Y$,sE,Pna,X$,W$,V$,Hf,Bc,Bc,G$,F$,E$,D$,C$,B$,A$,z$,iG,y$,x$,w$,Bc,kG,kG,rp,Je,Je,H$,Je,Bc,rG,qG,rp,jc,jc,pG,Sn,Bc,rG,qG,rp,jc,jc,pG,Sn,Bc,uG,tG,rp,jc,jc,sG,Sn,Bc,uG,tG,rp,jc,jc,sG,Sn,Hf,Bc,I2,H2,G2,Hf,Bc,F2,E2,D2,Bc,C2,z2,y2,x2,gH,gH,w2,v2,u2,t2,s2,Bc,r2,q2,p2,o2,ZG,ZG,n2,m2,l2,k2,j2,Bc,i2,h2,f2,e2,d2,c2,a2,$1,Bc,_1,Z1,X1,W1,V1,U1,S1,R1,Hf,Bc,He,Q1,P1,O1,N1,M1,L1,k0,j0,i0,h0,f0,d0,b0,Hf,Bc,He,K1,J1,I1,H1,G1,F1,y0,x0,w0,v0,t0,r0,p0,Mw,xG,E1,Mw,xG,D1,Bc,cs,cs,Rh,Rh,Rh,OG,jc,Yk,Yk,Bc,cs,cs,Rh,Rh,Rh,OG,jc,Yk,Yk,Bc,bs,bs,Rh,Rh,Rh,NG,jc,Yk,Yk,Bc,bs,bs,Rh,Rh,Rh,NG,jc,Yk,Yk,Bc,C1,x1,Bc,v1,r1,Bc,o1,l1,Bc,k1,h1,Bc,DG,g1,Ne,Bc,DG,f1,Ne,Hf,Kg,Bc,g$,eG,Bc,f$,e$,eG,gn,Kg,Bc,c$,xa,Hf,Bc,Df,Df,a$,U_,W_,X_,Bc,P_,Bc,O_,pn,gn,pn,pn,pn,pn,gn,Bc,N_,Bc,T_,V_,Y_,Bc,$_,__,Z_,Bc,Q_]);function mb(){return u.byteLength/65536|0}function rb(sb){sb=sb|0;var nb=mb()|0;var ob=nb+sb|0;if(nb<ob&&ob<65536){var pb=new ArrayBuffer(D(ob,65536));var qb=new Int8Array(pb);qb.set(v);v=new Int8Array(pb);w=new Int16Array(pb);x=new Int32Array(pb);y=new Uint8Array(pb);z=new Uint16Array(pb);A=new Uint32Array(pb);B=new Float32Array(pb);C=new Float64Array(pb);u=pb;t.buffer=u;e=y}return nb}return{"wa":fY,"xa":yM,"ya":yM,"za":zM,"Aa":zM,"Ba":Bc,"Ca":Ib,"Da":vaa,"Ea":xM,"Fa":taa,"Ga":saa,"Ha":_s,"Ia":Ne,"Ja":xaa,"Ka":waa,"La":Aaa,"Ma":sy,"Na":yaa,"Oa":AM,"Pa":zaa,"Qa":Hf,"Ra":DM,"Sa":CM,"Ta":DM,"Ua":oL,"Va":M_,"Wa":L_,"Xa":K_,"Ya":raa,"Za":tM,"_a":naa,"$a":sM,"ab":caa,"bb":p8,"cb":q8,"db":aaa,"eb":$9,"fb":Z9,"gb":baa,"hb":r8,"ib":F8,"jb":l8,"kb":H8,"lb":_8,"mb":n8,"nb":J8,"ob":o8,"pb":I8,"qb":m8,"rb":u8,"sb":s8,"tb":t8,"ub":B8,"vb":z8,"wb":A8,"xb":v8,"yb":w8,"zb":x8,"Ab":y8,"Bb":W8,"Cb":X8,"Db":g9,"Eb":b9,"Fb":a9,"Gb":$8,"Hb":f9,"Ib":e9,"Jb":c9,"Kb":d9,"Lb":k9,"Mb":l9,"Nb":h9,"Ob":j9,"Pb":i9,"Qb":P8,"Rb":V8,"Sb":T8,"Tb":S8,"Ub":U8,"Vb":Q8,"Wb":E8,"Xb":o9,"Yb":O8,"Zb":M8,"_b":Z8,"$b":G8,"ac":N8,"bc":L8,"cc":K8,"dc":p9,"ec":C8,"fc":q9,"gc":D8,"hc":n9,"ic":maa,"jc":kaa,"kc":J_,"lc":jaa,"mc":iaa,"nc":haa,"oc":faa,"pc":I_,"qc":eaa,"rc":daa,"sc":Y9,"tc":W9,"uc":U9,"vc":r9,"wc":T9,"xc":Fp,"yc":lc,"zc":FK,"Ac":Gd,"Bc":IK,"Cc":JK,"Dc":q7,"Ec":r7,"Fc":HK,"Gc":S7,"Hc":U7,"Ic":T7,"Jc":YK,"Kc":YK,"Lc":oL,"Mc":YF,"Nc":YF,"Oc":XF,"Pc":XF,"Qc":H_,"Rc":MK,"Sc":PK,"Tc":WK,"Uc":VK,"Vc":NK,"Wc":SK,"Xc":RK,"Yc":OK,"Zc":UK,"_c":TK,"$c":QK,"ad":om,"bd":KK,"cd":Q7,"dd":O6,"ed":N7,"fd":e7,"gd":S6,"hd":M7,"id":P6,"jd":I7,"kd":f7,"ld":O7,"md":B7,"nd":A7,"od":z7,"pd":F7,"qd":E7,"rd":D7,"sd":G7,"td":J7,"ud":H7,"vd":K7,"wd":Z6,"xd":o7,"yd":M6,"zd":$6,"Ad":_6,"Bd":V6,"Cd":a7,"Dd":U6,"Ed":l7,"Fd":G6,"Gd":I6,"Hd":J6,"Id":H6,"Jd":D6,"Kd":C6,"Ld":g7,"Md":i7,"Nd":n7,"Od":h7,"Pd":T6,"Qd":k7,"Rd":W6,"Sd":b7,"Td":j7,"Ud":X6,"Vd":R6,"Wd":c7,"Xd":Y6,"Yd":Q6,"Zd":E6,"_d":B6,"$d":A6,"ae":L6,"be":F6,"ce":y6,"de":z6,"ee":m7,"fe":G_,"ge":N6,"he":p7,"ie":y7,"je":P7,"ke":F_,"le":L7,"me":R7,"ne":$K,"oe":bL,"pe":cL,"qe":dL,"re":fL,"se":gL,"te":jL,"ue":eL,"ve":Ss,"we":_K,"xe":aL,"ye":W7,"ze":c8,"Ae":lc,"Be":IK,"Ce":JK,"De":Fp,"Ee":MK,"Fe":PK,"Ge":WK,"He":VK,"Ie":NK,"Je":SK,"Ke":RK,"Le":OK,"Me":UK,"Ne":TK,"Oe":QK,"Pe":om,"Qe":$K,"Re":bL,"Se":cL,"Te":dL,"Ue":fL,"Ve":gL,"We":jL,"Xe":eL,"Ye":Ss,"Ze":aL,"_e":lb,"$e":c5,"af":Daa,"bf":k8,"cf":d7,"df":S_,"ef":R_,"ff":E_,"gf":D_,"hf":B_,"jf":x_,"kf":C_,"lf":B_,"mf":A_,"nf":y_,"of":z_,"pf":y_,"qf":x_,"rf":x_}}return tb(vb)}
// EMSCRIPTEN_END_ASM




)(info);
  },

  instantiate: /** @suppress{checkTypes} */ function(binary, info) {
    return {
      then: function(ok) {
        var module = new WebAssembly.Module(binary);
        ok({
          'instance': new WebAssembly.Instance(module, info)
        });
        // Emulate a simple WebAssembly.instantiate(..).then(()=>{}).catch(()=>{}) syntax.
        return { catch: function() {} };
      }
    };
  },

  RuntimeError: Error
};

// We don't need to actually download a wasm binary, mark it as present but empty.
wasmBinary = [];


